/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Sep 27, 2016
Last udpate on: Nov 08, 2016

Written by:  	Rebecca de Guttry (rdeguttry@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans the Village baseline survey.


CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

	/*****************************************************************
	PROJECT: 		TUP_AFG, Targeting Ultra Poor in Afghanistan
					
	TITLE:			bl_village_cleaning.do
				
	AUTHOR: 		Rebecca de Guttry (rdeguttry@worldbank.org)

	DATE CREATED:	Sep 27, 2016

	LAST EDITED:	Nov 08, 2016, by Rebecca de Guttry (rdeguttry@worldbank.org)

	DESCRIPTION: 	Cleans Village Survey, Baseline survey.
		
	ORGANIZATION:	
					
	INPUTS: 		* Raw village survey dataset
					${bl_data_raw}/Village/Village_questionnaire_TUP_IE.dta
			
	OUTPUTS: 		* Cleaned village survey dataset
					${bl_data_final}/Village/village_cleaned.dta"
					
	NOTE:			The do file is still a draft
	******************************************************************/
	
********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* Raw data csv and stata
		gl village_raw_csv_bl "${TUP_DB}/Baseline/DataSets/Raw/Village_questionnaire_TUP_IE_WIDE.csv"
		gl village_raw_bl	  "${TUP_DB}/Baseline/DataSets/Raw/Village_questionnaire_TUP_IE.dta"
		
* Outputs	
		gl village_clean_bl	  "${TUP_DB}/Baseline/DataSets/Intermediate/village_clean_bl.dta"


/********************************************************************************
	** Part 1: Importing and cleaning
********************************************************************************


	import delimited "${village_raw_csv_bl}", encoding(ISO-8859-1) clear
	
	if	`c(stata_version)'>=14	{
		saveold "${village_raw_bl}", replace v(13)
	}
	else {
		save "${village_raw_bl}", replace
	}		
*/

	/****************************************************************
		1.1 Drop unnecessary variables
	****************************************************************/	

	use "${village_raw_bl}", clear 
	
	* Script variables
	drop intronote introscript promptend2 generated_note_name_28 resp_consent_vqv3 resp_consent_vqv18
	
	* Extra enumerator and supervisor variables (for confirmation)
	drop vc1_cal vc2_cal vc1_v vc2_v

	* GPS variable (already have single variables for latitude, longitude, etc.)
	drop a1_cal

	* v22_o (programmed by mistake, this is "Explain" if v22=="Other" but that was not an option)	
	drop resp_consent_vqv22_o

	/****************************************************************
		1.2 Drop test observations
	****************************************************************/	
		
	* Drop test observations
		drop if key=="uuid:8bdce2cf-d851-4002-9c0a-f3768811a29c" | key=="uuid:e9b8be8b-133d-45e4-912c-e7025a43865e"
	
	* Drop if villages not in list of final baseline villages
		destring vc4, replace
		#delimit ;			
			keep if inlist(vc4,	1,2,3,4,5,6,8,9,
								10,11,12,13,14,15,16,17,18,19,
								20,22,23,24,25,27,28,29,
								30,32,33,34,35,36,37,38,39,
								40,41,42,43,44,45,46,47,48,49,
								50,51,52,54,55,56,57,58,
								60,61,62,63,64,65,66,67,68,69,
								70,71,72,73,74,75,76,77,78,79,
								80,81,82,83,84,85,86,87,88);
		#delimit cr

	* Investigate
	* br if flag==1
	/* NOTE:	key=="uuid:6232e586-7679-4c34-bd59-3d6dbbeb81a4" appears to be a test observation: 
				text in the various "Other" explanations is in roman characters that do not make sense (e.g. "hgfh") */
				* browse if key=="uuid:6232e586-7679-4c34-bd59-3d6dbbeb81a4"
	drop if key=="uuid:6232e586-7679-4c34-bd59-3d6dbbeb81a4"
	
	* Ensure we only have 1 observation per village
	isid vc4

	* Destring variables that were strings because of test observations
	destring vc3, replace
	
	/****************************************************************
		1.4 Transform date and time variables
	****************************************************************/	

	/** Survey date
		Note:
				date 		"Date as per device"
				date_v 		"Confirm whether device date is right"
				date_a 		"If date is wrong, what is the date?"
				date_f 		"Final date" */
	drop date 
	gen		date	=	date(date_f, "DMY") if date_v==1
	replace	date	=	date(date_f, "YMD") if date_v==0

	format  date %d

	drop date_v date_a date_f

	lab var date "Date of survey"

	/** Survey time
		Note:
				time 		"Time as per device"
				time_v 		"Confirm whether device time is right"
				time_a 		"If time is wrong, what is the time?"
				time_f 		"Final time" */
	drop time
	gen		time	=	clock(time_f, "hms")	if time_v==1
	replace	time =	clock(time_a, "hms")	if time_v==0
	format  time %tcHH:MM:SS

	drop time_v time_a time_f

	lab var time "Survey time"	
	
	order date time, first

	* Drop other SCTO variables and GPS
	drop deviceid a1latitude a1longitude a1accuracy a1altitude a1_v subscriberid simid devicephonenum metainstanceid formdef_version key submissiondate starttime endtime
	
	* Rename to match dataset
	rename resp_consent_vq* *
	
	* Drop "Other, specify" variables that may have PII
	drop *_o
	
	
	/****************************************************************
		1.3 Clone and label raw variables
	****************************************************************/

		lab var		vc1	"Enumerator"
		lab var		vc2	"Supervisor"
		lab var		vc3	"District name"
		lab var		vc4	"Village name"
		lab var		vc5	"Respondent's willingness to answer questions"

	* Respondent occupation
		recode	v1 (-97=3)
		
		loc locc1 "member of local government / CDC committee"
		loc locc2 "malik (religious leader)"
		loc locc3 "other (specify)"
		
		forval val=1/3 {
			gen		v1_`val' = 1 if v1==`val' & v1<.
			replace	v1_`val' = 0 if v1!=`val' & v1<.
			lab var	v1_`val' "Respondent occupation is `locc`val''"
		}
		
	* Three main village activities 	(activ_three)
		* Although the questions asked for three, there are 4 options selected if Other is also selected
			split v2, destring gen(v2_)
			
			forval i=1/4 {
				recode v2_`i' (-97 = 20)
			}
			
			local activities	cashcrop	opium	foodcrop	orchard	livestock_small	livestock_large	forest	mining	labor	shop	weave	sow	mason	carpent	petty	smuggle	bread	gvt	military	oth
			local activ_nums 	1			2		3			4		5				6				7		8		9		10		11		12	13		14		15		16		17		18	19			20
			
			loc l1 "Cash cropping"
			loc l2 "Opium poppy"
			loc l3 "Food cropping"
			loc l4 "Orchards"
			loc l5 "Small livestock (e.g. chicken, rabbits)"
			loc l6 "Large livestock (e.g. cows)"
			loc l7 "Forest products"
			loc l8 "Mining"
			loc l9 "Labouring"
			loc l10 "Shop keeping"
			loc l11 "Carpet weaving"
			loc l12 "Sowing/tailoring"
			loc l13 "Masonry"
			loc l14 "Carpentry"
			loc l15 "Petty trading"
			loc l16 "Smuggling"
			loc l17 "Bread making"
			loc l18 "Government employment"
			loc l19 "Military service"
			loc l20 "Other (specify)"
			
			forvalues	index = 1/20 {

				local activity	: word `index' of `activities'
				local activ_num	: word `index' of `activ_nums'
				
				egen	v2_`activ_num'_temp = anymatch(v2_?), values(`activ_num')
				lab var v2_`activ_num'_temp "`l`activ_num'' is one of three main village activities"

			}
			
			drop v2_1 v2_2 v2_3 v2_4
			rename *_temp *
			rename v2_20 v2__97
			
		* Irrigation access (& phone access)
			loc lperc1 "10%"
			loc lperc2 "10-25%"
			loc lperc3  "25-50%"
			loc lperc4  "50-75%"
			loc lperc5  "75-100%" 

			forval val=1/5 {
				gen v4_a_`val'=1 if v4_a==`val'
				replace v4_a_`val'=0 if v4_a!=`val'
				gen v7_a_`val'=1 if v7_a==`val'
				replace v7_a_`val'=0 if v7_a!=`val'
				lab var v4_a_`val' "`lperc`val'' of households has access to irrigation"
				lab var v7_a_`val' "`lperc`val'' of households has access to a phone"
			}
					
			loc irrig_perc_var v4_a_*
			loc phone_perc_var v7_a_*
			
		* Irrigation
			
			* Main sources of irrigation in village (v4)
				split v4, destring gen(v4_)

				forval i=1/2{
					recode v4_`i' (-97 = 7)
				}
				
				local irrig_sources	river	well	spring	kariz	nawara	absialab	oth
				local irrig_nums 	1		2		3		4		5		6			7
				
				loc l1 "River, canal, dam"
				loc l2 "Deep well pump"
				loc l3 "Spring"
				loc l4 "Kariz"
				loc l5 "Nawara"
				loc l6 "Absialab, snow melt, flood"
				loc l7 "Other (specify)"
				
				forvalues index = 1/7 {

					local irrig_sourc	: word `index' of `irrig_sources'
					local irrig_num		: word `index' of `irrig_nums'
					
					egen	v4_`irrig_num'_temp = anymatch(v4_?), values(`irrig_num')
					lab var	v4_`irrig_num'_temp "`l`irrig_num'' is a main source of irrigation in village"
				}
				
				drop v4_1 v4_2
				rename *_temp *
				rename v4_7 v4__97
				rename v7_a_5 v7_a__97
		
	* Water

		* Main sources of water (v5)
			split		v5, destring gen(v5_)
			
			unab vars : v5_*
			local 		water_sourc_max `: word count `vars'' 
			
			forval i=1/`water_sourc_max' {
					recode v5_`i' (-97 = 11)
				}
			
			local water_sources	openwell	handpump	boredwell	spring_unp	spring_prot	piped	kariz	river	tanker	bottle	oth
			local water_nums 	1			2			3			4			5			6		7		8		9		10		11
		
			loc l1 "Open well"
			loc l2 "Hand pump"
			loc l3 "Bored wells (motorized hand pump)"
			loc l4 "Spring unprotected"
			loc l5 "Spring protected"
			loc l6 "Piped water"
			loc l7 "Kariz"
			loc l8 "River, lake, channel, pool, drainage"
			loc l9 "Water tanker"
			loc l10 "Bottled water, mineral water"
			loc l11 "Other (specify)"
		
			forvalues index = 1/11 {

				local water_sourc	: word `index' of `water_sources'
				local water_num		: word `index' of `water_nums'
			
				egen		v5_`water_num'_temp = anymatch(v5_?), values(`water_num')
				lab var		v5_`water_num'_temp "`l`water_num''"
			}
			
			drop v5_1 v5_2 v5_3 v5_4
			rename *_temp *
			rename v5_11 v5__97
  
	* Electricity
		
		* No of days with electricity from grid
		lab var		v6		"No. of days in last 7 days village had electricity from the grid"
		
		* Other sources of electricity
		lab var		v6_a	"Village has any other source of electricity (ex: generators)"
		
		* No of days with electricity from other sources
		lab var		v6_b	"No. of days in last 7 days village had electricity from other sources"

	* Phone
		* No of towers	
		lab var		v7	"Number of phone towers"

	* Label access variables 

		lab var	v8				"Boy primary – Number of schools in village"
		lab var	v8_p				"Boy primary – Number of public schools in village"
		lab var	v8_a			"Boy primary – Typical means of transport to nearest school"
		lab var	v8_b				"Boy primary – Minutes to nearest school"
		lab var	v8_c				"Boy primary – Nearest school is public or private"
		
		lab var	v8_g				"Girl primary – Number of schools in village"
		lab var	v8_p_g			"Girl primary – Number of public schools in village"
		lab var	v8_a_g			"Girl primary – Typical means of transport to nearest school"
		lab var	v8_b_g				"Girl primary – Minutes to nearest school"
		lab var	v8_c_g			"Girl primary – Nearest school is public or private"
		
		lab var	v9				"Boy secondary – Number of schools in village"
		lab var	v9_p			"Boy secondary – Number of public schools in village"
		lab var	v9_a			"Boy secondary – Typical means of transport to nearest school"
		lab var	v9_b				"Boy secondary – Minutes to nearest school"
		lab var	v9_c			"Boy secondary – Nearest school is public or private"
		
		lab var	v9_g				"Girl secondary – Number of schools in village"
		lab var	v9_p_g			"Girl secondary – Number of public schools in village"
		lab var	v9_a_g			"Girl secondary – Typical means of transport to nearest school"
		lab var	v9_b_g			"Girl secondary – Minutes to nearest school"
		lab var	v9_c_g			"Girl secondary – Nearest school is public or private"
		
		lab var	v10					"Number of health facilites in village"
		lab var	v10_p				"Number of public health facilites in village"
		lab var	v10_a				"Typical means of transport to nearest health facility"
		lab var	v10_b					"Minutes to nearest health facility"
		lab var	v10_b_p				"Nearest health facility is public or private"
		
		lab var	v11				"No. of months in the year main road is accessible by car"
		lab var	v11_a					"Current condition of the main road"
		lab var	v12					"Km to main market from village"
		
		lab var	v13						"Presence of a veterinary in village"
		
		lab var	v13_a					"Typical means of transport to nearest veterinary"
		lab var	v13_b					"Minutes to nearest veterinary"
		
		lab var	v14							"No. of commercial banks in village"
		
		lab var	v14_a					"Services offered by banks in village"
		
		lab var	v14_b					"Typical means of transport to nearest bank"
		lab var	v14_a2					"Minutes to nearest bank"
		lab var	v14_b2				"Services offered by nearest bank"
		
		lab var	v15						"No. of microfinance institutions in village"
		
		lab var	v15_a				"Services offered by microfinance institutions in village"
		
		lab var	v15_b				"Means of transport to nearest microfinance institution"
		lab var	v15_a2				"Minutes to nearest microfinance institution"
		lab var	v15_b2			"Services offered by the nearest microfinance institution"
		
		lab var	v16						"Active rotating savings groups in village"
		
		* Assistance received

		lab var	v19						"Households in village received any type of food assistance in past 12 months"
		lab var	v19_a					"Nature of food assistance received"
		lab var	v19_b					"Providers of food assistance"
		lab var	v20					"Households in village received any of the described types of nonfood assistance in past 12 months"
		lab var	v20_a				"Providers of nonfood assistance"
		lab var	v21					"Principal problems faced by households in village in past 12 months"
		lab var	v22					"Village experienced conflict, instability, and  violence in past 12 months"
		lab var	v22_a						"No. of times village experienced conflict in past 12 months"
		lab var	v22_b					"Source of conflict during last episode"
		lab var	v22_c					"There were casualties from violence in village in past 12 months"
		lab var	v22_d				"Number of casualties in village in past 12 months"
		lab var	v22_e				"Structures or properties damaged as a result of violence in past 12 months"
		lab var	v22_f				"Disruption to services during the conflict"
		lab var	v22_g			"Duration of disruption to services during the conflict (in days)" 
		lab var	v23			"Number of village households displaced by conflict in past 12 months who have not returned"
		lab var	v24			"Number of village households internally displaced by conflict from outside in past 12 months"


	/****************************************************************
		1.5 Transform select all that apply variables into dummy variables
	****************************************************************/	
	
		split	v14_b2, destring gen(v14_b2_)
		drop	v14_b2 
		
		split	v15_a, destring gen(v15_a_)
		drop	v15_a 
		
		split	v15_b2, destring gen(v15_b2_)	
		drop	v15_b2
					
		unab vars : v14_b2_*
		local 		v14_b2_max		`: word count `vars'' 

		unab vars : v15_a_*
		local 		v15_a_max		`: word count `vars'' 
		
		unab vars : v15_b2_*
		local 		v15_b2_max	`: word count `vars''
		
		
		local bank_services 		cred_agric	cred_nonagric	cred_pers	savings	oth
		local bank_services_nums	1			2				3			4		5
		
		recode v14_a 	(-97 =5)
		recode v14_b2_* (-97 =5)
		recode v15_a_* 	(-97 =5)
		recode v15_b2_* (-97 =5)
		
		forvalues index = 1/5 {

			local bank_service			: word `index' of `bank_services'
			local bank_service_num		: word `index' of `bank_services_nums'
			
			gen			v14_a_`bank_service_num'_temp 		= 0 if v14		!= 0
			gen			v14_b2_`bank_service_num'_temp		= 0 if v14		== 0
			gen			v15_a_`bank_service_num'_temp		= 0 if v15	!= 0
			gen			v15_b2_`bank_service_num'_temp		= 0 if v15	== 0
					
			replace 	v14_a_`bank_service_num'_temp = 1 if v14_a == `bank_service_num'		 /// v14_a is select all but currently only a max of one value is selected, at follow-up, change to split command like all others	

			forval	bank_near_serv_no		= 1	/ `v14_b2_max'		{
					replace v14_b2_`bank_service_num'_temp		= 1 if v14_b2_`bank_near_serv_no'			== `bank_service_num'
			} 
			forval	microfin_serv_no		= 1	/ `v15_a_max'		{
					replace v15_a_`bank_service_num'_temp		= 1 if v15_a_`microfin_serv_no'				== `bank_service_num'
			} 
			forval	microfin_near_serv_no	= 1	/ `v15_b2_max'	{
					replace v15_b2_`bank_service_num'_temp	= 1 if v15_b2_`microfin_near_serv_no'	 		== `bank_service_num'
			}
		}
		
		drop v14_a v14_b2_1 v14_b2_2 v14_b2_3 v14_b2_4 v15_a_1 v15_a_2 v15_a_3 v15_b2_1 v15_b2_2 v15_b2_3 v15_b2_4
		rename *_temp *
		rename (v14_a_5 v14_b2_5 v15_a_5 v15_b2_5) (v14_a__97 v14_b2__97 v15_a__97 v15_b2__97)
		
		lab var v14_a_1 "Bank in village provides access to credit/loans for agricultural/livestock related secondaryities (including microcredit)"
		lab var v14_a_2 "Bank in village provides access to credit/loans for nonagricultural but work related secondaryities (e.g. microenterprise development)"
		lab var v14_a_3 "Bank in village provides access to credit/loans for personal reasons (e.g. wedding)"
		lab var v14_a_4 "Bank in village provides access to savings"
		lab var v14_a__97 "Bank in village provides other service"

		lab var v14_b2_1 "Bank nearest to village provides access to credit/loans for agricultural/livestock related secondaryities (including microcredit)"
		lab var v14_b2_2 "Bank nearest to village provides access to credit/loans for nonagricultural but work related secondaryities (e.g. microenterprise development)"
		lab var v14_b2_3 "Bank nearest to village provides access to credit/loans for personal reasons (e.g. wedding)"
		lab var v14_b2_4 "Bank nearest to village provides access to savings"
		lab var v14_b2__97 "Bank nearest to village provides other service"

		lab var v15_a_1 "Microfinance institution in village provides access to credit/loans for agricultural/livestock related secondaryities (including microcredit)"
		lab var v15_a_2 "Microfinance institution in village provides access to credit/loans for nonagricultural but work related secondaryities (e.g. microenterprise development)"
		lab var v15_a_3 "Microfinance institution in village provides access to credit/loans for personal reasons (e.g. wedding)"
		lab var v15_a_4 "Microfinance institution in village provides access to savings"
		lab var v15_a__97 "Microfinance institution in village provides other service"

		lab var v15_b2_1 "Microfinance institution nearest to village provides access to credit/loans for agricultural/livestock related secondaryities (including microcredit)"
		lab var v15_b2_2 "Microfinance institution nearest to village provides access to credit/loans for nonagricultural but work related secondaryities (e.g. microenterprise development)"
		lab var v15_b2_3 "Microfinance institution nearest to village provides access to credit/loans for personal reasons (e.g. wedding)"
		lab var v15_b2_4 "Microfinance institution nearest to village provides access to savings"
		lab var v15_b2__97 "Microfinance institution nearest to village provides other service"

		order v14_a_*, after(v14)
		order v14_b2_*, after(v14_a2)
		order v15_a_*, after(v15)
		order v15_b2_*, after(v15_a2)
		
	/* food_all:	Nature of food assistance received
					Currently max of one option was selected, change to split at follow-up*/
		
		local food_types	child	work	free	oth
		local food_nums		1		2		3		4
		
		recode v19_a (-97=4)
				
		forvalues index = 1/4 {

			local food_type		: word `index' of `food_types'
			local food_num		: word `index' of `food_nums'
			
			gen			v19_a_`food_num'_temp = 0 if v19!=0
			replace 	v19_a_`food_num'_temp = 1 if v19_a == `food_num'			
		}
		*
		drop v19_a
		rename *_temp *
		rename v19_a_4 v19_a__97

		lab var v19_a_1 "Households in village received food for school children (eat at school or take home)"
		lab var v19_a_2 "Households in village received food for work or training"
		lab var v19_a_3 "Households in village received free food distributions"
		lab var v19_a__97 "Households in village received other food assistance programs (specify)"
	
		order v19_a_*, after(v19)
	
			
	** v20: Households in village received any of the described types of nonfood assistance in past 12 months	
		* Note: no "Explain" was programmed if other was chosen
		
		gen nonfood_rec = (v20!="0") ///  select all that apply with none as an option, changing it to filter dumy variable first 
		
		split v20, destring gen(v20_)
		drop v20
		
		local nonfood_types	empl	agr_inputs	agr_training	enterp_training	livestock_large	livestock_small	vet_serv	water	education	money	medical	constr	savings	oth
		local nonfood_nums 	1		2			3				4				5				6				7			8		9			10		11		12		13		14
		
		local vars v20_1 v20_2 v20_3 v20_4 v20_5 v20_6
		local 		nonfood_rec_max `: word count `vars'' 
		
		recode v20_1 v20_2 v20_3 v20_4 v20_5 v20_6 (-97=14)
		
		forvalues index = 1/14 {

			local nonfood_type	: word `index' of `nonfood_types'
			local nonfood_num	: word `index' of `nonfood_nums'
				
			gen			v20_`nonfood_num'_temp = 0 if nonfood_rec==1
			forval		dum = 1/`nonfood_rec_max' {
						replace 	v20_`nonfood_num'_temp = 1 if v20_`dum' == `nonfood_num'			
			}	
		}
		
		drop v20_1 v20_2 v20_3 v20_4 v20_5 v20_6
		rename *_temp *
		rename v20_14 v20__97
		
		*lab var nonfood_rec "Households in villages received nonfood assistance"
		lab var v20_1 "Households in villages received access to employment through a government program (NRAP)"
		lab var v20_2 "Households in villages received agricultural input assistance (tools, seeds, fertilizers, etc.)"
		lab var v20_3 "Households in villages received training and technical assistance in improved agricultural/livestock practices"
		lab var v20_4 "Households in villages received training and technical assistance in microenterprise development"
		lab var v20_5 "Households in villages received large livestock (e.g. cow)"
		lab var v20_6 "Households in villages received small livestock (e.g. chicken, rabbits)"
		lab var v20_7 "Households in villages received veterinary services"
		lab var v20_8 "Households in villages received water and/or sanitation"
		lab var v20_9 "Households in villages received assistance for education (e.g. school materials)"
		lab var v20_10 "Households in villages received direct money transfers"
		lab var v20_11 "Households in villages received medical services"
		lab var v20_12 "Households in villages received construction/building materials"
		lab var v20_13 "Households in villages received help accessing or setting up a savings group"
		lab var v20__97 "Households in villages received other type of nonfood assistance (specify)"
		
		order v20_1 - v20__97, after(v19_b) 

			
	/* v19_b & v20_a: 	Providers of food and nonfood assistance
											For v19_b, max of one option was selected, change to split at follow-up	*/

		split	v20_a, destring	gen(v20_a_)
		drop	v20_a

		unab vars : v20_a*
		local 		nonfood_prov_max `: word count `vars'' 
		
		recode v20_a_* (-97=8) (-99=9)
		recode v19_b (-97=8) (-99=9)

		local prov_types	gvt	wfp	int_oth	ngo	relig	commun	relatives	oth	dk
		local prov_nums 	1	2	3		4	5		6		7			8	9
		

		forvalues index = 1/9 {

			local prov_type	: word `index' of `prov_types'
			local prov_num	: word `index' of `prov_nums'
			
			gen			v19_b_`prov_num'_temp = 0 if v19 == 1	
			gen			v20_a_`prov_num'_temp = 0 if nonfood_rec == 1
			
			replace 	v19_b_`prov_num'_temp = 1 if v19_b == `prov_num'					
			forval		dum = 1/`nonfood_prov_max' {
				replace 	v20_a_`prov_num'_temp = 1 if v20_a_`dum' == `prov_num'			
			}				
			*	
		}
		
		drop v19_b v20_a_1 v20_a_2
		rename *_temp *
		rename (v19_b_9 v20_a_9) (v19_b__97 v20_a__97)

		lab var v19_b_1 "Government provided food assistance"
		lab var v19_b_2 "World Food Program provided food assistance"
		lab var v19_b_3 "Other international agency provided food assistance"
		lab var v19_b_4 "NGO provided food assistance"
		lab var v19_b_5 "Religious institution (i.e. mosque, church, etc.) provided food assistance"
		lab var v19_b_6 "Community provided food assistance"
		lab var v19_b_7 "Relatives/friends provided food assistance"
		lab var v19_b_8 "Other (specify) provided food assistance"
		lab var v19_b__97 "Don't know who provided food assistance"	

		lab var v20_a_1 "Government provided nonfood assistance"
		lab var v20_a_2 "World Food Program provided nonfood assistance"
		lab var v20_a_3 "Other international agency provided nonfood assistance"
		lab var v20_a_4 "NGO provided nonfood assistance"
		lab var v20_a_5 "Religious institution (i.e. mosque, church, etc.) provided nonfood assistance"
		lab var v20_a_6 "Community provided nonfood assistance"
		lab var v20_a_7 "Relatives/friends provided nonfood assistance"
		lab var v20_a_8 "Other (specify) provided nonfood assistance"
		lab var v20_a__97 "Don't know who provided nonfood assistance"

		order	v19_b_*, after(v19_a__97)
		order	v20_a_*, after(v20__97)
			

	** v21: Principal problems faced by households in village in past 12 months
		split v21, destring gen(v21_)
		drop v21
		
		local problems				drought	flood	landslide	disease_crop	disease_livestock	disease_human	food_price	inputs_cost	empl_loss	fire	illness	hhh_death	work_hhmember_death	oth_hhmember_death	theft	hailstone	earthquake	volcano	oth
		local problems_nums 		1		2		3			4				5					6				7			8			9			10		11		12			13					14					15		16			17			18		19
		
		unab vars : v21_*
		local 		problems_max `: word count `vars'' 
		
		recode v21_* (-97=19)
		
		forvalues index = 1/19 {

			local problem		: word `index' of `problems'
			local problem_num	: word `index' of `problems_nums'
			
			gen			v21_`problem_num'_temp = 0

			forval		dum = 1/`problems_max' {
				replace 	v21_`problem_num'_temp = 1 if v21_`dum' == `problem_num'			
			}	
		}
		*
		drop v21_1 - v21_9
		rename *_temp *
		rename v21_19 v21__97
					
		lab var v21_1 "Drought/irregular rains, prolonged dry spell is one of the main problems experienced by households in the past year"
		lab var v21_2 "Floods is one of the main problems experienced by households in the past year"
		lab var v21_3 "Landslides and mudslides is one of the main problems experienced by households in the past year"
		lab var v21_4 "Unusually high level of crop pests and disease is one of the main problems experienced by households in the past year"
		lab var v21_5 "Unusually high level of livestock diseases is one of the main problems experienced by households in the past year"
		lab var v21_6 "Unusually high level of human disease/epidemic is one of the main problems experienced by households in the past year"
		lab var v21_7 "Unusually high prices for food is one of the main problems experienced by households in the past year"
		lab var v21_8 "Unusually high cost of agricultural inputs (seeds, fertilizer, etc.) is one of the main problems experienced by households in the past year"
		lab var v21_9 "Loss or reduced employment/income for a household member is one of the main problems experienced by households in the past year"
		lab var v21_10 "Fires   is one of the main problems experienced by households in the past year"
		lab var v21_11 "Serious illness or accident of household member is one of the main problems experienced by households in the past year"
		lab var v21_12 "Death of the head of the household is one of the main problems experienced by households in the past year"
		lab var v21_13 "Death of a working household member is one of the main problems experienced by households in the past year"
		lab var v21_14 "Death of other household member is one of the main problems experienced by households in the past year"
		lab var v21_15 "Theft of productive resources is one of the main problems experienced by households in the past year"
		lab var v21_16 "Hailstones (grele) is one of the main problems experienced by households in the past year"
		lab var v21_17 "Earthquake is one of the main problems experienced by households in the past year"
		lab var v21_18 "Volcanic activity is one of the main problems experienced by households in the past year"
		lab var v21__97 "Other problem (specify) is one of the main problems experienced by households in the past year"	

		order v21_1 - v21__97, after(v20_a__97)
		
	
			
	*** conflict_damage: Structures or properties damaged as a result of violence in past 12 months
			
		gen conflict_damage = (v22_e!="0") if v22==1 ///  select all that apply with none as an option, changing it to filter dumy variable first 

		split	v22_e, destring gen(v22_e_)
		drop	v22_e
		
		local structures				homes	school	hospital	mosque	post	noanswer
		local structures_nums 			1		2		3			4		5		6
		
		recode v22_e* (-98=6)
		
		unab vars : v22_e*
		local 		conflict_damage_max `: word count `vars'' 
		
			forvalues index = 1/6 {

				local structure		: word `index' of `structures'
				local structure_num	: word `index' of `structures_nums'
				
				gen			v22_e_`structure_num'_temp = 0 if conflict_damage==1
				
				forval		dum = 1/`conflict_damage_max' {
						replace 	v22_e_`structure_num'_temp = 1 if v22_e_`dum' == `structure_num'			
				}	
			}
			
		drop v22_e_1
		rename *_temp *
		rename v22_e_6 v22_e__98
		
		*lab var conflict_damage "Conflict damaged village structures"
		lab var v22_e_1 "Conflict damaged villagers' homes"
		lab var v22_e_2 "Conflict damaged village school"
		lab var v22_e_3 "Conflict damaged village hospital"
		lab var v22_e_4 "Conflict damaged village mosque"
		lab var v22_e_5 "Conflict damaged armed post"
		lab var v22_e__98 "Respondent did not answer which structures were damaged"
		
		order v22_e_1 - v22_e__98, after(v22_d)
		

	*** v22_f: Structures or properties damaged as a result of violence in past 12 months
		**** NOTE: for survey uuid:6232e586-7679-4c34-bd59-3d6dbbeb81a4, both "None" and "Water" were selected

		* browse v22_f if surveyid=="uuid:6232e586-7679-4c34-bd59-3d6dbbeb81a4"
			
		gen conflict_disrup_yes = (v22_f!="1") if v22==1 ///  select all that apply with none as an option, changing it to filter dumy variable first 
		
		split	v22_f, destring gen(v22_f_)
		drop	v22_f
		
		local services				electricity	water	roadaccess	noanswer
		local services_nums 		2			3		4			5
		
		unab vars : v22_f_*
		local 		conflict_disrup_max `: word count `vars'' 
		
			forvalues index = 1/4 {

				local service		: word `index' of `services'
				local service_num	: word `index' of `services_nums'
				
				gen			v22_f_`service_num'_temp = 0 if conflict_disrup_yes==1
				
				forval		dum = 1/`conflict_disrup_max' {
						replace 	v22_f_`service_num'_temp = 1 if v22_f_`dum' == `service_num'			
				}	
			}
			
		drop v22_f_1
		rename *_temp *
		rename v22_f_5 v22_f__98
		
		lab var v22_f_2 "Conflict disrupted electricity"
		lab var v22_f_3 "Conflict disrupted drinking water"
		lab var v22_f_4 "Conflict disrupted access to roads"
		lab var v22_f__98 "Respondent did not answer what service conflict disrupted"	

		order v22_f_2 - v22_f__98, after(v22_e__98)
		
		
	/****************************************************************
		1.6 Label values
	****************************************************************/	

	* Transport	
		#delimit ;			
			label define transport		
				1 "Walking"
				2 "Bus"	
				3 "Private vehicle"	
				-97 "Other (specify)"	;			
		#delimit cr

		local transport_vars "v8_a v8_a_g v9_a v9_a_g v10_a v13_a v14_b v15_b"

		foreach transport_var of varlist `transport_vars' {
				label values `transport_var' transport
		}
			*

	* Road			
		#delimit ;			
			label define road		
				1 "No road exists"	
				2 "Dirt, very poor condition (not passable by any vehicle)"	
				3 "Dirt, poor condition (passable by bike/motorbike only)"	
				4 "Dirt, reasonable condition (passable by car)"	
				5 "Dirt, good condition (passable by truck/large vehicle)"	
				6 "Tarmac"	;
		#delimit cr

		label values v11_a road
							
	* Source			
		#delimit ;			
			label define source		
				1 " Attacks by insurgents"	
				2 " Military operations"	
				3 " Violence instigated by local militias"	
				4 " Suicide attacks"	
				5 " Armed robbery"	
				-97 "Other (specify)"	
				-98 "No answer"	;
		#delimit cr
					
		label values v22_b source

	* Public/private
		#delimit ;		
		label define pub_pvt_type
		1	"Public"
		2	"Private"
		-99	"Do not know" ;
		#delimit cr		

		local pub_pvt_vars	"v8_c v8_c_g v9_c v9_c_g v10_b_p"
		
		foreach pub_pvt_var of varlist `pub_pvt_vars' {
			label values `pub_pvt_var' pub_pvt_type
		}
		*
		
	* Yes/no variables
		#delimit ;		
		label define yesno	
				0 "No"
				1 "Yes" ;
		#delimit cr

		unab activ : v2_1 - v2__97
		unab water : v5_1 - v5__97
		unab irrig : v4_1 - v4__97
		unab bank  : v14_a_1 - v14_a__97 v14_b2_1 - v14_b2__97 v15_a_1 - v15_a__97 v15_b2_1 - v15_b2__97
		unab food  : v19_a_1 - v19_a__97 v19_b_1 - v19_b__97
		unab nonfood: v20_1 - v20__97 v20_a_1 - v20_a__97
		unab problem: v21_1 - v21__97
		unab damage: v22_e_1 - v22_e__98
		unab disrupt: v22_f_2 - v22_f__98
		
		local yesno_vars "v1_1 - v1_3 v2_1 - v2__97 v4_1 - v4__97 v5_1 - v5__97 vc5 `activ' `water' `irrig' v6_a v13 `bank' v16 `food' `nonfood' `problem' v19 v22 `damage' `disrupt'"
			
		
		foreach yesno_var of varlist `yesno_vars' {
				label values `yesno_var' yesno
				tab  `yesno_var' , nolabel
		}
		*
		
	* Yes/No/No answer

		#delimit ;		
		label define yesno_noansw	
			0 "No"
			1 "Yes"
			-98 "No answer"	;
		#delimit cr		

		label values v22 yesno_noansw
		label values v22_c yesno_noansw
	
	/****************************************************************
		2. FLAGGING
	****************************************************************/	

	* Most variables are select one / select all, so I only looked at few variables for flags
	#delimit ;
		local open_vars	"v6_b v7 v8 v8_p
						v8_b v8_g v8_p_g v8_b_g
						v9 v9_p v9_g v9_p_g
						v9_b_g v10 v10_p v10_b v11
						v12 v13_b v14 v14_a2 v15 v15_a2 
						v23 v24" ;
	#delimit cr		

		foreach open_var of varlist `open_vars' {
				tab `open_var' 
		}
		*

	* Distance duration variables: flag if time to reach place outside of village < 10 minutes	
		local dur_vars "v8_b v8_b_g v9_b v9_b_g v10_b v13_b v14_a2 v15_a2"

		foreach dur_var of varlist `dur_vars' {
			gen			`dur_var'_flag = 0 if `dur_var' < .
			replace		`dur_var'_flag = 1 if `dur_var' < 10
			lab var	`dur_var'_flag "Distance is less than 10 minutes"
			order 	`dur_var'_flag, after(`dur_var')
		}
	
	* Final decision: replace those for which distance = 0 as missing values

	
		foreach dur_var of varlist `dur_vars' {
			replace	`dur_var' = . if `dur_var' == 0
		}
		
		
	* Drop flags generated above after cleaning
		drop *_flag

	* Drop extra vars 
		drop conflict_damage conflict_disrup_yes nonfood_rec v1 v2 v4 v4_a v5 v7_a
		
	* Finish ordering
		order v1_1 - v1_3 v2_1 - v2__97 v4_1 - v4__97 v5_1 - v5__97, after(vc5)
		order v4_a_*, after(v4__97)
		order v7_a_*, after(v7)
				

	/****************************************************************
		SECTION X: SAVE 
	****************************************************************/

	if	`c(stata_version)'>=14	{
		saveold "${village_clean_bl}", replace v(13)
	}
	else {
		save "${village_clean_bl}", replace
	}		
