/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	March 19, 2019
Last udpate on: March 19, 2019

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Construct the financial inclusion index and saving behavior for the baseline to check on balance


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Basic cleaning
				Part 2 - Constructing Variables for Financial Index
				Part 3 - Treating outliers at the individual level before we sum: winsorize and replace the .o with median
				Part 4 - Constructing the index and saving dataset
				
				
				INPUTS:     	* Original TUP dataset

						
OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge 
				
				* Github files: 

Note: 			You will need to save the ado file that Johannes created (_gweightave.ado), which is an extension to
				egen, in your personal ado folder (find it by typing "sysdir"). Then you will be able to use
				For Mac you should be able to get there by: (1) opening Finder; (2) click ÔGoÕ in the menu bar; (3) press ÔoptionÕ - this will make ÔLibraryÕ 
				appear; and (4) follow the path indicated in the ÔPERSONALÕ directory (if personal doesn't exist, just create it.)
				For information on the command search for the _gweightave instructions.docx in Dropbox (egen indexvariable = weightave(varlist), normby(vartostandardize))
				You can also refer to Anderson (2008), p. 1485, and the GD paper's pre-analysis plan (the version online, p. 13).


*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off
set maxvar 20000

	* Input files
		global inputdata 				"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"
		global all_HH_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
		global profile 					"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
		global loan 		  			"${TUP_DB}/Baseline/DataSets/Intermediate/m_b_loans_bl.dta"
		global roster_bl_balance 		"${TUP_DB}/Baseline/DataSets/Intermediate/current_roster_bl_balancechecks.dta"

	 *Output files
		global finance_index_ses 			"${TUP_DB}/Baseline/DataSets/Intermediate/finance_index_ses_bl.dta"
		global finance_index_up 			"${TUP_DB}/Baseline/DataSets/Intermediate/finance_index_up_bl.dta"
		global finance_index_ses_flsample 	"${TUP_DB}/Baseline/DataSets/Intermediate/finance_index_ses_bl_flsample.dta"


********************************************************************************
	** Part 1: Basic cleaning
********************************************************************************
   
   *First dealing with the loans roster
	
	use "${inputdata}", clear

	keep hhid m* ultra_poor 
	
* Merge on follow-up data to compute the indices for the follow-up sample only 
	merge 1:1 hhid using "${all_HH_nopii_fl1}", keepusing(ultra_poor) keep(1 3)
	gen follow_up = _merge == 3
	drop _merge
	
*Merging to have the treatment variable and cortisol
*rename  HHID_survey bl_hhid
	merge 1:1 hhid using "${profile}", keepusing(treatment PRA_lottery) assert(2 3) 	
	count if _merge == 2
	assert r(N) == 47
	drop if _merge == 2 /*47 observations from the profile datasets do not have any data for wellbeing, probably due to attrition*/
	drop _merge

	gen 	control = 0 if treatment == 1
	replace control = 1 if treatment == 0 
	
	merge 1:m hhid using "${roster_bl_balance}", keepusing(HHsize) assert(1 3) nogen

	duplicates drop hhid, force

	merge 1:m hhid using "${loan}", keepusing(m1_a) assert(1 3) nogen
	duplicates drop hhid, force

/* Questions of importance for index: 
	m21 : knows different places where to save
	m23: have a saving account
	m22 : Ability to get money if needed
	m5 : outstanding cash loans
	m16 : Anyone saved money in last 4 weeks
	m19 : total amount saved over the last 4 weeks
	m20 : total savings

	secondary
	m1 : Whether anyone has an outstanding loan
	m2 : Whether loan from a formal institution
*/

*Cleaning the variables 
	mdesc m1 m23 m5 m16 m19 m20
	foreach y in m1 m23 m5 m16 m19 m20 {
	disp "`y'"
	replace `y' = .r if `y' == -98
	replace `y' = .d if `y' == -99
			}

	rename m20 saving
	label var saving "HH total saving"

	* We don't have the variable m19 for most of the HH (only asked in LHH if LHH was the head of the household, or there was no LHH (i.e. respondent is male))

	rename m16 save_4wdummy
	label var save_4wdummy "HH has saved in the last 4 weeks"

	rename m5 loan 
	label var loan "Total outstand cash loans"

	rename m23 saving_account
	label var saving_account "HH Has a formal savings account"

	gen fin_knowledge = 0
	label var fin_knowledge "HH knows different places to save"

	gen access_credit = 0 
	label var access_credit "Can access formal credit if needed"

	gen loan_dummy = m1 
	label var loan_dummy "Whether anyone in the HH have any kind of outstanding loan"


************************************************************************************************************
** Part 2: Constructing Variables for Financial Index
************************************************************************************************************


	foreach i in 1 3 4 5 {
	replace fin_knowledge = fin_knowledge + 1 if m21_`i' == 1 
	}

	/*Formal credit from Formal Banks, Microfinancial institutions*/
	foreach i in 1 2 { 
		replace access_credit =  1 if m22_`i' == 1 
	}
	replace access_credit = .r if m22__98 == 1 
	replace access_credit = .d if m22__99 == 1

	replace saving = 0 if saving == . & saving != .d	
	

	replace loan = 0 if m1 == 0
	replace loan = .d if m1 == -99
	replace loan = .r if m1 == -98
	

************************************************************************************************************
** Part 3: Treating outliers at the individual level before we sum: winsorize and replace the .o with median
************************************************************************************************************
		*Replacing .o for gross outliers for saving and loan. Impute with the median per ultra poor, treatment and number of loans  
		*As the total outstanding loan will depend on the number of loans the family has, we replace with the average loan and multiply by the number of loans owned by the family
		gen av_loan = loan / m1_a
		egen median_av_loan = median(av_loan) if av_loan > 0 , by(ultra_poor treatment)
		replace loan = median_av_loan * m1_a if loan == .o //16 changes made
		drop av_loan median_av_loan
		
		*For savings we will divide by the household size in adults equivalent
		gen av_saving = saving / HHsize
		egen median_av_saving = median(av_saving) if av_saving > 0 , by(ultra_poor treatment)
		replace saving = median_av_saving * HHsize if saving == .o //3 changes made		
		drop median_av_saving av_saving
		
		*Winsorizing  at 95 for loan, saving
		*All the 0 become missings which is an issue and should be corrected
		foreach var in saving loan {
			local lab : variable label `var'
			winsor2 `var' if `var'>0 , s(_win) c(0 95) by(ultra_poor treatment) 
			replace `var'_win = 0 if  `var' == 0
			label var `var'_win "Winsorized `lab'"
		}
		
		
********************************************************************************************************************************************
** Part 4: Constructing the index and saving dataset
********************************************************************************************************************************************


*Constructing the index
global financial_index fin_knowledge saving_account access_credit save_4wdummy  saving // saving_4w

egen fin_index_sdUP_bl = weightave($financial_index), normby(ultra_poor)
label var fin_index_sdUP_bl "Financial Inclusion Index, Standardized by Ultra Poor"

**********************Saving the bigger sample
				if	`c(stata_version)'>=14	{
				saveold "${finance_index_ses}", replace v(13)
			}
			else {
				save "${finance_index_ses}", replace
			}	

drop fin_index_sdUP_bl

keep if ultra_poor == 1
egen fin_index_sdC_bl = weightave($financial_index), normby(control)
label var fin_index_sdC_bl "Financial Inclusion Index, Standardized by Control"

*Saving
				if	`c(stata_version)'>=14	{
				saveold "${finance_index_up}", replace v(13)
			}
			else {
				save "${finance_index_up}", replace
			}	

*Constructing the index - follow-up sample 
preserve 
	drop fin_index_sdC_bl
	keep if follow_up == 1 

	egen fin_index_sdC_bl = weightave($financial_index), normby(control)
	label var fin_index_sdC_bl "Financial Inclusion Index, Standardized by Control"

				if	`c(stata_version)'>=14	{
				saveold "${finance_index_ses_flsample}", replace v(13)
			}
			else {
				save "${finance_index_ses_flsample}", replace
			}	
restore 
			