/*******************************************************************************	

Project:  		KePSIE - Kenya
Created on:  	June 27, 2019
Last udpate on: June 27, 2019

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Computes the Quantile Treatment Effect for the four main outcomes.   

CONTENT:		Part 0 - Create globals for directories and files
				Part 1 - Create the different graphs
				Part 2 - Combine the graphs on a single page

INPUTS:     	*dataset for analysis

OUTPUTS:		* Quantile Treatment Effect figures  

Note: This dofile requires two ado files to run which were taken from the paper "Distributional Impact Analysis", Bedoya et al.   	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000
	
	
	*Running the adofiles which will be used in the dofile
	global ado "/Volumes/Camila/Dropbox/World Bank/TUP/DataWork/MasterData/ado"
	local ado = 1
	if `ado' == 1	{
		do "${ado}/bscr.ado" 
		do "${ado}/dte.ado"		
		}

	*Inputs
		global 	inputdata	 	"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

	* Outputs
		global 	dataout_cate 		"${TUP_DB}/IE_Main_paper/Output/Raw"
	
	
	*Date 
		global date = word(c(current_date),1) + word(c(current_date),2) + word(c(current_date),3)


********************************************************************************
	** Part 1: Prepare dataset for bootstrap: drop all missing variables
********************************************************************************


use "${inputdata}", clear

keep if ultra_poor == 1

	
*----------------*
* Create indices *
*----------------*	

	* Human Security - Experiences
	*-----------------------------
	
		* Number of preventive measures
			egen 	num_preventive = rowtotal(s8_1 s8_2 s8_3 s8_4 s8_5 s8_6 s8_7 s8_8 s8_9 s8__97)
			replace num_preventive = . if s8__98 == 1

		loc experience_vars "s4 s5 s6 s7 num_preventive s9"
	
	* Human Security - Experiences
	*-----------------------------
			
		loc perception_vars "s14 s15"
	
	* Control dummy
		gen 	control = treatment==0
		replace control = . if mi(treatment)
		lab var control "HH is part of control group"


	loc experience_l	"Human Security - Experiences"
	loc perception_l	"Human Security - Perceptions"

	
	gl all "experience perception"

	foreach index in $all {
		display "`index'"
		des ``index'_vars'
		egen index_sdC_`index' = weightave(``index'_vars'), normby(control)
		lab var index_sdC_`index' "``index'_l'"	
	}	
		egen index_sdC_human_sec = weightave(index_sdC_experience index_sdC_perception), normby(control)
		lab var index_sdC_human_sec "Human Security"
	
	foreach var in experience perception human_sec {
		xtile 	`var'_q = index_sdC_`var', nq(3)
		replace `var'_q = `var'_q - 1
	}
	
	tempfile inputdata
	save	`inputdata'
		
********************************************************************************
	** Part 2: Prepare code and program for CATE and CI. 
********************************************************************************	

capture program drop myboot
program myboot, eclass

    syntax , stat(name) outcome(varname)

    tempname B b V

    matrix `B' = J(1, 18, .)
    local   k  = 0

     foreach v of varlist experience_q perception_q human_sec_q { 

        local k  = `k' + 1
        local K1 = 6*(`k' - 1) + 1
        local K2 = 6*(`k' - 1) + 2
        local K3 = 6*(`k' - 1) + 3
        local K4 = 6*(`k' - 1) + 4
        local K5 = 6*(`k' - 1) + 5
        local K6 = 6*(`k' - 1) + 6
		
       * reg `outcome' c.t#i.`v' i.`v' i.strata_expanded , cl(`vce')
        reg `outcome'  c.treatment#i.`v' i.`v' i.PRA_lottery, r
        matrix `b' = e(b)
        matrix `V' = e(V)

        matrix `B'[1,`K1'] = `b'[1,1]
        matrix `B'[1,`K2'] = `b'[1,2]
		matrix `B'[1,`K3'] = `b'[1,3]
        matrix `B'[1,`K4'] = `b'[1,2] - `b'[1,1] - (`stat'[1, `K2'] - `stat'[1, `K1'])		
        matrix `B'[1,`K4'] = `B'[1,`K4']/sqrt(`V'[1,1] + `V'[2,2] - 2*`V'[2,1])		
        matrix `B'[1,`K5'] = `b'[1,3] - `b'[1,1] - (`stat'[1, `K3'] - `stat'[1, `K1'])	
        matrix `B'[1,`K5'] = `B'[1,`K5']/sqrt(`V'[1,1] + `V'[3,3] - 2*`V'[3,1])
        matrix `B'[1,`K6'] = `b'[1,3] - `b'[1,2] - (`stat'[1, `K3'] - `stat'[1, `K2'])
        matrix `B'[1,`K6'] = `B'[1,`K6']/sqrt(`V'[3,3] + `V'[2,2] - 2*`V'[3,2])

        local names "`names' `v'_0 `v'_1 `v'_2 `v'_t01 `v'_t12 `v'_t02"
    }

    matrix colnames `B' = `names'

    ereturn post `B'
end

// Estimation
foreach var in exp_tot_m_pc_c_ppp {

	use `inputdata', clear	
	

matrix B_`var' = J(1, 18, 0)
*myboot, stat(B_`var') vce(market_all_expanded) outcome(`var')
myboot, stat(B_`var') outcome(`var')
matrix B_`var' = e(b)
matlist B_`var'


// Bootstrap

bootstrap, seed(0101) reps(50)  ///
    saving("${dataout_cate}/bs_sample_`var'_hf.dta", replace) :          ///
    myboot, stat(B_`var') outcome(`var')

	
// Confidence region

bscr *_0 *_1 *_2 using "${dataout_cate}/bs_sample_`var'_hf.dta", fwer(1)

	mat `var'_se = e(se)
	matlist `var'_se
	mat `var'_cr = e(cr)
	}
	
matlist B_exp_tot_m_pc_c_ppp
matlist exp_tot_m_pc_c_ppp_se
matlist exp_tot_m_pc_c_ppp_cr
matrix B_trans = B_exp_tot_m_pc_c_ppp'
matrix se_trans = exp_tot_m_pc_c_ppp_se'
matrix cr_trans = exp_tot_m_pc_c_ppp_cr'

mat A = J(9,1,.)
mat A[1,1] = B_trans[1,1]
mat A[2,1] = B_trans[2,1]
mat A[3,1] = B_trans[3,1]
mat A[4,1] = B_trans[7,1]
mat A[5,1] = B_trans[8,1]
mat A[6,1] = B_trans[9,1]
mat A[7,1] = B_trans[13,1]
mat A[8,1] = B_trans[14,1]
mat A[9,1] = B_trans[15,1]
matlist A 
svmat A, name(coef)
svmat se_trans, name(se)
svmat cr_trans, name(ci)
br coef1 se1 ci1 ci2
-

/*	
// Critical values

use "${dataout_cate}/bs_sample_`var'_hf.dta", clear

matrix T0_`var' = J(1, 6, 0)
local  k  = 0
local  l  = 95

 foreach v in jhic_bl_q outp_as_jan_bl_q {	
		forvalues i = 1/2 {
			local k = `k' + 1
			gen abs_`v'0`i' = abs(_b_`v'_t0`i')
			sum abs_`v'0`i', det
			matrix T0_`var'[1,`k'] = r(p`l')
		}
			local k = `k' + 1
			gen abs_`v'12 = abs(_b_`v'_t12)
			sum abs_`v'12, det
			matrix T0_`var'[1,`k'] = r(p`l')
	}

qui forvalues t = 1/2 {
    bscr *_t01 *_t02 *_t12, fwer(`t') level(`l') norecenter
    matrix T`t'_`var' = e(cv)
}

matrix T_`var' = [T0_`var' \ T1_`var' \ T2_`var']'
matrix list T_`var'

}

*Generating the table

global note  		" "
global A_title 		"JHIC Score"
global B_title 		"Outpatient"
global C_title 		"OOP"

foreach `var' in A B C {
	if "`var'" == A {
	local outcome jhic_all
	}
	if "`var'" == B {
	local outcome outp_as_jan
	}
	if "`var'" == C {
	local outcome oop_all
	}
	forvalues i = 1/2 {
		forvalues j = 1/3 {
		local k = 2*`j' + `i' - 2
		global `var'_`i'_`j'_6 : di %10.3fc `var'_se[1,`k'] 
		global `var'_`i'_`j'_7 : di %10.3fc `var'_se[1,`k'] 
		global `var'_`i'_`j'_8 : di %10.3fc `var'_se[2,`k'] 
		}	
	}
}

	
	texdoc do		"${IE_Main_Paper_do}/Analysis/CATE_table.do", replace	// Creates a .tex document
*/

*********************************End of dofile***********************************************************************
