/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	March 7, 2019
Last udpate on: March 7, 2019

Written by:  	Thomas Escande			

Revision: 		Maria Camila Ayala (mayalaguerrero@worldbank.org)

********************************************************************************	

THIS DO FILE: 	Construct the financial inclusion index and saving behavior 


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Constructing new variables
				Part 2 - Constructing Variables for Financial Index
				Part 3 - Treating outliers at the individual level before we sum: winsorize and replace the .o with median
				Part 4 - Constructing variables related to women's empowerment				
				Part 5 - Constructing the index and saving dataset				
				
				
				INPUTS:     	* Original TUP dataset

						
OUTPUTS:     	
				global finance_index_ses "${TUP_DB}/Followup_1/DataSets/Intermediate/finance_index_ses_fl1.dta"
				global finance_index_up "${TUP_DB}/Followup_1/DataSets/Intermediate/finance_index_up_fl1.dta"
				
				* Github files: 

Note: 			You will need to save the ado file that Johannes created (_gweightave.ado), which is an extension to
				egen, in your personal ado folder (find it by typing "sysdir"). Then you will be able to use
				For Mac you should be able to get there by: (1) opening Finder; (2) click ÔGoÕ in the menu bar; (3) press ÔoptionÕ - this will make ÔLibraryÕ 
				appear; and (4) follow the path indicated in the ÔPERSONALÕ directory (if personal doesn't exist, just create it.)
				For information on the command search for the _gweightave instructions.docx in Dropbox (egen indexvariable = weightave(varlist), normby(vartostandardize))
				You can also refer to Anderson (2008), p. 1485, and the GD paper's pre-analysis plan (the version online, p. 13).


*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off
set maxvar 20000

	* Input files
		global inputdata 	"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
		global profile 		"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
		global loan 		"${TUP_DB}/Followup_1/DataSets/Intermediate/m_b_loans_fl1.dta"
		global roster_final "${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1.dta"		

		
		*ado files

		* Output files: 
		global finance_index_ses "${TUP_DB}/Followup_1/DataSets/Intermediate/finance_index_ses_fl1.dta"
		global finance_index_up "${TUP_DB}/Followup_1/DataSets/Intermediate/finance_index_up_fl1.dta"

********************************************************************************
	** Part 1: Constructing new variables
********************************************************************************

	*Adding variable for the number of outstanding loans in the hhh which are owned by women - different dataset
	use "$roster_final", clear
	keep hhid member b6 b8 HHsize
	rename b6 b6_
	rename b8 b8_
	reshape wide b6_ b8_ , i(hhid) j(member)
	merge 1:m hhid using "${loan}", assert(1 3) keep(3) nogen //Only hh which have outstanding loans will merge
	
	gen woman_loan 				= 0 //all the women who have a loan but one are adults so no need for a distinction
	gen woman_loan_value 		= 0 //Values of the loan hold by women  
	
	*For now, even if it is shared loan, if one of the people is a woman, it would count
	forvalues hh_mem = 1/33 {
		replace woman_loan 		 = 1  if m2_roster_`hh_mem' == 1 & b6_`hh_mem' == 2 
		replace woman_loan_value = m4 if m2_roster_`hh_mem' == 1 & b6_`hh_mem' == 2  
	}
	
		replace woman_loan 		 = .d if m2_roster == "-99"
		replace woman_loan 		 = .r if m2_roster == "-98"
	
	*Getting total number of loans
	gen num_loan = m1_a if loan_number == 1 
	tab num_loan 	

	keep hhid loan_number m1_a m2 m3* woman_loan woman_loan_value HHsize


	reshape wide m2 m3* woman_loan woman_loan_value , i(hhid m1_a) j(loan_number)

*Gen a formal variable = 1 if at least one of the loan is from a formal institution
*For the others, only hh 2202 has said another formal institution

* Merge m1
	merge m:1 hhid using "${inputdata}", keepus(m1) assert(2 3) nogen

*We don't make it conditional so that part of the effect is also having new households taking a loan
gen formal_loan_dummy = 0
gen productive_loan   = 0 
gen consumption_loan  = 0

foreach var in formal_loan_dummy productive_loan consumption_loan {
	replace `var' = .r 	if inlist(m1, -98, .r)
	replace `var' = .d 	if inlist(m1, -98, .d)
}

forvalues i = 1/10 {
replace formal_loan_dummy = 1 if inlist(m2`i', 1, 2, 10) 
replace productive_loan   = 1 if m3_4`i' == 1 | m3_5`i' == 1 | m3_6`i' == 1 | m3_7`i' == 1
replace consumption_loan  = 1 if m3_1`i' == 1 | m3_2`i' == 1 | m3_8`i' == 1 | m3_9`i' == 1 
}


/*Here are the "others" for reason for taking a loan
*1138 1269 1959 2202 2219 electricity 1150 straw 1201 1513 5687 cow 1209 1320 6529 feed cattle 1250 1370 1619 2095 2155 6166 6407 6672 land 1638 2182 consumption 1955 sheep 5679 goat 6143 cattle 6635 shoes
In general, most of them are for building / buying a house or repairing something in the house */

replace productive_loan   = 1 if hhid==1150   | hhid==1201 | hhid==1513 |hhid==5687 |hhid==1209 |hhid==1320 |hhid==6529 |hhid==1250 |hhid==1370 |hhid==1619 |hhid==2095 |hhid==2155 |hhid==6166 |hhid==6407 |hhid==6672 |hhid==1955 |hhid==5679 |hhid==6143 
replace consumption_loan  = 1 if hhid==1138   | hhid==1269 | hhid==1959 |hhid==2202 |hhid==2219 |hhid==1638 |hhid==2182 |hhid==6635
replace formal_loan_dummy = 1 if hhid == 2202

label var formal_loan_dummy "Whether anyone in the HH have an outstanding loan from a formal institution"
label var productive_loan 	"Whether anyone in the HH has taken out a loan for productive purposes"
label var consumption_loan 	"Whether anyone in the HH has taken out a loan for consumption purposes"

*Replacing with don't answer for the ones with at least one loan with "don't answer"
* and none of their other loans is for productive activities, so we effectively don't know whether 
* or not they took a loan for a productive activity as it could be the purpose of the loan they don't want to answer. Same for consumption
	forvalues i = 1/10 {
			replace formal_loan_dummy = .r if formal_loan_dummy == 0 & m2`i' == -98 
			replace formal_loan_dummy = .d if formal_loan_dummy == 0 & m2`i' == -99
	}
	replace productive_loan    = .d  if hhid == 1583 | hhid == 1631 | hhid == 1677 | hhid == 1885 | hhid == 1979 | hhid == 5100 | hhid == 5481 | hhid == 6553
	replace consumption_loan   = .d  if hhid == 1631 | hhid == 1677 | hhid == 1885 

* Variables for purpose of loan
local purpose1 "Health Emergency"
local purpose2 "Food/Essential Items"
local purpose3 "Durable Goods"
local purpose4 "Buying Farm Inputs"
local purpose5 "Starting a Business"
local purpose6 "Investing in Business"
local purpose7 "Providing Working Capital for Business"
local purpose8 "Paying for Wedding/Religious Celebration"
local purpose9 "Paying Dowry"

forvalues purpose = 1/9 {
gen purpose`purpose'_loan = .
label var purpose`purpose'_loan "Anyone in the HH has taken a loan for `purpose`j''"
forvalues loan = 1/10 {
	replace purpose`purpose'_loan = m3_`purpose'`loan' 
	}
}

fsum purpose*_loan , stat(n mean sd) uselabel

* Source of loan

local source1 "Formal Banks"
local source2 "Microfinance Institution"
local source3 "Landlord"
local source4 "Employer"
local source5 "Relative"
local source6 "Friend"
local source7 "Local Money Lender"
local source8 "ROSCA/chit fund/merry-go-round"
local source9 "Grocery Shop"
local source10 "VSLA"

forvalues source = 1/10 {
gen source`source'_loan = .
label var source`source'_loan "Anyone in the HH has taken out a loan from `source`j''"
forvalues loan = 1/10 {
	replace source`source'_loan = 1 if m2`loan' == `source'
	}
}


fsum source*_loan , stat(n mean sd) uselabel


keep hhid formal_loan_dummy m1_a productive_loan consumption_loan source*_loan source10_loan purpose*_loan woman_loan* woman_loan_value* HHsize

merge 1:1 hhid using "${inputdata}", nogen assert(2 3)

forvalues j = 1/9 {
	replace purpose`j'_loan = .r 	if m1 == -98
	replace purpose`j'_loan = .d 	if m1 == -99
}

forvalues j = 1/10 {
	replace source`j'_loan = .r 	if m1 == -98
	replace source`j'_loan = .d 	if m1 == -99
}


************************************************************************************************************
** Part 2: Constructing Variables for Financial Index
************************************************************************************************************


		global id  hhid survey 

keep $id m* formal_loan_dummy productive_loan consumption_loan source*_loan source10_loan purpose*_loan woman_loan* woman_loan_value* HHsize

*Merging to have the treatment variable 
merge 1:1 hhid using "${profile}", keepusing(treatment PRA_lottery ultra_poor)	assert(2 3)
drop if _merge == 2 /*60 observations from the profile datasets do not have any data, probably due to attrition*/
drop _merge

gen 	control = 0 if treatment == 1
replace control = 1 if treatment == 0 


/*Questions of importance for index: 
m21 : knows different places where to save
m23: have a saving account
m22 : Ability to get money if needed
m5 : outstanding cash loans
m16 : Anyone saved money in last 4 weeks
m19 : total amount saved over the last 4 weeks
m20 : total savings

secondary
m1 : Whether anyone has an outstanding loan
m2 : Whether loan from a formal institution

*/


rename m20 saving
label var saving "HH total saving"

rename m19 saving_4w
label var saving_4w "HH savings over last 4 weeks"

rename m16 save_4wdummy
label var save_4wdummy "HH has saved in the last 4 weeks"

rename m5 loan 
label var loan "Total outstand cash loans"

rename m23 saving_account
label var saving_account "HH Has a formal savings account"

gen fin_knowledge = 0
label var fin_knowledge "HH knows different places to save"

gen access_credit = 0 
label var access_credit "Can access formal credit if needed"

gen loan_dummy = m1 
label var loan_dummy 	"Whether anyone in the HH have any kind of outstanding loan"



****Constructing the variables that will be used for the analysis
replace saving_4w = 0 	if save_4wdummy == 0
replace saving_4w = .r 	if save_4wdummy == .r
replace saving_4w = .d 	if save_4wdummy == .d

foreach i in 1 3 4 5 7 {
replace fin_knowledge = fin_knowledge + 1 if m21_`i' == 1 
}

replace fin_knowledge = .q if m21__97 == 1 & fin_knowledge == 0 & hhid != 6157  /*They mostly said they have no money for savings which is not really the question*/

foreach i in 1 2 { /*Formal credit from Formal Banks, Microfinancial institutions*/
replace access_credit =  1 if m22_`i' == 1 
}

replace access_credit = .r if m22__98 == 1 

replace access_credit = .d if m22__99 == 1 | hhid == 1030

replace saving = 0 if saving == . & saving != .d

*m20_a has missing values instead of -99 and -98
replace saving = .d if m20_a == .d
replace saving = .r if m20_a == .r

replace loan = 0 if m1 == 0

*m1 has missing values instead of -99 and -98
replace loan = .d if m1 == .d
replace loan = .r if m1 == .r


************************************************************************************************************
** Part 3: Treating outliers at the individual level before we sum: winsorize and replace the .o with median
************************************************************************************************************
		*Replacing .o for gross outliers for saving and loan. Impute with the median per ultra poor, treatment and number of loans  
		*As the total outstanding loan will depend on the number of loans the family has, we replace with the average loan and multiply by the number of loans owned by the family
		gen av_loan = loan / m1_a
		egen median_av_loan = median(av_loan) if av_loan > 0 , by(ultra_poor treatment)
		replace loan = median_av_loan * m1_a if loan == .o //38 changes made
		drop av_loan median_av_loan
		
		*For savings we will divide by the household size in adults equivalent
		gen av_saving = saving / HHsize
		egen median_av_saving = median(av_saving) if av_saving > 0 , by(ultra_poor treatment)
		replace saving = median_av_saving * HHsize if saving == .o //3 changes made		
		drop median_av_saving av_saving
		
		*Winsorizing  at 95 for loan, saving, saving_4w
		*All the 0 become missings which is an issue and should be corrected
		foreach var in saving saving_4w loan {
			local lab : variable label `var'
			winsor2 `var' if `var'>0 , s(_win) c(0 95) by(ultra_poor treatment) 
			replace `var'_win = 0 if  `var' == 0
			label var `var'_win "Winsorized `lab'"
		}


********************************************************************************************************************************************
** Part 4: Constructing variables related to women's empowerment
********************************************************************************************************************************************


*Constructing variables regarding women empowerment
gen woman_loan_dummy 	 = 0 
gen woman_loan_tot 	 	 = 0 
gen woman_loan_amount 	 = 0 

forvalues number = 1/10 {
replace woman_loan_dummy  = 1 	if !mi(woman_loan_dummy) & woman_loan`number' == 1
replace woman_loan_dummy  = .d 	if woman_loan`number' == .d
replace woman_loan_dummy  = .r 	if woman_loan`number' == .r

replace woman_loan_tot    	= 1 + woman_loan_tot 	if !mi(woman_loan_tot) & woman_loan`number' == 1
replace woman_loan_tot  	= .d 					if woman_loan`number' == .d
replace woman_loan_tot  	= .r 					if woman_loan`number' == .r

replace woman_loan_amount = woman_loan_amount + woman_loan_value`number'  if woman_loan`number' == 1 & !mi(woman_loan_value`number')
replace woman_loan_amount = .d if woman_loan_value`number' == .d | woman_loan`number' == .d | woman_loan`number' == .r
}

label var woman_loan_dummy 	"At least one woman in the HH has a loan"
label var woman_loan_tot 	"Number of outstanding loans owned by women in HH"
label var woman_loan_amount "Total amount owed by women in the HH"

drop woman_loan1 woman_loan2 woman_loan3 woman_loan4 woman_loan5 woman_loan6 woman_loan7 woman_loan8 woman_loan9 woman_loan10

*We wanted to look at rejection but first, we only ask about rejections households which have no outstanding loans and among them 
*only 57 households chose rejection as the reason for not having any outstanding loan.


********************************************************************************************************************************************
** Part 5: Constructing the index and saving dataset
********************************************************************************************************************************************


*Constructing the index
global financial_index fin_knowledge saving_account access_credit save_4wdummy saving_4w saving

egen fin_index_sdUP_fl1 = weightave($financial_index), normby(ultra_poor)
label var fin_index_sdUP_fl1 "Financial Inclusion Index, Standardized by Ultra Poor"

**********************Saving the bigger sample
				if	`c(stata_version)'>=14	{
				saveold "${finance_index_ses}", replace v(13)
			}
			else {
				save "${finance_index_ses}", replace
			}	


drop fin_index_sdUP_fl1

keep if ultra_poor == 1
egen fin_index_sdC_fl1 = weightave($financial_index), normby(control)
label var fin_index_sdC_fl1 "Financial Inclusion Index, Standardized by Control"

*Saving
				if	`c(stata_version)'>=14	{
				saveold "${finance_index_up}", replace v(13)
			}
			else {
				save "${finance_index_up}", replace
			}	
