/*******************************************************************************	
Project:  		TUP - Afghanistan
Created on:  	Feb 20, 2019
Last udpate on: Mar 12, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)
Revision: 		Thomas Escande

********************************************************************************			

THIS DO FILE: 	Creates the consumption variable, the consumption consistent with ALCS, and the below the poverty line.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off
set maxvar 20000

* Inputs
	gl consumption_fl1 			"${TUP_DB}/Followup_1/DataSets/Intermediate/c_a_foodconsumption_fl1.dta"
	gl current_roster_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/br_hhmemcurrent_fl1.dta"
	gl all_HH_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
	gl market_imputed_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/market_imputed_fl1.dta"
	gl nonfood_consumption_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/c_c_nonfoodconsumption_fl1.dta"
	gl profile_info 			"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"

* Outputs

	* if "`c(username)'" == "mcayala" { // Outputs are saved in Dropbox
	gl total_expenditure		"${TUP_DB}/Followup_1/DataSets/Intermediate/total_expenditure_fl1.dta"
	gl food_consumption_all		"${TUP_DB}/Followup_1/DataSets/Intermediate/food_consumption_all_fl1.dta"
	gl nonfood_consumption_all	"${TUP_DB}/Followup_1/DataSets/Intermediate/nonfood_consumption_all_fl1.dta"
	/*}

	if "`c(username)'" != "mcayala" { // Outputs are saved in local GitHub
	gl total_expenditure	"${fl1_dt}/Intermediate/total_expenditure_fl1.dta"	
	}
	*/


********************************************************************************
	** Part 1: Food items
********************************************************************************
	
	use "${consumption_fl1}", clear
		
	* Get ultra-poor variable 
		merge m:1 hhid using "${all_HH_nopii_fl1}", assert(3) nogen keepus(ultra_poor a5 a2)
		
	* Get number of HH members
		preserve
			use "${current_roster_fl1}", clear
			keep hhid b3
			duplicates drop hhid, force
			tempfile b3
			save	`b3'
		restore
		merge m:1 hhid using `b3', assert(3) nogen	
		
	rename  (c c_i c_a c_s) (consumed consumed_days consumed_qty consumed_source)
		
	* Generate consumption per capita
		*br hhid item consumed consumed_qty
		replace consumed_qty = 0 if consumed==0
		gen consumed_qty_pc = consumed_qty/b3
		lab var consumed_qty_pc "Quantity consumed per capita" 
			
	* Drop observations for "none"
		drop if inlist(item, 13, 23, 35, 40, 65, 85, 93, 98, 105)
		
	* Create unit for quantity
		gen unit_qty = .
		lab def unit_qty_l 1 "Kilogram" 2 "Grams" 3 "Pieces" 4 "Units" 5 "Liters"
		
		replace unit_qty = 1 if inlist(item_type, "Bread", "Meat", "Dairy", "Oils", "Vegetables", "Fruits", "Sweets")
		replace unit_qty = 2 if item == 94 | item == 95 | item_type=="Spices"
		replace unit_qty = 3 if item == 4
		replace unit_qty = 4 if item == 33
		replace unit_qty = 5 if item_type == "Beverages" & mi(unit_qty)
		lab val unit_qty unit_qty_l
		tab item unit_qty, m
		lab var unit_qty "Unit of measure"
		
	*-----------------------------------------------*
	* 1. Winsorization + replacing missings by mean *
	*-----------------------------------------------*	

		* We'll winsorize at the 99th percentile
		* Winsorisation: suffix (_c), meaning "capped".
			*br item ultra_poor consumed_qty_pc
			*sort item ultra_poor consumed_qty_pc
			winsor2 consumed_qty_pc if consumed_qty_pc>0, by(item ultra_poor) cuts(0 99) s(_c)
			replace consumed_qty_pc_c = 0 if consumed_qty_pc==0
			lab var consumed_qty_pc_c "Quantity consumed per capita (capped)"
			
			/*
			local value_label_item: value label item
			foreach item of numlist 1(1)105 {
				local l_`item' : label `value_label_item' `item'
				di "`l_`item''"
				count 				 	if item == `item' & consumed_qty_pc_c>0 & !mi(consumed_qty_pc_c) & ultra_poor == 1
				hist consumed_qty_pc_c 	if item == `item' & consumed_qty_pc_c>0 & !mi(consumed_qty_pc_c) & ultra_poor == 1, percent name("nup_`item'") title("`l_`item''") note(N=`r(N)')
			}			
			
			
		* Fix remaining outliers
			winsor2 consumed_qty_pc if consumed_qty_pc>0, by(item ultra_poor) cuts(0 97) s(_f) // items 7, 8, 9, 15, 51, 90
			winsor2 consumed_qty_pc if consumed_qty_pc>0, by(item ultra_poor) cuts(0 92) s(_f2) // items 37, 56, 58, 96
			winsor2 consumed_qty_pc if consumed_qty_pc>0, by(item ultra_poor) cuts(0 95) s(_f3) // item 86
			replace consumed_qty_pc_c = consumed_qty_pc_f if inlist(item, 7, 8, 9, 15, 51, 90) & consumed_qty_pc_c!=0
			replace consumed_qty_pc_c = consumed_qty_pc_f2 if inlist(item, 37, 56, 58, 96) & consumed_qty_pc_c!=0
			replace consumed_qty_pc_c = consumed_qty_pc_f3 if inlist(item, 86) & consumed_qty_pc_c!=0
			drop consumed_qty_pc_f*
			*/
			
		* Replace missings with group averages (grouped by HH size and ultra_poor)
			*br item ultra_poor b3 consumed_qty_pc_c
			bys item ultra_poor b3: egen consumed_mean = mean(consumed_qty_pc_c) if consumed_qty_pc_c>0
			bys item ultra_poor b3: egen consumed_mean_2 = mean(consumed_qty_pc_c) 
			bys item ultra_poor b3: egen qty_pc_mean = mean(consumed_mean) //Putting mean value in all the observations of the same group
			sum consumed_mean_2 if mi(qty_pc_mean) // it would be zero
			replace qty_pc_mean = consumed_mean_2 if mi(qty_pc_mean) 

			replace consumed_qty_pc_c = qty_pc_mean if mi(consumed_qty_pc_c) 

			drop qty_pc_mean consumed_mean consumed_mean_2
			
	*---------------------------------------------------*
	* 1.A. Winsorization + replacing missings by median *
	*---------------------------------------------------*	

		* We'll winsorize at the 99th percentile
		* Winsorisation: suffix (_c), meaning "capped".
			*br item ultra_poor consumed_qty_pc
			*sort item ultra_poor consumed_qty_pc
			winsor2 consumed_qty_pc if consumed_qty_pc>0, by(item ultra_poor) cuts(0 99) s(_c_median)
			replace consumed_qty_pc_c_median = 0 if consumed_qty_pc==0
			lab var consumed_qty_pc_c_median "Quantity consumed per capita (capped, median)"	
	
		* Replace missings with group median (grouped by HH size and ultra_poor)
			br item ultra_poor b3 consumed_qty_pc_c_median
			bys item ultra_poor b3: egen consumed_median = median(consumed_qty_pc_c_median) if consumed_qty_pc_c_median>0
			bys item ultra_poor b3: egen consumed_median_2 = median(consumed_qty_pc_c_median) 
			bys item ultra_poor b3: egen qty_pc_median = mean(consumed_median) //Putting median value in all the observations of the same group
			sum consumed_median_2 if mi(qty_pc_median) // it would be zero
			replace qty_pc_median = consumed_median_2 if mi(qty_pc_median) 

			replace consumed_qty_pc_c_median = qty_pc_median if mi(consumed_qty_pc_c_median) 

			drop qty_pc_median consumed_median consumed_median_2			

	*-----------------------------------------*
	* 2. Trimmed + replacing missings by mean *
	*-----------------------------------------*	

		* We'll trim at the 99th percentile
		* Trimmed: suffix (_t), meaning "trimmed".
			br item ultra_poor consumed_qty_pc
			sort item ultra_poor consumed_qty_pc
			winsor2 consumed_qty_pc if consumed_qty_pc>0, by(item ultra_poor) cuts(0 99) s(_t) trim
			replace consumed_qty_pc_t = 0 if consumed_qty_pc==0
			lab var consumed_qty_pc_t "Quantity consumed per capita (trimmed)"
				
		* Fix remaining outliers
			winsor2 consumed_qty_pc if consumed_qty_pc>0, by(item ultra_poor) cuts(0 97) s(_f) trim // items 7, 8, 9, 15, 51, 90
			winsor2 consumed_qty_pc if consumed_qty_pc>0, by(item ultra_poor) cuts(0 92) s(_f2) trim // items 37, 56, 58, 96
			winsor2 consumed_qty_pc if consumed_qty_pc>0, by(item ultra_poor) cuts(0 95) s(_f3) trim // item 86
			replace consumed_qty_pc_t = consumed_qty_pc_f if inlist(item, 7, 8, 9, 15, 51, 90) & consumed_qty_pc_t!=0
			replace consumed_qty_pc_t = consumed_qty_pc_f2 if inlist(item, 37, 56, 58, 96) & consumed_qty_pc_t!=0
			replace consumed_qty_pc_t = consumed_qty_pc_f3 if inlist(item, 86) & consumed_qty_pc_t!=0
			drop consumed_qty_pc_f*

		* Replace missings with group averages (grouped by HH size and ultra_poor)
			*br item ultra_poor b3 consumed_qty_pc_t
			bys item ultra_poor b3: egen consumed_mean = mean(consumed_qty_pc_t) if consumed_qty_pc_t>0
			bys item ultra_poor b3: egen consumed_mean_2 = mean(consumed_qty_pc_t) 
			bys item ultra_poor b3: egen qty_pc_mean = mean(consumed_mean) //Putting mean value in all the observations of the same group
			sum consumed_mean_2 if mi(qty_pc_mean) // it would be zero
			replace qty_pc_mean = consumed_mean_2 if mi(qty_pc_mean) 

			replace consumed_qty_pc_t = qty_pc_mean if mi(consumed_qty_pc_t)
			
			drop qty_pc_mean consumed_mean consumed_mean_2
			
	*--------------------------------------------------------------*			
	* 3. No winsorization or trimming + replacing missings by mean *
	*--------------------------------------------------------------*			
		
		* Rename variable
			rename consumed_qty_pc consumed_qty_pc_raw
			clonevar consumed_qty_pc = consumed_qty_pc_raw
			
		* Replace missings with group averages (grouped by HH size and ultra_poor)
			*br item ultra_poor b3 consumed_qty_pc_raw
			bys item ultra_poor b3: egen consumed_mean = mean(consumed_qty_pc) if consumed_qty_pc>0
			bys item ultra_poor b3: egen consumed_mean_2 = mean(consumed_qty_pc) 
			bys item ultra_poor b3: egen qty_pc_mean = mean(consumed_mean) //Putting mean value in all the observations of the same group
			sum consumed_mean_2 if mi(qty_pc_mean) // it would be zero
			replace qty_pc_mean = consumed_mean_2 if mi(qty_pc_mean) 

			replace consumed_qty_pc = qty_pc_mean if mi(consumed_qty_pc)
			
			drop qty_pc_mean consumed_mean consumed_mean_2
				
	*--------------*
	* Merge prices *
	*--------------*

		* Sweetener was not asked in market survey
			rename a5 district
			merge m:1 district item using "${market_imputed_fl1}", assert(1 3) 
			sum item if _merge == 1
			assert r(mean) == 91 // sweetner
			drop _merge

		* Fix prices when the quantityes is different
			* Spices need convertion since price is in Kg but qty is in grams
				replace price = price/1000 if item_type == "Spices" // price per gram

			* Green and black tea need transformation since price is for 100 grams, and qty is in grams
				replace price = price/100 if inlist(item, 94, 95) // price per gram
				
			* For water: We took the price from the internet 26 Afghani per 1.5L
			* Might need to come back to this later on 
				replace price = 26/1.5 if inlist(item, 96)	
				
	*-------------------------*
	* Consumption expenditure *
	*-------------------------*
		loc suffix_99win "_w"
		loc suffix_capped "_c"
		loc suffix_capped_median "_c_median"
		loc suffix_trimmed "_t"
		loc suffix_nowins ""
		
		loc label_capped "(capped)"
		loc label_capped_median "(capped, median)"
		loc label_trimmed "(trimmed)"
		loc label_nowins ""

		foreach var in capped capped_median trimmed nowins {

			* Monthly expenditure
				gen exp_f_m_pc_item`suffix_`var'' = consumed_qty_pc`suffix_`var'' * price * (30.5/7) // (30.5*7) is a conversion factor from weekly to monthly
				lab var exp_f_m_pc_item`suffix_`var'' "Expenditure (Afghani, per capita, per month) `label_`var''"

			* Expenditure by item_type
				bys hhid item_type: egen exp_f_m_pc`suffix_`var'' = sum(exp_f_m_pc_item`suffix_`var'')	
				
		}	

		* Save intermediate dataset here to save all the information for all the items
			sort hhid item
			save "${food_consumption_all}", replace

		* Keep one observation per household-item_type
			duplicates drop hhid item_type, force
			keep hhid item_type exp_f_m_pc* b3 ultra_poor
			drop exp_f_m_pc_item*
			
			replace item_type = "grain" if item_type=="Bread"
			replace item_type = "meat_fish" if item_type=="Meat"
			replace item_type = "oil" if item_type=="Oils"
			replace item_type = "spice" if item_type=="Spices"
			replace item_type = "veg" if item_type=="Vegetables"
			replace item_type = "fruit" if item_type=="Fruits"
			replace item_type = "sugar" if item_type=="Sweets"
			replace item_type = "beverage" if item_type=="Beverages"	
			replace item_type = "_"+lower(item_type)

		* Calculate in-house food expenditure	
			foreach var in capped capped_median trimmed nowins {
				bys hhid: egen exp_f_inhouse_m_pc`suffix_`var'' = sum(exp_f_m_pc`suffix_`var'')
			}

		* Reshape
			reshape wide exp_f_m_pc*, i(hhid) j(item_type) s

		* Labels
			foreach var in capped_median capped trimmed nowins {
				lab var exp_f_m_pc`suffix_`var''_beverage "Beverages expenditure (Afghani, per capita, per month) `label_`var''"
				lab var exp_f_m_pc`suffix_`var''_grain  "Grains/legumes/breads expenditure (Afghanis, per capita) `label_`var''"
				lab var exp_f_m_pc`suffix_`var''_dairy "Dairy products expenditure (Afghani, per capita, per month) `label_`var''"
				lab var exp_f_m_pc`suffix_`var''_fruit  "Fruits & nuts expenditure (Afghani, per capita, per month) `label_`var''"
				lab var exp_f_m_pc`suffix_`var''_meat_fish  "Meat & fish expenditure (Afghani, per capita, per month) `label_`var''"
				lab var exp_f_m_pc`suffix_`var''_oil  "Oils & fats expenditure (Afghani, per capita, per month) (Afghanis) `label_`var''"
				lab var exp_f_m_pc`suffix_`var''_spice "Spices expenditure (Afghani, per capita, per month) `label_`var''"
				lab var exp_f_m_pc`suffix_`var''_sugar "Sugars expenditure (Afghani, per capita, per month) `label_`var''"
				lab var exp_f_m_pc`suffix_`var''_veg "Vegetables expenditure (Afghani, per capita, per month) `label_`var''"
				rename exp_f_m_pc`suffix_`var''_* exp_f_m_pc_*`suffix_`var'' 
				lab var exp_f_inhouse_m_pc`suffix_`var'' "Montly expenditure in-house food (Afghani, per capita) `label_`var''"
			}

	*------------------------*	
	* Food outside the house *
	*------------------------*		
			
		* Get food consumption outside the house
			preserve
				use "${nonfood_consumption_fl1}", clear
				keep if item == 2
				keep hhid c12
				
				tempfile food_outside
				save	`food_outside'
			restore
			
		* Merge food outside the house
			merge 1:1 hhid using `food_outside', assert(3) nogen

		* Generate per capita consumption of food outside the house
			gen 	exp_f_outhouse_m_pc = c12/b3
			lab var exp_f_outhouse_m_pc "Montly expenditure outside house food (Afghani, per capita)"
			
		* 1. Winsorization + replacing missings by mean 
		*-----------------------------------------------		
		
			winsor2 exp_f_outhouse_m_pc if exp_f_outhouse_m_pc>0, by(ultra_poor) cuts(0 99) s(_c)
			replace exp_f_outhouse_m_pc_c = 0 if exp_f_outhouse_m_pc==0
			lab var exp_f_outhouse_m_pc_c "Montly expenditure outside house food (Afghani, per capita) (capped)"
			
			* Replace missings with group averages (grouped by HH size and ultra_poor)
				bys ultra_poor b3: egen outside_consumed_mean = mean(exp_f_outhouse_m_pc_c) if exp_f_outhouse_m_pc_c>0
				bys ultra_poor b3: egen outside_consumed_mean_2 = mean(exp_f_outhouse_m_pc_c)
				bys ultra_poor b3: egen qty_pc_mean = mean(outside_consumed_mean)
				sum outside_consumed_mean_2 if mi(qty_pc_mean)
				replace qty_pc_mean = outside_consumed_mean_2 if mi(qty_pc_mean)
				replace exp_f_outhouse_m_pc_c = qty_pc_mean if mi(exp_f_outhouse_m_pc_c)
				
				drop qty_pc_mean outside_consumed_mean outside_consumed_mean_2

					
		* 1.A. Winsorization + replacing missings by median 
		*--------------------------------------------------*	

			winsor2 exp_f_outhouse_m_pc if exp_f_outhouse_m_pc>0, by(ultra_poor) cuts(0 99) s(_c_median)
			replace exp_f_outhouse_m_pc_c_median = 0 if exp_f_outhouse_m_pc==0
			lab var exp_f_outhouse_m_pc_c_median "Montly expenditure outside house food (Afghani, per capita) (capped, median)"
		
			* Replace missings with group median (grouped by HH size and ultra_poor)
				*br item ultra_poor b3 consumed_qty_pc_c_median
				bys ultra_poor b3: egen consumed_median = median(exp_f_outhouse_m_pc_c_median) if exp_f_outhouse_m_pc_c_median>0
				bys ultra_poor b3: egen consumed_median_2 = median(exp_f_outhouse_m_pc_c_median) 
				bys ultra_poor b3: egen qty_pc_median = mean(consumed_median) //Putting median value in all the observations of the same group
				sum consumed_median_2 if mi(qty_pc_median) // it would be zero
				replace qty_pc_median = consumed_median_2 if mi(qty_pc_median) 

				replace exp_f_outhouse_m_pc_c_median = qty_pc_median if mi(exp_f_outhouse_m_pc_c_median) 

				drop qty_pc_median consumed_median consumed_median_2					
				
				
		* 2. Trimmed + replacing missings by mean 
		*-----------------------------------------			
			
			*br ultra_poor exp_f_outhouse_m_pc
			winsor2 exp_f_outhouse_m_pc if exp_f_outhouse_m_pc>0, by(ultra_poor) cuts(0 99) s(_t) trim
			replace exp_f_outhouse_m_pc_t = 0 if exp_f_outhouse_m_pc==0
			lab var exp_f_outhouse_m_pc_t "Montly expenditure outside house food (Afghani, per capita) (trimmed)"
			
			* Replace missings with group averages (grouped by HH size and ultra_poor)
				bys ultra_poor b3: egen outside_consumed_mean = mean(exp_f_outhouse_m_pc_t) if exp_f_outhouse_m_pc_t>0
				bys ultra_poor b3: egen outside_consumed_mean_2 = mean(exp_f_outhouse_m_pc_t)
				bys ultra_poor b3: egen qty_pc_mean = mean(outside_consumed_mean)
				sum outside_consumed_mean_2 if mi(qty_pc_mean)
				replace qty_pc_mean = outside_consumed_mean_2 if mi(qty_pc_mean)
				replace exp_f_outhouse_m_pc_t = qty_pc_mean if mi(exp_f_outhouse_m_pc_t) 
				
				drop qty_pc_mean outside_consumed_mean outside_consumed_mean_2	
				
		* 3. No winsorization or trimming + replacing missings by mean 
		*--------------------------------------------------------------	
				
			* Rename variable
				rename exp_f_outhouse_m_pc exp_f_outhouse_m_pc_raw
				clonevar exp_f_outhouse_m_pc = exp_f_outhouse_m_pc_raw
				
			* Replace missings with group averages (grouped by HH size and ultra_poor)
				br exp_f_outhouse_m_pc_raw exp_f_outhouse_m_pc
				sort exp_f_outhouse_m_pc_raw
				bys ultra_poor b3: egen outside_consumed_mean = mean(exp_f_outhouse_m_pc) if exp_f_outhouse_m_pc>0
				bys ultra_poor b3: egen outside_consumed_mean_2 = mean(exp_f_outhouse_m_pc)
				bys ultra_poor b3: egen qty_pc_mean = mean(outside_consumed_mean)
				sum outside_consumed_mean_2 if mi(qty_pc_mean)
				replace qty_pc_mean = outside_consumed_mean_2 if mi(qty_pc_mean)
				replace exp_f_outhouse_m_pc = qty_pc_mean if mi(exp_f_outhouse_m_pc) 
				
				drop qty_pc_mean outside_consumed_mean outside_consumed_mean_2				
			
	*---------------------------------*
	* Generate total food consumption *
	*---------------------------------*

		foreach var in capped capped_median trimmed nowins {

			egen 	exp_f_tot_m_pc`suffix_`var'' = rowtotal(exp_f_inhouse_m_pc`suffix_`var'' exp_f_outhouse_m_pc`suffix_`var'')
			lab var exp_f_tot_m_pc`suffix_`var'' "Food expenditure (Afghani, per capita, per month) `label_`var''"
		}
		
		drop b3 c12 
		tempfile food_exp
		save	`food_exp'

********************************************************************************
	** Part 2: Non-food items
********************************************************************************

	use "${nonfood_consumption_fl1}", clear	
		
	* Bring ultra-poor variable 
		merge m:1 hhid using "${all_HH_nopii_fl1}", assert(3) nogen keepus(ultra_poor treatment)

	* Get number of HH members
		preserve
			use "${current_roster_fl1}", clear
			keep hhid b3 
			duplicates drop hhid, force
			tempfile b3
			save	`b3'
		restore
		merge m:1 hhid using `b3', assert(2 3) nogen keep(3)
		
	* Fo Items other than soap, winsorize at 95% (inclusing 0) [cut at 400]
		winsor2 c13, by(item treatment) cuts(0 99) s(_w)
			replace c13_w = 0 if c13==0
		
	* For soap, winsorize to have 1000 max (which is 95%) 	
		winsor2 c12, by(item treatment) cuts(0 99) s(_w)
			replace c12_w = 0 if c12==0
			
	* Generate montly expenditure
	foreach suffix in "" "_w" {
		gen 	exp_nf_m`suffix' = c12`suffix' if item <= 20
		replace exp_nf_m`suffix' = c13`suffix'/12 if item > 20
		replace exp_nf_m`suffix' = .d if c13 == .d
		replace exp_nf_m`suffix' = .o if c13 == .o
		replace exp_nf_m`suffix' = .r if c13 == .r
		
		* Generate monthly expenditure per capita
		gen 	exp_nf_m_pc`suffix' = exp_nf_m`suffix'/b3	
	}		
		
	* Generate montly expenditure
		lab var exp_nf_m "Montly expenditure per item"
		lab var exp_nf_m_pc "Montly expenditure per capita per item"
		lab var exp_nf_m_w "Montly expenditure per item (99% winsorized)"
		lab var exp_nf_m_pc_w "Montly expenditure per capita per item (99% winsorized)"
		
	*-----------------------------------------------*
	* 1. Winsorization + replacing missings by mean *
	*-----------------------------------------------*			
			
		* We'll winsorize at the 99th percentile
		* Winsorisation: suffix (_c), meaning "capped".
			*br item ultra_poor exp_nf_m_pc
			sort item ultra_poor exp_nf_m_pc
			winsor2 exp_nf_m_pc if exp_nf_m_pc>0, by(item ultra_poor) cuts(0 99) s(_c)
			replace exp_nf_m_pc_c = 0 if exp_nf_m_pc==0

		* Replace missings with group averages (grouped by HH size and ultra_poor)
			bys item ultra_poor b3: egen exp_mean = mean(exp_nf_m_pc_c) if exp_nf_m_pc_c>0
			bys item ultra_poor b3: egen exp_mean_2 = mean(exp_nf_m_pc_c)
			bys item ultra_poor b3: egen exp_pc_mean = mean(exp_mean)
			sum exp_mean_2 if mi(exp_pc_mean)
			replace exp_pc_mean = exp_mean_2 if mi(exp_pc_mean)
			replace exp_nf_m_pc_c = exp_pc_mean if mi(exp_nf_m_pc_c)
			
			drop exp_mean exp_mean_2 exp_pc_mean
		
	*---------------------------------------------------*
	* 1.A. Winsorization + replacing missings by median *
	*---------------------------------------------------*	

		* We'll winsorize at the 99th percentile
		* Winsorisation: suffix (_c), meaning "capped".
			sort item ultra_poor exp_nf_m_pc
			winsor2 exp_nf_m_pc if exp_nf_m_pc>0, by(item ultra_poor) cuts(0 99) s(_c_median)
			replace exp_nf_m_pc_c_median = 0 if exp_nf_m_pc==0		
		
		* Replace missings with group median (grouped by HH size and ultra_poor)
			bys item ultra_poor b3: egen exp_median = median(exp_nf_m_pc_c_median) if exp_nf_m_pc_c_median>0
			bys item ultra_poor b3: egen exp_median_2 = median(exp_nf_m_pc_c_median)
			bys item ultra_poor b3: egen exp_pc_median = mean(exp_median)
			sum exp_median_2 if mi(exp_pc_median)
			replace exp_pc_median = exp_median_2 if mi(exp_pc_median)
			replace exp_nf_m_pc_c_median = exp_pc_median if mi(exp_nf_m_pc_c_median)
			
			drop exp_median exp_median_2 exp_pc_median
		
	*-----------------------------------------*
	* 2. Trimmed + replacing missings by mean *
	*-----------------------------------------*	
			
		* We'll winsorize at the 99th percentile
		* Winsorisation: suffix (_t), meaning "trimmed".
			sort item ultra_poor exp_nf_m_pc
			winsor2 exp_nf_m_pc if exp_nf_m_pc>0, by(item ultra_poor) cuts(0 99) s(_t) trim
			replace exp_nf_m_pc_t = 0 if exp_nf_m_pc==0
			
		* Replace missings with group averages (grouped by HH size and ultra_poor)
			bys item ultra_poor b3: egen exp_mean = mean(exp_nf_m_pc_t) if exp_nf_m_pc_t>0
			bys item ultra_poor b3: egen exp_mean_2 = mean(exp_nf_m_pc_t)
			bys item ultra_poor b3: egen exp_pc_mean = mean(exp_mean)
			sum exp_mean_2 if mi(exp_pc_mean)
			replace exp_pc_mean = exp_mean_2 if mi(exp_pc_mean)
			replace exp_nf_m_pc_t = exp_pc_mean if mi(exp_nf_m_pc_t)
	
			drop exp_mean exp_mean_2 exp_pc_mean
	
	*--------------------------------------------------------------*
	* 3. No winsorization or trimming + replacing missings by mean *
	*--------------------------------------------------------------*
			
		foreach suffix in "_w" "_pc" "_pc_w" {
		foreach time in "_m" {
		* Rename variable
			rename exp_nf`time'`suffix' exp_nf`time'`suffix'_raw
			clonevar exp_nf`time'`suffix' = exp_nf`time'`suffix'_raw	
		
		* Replace missings with group averages (grouped by HH size and ultra_poor)
			bys item ultra_poor b3: egen exp_mean`suffix' = mean(exp_nf`time'`suffix') if exp_nf`time'`suffix'>0
			bys item ultra_poor b3: egen exp_mean_2`suffix' = mean(exp_nf`time'`suffix')
			bys item ultra_poor b3: egen exp_pc_mean`suffix' = mean(exp_mean`suffix')
			sum exp_mean_2`suffix' if mi(exp_pc_mean`suffix')
			replace exp_pc_mean`suffix' = exp_mean_2`suffix' if mi(exp_pc_mean`suffix')
			replace exp_nf`time'`suffix' = exp_pc_mean`suffix' if mi(exp_nf`time'`suffix')
	
			drop exp_mean`suffix' exp_mean_2`suffix' exp_pc_mean`suffix'	
		}
	}	
			
		* Save temporary dataset for non-food all items
			save "${nonfood_consumption_all}", replace
		
		* Food consumed in house and outside is excluded, as it is already included in monthly food consumption
			drop if inlist(item, 1,2) 	
			
	*-------------------------------------*
	* Generate total non-food consumption *
	*-------------------------------------*
	
		foreach var in 99win capped capped_median trimmed nowins {
		
			* Consistent with other TUP
				bys hhid: egen exp_nf_tot_m_pc`suffix_`var'' = sum(exp_nf_m_pc`suffix_`var'')
				lab var exp_nf_tot_m_pc`suffix_`var'' "Non-food expenditure (Afghani, per capita, per month) `label_`var''"
				
			* Consistent with ALCS (previusly NRVA): exclude fines, weddings and funerals, celebrations and donations, housing and repair, health
				bys hhid: egen exp_nf_tot_m_pc`suffix_`var''_ALCS = sum(exp_nf_m_pc`suffix_`var'') if !inlist(item, 35, 36, 37, 21, 38)
				lab var exp_nf_tot_m_pc`suffix_`var''_ALCS "Non-food expenditure consistent with ALCS/NRVA (Afghani, per capita, per month) `label_`var''"		
		}		

		* Gen type of item
			gen item_type = .
			*lab def item_type 1 "Education" 2 "Household repairs" 3 "Medical" 4 "Personal and household items" 5 "Social" 6 "Temptations" 7 "Other"
			lab def item_type 1 "edu" 2 "hhrepair" 3 "medical" 4 "hh_items" 5 "social" 6 "tempt" 7 "transp" 8 "other"
			lab value item_type item_type
			replace item_type = 1 if inlist(item, 22, 23, 24, 25, 26)
			replace item_type = 2 if inlist(item, 21)
			replace item_type = 3 if inlist(item, 38)
			replace item_type = 4 if inlist(item, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 29, 30, 31, 32, 33, 34)
			replace item_type = 5 if inlist(item, 36, 37)
			replace item_type = 6 if inlist(item, 3, 4)
			replace item_type = 7 if inlist(item, 17, 18, 27, 28)
			replace item_type = 8 if inlist(item, 19, 20, 35)
			decode item_type, gen(item_type_s)
					
		* Generate consumption by type of item
			preserve
				foreach var in capped capped_median trimmed nowins {		
					bys hhid item_type: egen exp_nf_m_type`suffix_`var'' = sum(exp_nf_m_pc`suffix_`var'')
				}
					
				duplicates drop hhid item_type, force
				sort item_type
				keep hhid item_type_s exp_nf_m_type*
				rename exp_nf_m_type* exp_nf_m_type*_
				reshape wide exp_nf_m_type*, i(hhid) j(item_type_s) s
				
				rename exp_nf_m_type_c_* exp_nf_m_*_pc_c
				rename exp_nf_m_type_t_* exp_nf_m_*_pc_t
				rename exp_nf_m_type_* exp_nf_m_*_pc
				
				foreach var in capped trimmed nowins {			
					lab var exp_nf_m_edu_pc`suffix_`var'' "Education expenses `label_`var''"
					lab var exp_nf_m_hh_items_pc`suffix_`var'' "Personal and household items `label_`var''"
					lab var exp_nf_m_hhrepair_pc`suffix_`var'' "Household repairs `label_`var''"
					lab var exp_nf_m_medical_pc`suffix_`var'' "Medical expenses `label_`var''"
					lab var exp_nf_m_other_pc`suffix_`var'' "Other expenses `label_`var''"
					lab var exp_nf_m_social_pc`suffix_`var'' "Social expenses `label_`var''"
					lab var exp_nf_m_tempt_pc`suffix_`var'' "Temptation goods `label_`var''"
					lab var exp_nf_m_transp_pc`suffix_`var'' "Transportation `label_`var''"
				}	
				
				tempfile exp_nf_type
				save	`exp_nf_type'
			restore
			
		* Keep only on obs per HH
			keep if item == 3
			keep hhid exp_nf_tot_m_pc*
			merge 1:1 hhid using `exp_nf_type', assert(3) nogen
			
			tempfile non_food_exp
			save	`non_food_exp'	
				
********************************************************************************
	** Part 3: Total consumption
********************************************************************************

	* Merge food consumption
		merge 1:1 hhid using `food_exp', assert(3) nogen	
		
	*---------------------------*
	* Consistent with other TUP * 
	*---------------------------*
		
		loc suffix_capped "_c"
		loc suffix_trimmed "_t"
		loc suffix_nowins ""
		loc label_capped "(capped)"
		loc label_trimmed "(trimmed)"
	
		foreach var in capped capped_median trimmed {			
			egen exp_tot_m_pc`suffix_`var'' = rowtotal(exp_f_tot_m_pc`suffix_`var'' exp_nf_tot_m_pc`suffix_`var'')
			lab var exp_tot_m_pc`suffix_`var'' "Total (food & non-food) monthly expenditure per capita `label_`var''"	
		}
		
		* Use Food consumption without winsorization and Non-food consumtpion with 95% winsorization 
		egen exp_tot_m_pc = rowtotal(exp_f_tot_m_pc exp_nf_tot_m_pc_w)
		lab var exp_tot_m_pc "Total (food & winsorized non-food) monthly expenditure per capita"
		
	*---------------------------*
	* Consistent with ALCS/NRVA * 
	*---------------------------*
		
	/*	Several adjustments must be made to the total food+non-food consumption
		to make it comparable to the ALCS (previous NRVA) measure (and be able to use ALCS poverty
		line to calculate poverty incidence). Compared to our estimate so far, the ALCS
				(1)	excludes: 
					(a) lumpy expenditures:  weddings, funerals, Haj
					(b) investment expenditures: expenses for housing construction (reflected in value of house) 
					(c) expenditures not related to household well-being: fines, debt payments, charitable donations 
					(d) health expenditures because not comparable to the previous round
				(2) includes: 	
					(a) durables: “rental equivalent” of consumer durables are included in the consumption aggregate, 
						to reflect the opportunity cost of money tied up in durable goods and their 
						lifetime and depreciation
					(b) rent: the contribution of housing to household welfare is captured in the consumption aggregate 
						by estimating its rental value, estimated by fitting a hedonic pricing model, i.e. by 
						regressing self-housing value information on house characteristics.
						The share of total consumption of durables and rent calculated in the 2016-2017 NRVA 
						is as follows (page 347 of the ALCS report): https://washdata.org/sites/default/files/documents/reports/2018-07/Afghanistan%20ALCS%202016-17%20Analysis%20report.pdf
								
									Share of total consumption
						Food			55.5
						Non-food		26.1
						Durables		4.7
						Rent			13.8
						
						We take the average across all population (durables 4.7% + rent 13.8%) 
						and inflate the total consumption estimate by it to have a proxy 
						for durables and rent that enables us to calculate total consumption in a way
						that is consistent with the ALCS to calculate poverty incidence.
	*/		
				
	loc durable_share "0.047"
	loc rent_share "0.138"
	loc food_nonfood_share "0.815" // it adds up to 1
	
		foreach var in capped capped_median trimmed {			
			
			* Food + non-food
				egen food_nonfood`suffix_`var''_ALCS  = rowtotal(exp_f_tot_m_pc`suffix_`var'' exp_nf_tot_m_pc`suffix_`var''_ALCS)
			
			* Durables and rent estimate
				gen exp_durable_m_pc`suffix_`var'' = food_nonfood`suffix_`var''_ALCS  * `durable_share' / `food_nonfood_share'
				gen exp_rent_m_pc`suffix_`var''    = food_nonfood`suffix_`var''_ALCS  * `rent_share' / `food_nonfood_share'
				lab var exp_durable_m_pc`suffix_`var'' "Estime expenditure in durables `label_`var''"
				lab var exp_rent_m_pc`suffix_`var'' "Estime expenditure in rent `label_`var''"
	
			* Total consumption consistent with NRVA
				gen		exp_tot_m_pc`suffix_`var''_ALCS = exp_f_tot_m_pc`suffix_`var'' + exp_nf_tot_m_pc`suffix_`var''_ALCS + exp_durable_m_pc`suffix_`var'' + exp_rent_m_pc`suffix_`var'' 
				lab var	exp_tot_m_pc`suffix_`var''_ALCS "Total monthly expenditure per capita, consistent with ALCS (food+non-food+durables+rent) `label_`var''"
		}
	
	* Using winsorized non-food consumption and non-winsorized food consumption
			
			* Food + non-food
				egen food_nonfood_ALCS  = rowtotal(exp_f_tot_m_pc exp_nf_tot_m_pc_w_ALCS)
			
			* Durables and rent estimate
				gen exp_durable_m_pc = food_nonfood_ALCS  * `durable_share' / `food_nonfood_share'
				gen exp_rent_m_pc    = food_nonfood_ALCS  * `rent_share' / `food_nonfood_share'
				lab var exp_durable_m_pc "Estime expenditure in durables (winsorized non-food cons.)"
				lab var exp_rent_m_pc "Estime expenditure in rent (winsorized non-food cons.)"
	
			* Total consumption consistent with NRVA
				gen		exp_tot_m_pc_ALCS = exp_f_tot_m_pc + exp_nf_tot_m_pc_w_ALCS + exp_durable_m_pc + exp_rent_m_pc 
				lab var	exp_tot_m_pc_ALCS "Total monthly expenditure per capita, consistent with ALCS (food+non-food+durables+rent) (winsorized non-food cons.)"
		
		drop  food_nonfood_*

* Winsorize final consumption
	winsor2 exp_tot_m_pc, by(ultra_poor) cuts(0 95)
	winsor2 exp_tot_m_pc_ALCS, by(ultra_poor) cuts(0 95)
	
* Merging treatment and PRA
	merge 1:1 hhid using "${profile_info}", keepus(treatment PRA_lottery) keep(1 3) nogen
	
	
********************************************************************************
	** Part 4: Poverty Analysis
********************************************************************************

* National Poverty line brought to 2018 prices
	gen		pov_af	=	  2179.70   	// 
	lab	var	pov_af		"Afghanistan national poverty line"

	gen		below_pov_af	=	0
	replace	below_pov_af	=	1	if	exp_tot_m_pc<pov_af
	replace	below_pov_af	=.		if	mi(exp_tot_m_pc)
	lab	var	below_pov_af	"HH below national poverty line"	
	
	gen		below_pov_af_ALCS	=	0
	replace	below_pov_af_ALCS	=	1	if	exp_tot_m_pc_ALCS<pov_af
	replace	below_pov_af_ALCS	=.		if	mi(exp_tot_m_pc_ALCS)
	lab	var	below_pov_af_ALCS	"HH below national poverty line"	
	
	gen		below_pov_af_c	=	0
	replace	below_pov_af_c	=	1	if	exp_tot_m_pc_c<pov_af
	replace	below_pov_af_c	=.		if	mi(exp_tot_m_pc_c)
	lab	var	below_pov_af_c	"HH below national poverty line (winsorized)"	
	
	gen		below_pov_af_ALCS_c	=	0
	replace	below_pov_af_ALCS_c	=	1	if	exp_tot_m_pc_c_ALCS<pov_af
	replace	below_pov_af_ALCS_c	=.		if	mi(exp_tot_m_pc_c_ALCS)
	lab	var	below_pov_af_ALCS_c	"HH below national poverty line (winsorized)"
	
* Save
	if	`c(stata_version)'>=14	{
		saveold "${total_expenditure}", replace v(13)
	}
	else {
		save "${total_expenditure}", replace
	}		

	
	
