/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	March 13, 2019
Last udpate on: June 18, 2019

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Construct the time spent on each activities and earnings coming from it 


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Basic cleaning and preparing dataset
				Part 2 - Creating and cleaning variables per activity
				Part 3 - Creating combinations of various variables
				Part 4 - Summing variables within the household
				Part 5 - Computing Unemployment and labor participation
				Part 6 - Preparing variables to be added in data for analysis dataset which are the variables which will ultimately be used in the analysis
				

INPUTS: 				Original dataset		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
						Profile info			"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
						Activities roster 		"${TUP_DB}/Followup_1/DataSets/Intermediate/productive_act_fl1.dta"
						Activities roster male	"${TUP_DB}/Followup_1/DataSets/Intermediate/productive_act_m_fl1.dta"
						Labor participation 	"${TUP_DB}/Followup_1/DataSets/Intermediate/k5_1_fl1"
						Family member roster	"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_fl1"	

						
OUTPUTS:     	
				"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_ses_fl1.dta"
				"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_up_fl1.dta"
				"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_hh_fl1.dta"


Note: The dataset starts from a roster which is then reshaped to facilitate grouping of the different activities in larger categories. 
One issue coming from the reshaping is that details for activities not perfomed (like hours or wage) will become missing instead of 0. It is then not possible 
to differentiate directly between a missing from an activity that was done and a missing coming from an activity that was not done. To solve that issue, we replace 
with 0 when the activity was not done.
When we group variables to create a variable for a specific category, we use the "+" instead of egen, rowtotal() to make sure that as soon as there is one missing observation,
in this case due to the respondent not answering, the whole sum goes to 0. We cannot trust a total where one of the part is missing as the missing, and then the error, is random.

When we look at conditional variables (conditional on doing the activity), we replace with missing all the 0s due to not doing the activity (we overturn the first step more or less).   

*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

	clear all
	set more off
	set maxvar 20000

	* Input files
		global inputdata 			"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
		global profile 				"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
		global time_activities 		"${TUP_DB}/Followup_1/DataSets/Intermediate/k_e_timeuse_fl1.dta"
		global roster 				"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1.dta"	

		* Output files: 
	* if "`c(username)'" == "mcayala" { // Outputs are saved in Dropbox
	 
		global time_activities_ses "${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_ses_fl1.dta"
		global time_activities_up  "${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_up_fl1.dta"
		global time_activities_hh  "${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_hh_fl1.dta"
	/* }

	if "`c(username)'" != "mcayala" { // Outputs are saved in local GitHub

		global time_activities_ses "${fl1_dt}/Intermediate/time_activities_ses_fl1.dta"
		global time_activities_up "${fl1_dt}/Intermediate/time_activities_up_fl1.dta"		
		global time_activities_hh "${fl1_dt}/time_activities_hh_fl1.dta"
	}
	*/
		

********************************************************************************
** Part 1: Basic cleaning and preparing dataset
********************************************************************************

	use "${time_activities}", clear

	*Merging to get all the variables
		merge m:1 hhid member using "${roster}", assert(2 3) keep(3) keepusing(b5 b6 b8 lady_hh2 hhh_name2 treatment PRA_lottery ultra_poor) nogen //time use was not collected for some households
		merge m:1 hhid using "${inputdata}", assert(2 3) keep(3) keepusing(merge_mhhh) nogen

	*For Male of the Household, we have self reported time activities as well as time activities reported by the primary woman of the household
	*Whenever possible, we will replace and keep the
	
		*Replacing for the male of the household, whenever possible
		rename *_m *
		
		replace k30 				= k1_1 					if merge_mhhh == 3 & hhh_name2 == member & b6 == 1
		replace k30_3 				= k2_1 					if merge_mhhh == 3 & hhh_name2 == member & b6 == 1
		replace k30_3_hr 			= k2_1_hr 				if merge_mhhh == 3 & hhh_name2 == member & b6 == 1
		replace k30_1 				= k3_1 				    if merge_mhhh == 3 & hhh_name2 == member & b6 == 1

		drop k1_1 k2_1 k2_1_hr k3_1 k4_1

		rename k30 					k30_0_ 		/*Did activity*/
		rename k30_3 				k30_3_ 		/*Nomber of days in last 7 days*/
		rename k30_3_hr 			k30_3_hr_ 	/*number of hours last time did it*/
		rename k30_1 				k30_1_ 		/*Earned in last 4 weeks*/

	*No lady of the household chose don't answer or don't know
		drop if activity == -98 | activity == -99
	
	*Reshaping to have one variable per activity
		reshape wide k30_0_ k30_3_ k30_3_hr_ k30_1_ , i(hhid member lady_hh2  hhh_name2 k5_1) j(activity)

		
********************************************************************************
** Part 2: Creating and cleaning variables per activity
********************************************************************************

	*Creating locals for each activity
		loc	act0	none
		loc	act1	livestock
		loc	act2	ownFarming
		loc	act3	ownBiz
		loc	act4	oFarm
		loc	act5	maid
		loc	act6	outWork
		loc	act7	salEmp
		loc act8  	oPaidWork
		loc act9 	HHChores

	*Checking for missing 
	forval	actnum=0/9	{
	disp "`act`actnum'' days"
		count if mi(k30_3_`actnum') & k30_0_`actnum' == 1
		sum k30_3_`actnum' if k30_0_`actnum' == 1
	disp "`act`actnum'' hours"
		count if mi(k30_3_hr_`actnum') & k30_0_`actnum' == 1
		sum k30_3_hr_`actnum' if k30_0_`actnum' == 1
	disp "`act`actnum'' earnins"
		count if mi(k30_1_`actnum') & k30_0_`actnum' == 1
		sum k30_1_`actnum' if k30_0_`actnum' == 1
	}
	
/*Details of missing: 4 out of 484 for livestock hours, 3 out of 74 for others farming earnings, 1 out of 70 for maid earnings, 3 out of 159 
for othPaid earning and 1 out of 2030 for hhchores earnings*/


	*Per activities, creating one variable for whether the activity was done, for how long did the person do the activity and how much they earned,
	*over the last 4 weeks. Variables are generated in absolute and conditional on having done the activity (If did not do the activity becomes 0 in first case and missing in second case)
	
	forval	actnum=0/9	{
		gen	did_`act`actnum''				= 0
			replace did_`act`actnum'' 		= 1 if k30_0_`actnum' == 1 
			lab	var	did_`act`actnum''		"Did `act`actnum'' in last 4 week"

		gen day_`act`actnum'' 				= 0
			replace day_`act`actnum''   	= k30_3_`actnum' if k30_0_`actnum' == 1
			lab	var	day_`act`actnum''		"Number of days did `act`actnum'' in the past 7 days"

		gen hr_`act`actnum'' 				= 0
			replace hr_`act`actnum''   		= k30_3_hr_`actnum' if k30_0_`actnum' == 1
			lab	var	hr_`act`actnum''		"Number of hours did `act`actnum'' last time they did it"

		gen hr_`act`actnum''_4w  	= 0
			replace hr_`act`actnum''_4w = hr_`act`actnum'' * day_`act`actnum'' * 4 
			replace hr_`act`actnum''_4w = .d if hr_`act`actnum'' == .d | day_`act`actnum'' == .d //No .r for hours
			lab	var	hr_`act`actnum''_4w	"Average number of hours doing `act`actnum'' in the last 4 weeks"

	*Only for activities for which people receive a wage : other farming, maid, outside work, salaried employment and other paid work
		gen earnings_`act`actnum''_4w = 0
		
		if `actnum' == 4 | `actnum' == 5 | `actnum' == 6 | `actnum' == 7 | `actnum' == 8 {
			replace earnings_`act`actnum''_4w  = k30_1_`actnum' if k30_0_`actnum' == 1 
			lab	var earnings_`act`actnum''_4w "Average earnings doing `act`actnum'' over last 4 weeks"
			
		gen wage_`act`actnum''  		= .
			replace wage_`act`actnum''  = earnings_`act`actnum''_4w / hr_`act`actnum''_4w if k30_0_`actnum' == 1 
			replace wage_`act`actnum''  = .o if earnings_`act`actnum''_4w == .o | hr_`act`actnum''_4w == .o 
			replace wage_`act`actnum''  = .r if earnings_`act`actnum''_4w == .r | hr_`act`actnum''_4w == .r 
			replace wage_`act`actnum''  = .d if earnings_`act`actnum''_4w == .d | hr_`act`actnum''_4w == .d
			
			lab	var	wage_`act`actnum''  "Hourly wage doing `act`actnum'' conditional on doing the activity"
		}		
	}

********************************************************************************
** Part 3: Creating combinations of various variables
********************************************************************************
	*Total number of hours worked / Total earnings in any activity
		gen hr_tot_labor_4w 		= 0 
		label var hr_tot_labor_4w "Total number of hours worked in last 4 weeks"		
		
		gen tot_earnings_act_4w 	= 0
		label var tot_earnings_act_4w "Total earnings in last 4 weeks from activities"	


	forval	actnum=1/9	{
		replace hr_tot_labor_4w 		= hr_tot_labor_4w + hr_`act`actnum''_4w 			if k30_0_`actnum' == 1
		replace tot_earnings_act_4w 	= tot_earnings_act_4w + earnings_`act`actnum''_4w	if k30_0_`actnum' == 1
	}
	
	*Replacing with .d or .o or .r if one of the observation is missing
		replace hr_tot_labor_4w 	= .d if hr_livestock_4w == .d | hr_ownFarming_4w == .d | hr_ownBiz_4w == .d | hr_oFarm_4w == .d | hr_maid_4w == .d | hr_outWork_4w == .d | hr_salEmp_4w == .d | hr_oPaidWork_4w == .d	| hr_HHChores_4w == .d	
	foreach mis in .d .o .r {
		replace tot_earnings_act_4w 	= `mis' if earnings_livestock_4w == `mis' | earnings_ownFarming_4w == `mis' | earnings_ownBiz_4w == `mis' | earnings_oFarm_4w == `mis' | earnings_maid_4w == `mis' | earnings_outWork_4w == `mis' | earnings_salEmp_4w == `mis' | earnings_oPaidWork_4w == `mis'		
	}
	
	*Total number of hours worked excluding household work in the house
		gen hr_labor_nohh_4w 		= 0 
		label var hr_labor_nohh_4w 	 "Total number of hours worked in last 4 weeks, excluding hh chores"		

	forval	actnum=1/8	{
		replace hr_labor_nohh_4w 	= hr_labor_nohh_4w + hr_`act`actnum''_4w 	if k30_0_`actnum' == 1
	}
	*Replacing with .d if one of the observation is missing
		replace hr_labor_nohh_4w 	= .d if hr_livestock_4w == .d | hr_ownFarming_4w == .d | hr_ownBiz_4w == .d | hr_oFarm_4w == .d | hr_maid_4w == .d | hr_outWork_4w == .d | hr_salEmp_4w == .d | hr_oPaidWork_4w == .d	

		gen did_labor_nohh 				=  (did_livestock == 1 | did_ownFarming == 1 | did_ownBiz == 1 |did_oFarm == 1 | did_maid == 1 | did_outWork == 1 | did_salEmp == 1 | did_oPaidWork == 1)
		label var did_labor_nohh 			"Did any type of paid or revenue generating work in the last 4 weeks"	
		

	*Did any paid work
		gen did_paidwork 				=  (did_oFarm == 1 | did_maid == 1 | did_outWork == 1 | did_salEmp == 1 | did_oPaidWork == 1)
		label var did_paidwork 			"Did any type of paid work in the last 4 weeks"		
		
		gen hr_paidwork_4w 				= hr_oFarm_4w + hr_maid_4w + hr_outWork_4w + hr_salEmp_4w + hr_oPaidWork_4w
		replace hr_paidwork_4w 			= .d if hr_oFarm_4w == .d | hr_maid_4w == .d | hr_outWork_4w == .d | hr_salEmp_4w == .d | hr_oPaidWork_4w == .d
		label var hr_paidwork_4w 		"Total hours spent on paid work in last 4 weeks" 
	
	*Did any type of self employment : ie livestock, agriculture or business
		gen did_selfemploy 				=  (did_livestock == 1 | did_ownFarming == 1 | did_ownBiz == 1 )
		label var did_selfemploy 			"Did any type of self employment in the last 4 weeks"		
		
		gen hr_selfemploy_4w 			= hr_livestock_4w + hr_ownFarming_4w + hr_ownBiz_4w 
		replace hr_selfemploy_4w 		= .d if hr_livestock_4w == .d | hr_ownFarming_4w == .d | hr_ownBiz_4w == .d 
		replace hr_selfemploy_4w 		= .r if hr_livestock_4w == .r | hr_ownFarming_4w == .r | hr_ownBiz_4w == .r 
		label var hr_selfemploy_4w 			"Total hours spent on self employment in last 4 weeks" 
		
	* All Other Work variable 
		gen hr_oWork_4w 			= hr_oFarm_4w + hr_maid_4w + hr_outWork_4w + hr_salEmp_4w + hr_oPaidWork_4w
		replace hr_oWork_4w 		= .d if hr_oFarm_4w == .d | hr_maid_4w == .d | hr_outWork_4w == .d | hr_salEmp_4w == .d | hr_oPaidWork_4w == .d 
		replace hr_oWork_4w 		= .r if hr_oFarm_4w == .r | hr_maid_4w == .r | hr_outWork_4w == .r | hr_salEmp_4w == .r | hr_oPaidWork_4w == .r 
		label var hr_oWork_4w 			"Total hours spent on all other work in last 4 weeks" 
		
	*Putting all the variables in hour in days under the assumption of working 8hours a day
		global final_var1 paidwork tot_labor labor_nohh livestock ownFarming ownBiz oFarm maid outWork salEmp oPaidWork HHChores  

	foreach var in $final_var1 {
		gen hr_`var'_4w_d 		= hr_`var'_4w 	/ 8
	*Missings
		replace hr_`var'_4w_d = .d if hr_`var'_4w == .d 
		replace hr_`var'_4w_d = .r if hr_`var'_4w == .r 
	}
		
**************************************************************************************************************************************
** Part 4: Treating outliers at the individual level before we sum: winsorize and replace the .o with median by gender and ultra_poor
**************************************************************************************************************************************
		*Replacing .o, only in the earnings. Impute with the median 
	forval	actnum=4/8	{
		forvalues gender = 1/2 {
			forvalues up = 0/1 		{
	sum wage_`act`actnum'' if b6 == `gender' & ultra_poor == `up' , d 
	replace wage_`act`actnum'' = `r(p50)' 								if wage_`act`actnum'' 		 == .o & b6 == `gender' & ultra_poor == `up' 
	replace earnings_`act`actnum''_4w = `r(p50)' * hr_`act`actnum''_4w 	if earnings_`act`actnum''_4w == .o & b6 == `gender' & ultra_poor == `up' 
			}
		}
	}

		*Winsorizing total hours worked and total earning at 99
	winsor2 hr_labor_nohh_4w_d hr_tot_labor_4w_d tot_earnings_act_4w, s(_win) c(0 99)
	
	foreach var in hr_labor_nohh_4w_d hr_tot_labor_4w_d tot_earnings_act_4w {
		local lab : variable label `var'
		label var `var'_win "Winsorized `lab'"
	}
	
********************************************************************************************************************************************
** Part 5: Summing variables within the household (not used that much for now, if used later might need to add winsorized variables instead) 
********************************************************************************************************************************************

	*Create flags for the presence of .d or .r in the household 
	egen miss_d = total(cond(tot_earnings_act_4w==.d,1,0)), by(hhid) //Counting missing don't know
	egen miss_r = total(cond(tot_earnings_act_4w==.r,1,0)), by(hhid) //Counting missing don't answer 

			
	*Earnings from Household from all paying activities
			bys hhid : egen tot_hh_pay = sum(tot_earnings_act_4w) 				
				replace tot_hh_pay = .d if miss_d > 0 & !mi(miss_d)
				replace tot_hh_pay = .r if miss_r > 0 & !mi(miss_r)
				label var tot_hh_pay "HH Paid Labor, (4 weeks)"



	*Summing for : allf = "all adult women in the hh  except primary female", allm ="All adults male members of the hh except primary male", kidf = "all female kids of the hh btw 6 and 17 years old", kidm = "all male kids of the hh btw 6 and 17 years old"
	*kidf6_15 = "all female kids of the hh btw 6 and 14 years old", kidm6_15 = "all male kids of the hh btw 6 and 14 years old" 
	*kidf15_17 = "all female kids of the hh btw 15 and 17 years old", kidm15_17 = "all male kids of the hh btw 15 and 17 years old"
	*We don't record activities for children below 6
	
* Conditions to be considered children: we use the relationship to the head of the household
		loc cond_kid = "!inlist(b5, 1, 8, 9, 10, 14, 17, 18, 19, 20, 21)"
	
	*First, sum on doing the activity or not, only for the children
		global final_var_did paidwork  livestock ownFarming ownBiz maid oFarm outWork salEmp HHChores oPaidWork

	foreach var in $final_var_did { 	
		egen did_`var'_kidf 								= mean(cond(b8 > 5 & b8 < 18 & !mi(b8) & b6==2, did_`var', .))  	 , by(hhid)
		egen did_`var'_kidm 								= mean(cond(b8 > 5 & b8 < 18 & !mi(b8) & b6==1, did_`var', .))  	 , by(hhid)
	}
	*Labelling
	loc act10 	paidwork
	forval	actnum=1/10	{
		lab	var	did_`act`actnum''_kidf		"Did `act`actnum'' in last 4 week"
		lab	var	did_`act`actnum''_kidm		"Did `act`actnum'' in last 4 week"
			}
		
	*Second, sum on the number of hours spent doing the activity
		global final_var paidwork labor_nohh tot_labor livestock ownFarming ownBiz maid oFarm outWork salEmp HHChores oPaidWork

	foreach var in $final_var { 
	
			egen hr_`var'_4w_d_allhh 					= total(cond(b8 > 14 & !mi(b8) , hr_`var'_4w_d , .))		 		, by(hhid)
					egen miss_d_allhh 					= total(cond(hr_`var'_4w_d==.d & b8 > 14 & !mi(b8) ,1,0)), by(hhid) //Counting missing don't know
					egen miss_r_allhh 					= total(cond(hr_`var'_4w_d==.r & b8 > 14 & !mi(b8),1,0)), by(hhid) //Counting missing don't answer 
						replace hr_`var'_4w_d_allhh 	= .d if miss_d_allhh > 0 & !mi(miss_d_allhh)
						replace hr_`var'_4w_d_allhh 	= .r if miss_r_allhh > 0 & !mi(miss_r_allhh)
	
			egen hr_`var'_4w_d_aduf 					= total(cond(b8 > 17 & !mi(b8) & b6==2 & lady_hh2 != member, hr_`var'_4w_d , .))  	 , by(hhid) missing
					egen miss_d_aduf 					= total(cond(hr_`var'_4w_d==.d & b8 > 17 & !mi(b8) & b6==2 & lady_hh2 != member,1,0)), by(hhid) missing //Counting missing don't know
					egen miss_r_aduf 					= total(cond(hr_`var'_4w_d==.r & b8 > 17 & !mi(b8) & b6==2 & lady_hh2 != member,1,0)), by(hhid) missing //Counting missing don't answer 
						replace hr_`var'_4w_d_aduf 		= .d if miss_d_aduf > 0 & !mi(miss_d_aduf)
						replace hr_`var'_4w_d_aduf 		= .r if miss_r_aduf > 0 & !mi(miss_r_aduf)
			
			egen hr_`var'_4w_d_adum 					= total(cond(b8 > 17 & !mi(b8) & b6==1 & hhh_name2 != member , hr_`var'_4w_d , .))		, by(hhid) missing
					egen miss_d_adum 					= total(cond(hr_`var'_4w_d==.d & b8 > 17 & !mi(b8) & b6==1 & hhh_name2 != member ,1,0)), by(hhid) missing //Counting missing don't know
					egen miss_r_adum 					= total(cond(hr_`var'_4w_d==.r & b8 > 17 & !mi(b8) & b6==1 & hhh_name2 != member,1,0)), by(hhid) missing //Counting missing don't answer 
						replace hr_`var'_4w_d_adum 		= .d if miss_d_adum > 0 & !mi(miss_d_adum)
						replace hr_`var'_4w_d_adum 		= .r if miss_r_adum > 0 & !mi(miss_r_adum)
			
			egen hr_`var'_4w_d_kidf 					= total(cond(`cond_kid' & b8 > 5 & b8 < 18 & !mi(b8) & b6==2 & lady_hh2 != member, hr_`var'_4w_d, .))	,  by(hhid) missing
					egen miss_d_kidf 					= total(cond(hr_`var'_4w_d==.d & b8 > 5 & b8 < 18 & !mi(b8) & b6==2,1,0)), by(hhid) missing //Counting missing don't know
					egen miss_r_kidf 					= total(cond(hr_`var'_4w_d==.r & b8 > 5 & b8 < 18 & !mi(b8) & b6==2,1,0)), by(hhid) missing //Counting missing don't answer 
						replace hr_`var'_4w_d_kidf 		= .d if miss_d_kidf > 0 & !mi(miss_d_kidf)
						replace hr_`var'_4w_d_kidf 		= .r if miss_r_kidf > 0 & !mi(miss_r_kidf)
						
			egen hr_`var'_4w_d_kidf6_14 				= total(cond(`cond_kid' & b8 > 5 & b8 < 15 & !mi(b8) & b6==2 & lady_hh2 != member, hr_`var'_4w_d, .))	, by(hhid) missing
					egen miss_d_kidf6_14 				= total(cond(hr_`var'_4w_d==.d & b8 > 5 & b8 < 15 & !mi(b8) & b6==2,1,0)), by(hhid) missing //Counting missing don't know
					egen miss_r_kidf6_14 				= total(cond(hr_`var'_4w_d==.r & b8 > 5 & b8 < 15 & !mi(b8) & b6==2,1,0)), by(hhid) missing //Counting missing don't answer 
						replace hr_`var'_4w_d_kidf6_14 = .d if miss_d_kidf6_14 > 0 & !mi(miss_d_kidf6_14)
						replace hr_`var'_4w_d_kidf6_14 = .r if miss_r_kidf6_14 > 0 & !mi(miss_r_kidf6_14)
						
			egen hr_`var'_4w_d_kidf15_17 				= total(cond(`cond_kid' & b8 >= 15 & b8 <= 17 & !mi(b8) & b6==2 & lady_hh2 != member, hr_`var'_4w_d, .))	, by(hhid) missing
					egen miss_d_kidf15_17 				= total(cond(hr_`var'_4w_d==.d & b8 >= 15 & b8 <= 17 & !mi(b8) & b6==2,1,0)), by(hhid) missing //Counting missing don't know
					egen miss_r_kidf15_17 				= total(cond(hr_`var'_4w_d==.r & b8 >= 15 & b8 <= 17 & !mi(b8) & b6==2,1,0)), by(hhid) missing //Counting missing don't answer 
						replace hr_`var'_4w_d_kidf15_17 = .d if miss_d_kidf15_17 > 0 & !mi(miss_d_kidf15_17)
						replace hr_`var'_4w_d_kidf15_17 = .r if miss_r_kidf15_17 > 0 & !mi(miss_r_kidf15_17)
			
			egen hr_`var'_4w_d_kidm 					= total(cond(`cond_kid' & b8 > 5 & b8 <= 17 & !mi(b8) & b6==1  & hhh_name2 != member, hr_`var'_4w_d, .))	, by(hhid) missing
					egen miss_d_kidm 					= total(cond(hr_`var'_4w_d==.d & b8 > 5 & b8 < 18 & !mi(b8) & b6==1 & hhh_name2 != member,1,0)), by(hhid) missing //Counting missing don't know
					egen miss_r_kidm 					= total(cond(hr_`var'_4w_d==.r & b8 > 5 & b8 < 18 & !mi(b8) & b6==1 & hhh_name2 != member,1,0)), by(hhid) missing //Counting missing don't answer 
						replace hr_`var'_4w_d_kidm 		= .d if miss_d_kidm > 0 & !mi(miss_d_kidm)
						replace hr_`var'_4w_d_kidm 		= .r if miss_r_kidm > 0 & !mi(miss_r_kidm)
						
			egen hr_`var'_4w_d_kidm6_14 				= total(cond(`cond_kid' & b8 > 5 & b8 < 15 & !mi(b8) & b6==1 & hhh_name2 != member, hr_`var'_4w_d, .))	, by(hhid) missing
					egen miss_d_kidm6_14 				= total(cond(hr_`var'_4w_d==.d & b8 > 5 & b8 < 15 & !mi(b8) & b6==1 & hhh_name2 != member,1,0)), by(hhid) missing //Counting missing don't know
					egen miss_r_kidm6_14 				= total(cond(hr_`var'_4w_d==.r & b8 > 5 & b8 < 15 & !mi(b8) & b6==1 & hhh_name2 != member,1,0)), by(hhid) missing //Counting missing don't answer 
						replace hr_`var'_4w_d_kidm6_14 = .d if miss_d_kidm6_14 > 0 & !mi(miss_d_kidm6_14)
						replace hr_`var'_4w_d_kidm6_14 = .r if miss_r_kidm6_14 > 0 & !mi(miss_r_kidm6_14)
						
			egen hr_`var'_4w_d_kidm15_17 				= total(cond(`cond_kid' & b8 >= 15 & b8 <= 17 & !mi(b8) & b6==1 & hhh_name2 != member, hr_`var'_4w_d, .))	, by(hhid) missing
					egen miss_d_kidm15_17 				= total(cond(hr_`var'_4w_d==.d & b8 >= 15 & b8 <= 17 & !mi(b8) & b6==1 & hhh_name2 != member,1,0)), by(hhid) missing //Counting missing don't know
					egen miss_r_kidm15_17 				= total(cond(hr_`var'_4w_d==.r & b8 >= 15 & b8 <= 17 & !mi(b8) & b6==1 & hhh_name2 != member,1,0)), by(hhid) missing //Counting missing don't answer 
						replace hr_`var'_4w_d_kidm15_17 = .d if miss_d_kidm15_17 > 0 & !mi(miss_d_kidm15_17)
						replace hr_`var'_4w_d_kidm15_17 = .r if miss_r_kidm15_17 > 0 & !mi(miss_r_kidm15_17)
											
		drop miss_*
		}
		

	*Labelling the newly created variables
		local allhh "all hh members (older than 14)"
		local aduf 	"female adults in hh"
		local adum 	"male adults in hh"
		local kidf 	"female kids in hh"
		local kidm 	"male kids in hh"
		
		
		foreach endw in "" _allhh _aduf _adum _kidf _kidf6_14 _kidf15_17 _kidm _kidm6_14 _kidm15_17 {
		
		label var hr_livestock_4w_d`endw' 			"Hours worked on livestock"
		label var hr_ownFarming_4w_d`endw' 			"Hours worked on own farming"
		label var hr_ownBiz_4w_d`endw' 				"Hours worked on own business"
		label var hr_maid_4w_d`endw' 				"Hours worked as a maid"
		label var hr_oFarm_4w_d`endw'				"Hours worked in outside farming"
		label var hr_outWork_4w_d`endw'				"Hours worked in outside work"
		label var hr_salEmp_4w_d`endw' 				"Hours worked in salaried employment"
		label var hr_HHChores_4w_d`endw' 			"Hours worked in household chores"
		label var hr_oPaidWork_4w_d`endw'			"Hours worked in other paid work"
		
		label var hr_paidwork_4w_d`endw' 			"Total hours spent on paid work"
		label var hr_tot_labor_4w_d`endw' 			"Total hours worked"
		label var hr_labor_nohh_4w_d`endw' 			"Total hours worked, excluding household chores"	
		
		}

		
********************************************************************************
** Part 5: Computing Unemployment and labor participation
********************************************************************************

	*Employment
		gen employment = 0 
			replace employment = 1 if (k30_0_1 == 1 | k30_0_2 == 1 |k30_0_3 == 1 |k30_0_4 == 1 |k30_0_5 == 1 |k30_0_6 == 1 |k30_0_7 == 1 |k30_0_8 == 1) & b8 > 14  & !mi(b8)
			label var employment "Paid employment or self employment"
	
	*Labor participation: of Working age and working or have been looking for a job in the past 2 weeks (For Age : ILO definiton 15 and plus - See excel file on definition)
		gen labor_particip = 0
			replace labor_particip = 1 if (employment == 1 | k5_1 == 1) & b8 > 14 & !mi(b8) 
			label var labor_particip "Labor participation: working or looking for a job"

	*Unemployment (of working age, looking for a job and not working in paid activity) / Underemployment (Work less than 15 days a month, 8 hours a day and is looking for a job)
		gen unemployment = 0 
			replace unemployment = 1 if k5_1 == 1 & (k30_0_0 == 1 |  (k30_0_1 != 1 & k30_0_2 != 1 & k30_0_3 != 1 & k30_0_4 != 1 & k30_0_5 != 1 & k30_0_6 != 1 & k30_0_7 != 1 & k30_0_8 != 1)  ) & b8 > 14 & !mi(b8)
			label var unemployment "Unemployed: doing no activity at all or focusing only on household chores"

		gen under_employment = 0 
			replace under_employment = 1 if employment == 1 & k5_1 == 1 & hr_tot_labor_4w  < 120
			label var under_employment "Work less than 15 days a month, 8 hours a day and is looking for a job"
			
	*Merging again with roster to get all the observations missing
		merge 1:1 hhid member using "${roster}", assert(2 3) keep(3) nogen //time use was not collected for some households
	
*Saving the dataset with ultra poor and non ultra poor

			if	`c(stata_version)'>=14	{
				saveold "${time_activities_ses}", replace v(13)
			}
			else {
				save "${time_activities_ses}", replace
			}	



keep if ultra_poor == 1

*Saving the dataset with ultra poor only
			if	`c(stata_version)'>=14	{
				saveold "${time_activities_up}", replace v(13)
			}
			else {
				save "${time_activities_up}", replace
			}	

********************************************************************************
** Part 7: Preparing variables to be added in data for analysis dataset which are the variables which will ultimately be used in the analysis
********************************************************************************	
* Generate variables for female, male and all household as needed for merge
	use "${time_activities_ses}", clear
	
	* Primary female
	preserve
		keep if lady_hh2 == member & b6 == 2
		isid hhid
		keep hhid tot_hh_pay labor_particip employment hr_labor_nohh_4w hr_livestock_4w hr_ownFarming_4w hr_ownBiz_4w hr_oFarm_4w hr_maid_4w hr_outWork_4w hr_salEmp_4w hr_oPaidWork_4w hr_selfemploy_4w hr_oWork_4w
		rename * *_pf
		rename (hhid_pf tot_hh_pay_pf) (hhid tot_hh_pay)
		tempfile time_pf
		save	`time_pf'
	restore
	
	* Primary male
		keep if hhh_name2 == member & b6 == 1 /*Taking only Male of Household who is male*/
		isid hhid
		keep hhid labor_particip employment hr_labor_nohh_4w hr_livestock_4w hr_ownFarming_4w hr_ownBiz_4w hr_oFarm_4w hr_maid_4w hr_outWork_4w hr_salEmp_4w hr_oPaidWork_4w hr_selfemploy_4w hr_oWork_4w
		rename * *_pm
		rename hhid_pm hhid
		tempfile time_pm
		save	`time_pm'
		
	* Merge
		use `time_pf', clear
		merge 1:1 hhid using `time_pm'
		/*
		Result                           # of obs.
		-----------------------------------------
		not matched                           511
			from master                       503	(_merge==1)
			from using                          8	(_merge==2)

		matched                             1,980	(_merge==3)
		-----------------------------------------
Household not matching from using are either because they have no lady of the HH (1493, 1558, 1720, 5437, 5976) or the Lady of the HH reported "don't answer" in age (1151, 1286, 6561)
Household not matching from master because households have no primary male. 
		*/
		
		drop _merge
		
/* 
We are losing 4 households, for which we had no information on the earnings of the primary man (but we had for the rest of the family). But as we are missing the most important family member, 
we put the whole hh earnings to missing 
*/ 
	*Saving dataset with the time spent on each activities
		if	`c(stata_version)'>=14	{
			saveold "${time_activities_hh}", replace v(13)
		}
		else {
			save "${time_activities_hh}", replace
		}
	
*********************************End of dofile***********************************************************************
