/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	March 13, 2019
Last udpate on: June 18, 2019

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Construct the time spent on each activities and earnings coming from it 


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Basic cleaning and preparing dataset
				Part 2 - Creating and cleaning variables per activity
				Part 3 - Creating combinations of various variables
				Part 4 - Summing variables within the household
				Part 5 - Computing Unemployment and labor participation
				Part 6 - Preparing variables to be added in data for analysis dataset which are the variables which will ultimately be used in the analysis
				

INPUTS: 				Original dataset		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
						Profile info			"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
						Activities roster 		"${TUP_DB}/Followup_1/DataSets/Intermediate/productive_act_fl1.dta"
						Activities roster male	"${TUP_DB}/Followup_1/DataSets/Intermediate/productive_act_m_fl1.dta"
						Labor participation 	"${TUP_DB}/Followup_1/DataSets/Intermediate/k5_1_fl1"
						Family member roster	"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_fl1"	

						
OUTPUTS:     	
				"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_ses_fl1.dta"
				"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_up_fl1.dta"
				"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_hh_fl1.dta"


Note: The dataset starts from a roster which is then reshaped to facilitate grouping of the different activities in larger categories. 
One issue coming from the reshaping is that details for activities not perfomed (like hours or wage) will become missing instead of 0. It is then not possible 
to differentiate directly between a missing from an activity that was done and a missing coming from an activity that was not done. To solve that issue, we replace 
with 0 when the activity was not done.
When we group variables to create a variable for a specific category, we use the "+" instead of egen, rowtotal() to make sure that as soon as there is one missing observation,
in this case due to the respondent not answering, the whole sum goes to 0. We cannot trust a total where one of the part is missing as the missing, and then the error, is random.

When we look at conditional variables (conditional on doing the activity), we replace with missing all the 0s due to not doing the activity (we overturn the first step more or less).   

*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************


	* Input files
		global inputdata 			"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
		global profile_info 		"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
		global time_activities 		"${TUP_DB}/Followup_1/DataSets/Intermediate/k_e_timeuse_fl1.dta"
		global roster 				"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1.dta"	


		* Output files: 
	* if "`c(username)'" == "mcayala" { // Outputs are saved in Dropbox
	 
		global time_activities_long "${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_long_fl1.dta"
		global time_activities_ses "${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_ses_fl1.dta"
		global time_activities_up "${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_up_fl1.dta"
		global time_activities_hh "${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_hh_fl1.dta"
	/* }

	if "`c(username)'" != "mcayala" { // Outputs are saved in local GitHub

		global time_activities_ses "${fl1_dt}/Intermediate/time_activities_ses_fl1.dta"
		global time_activities_up "${fl1_dt}/Intermediate/time_activities_up_fl1.dta"		
		global time_activities_hh "${fl1_dt}/time_activities_hh_fl1.dta"
	}
	*/
		

********************************************************************************
** Part 1: Basic cleaning and preparing dataset
********************************************************************************

	use "${time_activities}", clear
	sort hhid member activity

	* Merging to get all the variables
		merge m:1 hhid member using "${roster}",  keepusing(b5 b6 b8 lady_hh2 hhh_name2 treatment PRA_lottery ultra_poor) assert(2 3) keep(3) nogen //time use was not collected for some household members
		merge m:1 hhid using "${inputdata}", assert(2 3) keep(3) keepusing(merge_mhhh) nogen

	* For Male of the Household, we have self reported time activities as well as time activities reported by the primary woman of the household
	* Whenever possible, we will replace and keep the
	
		rename *_m *
	
		*Replacing for the male of the household, whenever possible
		replace k30 		= k1_1 		if merge_mhhh == 3 & hhh_name2 == member & b6 == 1
		replace k30_3 		= k2_1 		if merge_mhhh == 3 & hhh_name2 == member & b6 == 1
		replace k30_3_hr 	= k2_1_hr 	if merge_mhhh == 3 & hhh_name2 == member & b6 == 1
		replace k30_1 		= k3_1 		if merge_mhhh == 3 & hhh_name2 == member & b6 == 1

		
		drop k1_1 k2_1 k2_1_hr k3_1 k4_1  merge_mhhh

	*No lady of the household chose don't answer or don't know
		drop if activity == -98 | activity == -99 | activity == 0
		
********************************************************************************
** Part 2: Creating and cleaning variables per activity
********************************************************************************

* Per activities, creating one variable for whether the activity was done, for how long did the person do the activity and how much they earned,
* over the last 4 weeks. Variables are generated in absolute and conditional on having done the activity (If did not do the activity becomes 0 in first case and missing in second case)
	
	gen 	did = 1 if k30 == 1
	replace did = 0 if k30 == 0
	lab var did "Did activity in last 4 week"
	
	gen 	days = k30_3
	replace days = 0 if did == 0
	lab var days "Number of days did activity in the past 7 days"
	
	gen 	hr = k30_3_hr
	replace hr = 0 if did == 0
	lab var hr "Number of hours did activity last time they did it"
	
	gen 	hr_4w = hr*days*4
	replace hr_4w = .d if hr == .d | days == .d
	replace hr_4w = .r if hr == .r | days == .r
	lab var hr_4w "Number of hours doing activity in the last 4 weeks"
	
* Only for activities for which people receive a wage : other farming, maid, outside work, salaried employment and other paid work
	gen 	earnings_4w = k30_1 if did == 1 & inlist(activity,4,5,6,7,8)
	tab earnings_4w if mi(earnings_4w) & did == 1 & inlist(activity,4,5,6,7,8), m // misisng values
	lab	var earnings_4w "Earnings doing activity over last 4 weeks"

	gen 	wage = earnings_4w/hr_4w
	replace wage = .d if wage == 0 // 0 earnings cannot count for the computation of the wage 
	replace wage = .o if earnings_4w == .o
	replace wage = .d if earnings_4w == .d
	replace wage = .r if earnings_4w == .r
	replace wage = . if b8 < 18 
	lab	var	wage  "Hourly wage (adults) conditional on doing the activity"
	
	*Winsorizing, in aggregate for all activities and then by activity 
	winsor2 wage , cuts(5 95) by(ultra_poor b6) suffix(_win_aggregate) 
	winsor2 wage , cuts(5 95) by(ultra_poor b6 activity) suffix(_win_activity) 	
	
	label var wage_win_activity  "winsorized (5 95) by activites"	
	label var wage_win_aggregate "winsorized (5 95) in aggregate"	
		
	*Saving dataset with the time spent on each activities
		if	`c(stata_version)'>=14	{
			saveold "${time_activities_long}", replace v(13)
		}
		else {
			save "${time_activities_long}", replace
		}	
	
