/*******************************************************************************	
*		Project:
*			TUP Endline (Phone Survey follow up) analysis
*		Created on:		2023-12-7

********************************************************************************	

********************************************************************************			

** PURPOSE: 	This do-file combines the ownership of livestock from each period in a single dataset and create variables for total livestock ownership in cow equivalent and monetary value to analyze the evolution of livestock ownership between the different periods. 
				
** INPUTS:     Livestock ownership datasets for each data collection and transfer of the asset during the intervention 
1- 	"${TUP_DB}/Baseline/DataSets/Intermediate/livestock_assets_index_bl.dta"
2-	"${TUP_DB_PII}/Monitoring/DataSets/Raw/Monitoring_all_final_15Aug2017.dta" /*Livestock transferred during the intervention*/
3-	"${TUP_DB}/Followup_1/DataSets/Intermediate/livestock_assets_index_fl1.dta"
4-	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_assets_index_phonesvy.dta"
				


** OUTLINE: 	Part 0: Initiate globals 
				Part 1: Import, standardize and save livestock ownership from each data collection period
					1.1 : Baseline
					1.2 : Transfer
					1.3 : Midline
					1.4 : Endline round 1
					1.5 : Endline round 4
				Part 2 : Combining the datasets, generate cow equivalent variables and categories of ownership quantities 


				
** OUTPUTS:    
1- 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/lstock_transition_cowequiv.dta"
2-	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/lstock_transition_graph_treatment.dta"
3-  "${TUP_DB}/Phone_Survey/DataSets/Intermediate/lstock_transition_graph_control.dta"
							
				

** Written by: Thomas Escande

*******************************************************************************/

*******************************************************************************/
version 13

********************************************************************************

*** # Part 0: Initiate globals 

********************************************************************************

* Inputs 	
gl livestock_value_bl					"${TUP_DB}/Baseline/DataSets/Intermediate/livestock_assets_index_bl.dta"
gl transfer_livestock_data 				"${TUP_DB}/Profile_and_merging/DataSets/Final/transfer_livestock_data.dta" /*Livestock transferred during the intervention*/
gl livestock_value_fl1					"${TUP_DB}/Followup_1/DataSets/Intermediate/livestock_assets_index_fl1.dta"
gl livestock_assets_index_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_assets_index_phonesvy.dta"

gl phone_svy_profile					"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

	


/* 

Conversion factors based on TUP transfer : 1 cow = 3 Sheep = 4 Goats .
For the chicken, we will get the valuation from price estimation at baseline.
Price for chicken, around 270 Afghanis (trimming at 5%/95%),  for the cow, 16000 (trimming at 5%/95%)
chicken would be 0.017, same as with international comparisons

		cattle 	= 1
		sheep 	= 1/3 = 0.33
		goats 	= 1/4=0.25
		chicken = 0.017
*/			
	
* Outputs
gl lstock_transition_cowequiv		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/lstock_transition_cowequiv.dta"
gl lstock_transition_all			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/lstock_transition_all.dta"
gl lstock_transition_graph_1		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/lstock_transition_graph_treatment.dta"
gl lstock_transition_graph_0		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/lstock_transition_graph_control.dta"
	

	
********************************************************************************

*** # Part 1: Import, standardize and save livestock ownership from each data collection period

********************************************************************************	
	
* (1) Baseline
use "${livestock_value_bl}", clear 
	merge m:1 hhid using "${phone_svy_profile}", keepus(anyround attrition_r* ultra_poor treatment) keep(3) nogen
	
	keep hhid lstock_num_goat lstock_num_cow lstock_num_sheep lstock_num_chicken lstock_value_cow   lstock_value_goat   lstock_value_chicken  lstock_value_sheep unit_value_cow unit_value_goat unit_value_chicken unit_value_sheep lstock_value_med_cow lstock_value_med_goat  lstock_value_med_chicken lstock_value_med_sheep
	
	*Generate total value of livestock limited to livestock collected in all rounds, ie cow, goat, chicken and sheep 
	gen tot_lstock_value = lstock_value_cow + lstock_value_goat + lstock_value_chicken + lstock_value_sheep
	gen tot_lstock_value_med = lstock_value_med_cow + lstock_value_med_goat + lstock_value_med_chicken + lstock_value_med_sheep	
	drop lstock_value_cow   lstock_value_goat   lstock_value_chicken  lstock_value_sheep lstock_value_med_cow  lstock_value_med_goat  lstock_value_med_chicken  lstock_value_med_sheep	

	* Reshape long
	rename (*_cow *_goat *_sheep *_chicken) (*1 *5 *6 *7)
	reshape long lstock_num unit_value , i(hhid tot_lstock_value tot_lstock_value_med) j(livestock)	

	gen period = "baseline"
	
	tempfile baseline
	save `baseline'	

* (2) Transfer	
****Doing it first for control so nothing changes in terms of assets (it is the assumption)
	drop period 
	gen period = "transfer"
	
	tempfile transfer_c
	save `transfer_c'	
	
***Now working with the transfer dataset
use "${transfer_livestock_data}", clear 

format hhid %8.0g

keep hhid Cow* Sheep* Goat*  Number 
keep if !mi(hhid)

destring Number, replace

*Quick cleaning 
replace Cow = "Cow" if Cow =="cow"
replace CowPregnant = "Yes" if CowPregnant =="15-Mar-17" | CowPregnant =="Yes "

*Including calf and baby /*Counting Pregnant Cow as 1 for the transfer as we won't be able to discreminate in later rounds between pregnant and not pregnant cows and counting cow + calf as 2*/
gen 	lstock_numcow = Number*2   	if Cow == "Cow" & CowWithCalf == "Yes" 
replace lstock_numcow = Number*1   	if Cow == "Cow" & CowPregnant == "Yes"  
gen 	lstock_numsheep = Number*1   	if (Sheep == "Sheep" | Sheep == "Sheep ") & Sheepwithlamb != "With Lambs"
replace lstock_numsheep = Number*2 	if (Sheep == "Sheep" | Sheep == "Sheep ") & (Sheepwithlamb == "With Lambs" | Sheepwithlamb == "With Lamb")
gen 	lstock_numgoat = Number*1   	if Goat == "Goat" & Goatwithbaby != "With Yeanling"
replace lstock_numgoat = Number*2  	if Goat == "Goat" & Goatwithbaby == "With Yeanling"

keep hhid lstock* 
reshape long lstock_num, i(hhid) j(livestock) string

replace livestock = "1" if livestock == "cow"
replace livestock = "5" if livestock == "goat"
replace livestock = "6" if livestock == "sheep"

destring livestock, replace

replace lstock_num = 0 if mi(lstock_num)

rename lstock_num lstock_num_add

merge 1:1 hhid livestock using `transfer_c' , keep(2 3) nogen	

replace lstock_num_add = 0 if mi(lstock_num_add)

*Different valuation for the transfer. Each transfer is estimated at a value of 37 000 AFN, no matter the type or number of animals in the transfer, all more or less equivalent
gen lstock_value_add = 37000 if !mi(lstock_num_add) & lstock_num_add > 0
	
replace lstock_num 		= lstock_num 	+ lstock_num_add if !mi(lstock_num_add)
bys hhid:	egen tot_lstock_value_add = max(lstock_value_add) 

* Total livestock value
replace tot_lstock_value 		= tot_lstock_value 	+ tot_lstock_value_add if !mi(tot_lstock_value_add)
replace tot_lstock_value_med	= tot_lstock_value_med 	+ tot_lstock_value_add if !mi(tot_lstock_value_add)

drop lstock_num_add tot_lstock_value_add lstock_value_add


	tempfile transfer
	save `transfer'	
	
* (3) Midline
use "${livestock_value_fl1}", clear 
	merge m:1 hhid using "${phone_svy_profile}", keepus(anyround attrition_r* ultra_poor treatment) keep(3) nogen
	
	keep hhid lstock_num_goat lstock_num_cow lstock_num_sheep lstock_num_chicken lstock_value_cow   lstock_value_goat   lstock_value_chicken  lstock_value_sheep unit_value_cow unit_value_goat unit_value_chicken unit_value_sheep lstock_value_med_cow lstock_value_med_goat  lstock_value_med_chicken lstock_value_med_sheep
	
	*Generate total value of livestock limited to livestock collected in all rounds, ie cow, goat, chicken and sheep 
	egen tot_lstock_value = rowtotal(lstock_value_cow  lstock_value_goat lstock_value_chicken lstock_value_sheep), m // make consistent
	egen tot_lstock_value_med = rowtotal(lstock_value_med_cow  lstock_value_med_goat lstock_value_med_chicken lstock_value_med_sheep), m // make consistent
	
	drop lstock_value_cow   lstock_value_goat   lstock_value_chicken  lstock_value_sheep

	* Reshape long
	rename (*_cow *_goat *_sheep *_chicken) (*1 *5 *6 *7)
	reshape long lstock_num unit_value , i(hhid tot_lstock_value tot_lstock_value_med) j(livestock)	

	gen period = "midline"
	
	tempfile midline
	save `midline'

* (4) Endline round 1
use "${livestock_assets_index_phonesvy}", clear 
	* Keep the endline sample 
	merge m:1 hhid using "${phone_svy_profile}", keepus(attrition_r1 attrition_r4) keep(3) nogen
	keep if attrition_r1 == 0 
	tab attrition_r1 // 96 HHs are R2 only and don't have this data 
	
	
	keep hhid lstock_num_cow_1 lstock_num_goat_1 lstock_num_sheep_1 lstock_num_chicken_1
	
	* Reshape long
	rename (*_cow_1 *_goat_1 *_sheep_1 *_chicken_1) (*1 *5 *6 *7)
	reshape long lstock_num , i(hhid) j(livestock)


	gen period = "follow_up_r1"

	tempfile endline_r1
	save `endline_r1'
	
* (5) Endline round 4
use "${livestock_assets_index_phonesvy}", clear 
	* Keep the endline sample 
	merge m:1 hhid using "${phone_svy_profile}", keepus(attrition_r1 attrition_r4) keep(3) nogen
	keep if  attrition_r4 == 0

	
	keep hhid  lstock_num_cow_4 lstock_num_goat_4 lstock_num_sheep_4 lstock_num_chicken_4 unit_value_cow_4 unit_value_goat_4 unit_value_sheep_4 unit_value_chicken_4 tot_lstock_value_4  tot_lstock_value_med_4

	
	* Reshape long
	rename (*_cow_4 *_goat_4 *_sheep_4 *_chicken_4) (*1 *5 *6 *7)
	reshape long lstock_num unit_value, i(hhid tot_lstock_value_4 tot_lstock_value_med_4) j(livestock)

	rename tot_lstock_value_4 		tot_lstock_value 
	rename tot_lstock_value_med_4 	tot_lstock_value_med	
	
	gen period = "follow_up_r4"

	
	
********************************************************************************

*** # Part 2: Combining the datasets, generate cow equivalent variables and categories of ownership quantities 

********************************************************************************

	
*Creating a dataset to know for each households for which period we have data on livestock
preserve
	keep hhid livestock
gen data_end_r4 = 1 

	merge 1:1 hhid livestock using "`baseline'"
rename _merge merge_end_bl
	merge 1:1 hhid livestock using "`transfer'"
rename _merge merge_end_r4_bl_tr	
	merge 1:1 hhid livestock using "`midline'"
rename _merge merge_end_r4_bl_mid 
	merge 1:1 hhid livestock using "`endline_r1'"
rename _merge merge_end_r4_bl_end_r1 

gen data_bl  	= 1 if 	inlist(merge_end_bl,2,3)
gen data_tr  	= 1 if 	inlist(merge_end_r4_bl_tr,2,3)
gen data_mid 	= 1 if 	inlist(merge_end_r4_bl_mid,2,3)
gen data_end_r1 = 1 if 	inlist(merge_end_r4_bl_end_r1,2,3)



duplicates drop hhid, force
drop livestock lstock_num period merge*

	tempfile round_available
	save `round_available'

restore 	

	
	append using "`baseline'"
	append using "`transfer'"
	append using "`midline'"	
	append using "`endline_r1'"		
	
	merge m:1 hhid using `round_available',  nogen keepus(data_bl data_tr data_mid data_end_r1 data_end_r4)
	
	
	merge m:1 hhid using "${phone_svy_profile}", keepus(ultra_poor treatment) assert(2 3) keep(3) nogen

	label values livestock livestock_l
	sort period hhid livestock
	order hhid period  ultra_poor treatment livestock lstock_num tot_lstock_value
	
	* Now in terms of cows (naive calculation for now)
	gen lstock_unit_cow = .
	
	*Using TUP transfers equivalence
		replace lstock_unit_cow = 1 	* lstock_num if livestock == 1 // cow 
		replace lstock_unit_cow = 0.25 	* lstock_num if livestock == 5 // goat 
		replace lstock_unit_cow = 1/3 	* lstock_num if livestock == 6 //  sheep		
		replace lstock_unit_cow = 0.017	* lstock_num if livestock == 7 	// Chicken		
		
	* Winsorize value of livestock at 99th pct by treatment to be consistent with endline  
		foreach var in tot_lstock_value { 
			winsor2 `var', by(treatment period) cuts(0 99) suff(_w99t) 
			replace `var'_w99t = `var' if mi(`var'_w99t) 
			local l_`var' : variable label `var' 
			lab var `var'_w99t "`l_`var'' - Treatment Winsorized (99%)" 
		}	
		
	* Putting monetary variables in 2018 constant USD 
	foreach var in tot_lstock_value unit_value {
		
	gen     `var'_18afn = `var' 
	replace `var'_18afn = (`var' * ($cpi_econ_fl1 / $cpi_econ_bl))  	if period == "baseline" | period == "transfer" 
	replace `var'_18afn = (`var' * ($cpi_econ_fl1 / $cpi_econ_phone)) 	if period == "follow_up_r1" | period == "follow_up_r4" 

	}

* Nominal USD conversion
	foreach var in tot_lstock_value tot_lstock_value_w99t {
		local `var'l : var lab `var'
		local `var'l: subinstr local `var'l "(AFN)" "(USD)", all
		gen `var'_usd = `var' / $exchange_rate_2016 if (period == "baseline" | period == "transfer" )
			replace `var'_usd = `var' / $exchange_rate_2018 if period == "midline"	
			replace `var'_usd = `var' / $exchange_rate_2021 if (period == "follow_up_r1" | period == "follow_up_r4")
		lab var `var'_usd "``var'l'"
	} 	
	
	* Saving  dataset with all the livestock information
	save "${lstock_transition_all}", replace 	
	
	*Collapse to get everything in one unit 
	collapse (sum) lstock_unit_cow (mean) treatment (mean) tot_lstock_value (mean) tot_lstock_value_usd (mean) tot_lstock_value_18afn (mean) tot_lstock_value_w99t (mean) tot_lstock_value_w99t_usd (mean) data_bl (mean) data_tr (mean) data_mid (mean) data_end_r1 (mean) data_end_r4 , by(period hhid)

	* Saving intermediate dataset to be used in other graphs 
	save "${lstock_transition_cowequiv}", replace 
	
	*Dropping baseline and 4th round as it will not be used in the transfer dataset 
	drop if period == "baseline"
	drop if period == "follow_up_r4"	

	*Keeping variables of interest 
	keep treatment lstock_unit_cow hhid period
	 
	 *Put it in categories, can be changed later on, separately by control and treatment 
	 
forvalues treat = 0/1 {
preserve	

	 keep if treatment == `treat'
	 
	 gen 	 lstock_cat = 0 if inrange(lstock_unit_cow, 0, 0.5)    	
	 replace lstock_cat = 1 if inrange(lstock_unit_cow, 0.5, 1)    & lstock_unit_cow != 0.5 	 	
	 replace lstock_cat = 2 if inrange(lstock_unit_cow, 1, 1.5)    & lstock_unit_cow != 1		  
	 replace lstock_cat = 3 if lstock_unit_cow > 1.5   			// More than 1.5 							
	 
	drop  lstock_unit_cow treatment  
	
	reshape wide lstock_cat , i(hhid) j(period) string
	 
	collapse 	(count) hhid , by(lstock_cat* )
	
	keep if !mi( lstock_catfollow_up_r1 ) & !mi( lstock_catmidline ) & !mi( lstock_cattransfer )
	
	rename hhid Freq

	rename lstock_cattransfer 		Transfer 
	rename lstock_catmidline 		Midline 
	rename lstock_catfollow_up_r1  	Endline	

	
	 order  Transfer Midline Endline  
	
save "${lstock_transition_graph_`treat'}", replace 	 
	 
restore		
}



