/*-----------------------------------------------------------------------------
Date:    September 8 , 2017                                                                
Revised: November 1, 2017                                                                           
Title: caloric.do                                                                      
Purpose: Calculate the caloric intake in the ACLS 2016
Author:  Germiniasi, Andrea & Wieser, Christina                                                          
Contact: a.germiniasi@gmail.com & cwieser@worldbank.org
-----------------------------------------------------------------------------*/
clear
capture log close
set more off
version 13.1
set type double, perm

use "$input\M_03.dta", clear

gen age= q3_4
gen sex= q3_5

count if age==.
count if sex==.

*NO MISSING AGE OR SEX VALUES

**1) CALCULATE AGE-SEX CALORIES REQUIREMENT

/*
The following caloric requirements will be applied by sex and age groups: -- VERFIED BY WFP
Age and Sex Kcal requirement	
S/N	Age 	Kcal Requirement	
		    Male	Female	Difference
1	0-4	    1320	1250	70
2	5-9	    1980	1730	250
3	10-14	2370	2040	330
4	15-19	2700	2120	580
5	20-59	2460	1990	470
6	60+	    2010	1780	230

Recently, we have received a new table (column 2 in Table 1) from the WFP 
that slightly differs from caloric composition (column 3) used by NRVA 2011-12 analysis
*/

gen Age_Sex_cal=.
replace Age_Sex_cal = 1320 if sex==1 & age <5
replace Age_Sex_cal = 1980 if sex==1 & age >=5 & age < 10
replace Age_Sex_cal = 2370 if sex==1 & age >=10 & age < 15
replace Age_Sex_cal = 2700 if sex==1 & age >=15 & age < 20
replace Age_Sex_cal = 2460 if sex==1 & age >=20 & age < 60
replace Age_Sex_cal = 2010 if sex==1 & age >=60 & age != .

replace Age_Sex_cal = 1250 if sex==2 & age <5
replace Age_Sex_cal = 1730 if sex==2 & age >=5 & age < 10
replace Age_Sex_cal = 2040 if sex==2 & age >=10 & age < 15
replace Age_Sex_cal = 2120 if sex==2 & age >=15 & age < 20
replace Age_Sex_cal = 1990 if sex==2 & age >=20 & age < 60
replace Age_Sex_cal = 1780 if sex==2 & age >=60 & age != .
/*
**Calculate winter adjusted age-sex caloric requirement
**Based on file shared by WFP on October 11, 2017 (Winter months and severity 11102017.xlsx & Kcal requirment based on Sex and Age.xlsx)
merge m:1 hhid using "$output/core.dta", keepusing(int_month_s int_year_s)
drop _merge

gen winter=0 
*severe winter 
foreach i in 8 11 10 24 23 17{
replace winter=1 if Province_Name==`i' & int_month_s>=8&int_month_s<=12
}
replace winter=1 if Province_Name==31 & int_month_s>=9&int_month_s<=12

*moderate winter
foreach i in 1 2 3 4 5 21 28 20 22 29 9 19 18 12 13 34 25 26 33 32{
replace winter=1 if Province_Name==`i' & int_month_s>=10&int_month_s<=12
}
replace winter=1 if Province_Name==16 & int_month_s>=8&int_month_s<=12

*soft(mild) winter: the duration of winter is reduced by one month 
foreach i in 15 6 7 14 30 27{
replace winter=1 if Province_Name==`i' & int_month_s>=11&int_month_s<=11
}

replace Age_Sex_cal = 1320 if sex==1 & age <5 & winter==1				//normal caloric requirement
replace Age_Sex_cal = 2080 if sex==1 & age >=5 & age < 10& winter==1
replace Age_Sex_cal = 2520 if sex==1 & age >=10 & age < 15& winter==1
replace Age_Sex_cal = 3000 if sex==1 & age >=15 & age < 20& winter==1
replace Age_Sex_cal = 2760 if sex==1 & age >=20 & age < 60& winter==1
replace Age_Sex_cal = 2310 if sex==1 & age >=60 & age != .& winter==1

replace Age_Sex_cal = 1250 if sex==2 & age <5 & winter==1				//normal caloric requirement
replace Age_Sex_cal = 1830 if sex==2 & age >=5 & age < 10& winter==1
replace Age_Sex_cal = 2190 if sex==2 & age >=10 & age < 15& winter==1
replace Age_Sex_cal = 2420 if sex==2 & age >=15 & age < 20& winter==1
replace Age_Sex_cal = 2290 if sex==2 & age >=20 & age < 60& winter==1
replace Age_Sex_cal = 2080 if sex==2 & age >=60 & age != .& winter==1
*/
*destring(HH_Mem_ID Unique_Mem_ID), replace 2012 code

collapse(mean)  AvgAgeSexCal=Age_Sex_cal, by(hhid)
sort hhid

preserve
	use "$input/F_23.dta", clear
	keep hhid hh_size
	sort hhid
	tempfile hsize
	save `hsize'
restore

preserve
	use "$raw/weight file", clear
rename hh_id hhid

keep hhid hh_weight ind_weight 
sort hhid
tempfile weight
save `weight'
restore

* merge from datafile (check consistency with the roster)
merge 1:1 hhid using `hsize'
drop _merge

merge 1:1 hhid using `weight'

keep hhid hh_size AvgAgeSexCal hh_weight ind_weight
saveold "$output\temp_ascal.dta",  replace


**2) CALCULATE EFFECTIVE NUMBER OF MEMBERS IN THE HOUSEHOLD
use "$input/F_23.dta", clear

*ACCOUNT FOR GUESTS EATING IN THE HOUSEHOLD IN THE LAST SEVEN DAYS AND MEALS EATEN OUT OF THE HOUSEHOLD BY
*HOUSEHOLD MEMBERS (23,2 & 23.3) THIS IS IMPORTANT TO DETERMINE ACCURATELY BECAUSE THE PROPORTION OF THE POPULATION BELOW
*MINIMUM DIETARY ENERGY CONSUMPTION"

** DEFINITION OF EFFECTIVE MEMBERS IS THE SAME AS IN POVERTY LINE FILE
** SEE Q23_1, GUEST MEALS AND MEALS EATEN AS GUEST

/*
q23_1          byte    %8.0g                 Q23.1. HH members present and dinner during last 7 days
q23_2          byte    %8.0g                 Q23.2. Meals eaten by guests of the hh in last 7 days
q23_3          byte    %8.0g                 Q23.3. Meals eaten hh members outside the home (last 7 days - checked questionnaire)

q23_7 Number of Days
q23_8 Source
q23_9 Amount
*/

/*
. des q23_4*

              storage   display    value
variable name   type    format     label      variable label
------------------------------------------------------------------------------------------------------------------------------------------
q23_4_a        byte    %8.0g                 Q23.4.a. Meals eaten yesterday by children under 5
q23_4_b        byte    %8.0g                 Q23.4.b. Meals eaten yesterday by boys 5 - 17 yrs
q23_4_c        byte    %8.0g                 Q23.4.c. Meals eaten yesterday by girls 5 - 17 years
q23_4_d        byte    %8.0g                 Q23.4.d. Meals eaten yesterday by adult men
q23_4_e        byte    %8.0g                 Q23.4.e. Meals eaten yesteray by adult women
q23_4_f        byte    %8.0g                 Q23.4.f. Meals eaten yesterday by elderly 65+

. su q23_4*

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
    q23_4_a |     14395    4.277041    1.413063          0         16
    q23_4_b |     14239    3.101763    .6144503          0         15
    q23_4_c |     13517    3.049567    .5831808          0         18
    q23_4_d |     19153    2.920535    .4262099          0         15
    q23_4_e |     19547    2.944032    .3378303          0         12
-------------+--------------------------------------------------------
    q23_4_f |      3406    2.738403    .8855036          0          9
	
bys hhid: egen meals_yest = sum(q23_4_a q23_4_b q23_4_c q23_4_d q23_4_e q23_4_f)

gen sh_child = q23_4_a/meals_yest
egen sh_boygirl = sum(q23_4_b q23_4_c)/meals_yest
egen sh_adult = sum(q23_4_d q23_4_e)/meals_yest
gen sh_old = q23_4_f/meals_yest

local adj_child = ?
local adj_boygirl = ?
local adj_old = ?

gen meals_week = 21*(`adj_child'*sh_child + `adj_boygirl'*sh_boygirl + sh_adult + `adj_old'*sh_old)

gen EffHHmember = (q23_1*21 - zz + q23_2)/meals_week
*/

gen zz = q23_3
replace zz = q23_1*21 if q23_3 > q23_1 *21 & q23_3!=.a
gen EffHHmember = (q23_1*21 - zz + q23_2)/21
lab var EffHHmember "Number of effective HH members: use q23_1 and topcode meals eaten out"
drop zz
sum EffHHmember
sort hhid
keep hhid EffHHmember q23_1

tempfile eff
save `eff'


**3) RESHAPE FOOD QUANTITY FILE
use "$input\F_23.dta", clear

keep hhid q23_1 q23_2 q23_3 q23_7_* q23_8_* q23_9_*
reshape long q23_7_ q23_8_ q23_9_, i(hhid) j(item_n) string

gen item=.
replace item=0 if item_n=="Rice_High_Quality"
replace item=1 if item_n=="Rice_Low_Quality"
replace item=2 if item_n=="Wheat_Flour"
replace item=3 if item_n=="Purchased_Nan"
replace item=4 if item_n=="Barley"
replace item=5 if item_n=="Maize"
replace item=6 if item_n=="Beans"
replace item=7 if item_n=="Mung"
replace item=8 if item_n=="Chick_Peas"
replace item=9 if item_n=="Lentils"
replace item=10 if item_n=="Pasta"
replace item=11 if item_n=="Other_Bread"
replace item=12 if item_n=="Beef"
replace item=13 if item_n=="Veal"
replace item=14 if item_n=="Mutton"
replace item=15 if item_n=="Goat"
replace item=16 if item_n=="Chicken"
replace item=17 if item_n=="Liver"
replace item=18 if item_n=="Dried_Meat"
replace item=19 if item_n=="Fish"
replace item=20 if item_n=="Other_Meat"
replace item=21 if item_n=="Milk_Fresh"
replace item=22 if item_n=="Milk_Powdered"
replace item=23 if item_n=="Yogurt"
replace item=24 if item_n=="Curd"
replace item=25 if item_n=="Krut"
replace item=26 if item_n=="Dogh"
replace item=27 if item_n=="Ghee"
replace item=28 if item_n=="Butter"
replace item=29 if item_n=="Cheese"
replace item=30 if item_n=="Eggs"
replace item=31 if item_n=="Other_Dairy"
replace item=32 if item_n=="Vegetable_Oil"
replace item=33 if item_n=="Animal_Fat"
replace item=34 if item_n=="Other_Oils"
replace item=35 if item_n=="Potato"
replace item=36 if item_n=="Sweet_Potato"
replace item=37 if item_n=="Onion"
replace item=38 if item_n=="Tomato"
replace item=39 if item_n=="Okra"
replace item=40 if item_n=="Spinach"
replace item=41 if item_n=="Cauliflower"
replace item=42 if item_n=="Eggplant"
replace item=43 if item_n=="Carrots"
replace item=44 if item_n=="Pumpkin"
replace item=45 if item_n=="Cucumber"
replace item=46 if item_n=="Radish"
replace item=47 if item_n=="Turnip"
replace item=48 if item_n=="Cabbage"
replace item=49 if item_n=="Leek"
replace item=50 if item_n=="Baracoli"
replace item=51 if item_n=="Hot_Pepper"
replace item=52 if item_n=="Wild_Leafy"
replace item=53 if item_n=="Coriander"
replace item=54 if item_n=="Mint"
replace item=55 if item_n=="Dried_Tomatoes"
replace item=56 if item_n=="Dried_Vegetables"
replace item=57 if item_n=="Pickled_Vegetables"
replace item=58 if item_n=="Green_Beans"
replace item=59 if item_n=="Other_Vegetables"
replace item=60 if item_n=="Apple"
replace item=61 if item_n=="Grapes"
replace item=62 if item_n=="Melon"
replace item=63 if item_n=="Peach"
replace item=64 if item_n=="Dried_Apricots"
replace item=65 if item_n=="Orange"
replace item=66 if item_n=="Pomegranate"
replace item=67 if item_n=="Plum"
replace item=68 if item_n=="Pear"
replace item=69 if item_n=="Banana"
replace item=70 if item_n=="Raisins"
replace item=71 if item_n=="Fresh_Mulberries"
replace item=72 if item_n=="Dried_Mulberries"
replace item=73 if item_n=="Mangoes"
replace item=74 if item_n=="Walnuts"
replace item=75 if item_n=="Pistachio"
replace item=76 if item_n=="Almonds"
replace item=77 if item_n=="Other_Fruit"
replace item=78 if item_n=="White_Sugar"
replace item=79 if item_n=="Brown_Sugar"
replace item=80 if item_n=="Honey"
replace item=81 if item_n=="Chocolates"
replace item=82 if item_n=="Black_Tea"
replace item=83 if item_n=="Green_Tea"
replace item=84 if item_n=="Bottled"
replace item=85 if item_n=="Other_Beverages"
replace item=86 if item_n=="Salt"
replace item=87 if item_n=="Black_Pepper"
replace item=88 if item_n=="Ginger_Garlic"
replace item=89 if item_n=="Tomato_Sauce"
replace item=90 if item_n=="Mixed_Spices"
replace item=91 if item_n=="Other_Spices"
replace item=201 if item_n=="Fresh_Apricots"

foreach i in 7 8 9 {
	cap rename q23_`i'_ q23_`i'
}
recode q23_8 (9=.)
label define source 1 "Purchase" 2 "Own production" 3 "Bartered/payment in kind" 4 "Borrowed/taken on credit" 5 "Received as gift" 6 "Food aid" 
label val q23_8 source

replace item=205 if item==2 & q23_8==2
replace item_n="Wheat_local_farm_gate" if item==205

capture rename q23_9_ q23_9
tabstat q23_9, by(item) stat(mean p50 sd p10 p90)

tempfile junk_food
save `junk_food', replace

use `junk_food', clear

*ADJUST MEASUREMENT UNITS (convert everything in KG)
*1 ITEMS MEASURED IN GRAMS black tea, green tea, black pepper + additional items 2016: Ginger, Tomato Sauce, Mixed Spices, Other spices 
replace q23_9= q23_9/1000 if (item == 82|item == 83|item == 87|item == 88|item == 89|item == 90|item == 91)

*2 ITEMS MEASURED IN PIECES (nan, eggs, mangoes, bananas - edible portion only)
* average-sized banana weighs 83 grams 
replace q23_9=q23_9*0.083 if item == 69
* one piece of nan 200g
replace q23_9=q23_9*0.2 if item == 3
* average sized egg 59g
replace q23_9=q23_9*0.059 if item == 30
* average size mango 215g 
replace q23_9=q23_9*0.215 if item == 73  // email Sept 30 from Ahmad Khalid (he confirmed)
* average size cauliflower 750g
replace q23_9=q23_9*0.75 if item == 41


**3) MERGE CALORIE VALUES IN FOOD ITEMS
sort item
merge m:1 item using "$output\nutrients_16-17.dta"   // using WFP data 
											  // vs nutrients_12: note correct caloric contenct for shelled nuts 
											  // and caloric info for residual cagegories [e.g. "other meat"])
assert _merge==3
drop _merge
drop kcal100g kcaledible

/* nutrients_16
. merge m:1 item using "$output\nutrients_16-17.dta" 

    Result                           # of obs.
    -----------------------------------------
    not matched                             0
    matched                         1,825,096  (_merge==3)
    -----------------------------------------
*/

foreach var in 11 20 31 34 50 59 77 91 201 {   // item 50 is "Baracoli" (n/a in 2016)
	di "`var'"
	sum q23_9 if item==`var'
}

**DROP ITEMS IN "OTHER" CATEGORIES
*ITEM DROPPED IN 2007-08
*drop if inlist(item,11,20,31,59,77,85,91)
/*
11	other_bread
20	other_meat
31	other_dairy
59	other_vegetables
77	other_fruit
85	other_beverages  -- already not available in the caloric table (fooditem)
91	other_spices     -- already not available in the caloric table (fooditem)

. tab fooditem if inlist(item,11,20,31,59,77,85,91)

               fooditem |      Freq.     Percent        Cum.
------------------------+-----------------------------------
            Other Fruit |     19,838       20.00       20.00
    Other Meat and fish |     19,838       20.00       40.00
Other bread and cereals |     19,838       20.00       60.00
   Other dairy products |     19,838       20.00       80.00
       Other vegetables |     19,838       20.00      100.00
------------------------+-----------------------------------
                  Total |     99,190      100.00
*/

*ITEMS DROPPED IN 2011-12
*NOTE--FRESH APRICOTS DROPPED!! 
*BROCOLI DROPPED--HAS NO PRICE DATA
*BEVERAGES, SALT ETC WITH ZERO CALORIES DROPPED

/*
drop if inlist(item,11,20,31,34,50,59,77,82,83,84,85,86,91,201)   // ATTENTION: command with nutrients_12

11	other_bread
20	other_meat
31	other_dairy
34	Other_Oil
50	#N/A           // brocoli   (availble only in the caloric table)
59	other_vegetables
77	other_fruit
82	Black_tea  			-- already not available in the caloric table (fooditem)
83	Green_tea   		-- already not available in the caloric table (fooditem)
84	Bottled       		-- already not available in the caloric table (fooditem)
85	other_beverages     -- already not available in the caloric table (fooditem)
86	Salt
91	other_spices        -- already not available in the caloric table (fooditem)
201	Fresh Apricots

. tab fooditem if inlist(item,11,20,31,34,50,59,77,82,83,84,85,86,91,201)

               fooditem |      Freq.     Percent        Cum.
------------------------+-----------------------------------
        Fresh Appricots |     19,838       14.29       14.29
            Other Fruit |     19,838       14.29       28.57
    Other Meat and fish |     19,838       14.29       42.86
Other bread and cereals |     19,838       14.29       57.14
   Other dairy products |     19,838       14.29       71.43
        Other oils/ fat |     19,838       14.29       85.71
       Other vegetables |     19,838       14.29      100.00
               broccoli |          1        0.00      100.00
------------------------+-----------------------------------
                  Total |    138,867      100.00
*/

* verify what we want to drop (besides _merge != 3)
drop if inlist(item,11,20,31,34,59,77,82,83,84,85,86,91,201)

gen calitem =  q23_9* kcalskg

**4) SUM CALORIES AT HH LEVEL
collapse (sum) calitem, by(hhid)

sort hhid
merge 1:1 hhid using "$output\temp_ascal.dta"
drop _merge
sort hhid
merge 1:1 hhid using `eff'
drop _merge

replace EffHHmember = hh_size if EffHHmember == .
replace EffHHmember = . if hh_size == 0

count if EffHHmember==0
*61
replace EffHHmember=q23_1 if EffHHmember<1

rename calitem khh
*gen kpd=khh/(q23_1*7) 
gen kpd=khh/(EffHHmember*7)  //  61 missing

label var khh "Kcal per HH per week"
label var kpd "Kcals per person per day"

**5) CALCULATE FOOD INSECURE HH

*gen Foodinsec = kpd<AvgAgeSexCal
*replace Foodinsec = . if kpd==.
*label var Foodinsec "Food insecurity index"

**USE FSI2 AND FSI3
gen fsi2 = (khh/(q23_1*7))<AvgAgeSexCal 
replace fsi2 = . if kpd == .
label var fsi2 "Caloric deficiency: using Q23_1 and age-sex adjustment"

gen fsi3 = (khh/(q23_1*7))<2100 
replace fsi3 = . if kpd == .
label var fsi3 "Caloric deficiency: using Q23_1 size and 2,100 Kcal"

sort hhid
saveold "$output\fsi.dta",  replace

merge 1:1 hhid using "$output\core.dta"
// quarters defined in core.dta

sum fsi2 fsi3 [aw=ind_weight]

table quarter2 [aw=ind_weight], c(mean fsi2 mean fsi3) row
table quarter2 [aw=ind_weight] , by (urru) c(mean fsi2 mean fsi3) row

saveold "$output\caloric.dta", replace

/*--------------------------------End of do file--------------------------------*/
