*********************************************************************
*DURABLE GOODS ALCS 2017- CHECK DATA AND CONSTRUCT AGGREGATES
*TABULATE AND COMPARE TO NRVA 2007-08 
*Zihao "Tobias" Wang & Christina Wieser
*contact zwang5@worldbank.org; cwieser@worldbank.org
*********************************************************************

/* -----------------------------------------------------------------------
 1. Cleaning
    1.1 clean data and check data quality 
	1.2 check range of values
    1.3 Outliers detection (mean+3*SD)
 2. Service Values
 3. Cleaning-Second Section of Asset Values   
    3.1 data quality 
	3.2 Outliers--three methods 
        3.2.1 method 1: 5 times the 99 percentile
		3.2.2 method 2: mean+3SD
		3.2.3 method 3: median+3*interquartile range	
	3.3 recode value "999999" to "."
 4. Service Values-Second Section of Assets   
 5. Service Values-All Assets
 6. Tabulation Of Assets- 2017    
	6.1 2017- mean number of major assets by sector
	6.2 percentage of hholds that own major assets 
    6.3: 2017- MEAN NUMBER OF MINOR ASSETS BY SECTOR
    6.4: PERCENTAGE OF HHOLDS THAT OWN THE MINOR ASSETS
	
	N.B.:
	Module No. changed, in accordance with the 2011-12 NRVA questionnaire. 
	a. H_01 H_02 (16-17 ALCS) to M_01_02 (11-12 NRVA) 
	b. H_03 (16-17 ALCS) to M_03 (11-12 NRVA) 
	c. H_04 (16-17 ALCS) to M_04 (11-12 NRVA) 
	d. H_05 (16-17 ALCS) to M_05 (11-12 NRVA)
	e. H_06 (16-17 ALCS) to M_06 (11-12 NRVA) 
	f. H_07 (16-17 ALCS) to M_07a M_07b M_07c (11-12 NRVA) 
	g. H_08 (16-17 ALCS) to M_09 (11-12 NRVA) 
	h. H_09 (16-17 ALCS) to M_10 (11-12 NRVA)
	i. H_10 (16-17 ALCS) to M_13 (11-12 NRVA)
	j. H_11 (16-17 ALCS) to M_12 (11-12 NRVA)
	k. H_12 (16-17 ALCS) to M_08 (11-12 NRVA)
	l. H_13 (16-17 ALCS) to M_11 (11-12 NRVA)
	m. H_21 (16-17 ALCS) to F_21 (11-12 NRVA) 
	n. H_22 (16-17 ALCS) to F_22 (11-12 NRVA) 
	o. H_23 (16-17 ALCS) to F_23 (11-12 NRVA)
	p. H_25 (16-17 ALCS) to F_24 (11-12 NRVA)
	
-------------------------------------------------------------------------- */ 

version 13
clear
capture log close
set logtype text
capture log close
log using "$logfolder\durables.txt", replace
set more off
set type double, perm

***************************************************************************
*1 CLEANING
***************************************************************************
*1.1 clean data and check data quality 
*CHECK DATA QUALITY
use "$input/M_07b.dta", clear 
bysort hhid: gen j= _n
count if j==1
*19838-->ALL HOUSEHOLDS IN THE MAIN DATA SET ARE INCLUDED IN THE DURABLES FILE.
sum hh_weight ind_weight if j==1
drop j

*CHECK IF ANY HHOLDS REPORT BOTH SALE AND PURCHASE PRICE
sum if q7_4!=. & q7_5!=.
/*    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
        hhid |          0
   hh_weight |          7    219.5714    148.1495         41        420
  ind_weight |          7    1162.143    652.7721        164       2100
       asset |          7    10.57143    4.755949          5         17
        q7_3 |          7    .8571429    .3779645          0          1
        q7_4 |          7    55064.29    130501.8        350     350000
        q7_5 |          7    97557.14    167223.2          0     380000*/
		
*-> SEVEN OBS WITH VALUES FOR BOTH PURCHASE AND RESALE VALUE. SIX WERE PURCHASED IN THE LAST 12 MONTHS
replace q7_5=. if q7_3==1 & q7_4!=. & q7_5!=.

*CHECK IF THRE ARE ANY RECORDS WHERE HH REPORTED NEITHER VALUES (PURCHASE OR RESALE)
gen val = .
replace val =  q7_4
replace val =  q7_5 if val==.
su if val==.
/*  Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
Household_~e |          0
       asset |      6,666     8.60036    3.565092          1         18
        q7_3 |      6,620    .0231118    .1502699          0          1
        q7_4 |          0
        q7_5 |          0
-------------+---------------------------------------------------------
         val |          0
*/
*-> IN 2007-08, THERE WERE 342 RECORDS OUT OF 71,488 THAT DID NOT REPORT ANY VALUES OF ASSET
* in 2011-12, there were 1,719 out of 86,582 OBS reported no value of assets
* ALCS 2016-17, 6,620 out 105,226 OBS reported no value of assets 	

*incoporate stratum, district and provincial code 
merge m:1 hhid using "$output/core.dta"
drop _merge
*drop observations with no asset
drop if asset==. 

*1.2: CHECK RANGE OF VALUES. 9999999 is "I don't know"
count if val==9999999
*5 obs have values of 9999999
capture program drop miss
program define miss
     capture drop m_`1'
     gen     m_`1' = 0
     replace m_`1' = 1 if (`1' == 9 | `1' == 99 | `1' == 999 |  `1' == 99999 | `1' == 999999 | `1' == 6666666  |`1' == 8888888 |`1' == 9999999)  
end
miss val
replace val=. if m_val==1
tempfile topcoding						
saveold `topcoding', version(13)		

/*================================================================================================================
* Detection and replacing outliers: mean+3*SD    
*================================================================================================================
We detect outliers at the provincial level and replace outliers with medians in the sequence of: 
1.  EA if at least 6 households have non-missing and non-outlier values
2.	urban district/rural district if at least 20 households have non-missing and non-outlier values
3.  district if at least 20 households have non-missing and non-outlier values
4.	urban province/by rural province if at least 20 households have non-missing and non-outlier values
5. 	urban/ rural nation if at least 20 households have non-missing and non-outlier values
6. 	national median
================================================================================================================*/
use `topcoding', clear  

gen lnval=ln(val)

* generate outlier flag
gen byte flag = 0
la var flag "flagged as an outlier"
cap la def flag 0 "Not an outlier" 1 "Outlier" 2 "N.A."
la val flag flag

* gen separate clean value variable
gen val_raw = val
label var val_raw "value of asset (Afs) - raw data"
label var val "value of asset (Afs) - outlier cleaned"

local sigma = 3

rename asset Asset
clonevar asset=Asset
*Create unique district codes
gen _district = string(District_Code, "%02.0f")
gen _province = string(Province_Code, "%02.0f")
egen district = concat(_province _district)
destring district, replace
drop _district _province

foreach i in ea rd ud d rp up rn un n {                  
	gen med_`i'=.
}
	
qui levelsof asset, local(asset)
foreach a of local asset {

	qui levelsof Province_Code, local(Province_Code)
	foreach p of local Province_Code {
		
		qui sum lnval [aw=hh_weight] if !mi(val_raw) & Province_Code == `p' & asset==`a' 
			
		* When the variance of lnval is greater than zero we detect and replace outliers
		qui replace flag=2 if (r(Var) == 0 | r(Var) ==.) & Province_Code == `p' & asset==`a' & !mi(lnval) /* not possible to detect outliers */

		if r(Var) != 0 & r(Var) !=. {

			local what: label (asset) `a'
			local where: label (Province_Code) `p'
			qui dis in yellow "(`a') - `what' - `where'"
				
			qui sum lnval [aw=hh_weight] if !mi(val_raw) & Province_Code==`p' & asset==`a', d
			loc amean_`a' = r(mean)
			loc amed_`a' = r(p50)
			loc asd_`a' = r(sd)
			loc iqr_`a' = r(p75) - r(p25)
			
			*Outlier defined as: value of a particular asset is greater than 3 standard deviations of the mean of the logarithm of the original variable	
			qui replace flag = 1 if (lnval - `amean_`a'') > `sigma'*`asd_`a'' & Province_Code==`p' & asset==`a' & !mi(lnval)		
		}
	}	
}	

*input method2(the lowest value of outliers) to the table 
sleep 1000
putexcel set "$output/temp/durables/durables_sec1.xlsx", sheet(Asset_Dcrip) modify 
local row=2

bysort asset Province_Code: egen lb_m2=min(val) if flag==1

qui levelsof asset, local(asset)
foreach x of local asset{
     local row=`row'+1
	 quiet putexcel A`row' = ("Item") B`row' = ("Prov") C`row' = ("N") D`row' = ("Mean") E`row' = ("Median") F`row' = ("Method1") G`row'=("Nr of Outliers") H`row' = ("Method2") I`row'=("Nr of Outliers") J`row' = ("Method3") K`row'=("Nr of Outliers") L`row' = ("P99") M`row' = ("r(max)")
	 local row=`row'+1
     
	 qui levelsof Province_Name, local(Province_Name)
	 foreach y of local Province_Name{
	        qui sum lb_m2 [aw=hh_weight] if !mi(val) & asset== `x' & Province_Code==`y', d
		    return list 
			sleep 1000
	        quiet putexcel A`row' = ("Item`x'") B`row' = ("Prov`y'") 
			quiet capture putexcel H`row' = ((`r(mean)')/68) 
        
		    foreach i in H {
		    *keep two decimals 
			sleep 1000
            putexcel `i'`row'=nformat("number_d2")
		    }
		    local row=`row'+1
     }
}

*Create the minimum # of non-missing non-outlier obs to be replaced with medians
gen n=1 if val!=. & flag==0
bys cid asset: egen nr_ea=total(n)						//Nr of obs by EA for each asset
bys district asset urru: egen nr_dur=total(n)			//Nr of obs by urban/rural district for each asset
bys district asset: egen nr_d=total(n)                  //Nr of obs by district for each asset    
bys Province_Code asset urru: egen nr_p=total(n)		//Nr of obs by urban/rural province for each asset
bys asset urru: egen nr_n=total(n)						//Nr of obs by urban/rural in nation for each asset
drop n

* Median EA
	qui levelsof cid, local(cid)
	foreach c of local cid {
		qui levelsof asset, local(asset)
		foreach a of local asset {
			_pctile val [aw=hh_weight] if cid==`c' & asset==`a' & flag==0, p(50)
			replace med_ea = r(r1) if !mi(val) & cid== `c' & asset==`a' 
	}
}

*Median District: urban/rural 
	qui levelsof asset, local(asset)
	foreach a of local asset {
		qui levelsof district, local(district)
		foreach d of local district {
			_pctile val [aw=hh_weight] if district==`d' & asset==`a' & urru==2 & flag==0, p(50)
			replace med_rd = r(r1) if !mi(val) & district==`d' & asset==`a' & urru==2
			_pctile val [aw=hh_weight] if district==`d' & asset==`a' & urru==1 & flag==0, p(50)
			replace med_ud = r(r1) if !mi(val) & district==`d' & asset==`a' & urru==1
	}
}

*Median District:        
	qui levelsof asset, local(asset)
	foreach a of local asset {
		qui levelsof district, local(district)
		foreach d of local district {
			_pctile val [aw=hh_weight] if district==`d' & asset==`a' & flag==0, p(50)
			replace med_d = r(r1) if !mi(val) & district==`d' & asset==`a' 
	}
}

*Median urban rural Province
	qui levelsof asset, local(asset)
	foreach a of local asset {
		qui levelsof Province_Code, local(Province_Code)
		foreach p of local Province_Code {
			_pctile val [aw=hh_weight] if Province_Code==`p' & asset==`a' & urru==2 & flag==0, p(50)
			replace med_rp = r(r1) if !mi(val) & Province_Code==`p' & asset==`a' & urru==2
			_pctile val [aw=hh_weight] if Province_Code==`p' & asset==`a' & urru==1 & flag==0, p(50)
			replace med_up = r(r1) if !mi(val) & Province_Code==`p' & asset==`a' & urru==1
		}
}

*National rural and urban median
	qui levelsof asset, local(asset)
	foreach a of local asset {
			_pctile val [aw=hh_weight] if asset==`a' & urru==2 & flag==0, p(50)
			replace med_rn = r(r1) if !mi(val) & asset==`a' & urru==2
			_pctile val [aw=hh_weight] if asset==`a' & urru==1 & flag==0, p(50)
			replace med_un = r(r1) if !mi(val) & asset==`a' & urru==1
}

* National median
	qui levelsof asset, local(asset)
	foreach a of local asset {
			_pctile val [aw=hh_weight] if asset==`a' & flag==0, p(50)
			replace med_n = r(r1) if !mi(val) & asset==`a' 
}

tab flag

* Replace outliers with median values of:
	* Stage 1: median of EA if at least six observations
	* Stage 2: median of urban/rural district if at least 20 observations
    * Stage 3: median of district if at least 20 observations            
	* Stage 4: median of urban/rural province if at least 20 observations
	* Stage 5: median of urban/rural national if at least 20 observations
	* Stage 6: national median

replace val=. if flag==1										//602 outliers
replace val=med_ea if flag==1 & nr_ea>=6 & val==.				//390 replaced with EA median
replace val=med_rd if flag==1 & nr_dur>=20 & val==. & urru==2	//77  replaced with rural district median 
replace val=med_ud if flag==1 & nr_dur>=20 & val==. & urru==1	//38  replaced with urban district median 
replace val=med_d  if flag==1 & nr_d>=20 & val==.               //16  replaced with district median      
replace val=med_rp if flag==1 & nr_p>=20 & val==. & urru==2		//67  replaced with rural province median
replace val=med_up if flag==1 & nr_p>=20 & val==. & urru==1		//2   replaced with urban province median
replace val=med_rn if flag==1 & nr_n>=20 & val==. & urru==2		//5   replaced with rural national median
replace val=med_un if flag==1 & nr_n>=20 & val==. & urru==1		//7   replaced with urban national median            
replace val=med_n if flag==1 & val==.							//0   replaced with national median 

drop med_* nr_*					
				
local row=2
sleep 1000
putexcel set "$output/temp/durables/durables_sec1.xlsx", sheet(Asset_Dcrip) modify
*the distribution of outliers by asset and province
qui levelsof asset, local(asset)
foreach x of local asset {
	local row=`row'+1
	quiet putexcel I`row'=("Nr of Outliers") 
	local row=`row'+1
    qui levelsof Province_Name, local(Province_Name)
	foreach y of local Province_Name{
		count if flag==1 & asset==`x' & Province_Code==`y'
		return list
	    quiet putexcel I`row'=(`r(N)') 
		local row=`row'+1
	}
}

*Descriptives post-cleaning:
decode Province_Name , gen(province)
	* by asset
	preserve
		gen outlier=flag==1
		gen na=flag==2
		collapse (mean) mean=val (median) median=val	 		///
				 (firstnm) asset (count) n=val	 				///
				 (sum) outlier na, by(Asset)
		format mean median %9.2fc
		label var asset "AssetNo"
		label var n "Obs"
		label var outlier "Nr_of_Outliers"
		label var na "Flag_is_2"
		saveold "$output\temp\meanSD_asset", replace
		sleep 1000
		export excel using "$output/temp/durables/durables_sec1.xlsx", sheet("M2_stats") sheetmodify cell(A1) firstrow(varlabels)
	restore
	
	* by province
	preserve
		gen outlier=flag==1
		gen na=flag==2
		collapse (mean) mean=val (median) median=val	 		///
			(firstnm) Province_Name (count) n=val	 			///
			(sum) outlier na, by(Province_Code)
		format mean median %9.2fc
		label var Province_Name "Province Name"
		label var n "Obs"
		label var outlier "Nr_of_Outliers"
		label var na "Flag_is_2"
		saveold "$output\temp\meanSD_province", replace
		sleep 1000
		export excel using "$output/temp/durables/durables_sec1.xlsx", sheet("M2_stats") sheetmodify cell(I1) firstrow(varlabels)	
	restore	

drop province	
saveold "$output\temp\asset_meanSD", replace

***************************************************************************
* 2. Service Values 
***************************************************************************
*CALCULATE SERVICE VALUES: 
**LIFE OF ASSETS = 10 YEARS, INTEREST RATE = 4 % -> USE 14% RATE
use "$output\temp\asset_meanSD.dta", clear
gen ser = val*0.14/12
preserve
	collapse (sum) ser, by(hhid)
	sort hhid
	*tempfile a
	*saveold `a', version(13)
    saveold "$output\temp\a", replace
	restore
***CREATE ESTIMATES COMPARABLE TO 2007-08. EXCLUDE computer, washing machine, vacuum cleaner, meat grinder, bread oven, gas heater, electric fans 
drop if asset==14 | asset==2 | asset==3 | asset==4 | asset==5 | asset==7 | asset==10
ren ser ser_comp
collapse (sum) ser_comp, by(hhid)
sort hhid
*tempfile acomp
*saveold `acomp', version(13)
saveold "$output\temp\acomp.dta", replace 

***************************************************************************
* 3. Cleaning-Second Section of Asset Values                               
***************************************************************************
use "$input\M_07c.dta", clear 
*3.1: DATA QUALITY 
recode Q_7_6_Mobile_Own Q_7_7_Mobile_Sold Q_7_6_Carpets_Own Q_7_7_Carpets_Sold Q_7_6_Gilim_Own Q_7_7_Gilim_Sold Q_7_6_Blankets_Own Q_7_7_Blankets_Sold Q_7_6_Satellitedishes_Own Q_7_7_SatelliteDishes_Sold Q_7_6_SolarPanel_Own Q_7_7_SolarPanel_Sold Q_7_7_Kitchen_Utensils_Sold (0=.)
* MISSING VALUES
sum Q_7_6_Mobile_Own - Q_7_7_Kitchen_Utensils_Sold
/*  Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
Q_7_6_Mobi~n |     15,762    2.171362    4.114966          1         99
Q_7_7_Mobi~d |     15,708    9834.669     78218.4         25     999999
Q_7_6_Carp~n |      3,495    2.888984    8.914414          1         99
Q_7_7_Carp~d |      3,463    16037.79    76381.83        200     999999
Q_7_6_Gili~n |     19,562    3.757847    3.830891          1         99
-------------+---------------------------------------------------------
Q_7_7_Gili~d |     19,508    16973.38      106571         50     999999
Q_7_6_Blan~n |     19,782    10.74285    6.280201          1         99
Q_7_7_Blan~d |     19,731    22195.06    126713.7         40     999999
Q_7_6_Sate~n |      3,595    1.156328    .9489096          1          9
Q_7_7_Sate~d |      3,552    9689.144    89876.24          1     999999
-------------+---------------------------------------------------------
Q_7_6_Sola~n |     12,683    1.249547    .7436418          1          9
Q_7_7_Sola~d |     12,621    11598.89    87980.55         45     999999
Q_7_7_Kitc~d |     19,700    28692.28    152216.5         99     999999*/

*incoporate stratum, district and provincial code 
merge m:1 hhid using "$output/core.dta"
tab _merge
drop _merge

*3.2: Outliers 
*GENERATE UNIT VALUES
gen uv1 = Q_7_7_Mobile_Sold/ Q_7_6_Mobile_Own
gen uv2 = Q_7_7_Carpets_Sold/ Q_7_6_Carpets_Own
gen uv3 = Q_7_7_Gilim_Sold/ Q_7_6_Gilim_Own
gen uv4 = Q_7_7_Blankets_Sold/ Q_7_6_Blankets_Own
gen uv5 = Q_7_7_SatelliteDishes_Sold/Q_7_6_Satellitedishes_Own
gen uv6 = Q_7_7_SolarPanel_Sold/Q_7_6_SolarPanel_Own
*tempfile topcoding2
*saveold `topcoding2', version(13)
saveold "$output\temp\topcoding2", replace

/*================================================================================================================
* Outlier detection for UVs: mean+3*SD
*================================================================================================================
We detect outliers and replace missing values with medians 
according to the matrix in the sequence of: 
1.  EA if at least 6 households have non-missing and non-outlier values
2.	urban district/rural district if at least 20 households have non-missing and non-outlier values
3.  district if at least 20 households have non-missing and non-outlier values
4.	urban province/by rural province if at least 20 households have non-missing and non-outlier values
5. 	urban/ rural nation if at least 20 households have non-missing and non-outlier values
6. 	national median
================================================================================================================*/
use "$output\temp\topcoding2.dta", clear

*summary statistics
*stats are converted to exponential form and to U.S. dollar (USD 1= AFN 68) 

loc sigma=3

*Create unique district codes
gen _district = string(District_Code, "%02.0f")
gen _province = string(Province_Code, "%02.0f")
egen district = concat(_province _district)
destring district, replace
drop _district _province

foreach x of numlist 1/6 {
   foreach i in ea rd ud d rp up rn un n {                  
	gen med_`i'`x'=.
   }
}
**SOME UNIT VALUES ABOVE 5 X PCT99 in both 2016-17 and 2011-12. THIS WASNT A PROBLEM IN 2007-08.
**CLEAN VALUES THAT ARE OUT OF RANGE: REPLACE OULYING VALUES WITH 5 X PCT99
	*generate outlier flag 
    foreach x of numlist 1/6 {
	gen byte flag`x'=0 
    la var flag`x' "flagged as an outlier" 
    cap la def flag`x' 0 "Not an outlier" 1 "Outlier" 2 "N.A."
    la val flag`x' flag`x' 
	*gen logged value
	gen lnuv`x'=ln(uv`x')
    }
	
foreach x of numlist 1/6 {

    qui levelsof Province_Name, local(Province_Name)
	foreach y of local Province_Name{
	  quiet sum lnuv`x' [aw=hh_weight] if !mi(uv`x')&Province_Name==`y',d 
	  *when the variance of uv`x' is greater than zero we detect and replace outliers 
	  qui replace flag`x'=2 if (r(Var)==0|r(Var)==.) & Province_Name==`y' & !mi(lnuv`x')
	  
	  if r(Var)!=0 & r(Var)!=. {
	     quiet sum lnuv`x' [aw=hh_weight] if Province_Name==`y'&!mi(uv`x'), d
		 loc amean_`x'=r(mean)
		 loc amed_`x'=r(p50)
		 loc asd_`x'=r(sd)
		 loc ap99_`x'=r(p99)
		 
		 *Outlier defined as: value of a particular asset is greater than mean plus 3 times the sd of the log scale
		 qui replace flag`x'=1 if lnuv`x'>`amean_`x''+`sigma'*`asd_`x''&Province_Name==`y'& !mi(lnuv`x')
			 }
      }
}

*input method2(lowest value of outliers)to the table 
sleep 1000
putexcel set "$output/temp/durables/durables_sec1.xlsx", sheet(Asset2_Dcrip) modify 
local row=2
foreach x of numlist 1/6 {
bysort Province_Code: egen lb_m2`x'=min(uv`x') if flag`x'==1
}

foreach x of numlist 1/6 {
     local row=`row'+1
	 quiet putexcel A`row' = ("Item") B`row' = ("Prov") C`row' = ("N") D`row' = ("Mean") E`row' = ("Median") F`row' = ("Method1") G`row'=("Nr of Outliers") H`row' = ("Method2") I`row'=("Nr of Outliers") J`row' = ("Method3") K`row'=("Nr of Outliers") L`row' = ("P99") M`row' = ("r(max)")
	 local row=`row'+1
     
	 qui levelsof Province_Name, local(Province_Name)
	 foreach y of local Province_Name{
	        qui sum lb_m2`x' [aw=hh_weight] if !mi(uv`x') & Province_Code==`y', d
		    return list 
			putexcel A`row' = ("Item`x'") B`row' = ("Prov`y'")
	        quiet capture putexcel H`row' = ((`r(mean)')/68) 
        
		    foreach i in H {
		    *keep two decimals 
            putexcel `i'`row'=nformat("number_d2")
		    }
		    local row=`row'+1
     }
}

*Create the minimum # of non-missing non-outlier obs to be replaced with medians
    foreach x of numlist 1/6 {
	gen n`x'=1 if !mi(uv`x') & flag`x'==0
    }
	foreach x of numlist 1/6 {
    bys cid: egen nr_ea`x'=total(n`x')						//Nr of obs by EA for each asset
	bys district urru: egen nr_dur`x'=total(n`x')		    //Nr of obs by urban/rural district for each asset
	bys district: egen nr_d`x'=total(n`x')                  //Nr of obs by district for each asset              
	bys Province_Code urru: egen nr_p`x'=total(n`x')		//Nr of obs by urban/rural province for each asset
	bys urru: egen nr_n`x'=total(n`x')						//Nr of obs by urban/rural in nation for each asset
}

* Median EA
	qui levelsof cid, local(cid)
	 foreach c of local cid {
       foreach x of numlist 1/6 {
			_pctile uv`x' [aw=hh_weight] if cid==`c' & flag`x'==0, p(50)
			replace med_ea`x' = r(r1) if !mi(uv`x') & cid==`c' 
	}
}

*Median District: urban/rural 
       foreach x of numlist 1/6 {
		qui levelsof district, local(district)
		foreach d of local district {
			_pctile uv`x' [aw=hh_weight] if district==`d' & urru==2 & flag`x'==0, p(50)
			replace med_rd`x' = r(r1) if !mi(uv`x') & district==`d' & urru==2
			_pctile uv`x' [aw=hh_weight] if district==`d' & urru==1 & flag`x'==0, p(50)
			replace med_ud`x' = r(r1) if !mi(uv`x') & district==`d' & urru==1
	}
}

*Median District 
      foreach x of numlist 1/6 {
		qui levelsof district, local(district)
		foreach d of local district {
			_pctile uv`x' [aw=hh_weight] if district==`d' & flag`x'==0, p(50)
			replace med_d`x' = r(r1) if !mi(uv`x') & district==`d' 
	}
}

*Median urban rural Province
      foreach x of numlist 1/6 {
		qui levelsof Province_Code, local(Province_Code)
		foreach p of local Province_Code {
			_pctile uv`x' [aw=hh_weight] if Province_Code==`p' & urru==2 & flag`x'==0, p(50)
			replace med_rp`x' = r(r1) if !mi(uv`x') & Province_Code==`p' & urru==2
			_pctile uv`x' [aw=hh_weight] if Province_Code==`p' & urru==1 & flag`x'==0, p(50)
			replace med_up`x' = r(r1) if !mi(uv`x') & Province_Code==`p' & urru==1
		}
}

*National rural and urban median
      foreach x of numlist 1/6 {
			_pctile uv`x' [aw=hh_weight] if urru==2 & flag`x'==0, p(50)
			replace med_rn`x' = r(r1) if !mi(uv`x') & urru==2
			_pctile uv`x' [aw=hh_weight] if urru==1 & flag`x'==0, p(50)
			replace med_un`x' = r(r1) if !mi(uv`x') & urru==1
}

* National median
      foreach x of numlist 1/6 {
			_pctile uv`x' [aw=hh_weight] if flag`x'==0, p(50)
			replace med_n`x' = r(r1) if !mi(uv`x') 
}

foreach x of numlist 1/6 {
tab flag`x'
}

* Replace outliers with median values of:
	* Stage 1: median of EA if at least six observations
	* Stage 2: median of urban/rural district if at least 20 observations
	* Stage 3: median of district if at least 20 observations             
	* Stage 4: median of urban/rural province if at least 20 observations
	* Stage 5: median of urban/rural national if at least 20 observations
	* Stage 6: national median

foreach x of numlist 1/6 {
replace uv`x'=. if flag`x'==1										        
replace uv`x'=med_ea`x' if flag`x'==1 & nr_ea`x'>=6 & uv`x'==.				
replace uv`x'=med_rd`x' if flag`x'==1 & nr_dur`x'>=20 & uv`x'==. & urru==2  
replace uv`x'=med_ud`x' if flag`x'==1 & nr_dur`x'>=20 & uv`x'==. & urru==1	
replace uv`x'=med_d`x' if flag`x'==1  & nr_d`x'>=20 & uv`x'==.              
replace uv`x'=med_rp`x' if flag`x'==1 & nr_p`x'>=20 & uv`x'==. & urru==2	
replace uv`x'=med_up`x' if flag`x'==1 & nr_p`x'>=20 & uv`x'==. & urru==1	
replace uv`x'=med_rn`x' if flag`x'==1 & nr_n`x'>=20 & uv`x'==. & urru==2	
replace uv`x'=med_un`x' if flag`x'==1 & nr_n`x'>=20 & uv`x'==. & urru==1	
replace uv`x'=med_n`x' if flag`x'==1 & uv`x'==.							    
}
saveold "$output\temp\TEMP7.dta", replace				                   
drop med_* nr_*

/*-------------------
uv1: 164 outliers. 129 replaced with EA median, 28 replaced with rural district median, 7 replaced with rural province median

uv2: 40 outliers. 9 replaced with EA median, 6 replaced with rural district median, 11 replaced with urban district median, ///
2 replaced with district median, 9 replaced with rural province median, 2 replaced with rural national median, 1 replaced with urban national median

uv3: 159 outliers. 146 replaced with EA median, 5 replaced with rural district median, 6 replaced with urban district median, ///
2 replaced with rural province median

uv4: 164 outliers. 164 replaced with EA median

uv5: 46 outliers. 12 replaced with EA median, 14 replaced with rural district median, 4 replaced with urban district median, ///
4 replaced with district median, 11 replaced with rural province median, 1 replaced with rural national median 

uv6: 146 outliers. 120 replaced with EA median, 15 replaced with rural district median, 1 replaced with urban district median,///
2 replaced with district median, 7 replaced with rural province median, 1 replaced with urban province median
-------------------*/

local row=2
sleep 1000
putexcel set "$output/temp/durables/durables_sec1.xlsx", sheet(Asset2_Dcrip) modify
*the distribution of outliers by asset and province
foreach x of numlist 1/6 {
	local row=`row'+1
	quiet putexcel I`row'=("Nr of Outliers") 
	local row=`row'+1
    qui levelsof Province_Name, local(Province_Name)
	foreach y of local Province_Name{
		count if flag`x'==1 & Province_Code==`y'
		return list
	    quiet putexcel I`row'=(`r(N)') 
		local row=`row'+1
	}
}

*Descriptives post-cleaning:
decode Province_Name , gen(province)

    *by asset 
    preserve  	 
     foreach x of numlist 1/6 {
	     gen outlier`x'=flag`x' if flag`x'==1 
         gen na`x'=flag`x' if flag`x'==2 
		 }
     collapse (count) n1=uv1  (sum) outlier1 (count) n2=uv2 (sum) outlier2  ///
	 (count) n3=uv3 (sum) outlier3 (count) n4=uv4 (sum) outlier4 ///
	 (count) n5=uv5 (sum) outlier5 (count) n6=uv6 (sum) outlier6 
	 sleep 1000
     export excel using "$output/temp/durables/durables_sec1.xlsx", sheet("A2_M2_outliers") sheetmodify cell(A1) firstrow(variables) 
	 restore 

	*by province
	preserve 
	 foreach x of numlist 1/6 {
	 gen outlier`x'=flag`x' if flag`x'==1 
     gen na`x'=flag`x' if flag`x'==2 
	}
    collapse (firstnm) Province_Name (count) n1=uv1  (sum) outlier1 (count) n2=uv2 (sum) outlier2      ///
	(count) n3=uv3 (sum) outlier3 (count) n4=uv4 (sum) outlier4                ///
	(count) n5=uv5 (sum) outlier5 (count) n6=uv6 (sum) outlier6, by(Province_Code) 
	sleep 1000
    export excel using "$output/temp/durables/durables_sec1.xlsx", sheet("A2_M2_outliers") sheetmodify cell(A4) firstrow(variables) 
	restore 

drop province	
saveold "$output\temp\asset2_meanSD", replace

*3.3 recode value "999999" to ".".
use "$output\temp\asset2_meanSD", clear
gen val_mobile= uv1*Q_7_6_Mobile_Own
gen val_carpet= uv2*Q_7_6_Carpets_Own
gen val_gilim=  uv3*Q_7_6_Gilim_Own
gen val_blankets=  uv4* Q_7_6_Blankets_Own
gen val_Satellitedishes_Own=uv5*Q_7_6_Satellitedishes_Own
gen val_SolarPanel=uv6*Q_7_6_SolarPanel_Own
sum val_mobile - val_SolarPanel
/*  Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
  val_mobile |     15,705    4213.892    12714.38         25     999999
  val_carpet |      3,463    12897.46    42863.89        200     999999
   val_gilim |     19,508    16845.23    105483.4         50     999999
val_blankets |     19,731    22178.17    126594.3         40     999999
val_Satell~n |      3,551    2014.326    5504.212          1      60000
-------------+---------------------------------------------------------
val_SolarP~l |     12,618    4503.063    9234.497         45     180000 */

foreach var in val_mobile val_carpet val_gilim val_blankets val_Satellitedishes_Own val_SolarPanel Q_7_7_Kitchen_Utensils_Sold{
replace `var'=. if `var'==999999
}

***************************************************************************
* 4. Service Values-Second Section of Assets.                              
***************************************************************************
**CALCULATE SERVICE VALUES
**LIFE OF ASSETS = 10 YEARS, INTEREST RATE = 4 % -> USE 14% RATE
egen zz= rsum(val_mobile val_carpet val_gilim val_blankets val_Satellitedishes_Own val_SolarPanel Q_7_7_Kitchen_Utensils_Sold)
gen serb = zz*0.14/12
sort hhid
**CALCULATE SERVICE VALUES COMPARABLE TO 2007-08, excluding solar panel and satellite dishes
**LIFE OF ASSETS = 10 YEARS, INTEREST RATE = 4 % -> USE 14% RATE
egen aa= rsum(val_mobile val_carpet val_gilim val_blankets Q_7_7_Kitchen_Utensils_Sold)
gen serb_comp = aa*0.14/12
keep hhid serb serb_comp
sort hhid
*tempfile b
*saveold `b', version(13)
saveold "$output\temp\b", replace 

***************************************************************************
* 5. Service Values-all assets                                             
***************************************************************************
use "$output\temp\a", clear
merge hhid using "$output\temp\b"
tab _merge
drop _merge
egen durables = rsum(ser serb)
la var durables "Monthly service value from durables"
sort hhid
merge hhid using "$output\temp\acomp"
tab _merge
drop _merge
egen durables_comp = rsum(ser_comp serb_comp)
la var durables_comp "Monthly service value from durables(comparable to 07-08)"
drop ser serb ser_comp serb_comp

*2017 SUMMARY OF SERVICE VALUE OF DURABLES
sum durables , d
*2017 SUMMARY OF SERVICE VALUE OF DURABLES COMPARABLE TO 2007-08 (EXCLUDES electric fans, computer, washing machine, vacuum cleaner, meat grinder, bread oven, gas heater, solar panel and satellite dishes )
sum durables_comp , d
sort hhid
saveold "$output\temp_durables", version(13) replace

use "$output\core.dta", clear
sort hhid
merge hhid using  "$output\temp_durables"
*2017 SUMMARY OF SERVICE VALUE OF DURABLES
sum durables [aw= hh_weight], d
*2017 SUMMARY OF SERVICE VALUE OF DURABLES COMPARABLE TO 2007-08 (EXCLUDES electric fans, computer, washing machine, vacuum cleaner, meat grinder, bread oven, gas heater, solar panel and satellite dishes )
sum durables_comp [aw= hh_weight], d

****************************************************************************
* 6. TABULATION OF ASSETS- 2017                                             
****************************************************************************
use "$input\M_07a.dta", clear
by hhid, sort: gen j=_n
count if j==1
*19838
/*
sum hh_weight ind_weight if j==1
    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
   hh_weight |         10       144.1     111.023         20        375*/
*2011-12
/*  Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
   hh_weight |     20828    174.2592    182.4723         18       1563
  ind_weight |     20828    1294.162    1583.518         38      39075 */ 

merge hhid using "$output\core.dta"
ren q7_2 tot_assets
ren q7_1_a Refrigerator
ren q7_1_b Washing_Machine 
ren q7_1_c Vacuum_Cleaner 
ren q7_1_d Meat_Grinder
ren q7_1_e Bread_Oven
ren q7_1_f Stove
ren q7_1_g Gas_Heater
ren q7_1_h Sewing_Machine
ren q7_1_i Iron 
ren q7_1_j Electric_Fan
ren q7_1_k Radio
ren q7_1_l TV
ren q7_1_m VCR
ren q7_1_n Computer
ren q7_1_o Bicycle
ren q7_1_p Motorcycle
ren q7_1_q Car
ren q7_1_r Tractor
la define sector 1 "Urban" 2 "Rural+Kuchi"
la values urru 
ren urru sector

*ONLY 2 OBS FOR WHICH ALL ASSET VALUES ARE MISSING. SO MISSING TREATED AS MISSING
*TOTAL PIECES OF ASSETS EXCLUDING computer, washing machine, vacuum cleaner, meat grinder, bread oven, gas heater Electric fan
*satellite phone is also not included, because it is not in the 2016-17 survey 
egen tot_assets_comp= rsum (Refrigerator Stove Sewing_Machine Iron Radio TV VCR Bicycle Motorcycle Car Tractor)

*6.1: 2017- MEAN NUMBER OF MAJOR ASSETS BY SECTOR
table sector [aw= hh_weight], c (mean Refrigerator mean Stove mean Sewing_Machine mean Iron mean Radio ) row
table sector [aw= hh_weight], c (mean TV mean VCR mean Electric_Fan mean Bicycle mean Computer) row
table sector [aw= hh_weight], c (mean Washing_Machine mean Vacuum_Cleaner mean Meat_Grinder mean Gas_Heater mean Bread_Oven ) row
table sector [aw= hh_weight], c (mean Motorcycle mean Car mean Tractor mean tot_assets mean tot_assets_comp) row

*6.2: PERCENTAGE OF HHOLDS THAT OWN THE MAJOR ASSETS
*WHETHER OWNS OR NOT OWN
	foreach var in Refrigerator Computer Stove Sewing_Machine Iron Radio TV VCR Electric_Fan Bicycle Motorcycle Car Tractor Washing_Machine Vacuum_Cleaner Meat_Grinder Gas_Heater Bread_Oven tot_assets tot_assets_comp { //Electric_fan
		gen `var'_ysno=.
		replace `var'_ysno=0 if `var'==0
		replace `var'_ysno= 1 if `var'>=1 & `var'!=.
		}		
table sector [aw= hh_weight], c (mean Refrigerator_ysno mean Stove_ysno mean Sewing_Machine_ysno mean Iron_ysno mean Radio_ysno ) row
table sector [aw= hh_weight], c (mean TV_ysno mean VCR_ysno mean Electric_Fan_ysno mean Bicycle_ysno mean Computer_ysno) row
table sector [aw= hh_weight], c (mean Washing_Machine_ysno mean Vacuum_Cleaner_ysno mean Meat_Grinder_ysno mean Gas_Heater_ysno mean Bread_Oven_ysno ) row
table sector [aw= hh_weight], c (mean Motorcycle_ysno mean Car_ysno mean Tractor_ysno mean tot_assets_ysno mean tot_assets_comp_ysno) row

*the second section of assets 
use "$input\M_07c.dta", clear
merge hhid using "$output\core.dta"

rename Q_7_6_Mobile_Own Mobile
rename Q_7_6_Carpets_Own Carpets
rename Q_7_6_Gilim_Own Gilim
rename Q_7_6_Blankets_Own Blankets
rename Q_7_6_Satellitedishes_Own SatelliteDishes
rename Q_7_6_SolarPanel_Own SolarPanel
la define sector 1 "Urban" 2 "Rural+Kuchi"
la values urru 
ren urru sector

egen tot_assets= rsum (Mobile Carpets Gilim Blankets SatelliteDishes SolarPanel)
egen tot_assets_comp=rsum (Mobile Carpets Gilim Blankets)


*6.3: 2017- MEAN NUMBER OF MINOR ASSETS BY SECTOR
table sector [aw= hh_weight], c (mean Mobile mean Carpets mean Gilim mean Blankets) row
table sector [aw= hh_weight], c (mean SatelliteDishes mean SolarPanel) row

*6.4: PERCENTAGE OF HHOLDS THAT OWN THE MINOR ASSETS
*WHETHER OWNS OR NOT OWN
	foreach var in Mobile Carpets Gilim Blankets SatelliteDishes SolarPanel tot_assets tot_assets_comp {
		gen `var'_ysno=.
		replace `var'_ysno=0 if `var'==0
		replace `var'_ysno= 1 if `var'>=1 & `var'!=.
		}		
table sector [aw= hh_weight], c (mean Mobile_ysno mean Carpets_ysno mean Gilim_ysno mean Blankets_ysno) row
table sector [aw= hh_weight], c (mean SatelliteDishes_ysno mean SolarPanel_ysno) row

capture log close
***********************************************************************************************************************************************
