
/*================================================================================================================
* Detection and replacing outliers: mean+3*SD    
*================================================================================================================
We detect outliers at the provincial level and replace outliers with medians in the sequence of: 
1.  EA if at least 6 households have non-missing and non-outlier values
2.	urban district/rural district if at least 20 households have non-missing and non-outlier values
3.  district if at least 20 households have non-missing and non-outlier values
4.	urban province/by rural province if at least 20 households have non-missing and non-outlier values
5. 	urban/ rural nation if at least 20 households have non-missing and non-outlier values
6. 	national median
================================================================================================================*/

******************
** TOP OUTLIERS **
******************

use "$output\junk_food.dta", clear

//gen cons_pc=q23_9/hh_size if !mi(q23_9)
//label var cons_pc "Quantities consumed per capita"

gen lncons_pc=ln(cons_pc)

* generate outlier flag
gen byte flag = 0
la var flag "flagged as an outlier"
cap la def flag 0 "Not an outlier" 1 "Outlier" 2 "N.A."
la val flag flag

* gen separate clean cons_pc variable
clonevar cons_pc_raw=cons_pc
label var cons_pc_raw "Amount used in last 7 days - raw data"
label var cons_pc "Amount used in last 7 days - outlier cleaned"

local sigma = 3

*Create unique district codes
gen _district = string(District_Code, "%02.0f")
gen _province = string(Province_Code, "%02.0f")
egen district = concat(_province _district)
destring district, replace
drop _district _province

foreach i in ea rd ud d rp up rn un n {                  
	gen med_`i'=.
}
	
qui levelsof item, local(item)
foreach a of local item {

	qui levelsof Province_Code, local(Province_Code)
	foreach p of local Province_Code {
		
		qui sum lncons_pc [aw=hh_weight] if !mi(cons_pc_raw) & Province_Code == `p' & item==`a' 
			
		* When the variance of lncons_pc is greater than zero we detect and replace outliers
		qui replace flag=2 if (r(Var) == 0 | r(Var) ==.) & Province_Code == `p' & item==`a' & !mi(lncons_pc) /* not possible to detect outliers */

		if r(Var) != 0 & r(Var) !=. {

			local what: label (item) `a'
			local where: label (Province_Code) `p'
			dis in yellow "(`a') - `what' - `where'"
				
			qui sum lncons_pc [aw=hh_weight] if !mi(cons_pc_raw) & Province_Code==`p' & item==`a', d
			loc amean_`a' = r(mean)
			loc asd_`a' = r(sd)
			
			*Outlier defined as: value of a particular item is greater than 3 standard deviations of the mean of the logarithm of the original variable	
			qui replace flag = 1 if (lncons_pc - `amean_`a'') > `sigma'*`asd_`a'' & Province_Code==`p' & item==`a' & !mi(lncons_pc)		
		}
	}	
}	

save "$output/temp/QOut_temp1.dta", replace

use "$output/temp/QOut_temp1.dta", clear

*Create the minimum # of non-missing non-outlier obs to be replaced with medians
gen n=1 if cons_pc!=. & flag==0
bys cid item: egen nr_ea=total(n)						//Nr of obs by EA for each item
bys district item urru: egen nr_dur=total(n)			//Nr of obs by urban/rural district for each item
bys district item: egen nr_d=total(n)                  //Nr of obs by district for each item    
bys Province_Code item urru: egen nr_p=total(n)		//Nr of obs by urban/rural province for each item
bys item urru: egen nr_n=total(n)						//Nr of obs by urban/rural in nation for each item
drop n

save "$output/temp/QOut_temp2.dta", replace

/*
* Median EA
	qui levelsof cid, local(cid)
	foreach c of local cid {
		qui levelsof item, local(item)
		foreach a of local item {
			_pctile cons_pc [aw=hh_weight] if cid==`c' & item==`a' & flag==0, p(50)
			replace med_ea = r(r1) if !mi(cons_pc) & cid== `c' & item==`a' 
	}
}
save "$output/temp/QOut_temp3.dta", replace
*/

use "$output/temp/QOut_temp2.dta", clear
*Median District: urban/rural 
	qui levelsof item, local(item)
	foreach a of local item {
		qui levelsof district, local(district)
		foreach d of local district {
			_pctile cons_pc [aw=hh_weight] if district==`d' & item==`a' & urru==2 & flag==0, p(50)
			replace med_rd = r(r1) if !mi(cons_pc) & district==`d' & item==`a' & urru==2
			_pctile cons_pc [aw=hh_weight] if district==`d' & item==`a' & urru==1 & flag==0, p(50)
			replace med_ud = r(r1) if !mi(cons_pc) & district==`d' & item==`a' & urru==1
	}
}
save "$output/temp/QOut_temp4.dta", replace

*Median District:        
	qui levelsof item, local(item)
	foreach a of local item {
		qui levelsof district, local(district)
		foreach d of local district {
			_pctile cons_pc [aw=hh_weight] if district==`d' & item==`a' & flag==0, p(50)
			replace med_d = r(r1) if !mi(cons_pc) & district==`d' & item==`a' 
	}
}
save "$output/temp/QOut_temp5.dta", replace

*Median urban rural Province
	qui levelsof item, local(item)
	foreach a of local item {
		qui levelsof Province_Code, local(Province_Code)
		foreach p of local Province_Code {
			_pctile cons_pc [aw=hh_weight] if Province_Code==`p' & item==`a' & urru==2 & flag==0, p(50)
			replace med_rp = r(r1) if !mi(cons_pc) & Province_Code==`p' & item==`a' & urru==2
			_pctile cons_pc [aw=hh_weight] if Province_Code==`p' & item==`a' & urru==1 & flag==0, p(50)
			replace med_up = r(r1) if !mi(cons_pc) & Province_Code==`p' & item==`a' & urru==1
		}
}
save "$output/temp/QOut_temp6.dta", replace

*National rural and urban median
	qui levelsof item, local(item)
	foreach a of local item {
			_pctile cons_pc [aw=hh_weight] if item==`a' & urru==2 & flag==0, p(50)
			replace med_rn = r(r1) if !mi(cons_pc) & item==`a' & urru==2
			_pctile cons_pc [aw=hh_weight] if item==`a' & urru==1 & flag==0, p(50)
			replace med_un = r(r1) if !mi(cons_pc) & item==`a' & urru==1
}
save "$output/temp/QOut_temp6.dta", replace

* National median
	qui levelsof item, local(item)
	foreach a of local item {
			_pctile cons_pc [aw=hh_weight] if item==`a' & flag==0, p(50)
			replace med_n = r(r1) if !mi(cons_pc) & item==`a' 
}
save "$output/temp/QOut_temp8.dta", replace

tab flag

* Replace outliers with median cons_pcues of:
	* Stage 1: median of EA if at least six observations
	* Stage 2: median of urban/rural district if at least 20 observations
    * Stage 3: median of district if at least 20 observations            
	* Stage 4: median of urban/rural province if at least 20 observations
	* Stage 5: median of urban/rural national if at least 20 observations
	* Stage 6: national median

replace cons_pc=. if flag==1											//602 outliers
*replace cons_pc=med_ea if flag==1 & nr_ea>=6 & cons_pc==.				//390 replaced with EA median
replace cons_pc=med_rd if flag==1 & nr_dur>=20 & cons_pc==. & urru==2	//77  replaced with rural district median 
replace cons_pc=med_ud if flag==1 & nr_dur>=20 & cons_pc==. & urru==1	//38  replaced with urban district median 
replace cons_pc=med_d  if flag==1 & nr_d>=20 & cons_pc==.               //16  replaced with district median      
replace cons_pc=med_rp if flag==1 & nr_p>=20 & cons_pc==. & urru==2		//67  replaced with rural province median
replace cons_pc=med_up if flag==1 & nr_p>=20 & cons_pc==. & urru==1		//2   replaced with urban province median
replace cons_pc=med_rn if flag==1 & nr_n>=20 & cons_pc==. & urru==2		//5   replaced with rural national median
replace cons_pc=med_un if flag==1 & nr_n>=20 & cons_pc==. & urru==1		//7   replaced with urban national median            
replace cons_pc=med_n if flag==1 & cons_pc==.							//0   replaced with national median 

cap drop lncons_pc district med_ea med_rd med_ud med_d med_rp med_up med_rn med_un med_n nr_ea nr_dur nr_d nr_p nr_n

saveold "$output/quant_out_top.dta", replace
/*
*****************************
** Top and bottom outliers **
*****************************

use "$output\junk_food_pre_clean.dta", clear

gen cons_pc=q23_9/hh_size if !mi(q23_9)
label var cons_pc "Quantities consumed per capita"

gen lncons_pc=ln(cons_pc)

* generate outlier flag
gen byte flag = 0
la var flag "flagged as an outlier"
cap la def flag 0 "Not an outlier" 1 "Outlier" 2 "N.A."
la val flag flag

* gen separate clean cons_pc variable
clonevar cons_pc_raw=cons_pc
label var cons_pc_raw "Amount used in last 7 days - raw data"
label var cons_pc "Amount used in last 7 days - outlier cleaned"

local sigma = 3

*Create unique district codes
gen _district = string(District_Code, "%02.0f")
gen _province = string(Province_Code, "%02.0f")
egen district = concat(_province _district)
destring district, replace
drop _district _province

foreach i in ea rd ud d rp up rn un n {                  
	gen med_`i'=.
}
	
qui levelsof item, local(item)
foreach a of local item {

	qui levelsof Province_Code, local(Province_Code)
	foreach p of local Province_Code {
		
		qui sum lncons_pc [aw=hh_weight] if !mi(cons_pc_raw) & Province_Code == `p' & item==`a' 
			
		* When the variance of lncons_pc is greater than zero we detect and replace outliers
		qui replace flag=2 if (r(Var) == 0 | r(Var) ==.) & Province_Code == `p' & item==`a' & !mi(lncons_pc) /* not possible to detect outliers */

		if r(Var) != 0 & r(Var) !=. {

			local what: label (item) `a'
			local where: label (Province_Code) `p'
			dis in yellow "(`a') - `what' - `where'"
				
			qui sum lncons_pc [aw=hh_weight] if !mi(cons_pc_raw) & Province_Code==`p' & item==`a', d
			loc amean_`a' = r(mean)
			loc asd_`a' = r(sd)
			
			*Outlier defined as: value of a particular item is greater than 3 standard deviations of the mean of the logarithm of the original variable	
			qui replace flag = 1 if (abs(lncons_pc - `amean_`a'')) > `sigma'*`asd_`a'' & Province_Code==`p' & item==`a' & !mi(lncons_pc)		
		}
	}	
}	

save "$output/temp/QOut_temp1b.dta", replace

use "$output/temp/QOut_temp1b.dta", clear

*Create the minimum # of non-missing non-outlier obs to be replaced with medians
gen n=1 if cons_pc!=. & flag==0
bys cid item: egen nr_ea=total(n)						//Nr of obs by EA for each item
bys district item urru: egen nr_dur=total(n)			//Nr of obs by urban/rural district for each item
bys district item: egen nr_d=total(n)                  //Nr of obs by district for each item    
bys Province_Code item urru: egen nr_p=total(n)		//Nr of obs by urban/rural province for each item
bys item urru: egen nr_n=total(n)						//Nr of obs by urban/rural in nation for each item
drop n

save "$output/temp/QOut_temp2b.dta", replace

/*
* Median EA
	qui levelsof cid, local(cid)
	foreach c of local cid {
		qui levelsof item, local(item)
		foreach a of local item {
			_pctile cons_pc [aw=hh_weight] if cid==`c' & item==`a' & flag==0, p(50)
			replace med_ea = r(r1) if !mi(cons_pc) & cid== `c' & item==`a' 
	}
}
save "$output/temp/QOut_temp3.dta", replace
*/

use "$output/temp/QOut_temp2b.dta", clear
*Median District: urban/rural 
	qui levelsof item, local(item)
	foreach a of local item {
		qui levelsof district, local(district)
		foreach d of local district {
			_pctile cons_pc [aw=hh_weight] if district==`d' & item==`a' & urru==2 & flag==0, p(50)
			replace med_rd = r(r1) if !mi(cons_pc) & district==`d' & item==`a' & urru==2
			_pctile cons_pc [aw=hh_weight] if district==`d' & item==`a' & urru==1 & flag==0, p(50)
			replace med_ud = r(r1) if !mi(cons_pc) & district==`d' & item==`a' & urru==1
	}
}
save "$output/temp/QOut_temp4b.dta", replace

*Median District:        
	qui levelsof item, local(item)
	foreach a of local item {
		qui levelsof district, local(district)
		foreach d of local district {
			_pctile cons_pc [aw=hh_weight] if district==`d' & item==`a' & flag==0, p(50)
			replace med_d = r(r1) if !mi(cons_pc) & district==`d' & item==`a' 
	}
}
save "$output/temp/QOut_temp5b.dta", replace

*Median urban rural Province
	qui levelsof item, local(item)
	foreach a of local item {
		qui levelsof Province_Code, local(Province_Code)
		foreach p of local Province_Code {
			_pctile cons_pc [aw=hh_weight] if Province_Code==`p' & item==`a' & urru==2 & flag==0, p(50)
			replace med_rp = r(r1) if !mi(cons_pc) & Province_Code==`p' & item==`a' & urru==2
			_pctile cons_pc [aw=hh_weight] if Province_Code==`p' & item==`a' & urru==1 & flag==0, p(50)
			replace med_up = r(r1) if !mi(cons_pc) & Province_Code==`p' & item==`a' & urru==1
		}
}
save "$output/temp/QOut_temp6b.dta", replace

*National rural and urban median
	qui levelsof item, local(item)
	foreach a of local item {
			_pctile cons_pc [aw=hh_weight] if item==`a' & urru==2 & flag==0, p(50)
			replace med_rn = r(r1) if !mi(cons_pc) & item==`a' & urru==2
			_pctile cons_pc [aw=hh_weight] if item==`a' & urru==1 & flag==0, p(50)
			replace med_un = r(r1) if !mi(cons_pc) & item==`a' & urru==1
}
save "$output/temp/QOut_temp6b.dta", replace

* National median
	qui levelsof item, local(item)
	foreach a of local item {
			_pctile cons_pc [aw=hh_weight] if item==`a' & flag==0, p(50)
			replace med_n = r(r1) if !mi(cons_pc) & item==`a' 
}
save "$output/temp/QOut_temp8b.dta", replace

tab flag

* Replace outliers with median cons_pcues of:
	* Stage 1: median of EA if at least six observations
	* Stage 2: median of urban/rural district if at least 20 observations
    * Stage 3: median of district if at least 20 observations            
	* Stage 4: median of urban/rural province if at least 20 observations
	* Stage 5: median of urban/rural national if at least 20 observations
	* Stage 6: national median

replace cons_pc=. if flag==1											//602 outliers
*replace cons_pc=med_ea if flag==1 & nr_ea>=6 & cons_pc==.				//390 replaced with EA median
replace cons_pc=med_rd if flag==1 & nr_dur>=20 & cons_pc==. & urru==2	//77  replaced with rural district median 
replace cons_pc=med_ud if flag==1 & nr_dur>=20 & cons_pc==. & urru==1	//38  replaced with urban district median 
replace cons_pc=med_d  if flag==1 & nr_d>=20 & cons_pc==.               //16  replaced with district median      
replace cons_pc=med_rp if flag==1 & nr_p>=20 & cons_pc==. & urru==2		//67  replaced with rural province median
replace cons_pc=med_up if flag==1 & nr_p>=20 & cons_pc==. & urru==1		//2   replaced with urban province median
replace cons_pc=med_rn if flag==1 & nr_n>=20 & cons_pc==. & urru==2		//5   replaced with rural national median
replace cons_pc=med_un if flag==1 & nr_n>=20 & cons_pc==. & urru==1		//7   replaced with urban national median            
replace cons_pc=med_n if flag==1 & cons_pc==.							//0   replaced with national median 

cap drop lncons_pc district med_ea med_rd med_ud med_d med_rp med_up med_rn med_un med_n nr_ea nr_dur nr_d nr_p nr_n

saveold "$output/quant_out_topbottom.dta", replace

/*--------------------------------End of do file--------------------------------*/
