/*--------------------------------------------------------------------------------------\
| Date:    	October 17, 2013															|
| Revised:																				|
| Title:   	povline.do																	|
| Purpose: 	A. Use food bundle of 2007-08												|
|			B. Create food poverty lines in 2016-17 (q2007*p2016)						|
|			C. Add non-food poverty lines (2007 nf povline updated using nf cpi			|
|			D. Create total poverty line (food + non-food poverty line)					|
| Author:  	Christina Wieser									                    	|
| Contact: 	cwieser@worldbank.org                                  	                    |
\--------------------------------------------------------------------------------------*/
clear
set mem 150m
set matsize 200
capture log close

***************************************************************************
* Part B: Create food poverty lines in 2016-17 using 2007-08 food bundle **
***************************************************************************

use "$auxiliary/food_bundle.dta", clear

*Merge 2016-17 prices
merge 1:1 item using "$output/price_base_2016.dta"
*keep if _merge==3 								//We have 92 food items (exclude broccoli and fresh apricots)
drop _merge

gen pq=p0*quantity07

* FPL = 2100*((q2007 * p2016)/tcalpcday) 
egen fline=total(pq)
replace fline=30.4*fline
label var fline "Monthly Food poverty line in 2007-08 (based on 2007-08 food bundle)"

keep fline
duplicates drop
gen regstrat=1
gen quarter2=1
tempfile fline
save `fline'

*****************************************************************************
* Part C: Add non-food poverty lines (2007 nf povline updated using nf cpi **
*****************************************************************************
use "$data07\povlines.dta" , clear
keep regstrat nfline
gen quarter=1
tempfile nom_nfline 
saveold `nom_nfline'

*-------------------------------------------------------------------------------------------------------------------
* Create temporal inflation using non-food CPI
import excel "$path\data\Auxiliary files\cpi\Long series CPI base on 2004_171020.xlsx", sheet("Sheet1") firstrow clear
rename A Year 
rename B Month 

keep if inlist(Year, 2007, 2008, 2016, 2017)

*gen quarter variable 
gen quarter2007=.
replace quarter2007=1 if inlist(Month, "Aug", "Sep", "Oct", "Nov") & Year==2007
replace quarter2007=2 if (Month=="Dec" & Year==2007) | (inlist(Month, "Jan","Feb") & Year==2008)
replace quarter2007=3 if inlist(Month, "Mar", "Apr", "May") & Year==2008
replace quarter2007=4 if inlist(Month, "Jun", "Jul", "Aug", "Sep") & Year==2008

/*
In 2016-17 the calendar conversion between the Gregorian and the Iranian Calendar:
2016-17 Quarter definiton 
quarter 		From-To									From-To 
1	1-Hmal 		(Mar 20-Apr 19, 2016) 		4-Saratan 	(Jun 21-Jul 21, 2016) 
2	5-Asad 		(Jul 22-Aug 21, 2016) 		7-Mizan 	(Sep 22-Oct 21, 2016)
3	8-Aqrab 	(Oct 22-Nov 20, 2016)		10-Jadi 	(Dec 21, 2016-Jan 19, 2017)
4	11-Dalwa 	(Jan 20-Feb 18, 2017)		1-Hmal 		(March 21- Apr 20, 2017) 
*/
gen quarter2016=.
replace quarter2016=1 if inlist(Month, "Apr", "May", "Jun", "Jul") & Year==2016
replace quarter2016=2 if inlist(Month, "Aug", "Sep", "Oct") & Year==2016
replace quarter2016=3 if (Month=="Jan" & Year==2017)|(inlist(Month, "Nov", "Dec") & Year==2016)
replace quarter2016=4 if inlist(Month, "Feb", "Mar", "Apr") & Year==2017

drop if quarter2016==. & quarter2007==.

*quarterly index: 
egen Qindex07=mean(NonFood) if quarter2007!=., by(quarter2007)
egen Qindex16=mean(NonFood) if quarter2016!=., by(quarter2016)

preserve 
	collapse (mean) Qindex07, by(quarter2007) 
	rename quarter2007 quarter
	tempfile Qindex07
	saveold `Qindex07'
restore 

collapse (mean) Qindex16, by(quarter2016) 
rename quarter2016 quarter 
merge 1:1 quarter using `Qindex07'
drop _merge 
drop if quarter==.
keep if quarter==1
merge 1:n quarter using `nom_nfline'
drop _merge

*obtain 16-17 NF-LINE
gen nfline1=. 
replace nfline1=nfline*(Qindex16/Qindex07)

drop nfline Qindex16 Qindex07 quarter
rename nfline1 nfline 

merge 1:1 regstrat using `fline'
drop _merge

replace fline = fline[_n-1] if missing(fline) 
replace quarter2 = quarter2[_n-1] if missing(quarter2) 

********************************************************************
*Part D: Create total poverty line (food + non-food poverty line) **
********************************************************************

gen double pline = fline+nfline
	label var pline "Total monthly poverty line in 2016-17"
	label var nfline "Monthly 2016-17 nonfood poverty line (temporally adjusted from 07-08)"

saveold "$output/povlines.dta", replace

/*--------------------------------End of do file--------------------------------*/
