/*-----------------------------------------------------------------------------
Date:    October 29, 2017                                                                
Revised:                                                                            
Title: price_adjust.do                                                                      
Purpose: 1) temporal adjustment and 2) spatial adjustment 

Author:  Germiniasi, Andrea                                                             
Contact: a.germiniasi@gmail.com           
-----------------------------------------------------------------------------*/
set more off

**********************************************************************     
** 1. Construct Temporal Deflators to adjust nonfood expenditures       
**********************************************************************

import excel "$auxiliary/cpi/Long series CPI base on 2004.xlsx", cellrange("EO4:FD6") clear 

mkmat _all, matrix(CPI_temp)
matrix CPI = CPI_temp'

matrix colnames CPI = CPI_all CPI_food CPI_nonfood
matrix rownames CPI = Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec Jan Feb Mar Apr

* get original row names of matrix (and row count)
local rownames : rowfullnames CPI
local c : word count `rownames'

clear
svmat CPI, names(col)

* add matrix row names to dataset
gen rownames = ""
forvalues i = 1/`c' {
    replace rownames = "`:word `i' of `rownames''" in `i'
}

gen n = _n
gen year = 2016 if n <= 12
replace year = 2017 if n > 12

keep if inrange(n,4,16)

* note from cons.do
*Price survey was not conducted until April 2016. 

gen quarter2 = 1 if inrange(n,4,7) & year == 2016  		// Q1: April-July 2016
replace quarter2 = 2 if inrange(n,8,10) & year == 2016	// Q2: August-October 2016
replace quarter2 = 3 if inrange(n,11,12) & year == 2016 | inrange(n,13,13) & year == 2017	// Q3: November 2016-January 2017
replace quarter2 = 4 if inrange(n,14,16) & year == 2017	// Q4: February-April 2017

bys quarter: egen CPI_nf_avg = mean(CPI_nonfood)

*average CPI quarter 1 (nonfood only)
gen CPI_nf_q1 = CPI_nf_avg if quarter == 1
egen CPI_nf_base = mean(CPI_nf_q1)

gen adj_fact_nf = CPI_nf_avg / CPI_nf_base

tab adj_fact_nf

/*
adj_fact_nf |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |          4       30.77       30.77
   1.021272 |          3       23.08       53.85
   1.036392 |          3       23.08       76.92
   1.038022 |          3       23.08      100.00
------------+-----------------------------------
      Total |         13      100.00
*/

collapse adj_fact_nf, by(quarter)

save "$output/temporal_adj_nf_16", replace

**********************************************************************     
** 2. Construct Laspeyres Index to adjust food expenditures
**    Using quarter 1 prices and region 1 as the reference price
**    Based on expenditure shares of the price-adjusted food poor        
**********************************************************************

use "$output\temp_longfoodexp", clear
drop if price ==. 
sort hhid
drop Province_Name
merge hhid using "$output\core"
tab _m
keep if _m==3

drop _merge
sort hhid

*2007 methdology - incorrect as it takes a weighted average based on all housheolds (also those outside the base)
*egen pp = mean(price) if quarter == 1 & regstrat ==1, by(item)
*egen p0 = max(pp), by(item)   // this is average price OVER QUARTER 1 and REGION 1(all population)
*drop pp
*collapse (max) p0 (mean) price [aw=hh_weight], by(item)  // (all hosuehold)

* Calculate p0 and the budget share using the 2007 food bundle and the 2016 base prices
preserve 
	keep if quarter==1 & regstrat==1
	collapse p0 = price [aw=hh_weight], by(item)  // this is the preferred way - otherwise you weight by hh not in Q1 and R1
	label var p0 "Reference price, quarter 1 and region 1"
	sort item
	save "$output/price_base_2016", replace  // this will be used to build the FPL 

	merge 1:1 item using "$auxiliary\food_bundle"  
	tab item _merge if _merge != 3, nolab
	drop _merge

	/* 
	. tab item _m if _m != 3, nolab

			   |   _merge
	 Item code |         1 |     Total
	-----------+-----------+----------
			11 |         1 |         1 
			20 |         1 |         1 
			31 |         1 |         1 
			59 |         1 |         1 
			77 |         1 |         1 
			85 |         1 |         1 
			91 |         1 |         1 
		   201 |         1 |         1 
	-----------+-----------+----------
		 Total |         8 |         8 

	11	other_bread
	20	other_meat
	31	other_dairy
	59	other_vegetables
	77	other_fruit
	85	other_beverages
	91	other_spices
	201	Fresh Apricots  
	*/

	keep if !inlist(item,11,20,31,59,77,85,91,201)  // note: bs will be missing even if we do not drop them

	** Evaluate per capita daily quantities of the food bundle (pcdq) at 2016 reference prices (p0)
	gen exp_adj = p0*quantity07  // missing value for the items above

	** Exclude other items to match pov bundle
	egen sumfex_all = sum(exp_adj) 
	label var sumfex "Cost of food bundle, pre-adjustment for 2100 calories"

	** Calculate budget shares
	gen win_z = exp_adj/sumfex_all 
	label var win_z "Food-item Shares of the Food Poor, Price-adjusted, All"

	* Confirm shares of items sum to 1 
	egen test = sum(win_z)
	summ test
	drop test

	tempfile bshares_2007
	save `bshares_2007', replace
restore

collapse (mean) price [aw=hh_weight], by(regstrat quarter item)  // prepare price vector (across region and quarter)
rename price pr

sort item
merge m:1 item using `bshares_2007'  
tab item _merge if _merge != 3
drop _merge

/* OK, usual "others" items
. tab item _m if _m != 3

           |   _merge
 Item code | master on |     Total
-----------+-----------+----------
        11 |        56 |        56 
        20 |        56 |        56 
        31 |        56 |        56 
        59 |        56 |        56 
        77 |        56 |        56 
        85 |        56 |        56 
        91 |        56 |        56 
-----------+-----------+----------
     Total |       392 |       392 

*/
* Generate Laspayres Index
gen double qq = win_z*(pr/p0)  // missing values for "others" item and apricot

collapse (sum) qq, by(regstrat quarter)
rename qq lsindexreg_z
label var lsindexreg_z "Food Laspeyres Index by region-quarter: All items - base: region 1 , quarter 1"
sort regstrat quarter
saveold "$output\LasSPIregqrt", replace

summ l*, detail
table regstrat quarter, c(mean lsindexreg_z)

**********************************************************************     
** 3. Create adjusted (real) 2016 food expenditures using quarter 1    
**    prices over all regions as the reference price
**********************************************************************

use "$output\temp_aggcons.dta", clear  
merge 1:1 hhid using "$output\core"
keep if _merge==3
drop _merge
merge 1:1 hhid using "$input/F_23.dta", keepusing(hh_size)  // for hhsize
keep if _merge==3
drop _merge
sort regstrat quarter
merge m:1 regstrat quarter using "$output\LasSPIregqrt"

/*
    Result                           # of obs.
    -----------------------------------------
    not matched                             0
    matched                            19,838  (_merge==3)
    -----------------------------------------
*/
keep if _merge==3
drop _merge
sort hhid
keep  hhid cid hh_weight hexnom* cid hh_size Province* regstrat quarter urru lsindex* // stratum pop_weight hhmebcnt urk  urbrur 

* NOMINAL EXPENDITURES PER CAPITA
gen double pcfexall_nomi = hexnom_f/(hh_size)
label var pcfexall_nomi "PC monthly food cons-all items, nominal"

gen double pcnfxall_nomi = hexnom_n/(hh_size)
label var pcnfxall_nomi "PC monthly non-food cons, all items, nominal"

/*gen double pcexpall_nomi = pcfexall_nomi+pcnfxall_nomi
label var pcexpall_nomi "PC monthly total consumption, all items, nominal"*/

gen double pcexd_nomi = hexnom_d/(hh_size)
gen double pcexr_nomi = hexnom_r/(hh_size)

gen double pcexall_nomi = pcfexall_nomi + pcnfxall_nomi + pcexd_nomi + pcexr_nomi

tabstat pcfexall_nomi pcnfxall_nomi pcexd_nomi pcexr_nomi pcexall_nomi [w=hh_weight*hh_size], by(quarter)

/*
Summary statistics: mean
  by categories of: quarter2 

quarter2 |  pcfexa~i  pcnfxa~i  pcexd_~i  pcexr_~i  pcexal~i
---------+--------------------------------------------------
       1 |  1293.483  625.7556  112.0436  353.4535  2384.736
       2 |  1309.905  556.1274  104.4936  303.0365  2273.562
       3 |  1049.243  604.4078  103.3996  308.2238  2065.274
       4 |  1006.063  607.0797  105.6472  290.2954  2009.085
---------+--------------------------------------------------
   Total |  1182.215  595.0945  106.3437  314.0172   2197.67
------------------------------------------------------------
*/

merge m:1 quarter using "$output/temporal_adj_nf_16"
keep if _merge==3
drop _merge

* Adjust expenditures
* Food
gen double pcexf_adj  = pcfexall_nomi/(lsindexreg_z)
label var pcexf_adj "PC monthly food cons, adj by 14 reg-quarter price index"

* Nonfood
gen double pcexn_adj  = pcnfxall_nomi/adj_fact_nf
label var pcexn_adj "PC monthly non-food, adj by quarterly non-food cpi"

* rent and durables (temporally adjusted)
foreach i in d r {
	gen pchexnom_`i'=hexnom_`i'/hh_size
}

foreach i in d r {
	gen pcex`i'_adj=pchexnom_`i'/adj_fact_nf
}

label var pcexd_adj "PC monthly durables, adj by quarterly non-food cpi"
label var pcexr_adj "PC monthly rent, adj by quarterly non-food cpi"

gen double pcexall_adj = pcexf_adj + pcexn_adj + pcexd_adj + pcexr_adj
label var  pcexall_adj "PC monthly total cons, adj by 14 reg-quarter price index"

tabstat pcexf_adj pcexn_adj pcexd_adj pcexr_adj pcexall_adj [w=hh_weight*hh_size], by(quarter)
/*

Summary statistics: mean
  by categories of: quarter2 

quarter2 |  pcexf_~j  pcexn_~j  pcexd_~j  pcexr_~j  pcexal~j
---------+--------------------------------------------------
       1 |  1357.292  625.7556  112.0436  353.4535  2448.545
       2 |  1410.713  544.5441  102.3172  296.7247  2354.299
       3 |  1083.076  582.2685  99.61209  296.9336   2061.89
       4 |  1015.758  585.7623  101.9374  280.1018   1983.56
---------+--------------------------------------------------
   Total |  1239.408  581.8978  104.0119  307.3017   2232.62
------------------------------------------------------------
*/

keep hhid Province_Code cid Province_Name hh_weight urru regstrat quarter2 hh_size pcexf_adj pcexn_adj pcexd_adj pcexr_adj pcexall_adj
save "$output\temp_pccons", replace

cap log close

/*--------------------------------End of do file--------------------------------*/

