
/*--------------------------------------------------------------------------------------------------------------------------\
| Date:    	4th Oct 2017                                                                                                   	|
| Title:   	rent2017.do 																									|
| Purpose: 	1) Explore ALCS 07/08 housing value and rent data  																|	
|			2) Construct variables for modeling 																			|
|			3) Model estimation and prediction 																				|
|			4) Convert housing value to rent 																				|
| Author:  Zihao "Tobias" Wang & Christina Wieser (based on 2011-12 do files)                                               | 
| Contact: zwang5@worldbank.org & cwieser@worldbank.org                                                    					|
\---------------------------------------------------------------------------------------------------------------------------*/

/* ---------------------------------------------------------------------------
 1. Explore ALCS 07/08 housing value and rent data  
    1.1 Building the data 
	1.2 Check data-missing values
	1.3 Strata of tent-dwellers
 2. Construct variables for modeling 
 3. Model estimation and prediction 
	3.1 Trial 1: 2011/12 NRVA  model by urban, rural, and tent
	3.2 Trial 2: developing a new model by urban, rural, tent
    3.3 Trial 3: pared regressions by urban, rural, tent 
    ------------------------------------------------------------
    3.4 Trial 4: 2011/12 NRVA  model by urban, rural, and kuchi
	3.5 Trial 5: developing a new model by urban, rural, kuchi
	3.6 Trial 6: pared regressions by urban, rural, kuchi
 4. Tabulate results:Trial 1-6 
 5. Rescaling Factor 
 6. Substitute imputed housing value w/ PSU median
 7. Convert housing value to rent 
    7.1 find a sensible interest rate and depreciation rate 
	7.2 imputing rents
	7.3 validate results 
		
	N.B.: 	
	Module No. changed, in accordance with the 2011-12 NRVA questionnaire. 
	a. H_01 H_02 (16-17 ALCS) to M_01_02 (11-12 NRVA) 
	b. H_03 (16-17 ALCS) to M_03 (11-12 NRVA) 
	c. H_04 (16-17 ALCS) to M_04 (11-12 NRVA) 
	d. H_05 (16-17 ALCS) to M_05 (11-12 NRVA)
	e. H_06 (16-17 ALCS) to M_06 (11-12 NRVA) 
	f. H_07 (16-17 ALCS) to M_07a M_07b M_07c (11-12 NRVA) 
	g. H_08 (16-17 ALCS) to M_09 (11-12 NRVA) 
	h. H_09 (16-17 ALCS) to M_10 (11-12 NRVA)
	i. H_10 (16-17 ALCS) to M_13 (11-12 NRVA)
	j. H_11 (16-17 ALCS) to M_12 (11-12 NRVA)
	k. H_12 (16-17 ALCS) to M_08 (11-12 NRVA)
	l. H_13 (16-17 ALCS) to M_11 (11-12 NRVA)
	m. H_21 (16-17 ALCS) to F_21 (11-12 NRVA) 
	n. H_22 (16-17 ALCS) to F_22 (11-12 NRVA) 
	o. H_23 (16-17 ALCS) to F_23 (11-12 NRVA)
	p. H_25 (16-17 ALCS) to F_24 (11-12 NRVA)
 -------------------------------------------------------------------------- */ 

version 13
clear
pause on
set more off
set mem 150m
set matsize 200
capture log close
set type double, perm

log using "$logfolder\rent-explore.log", replace

*********************************************************************
*** 1.   Explore ALCS 16/17 housing value and rent data              
*********************************************************************
*1.1 building the data 
* Merge in files to get sample design info (weights, clusters, strata)
* Merge in files to urban, rural, kuchi
use "$input\M_04.dta", clear
sort hhid
merge 1:1 hhid using "$output\core.dta"
drop _merge

*recode missing values
foreach i in 1 5 6 7 8 9 12 13 15 16 17 19 20 21 22 23 {
	recode q4_`i' (.a=.)
}

foreach i in 2 3 4 {
	recode q4_`i' (9=.)
}
rename urruku urk

* Strata variable does not exist, create by interacting provincec and URK
     tab urk [aw=hh_weight]
     * create 35 unique strata -- 34 provinces, 1 kuchi
	 gen     strata = 0                if urk==3
     replace strata = Province_Code    if urk!=3
     codebook strata
	 
*sum the cost of dwelling 
sum q4_8, d
sum  q4_8 if  q4_8!=88888888, d
sort hhid

*Replace "strange" values with missing
gen  h_val = q4_8 if q4_8!=88888 & q4_8!=8888888 & q4_8!=88988888 & q4_8!=99999999 & q4_8!=89888888 & q4_8!=88888888 
replace h_val=. if q4_8==0
misstable sum h_val				//About half of observations do not indicate value of dwelling
label var h_val "estimated housing value (for owners)"

table urk, c(n h_val mean h_val median h_val) row col
tab h_val urk, m
*missing values in urban about 59%, in rural about 45%, for kuchi about 44%

replace q4_5=. if q4_5==9

*Check if renters have credible housing values
gen own_rent=.
replace own_rent=1 if q4_6>=1 & q4_6<=7
replace own_rent=2 if q4_6==8 | q4_6==9

label define own_rent 1 "owners" 2 "renters"				
label val own_rent own_rent 
tab own_rent if h_val!=.
tab  own_rent urk if h_val!=., m

*1.3 strata of tent-dwellers: 471 kuchi hhs, 8 rural hhs and 4 urban hhs
tab q4_1 urk 

*Clean rent variable: replace "0" rents 
gen rent=q4_7
replace rent=. if q4_7==0 | q4_7==.
label var rent "reported rent (for renters)"
tab rent own_rent, m									//There are 2 hhs who indicated rent but not occupancy status

*Clean number of rooms
gen numrm=q4_13
replace numrm=. if q4_13==0

count if !mi(rent) & !mi(h_val)							//no observations for which both rent and housing value are nonmissing

*****************************************
** 2. Construct variables for modeling **
*****************************************
*Construct variables
*N.B.
*a. 2016-17: dwl34 of NRVA 2011-12 is identical to dwl3 of ALCS 16-17
*2011-12 code: gen dwl34 = dwl3==1|dwl4==1

*b. no access to dwelling in the new survey (4.1.1 ALCS note)
*2011-12 code deleted: tab Q_4_11, gen(acc)

*c. wood as a wall material is not a answer choice (4.1.2 ALCS note)

*d. several toilet answer choices have been added in 2016-17 ALCS
* They are expanded from the variable flush latrine used by NRVA 2011-12 model (4.1.2 ALCS note)

*Toilet facilities
gen toilet=.
replace toilet=1 if q4_19==2
replace toilet=2 if q4_19==1
replace toilet=3 if q4_19==3 | q4_19==8 | q4_19==9   
replace toilet=4 if q4_19>=4 & q4_19<=7
replace toilet=5 if q4_19==10
replace toilet=6 if q4_19==11
label define toilet 1 "open pit" 2 "covered latrine" 3 "improved latrine" 4 "(pour) flush toilet" 5 "no facility" 6 "other"
label val toilet toilet
label var toilet "toilet facility"
tab toilet, gen(toilet_)


*Roof materials
gen roof=.
replace roof=1 if q4_3==1
replace roof=2 if q4_3==2
replace roof=3 if q4_3==4
replace roof=4 if q4_3==5
*tin/metal: so few obs that cannot be its own category 
replace roof=5 if q4_3==3 | q4_3==6
label define roof 1 "concrete" 2 "wood" 3 "girder" 4 "mud" 5 "other"              
label val roof roof
label var roof "roof material"
tab roof, gen(roof_)


*Type of dwelling
gen dwel_type=.
replace dwel_type=1 if q4_1==1
replace dwel_type=2 if q4_1==2 | q4_1==3
replace dwel_type=3 if q4_1==4
replace dwel_type=4 if q4_1==5
replace dwel_type=5 if q4_1==6
label define dwel_type 1 "single family home" 2 "part of shared house/apartment" 3 "tent" 4 "temporary shelter/shack" 5 "other"
label val dwel_type dwel_type
label var dwel_type "type of dwelling"
tab dwel_type, gen(dwel_)


*Wall material
tab q4_2, gen(wall_)

*Floor material
tab q4_4, gen(flo_)

*Age of dwelling
tab q4_5, gen(age)

*Type of kitchen facility
tab q4_12, gen(kit_)

//CW new in 2016-17 - we need to code the same for 2007-08 and 2011-12. 
*Access to electricity
foreach i in a b c d e f g h i {
	recode q4_14_`i' (2=0), gen(acc_`i')
}
label var acc_a "Electricity: Electric grid"                          
label var acc_b "Electricity: government generator"
label var acc_e "Electricity: community generator"
label var acc_f "Electricity: community dynamo"

gen acc_com=(acc_e==1 | acc_f==1)
label var acc_com "Electricity: community generator or dynamo"

*Source of lighting if electricity
gen elec=(q4_15==2) if q4_15!=.
label var elec "Electricity for lighting"

*Source of drinking water
gen w_pipe=(q4_21==1 | q4_21==2) if q4_21!=.                         
gen w_tap=(q4_21==3) if q4_21!=.
gen w_pump=(q4_21==4) if q4_21!=.
gen w_well=(q4_21==7 | q4_21==8) if q4_21!=.
label var w_pipe "Drinking water: piped"
label var w_tap "Drinking water: pulic tap/standpipe"
label var w_pump "Drinking water: hand pump, bore hole"
label var w_well "Drinking water: well protected or unprotected"

tab Province_Code, gen(prv)
tab dwel_type urk, col nof

** Separate HH into 3 groups: urban, rural, and tents
gen hval_type = .
replace hval_type = 1 if  urk ==1
replace hval_type = 2 if  urk !=1
replace hval_type = 3 if  q4_1==4
label def hval_type 1 "Urban dwelling" 2 "Rural dwelling" 3 "Tents"
label val hval_type hval_type
* N.B.: rural dwellings include permanent housing of Kuchi communities in rural areas


*check housing characteristics for renters and owners 
su numrm toilet_1 toilet_2 toilet_3 toilet_4 toilet_5 roof_1 roof_2 roof_3 roof_4 dwel_1 dwel_2 dwel_3 dwel_4 wall_1 wall_2 ///
wall_3 wall_4 flo_1 flo_2 age1 age2 age3 age4 age5 age6 kit_1 kit_2 kit_3 kit_4 acc_a acc_b acc_e acc_f elec w_pipe w_tap ///
w_pump w_well if q4_7~=.& hval_type==1

su numrm toilet_1 toilet_2 toilet_3 toilet_4 toilet_5 roof_1 roof_2 roof_3 roof_4 dwel_1 dwel_2 ///
dwel_3 dwel_4 wall_1 wall_2 wall_3 wall_4 flo_1 flo_2 age1 age2 age3 age4 age5 age6 kit_1 kit_2 ///
kit_3 kit_4 acc_a acc_b acc_e acc_f elec w_pipe w_tap w_pump w_well if h_val~=.& hval_type==1

*****************************************
** 3. Model estimation and prediction  **
*****************************************

gen lnhval = ln(h_val)

*Create the best possible model in each year - new model for 2016-17
*3 seperate models: 1) urban; 2) rural; 3 (tents)

*****************
* URBAN MODEL	*
*****************
global indvar numrm toilet_1 toilet_3 toilet_4 toilet_5 toilet_6 roof_1 roof_2 roof_3 roof_5 dwel_2 dwel_3 dwel_4 /// 
	wall_2 wall_3 wall_4 wall_5 flo_1 flo_3 age2 age3 age4 age5 age6 kit_1 kit_2 kit_3 kit_5 acc_a acc_b ///     
	acc_e acc_f elec w_tap w_pump w_well
global location prv2-prv34 
*reference groups: covered latrine (toilet_2); mud roof (roof_4); Single family home (dwel_1); fired brick/stone wall (wall_1) 
*concrete/tile floor (flo_2); less than 2 years (age1); cooking in open (kit_4); Kabul (prv1); w_pipe (piped water)

svyset cid [w=hh_weight], strata(Province_Code)
stepwise, pr(0.05): reg lnhval $indvar $location [aw=hh_weight] if hval_type==1
	
predict irent_u if hval_type ==1, xb
*Duan’s Estimator: 
	predict resid1 if hval_type==1 & hval_type!=., resid
	gen eresid1=exp(resid1)
	egen meresid1=mean(eresid1)   // meresid1 is the Duan’s smearing estimator 
	replace irent_u=exp(irent_u)*meresid1

drop resid1 eresid1 meresid1

*****************
* RURAL MODEL	*
*****************
global indvar numrm toilet_1 toilet_2 toilet_3 toilet_4 toilet_6 roof_1 roof_2 roof_3 dwel_2 dwel_3 dwel_4 /// 
	wall_2 wall_3 wall_4 wall_5 flo_2 flo_3 age2 age3 age4 age5 age6 kit_1 kit_2 kit_3 kit_5 ///
	acc_a acc_b acc_com elec w_pipe w_tap w_pump w_well
global location prv1 prv3-prv34 
*reference groups: no faciilty (toilet_5); mud roof (roof_4); Single family home (dwel_1); fired bricks (wall_1) 
*mud floor (flo_1); less than 2 years (age1); cooking in open (kit_4); Province 2

svyset cid [w=hh_weight], strata(Province_Code)
stepwise, pr(0.05): reg lnhval $indvar $location [aw=hh_weight] if hval_type==2

predict irent_r if hval_type==2, xb
*Duan’s Estimator: 
	predict resid1 if hval_type==2 & hval_type!=., resid
	gen eresid1=exp(resid1)
	egen meresid1=mean(eresid1)  
	replace irent_r=exp(irent_r)*meresid1

drop resid1 eresid1 meresid1

*****************
* TENT MODEL	*
*****************
global indvar numrm toilet_1 toilet_2 toilet_3 kit_2 kit_3 kit_5 elec w_pump w_well         
global location prv1-prv22 prv24-prv34 
*reference groups: no faciilty (toilet_5); cooking in open (kit_4); Province 23; flush latrine(toilet_4) no obs; kit_1 no obs 

stepwise, pr(0.05): reg lnhval $indvar $location [aw=hh_weight] if hval_type==3

predict irent_t if hval_type==3, xb
*Duan’s Estimator: 
	predict resid1 if hval_type==3 & hval_type!=., resid
	gen eresid1=exp(resid1)
	egen meresid1=mean(eresid1)  
	replace irent_t=exp(irent_t)*meresid1

drop resid1 eresid1 meresid1

*check percentiles of predicted values compared to those of lnhval;            
*Comparison: urban, rural and tent 
di in red "summary stats URBAN irent vs. actual"
	sum irent_u, d
	sum h_val if hval_type==1, d
di in red "summary stats RURAL irent vs. actual"
	sum irent_r, d
	sum h_val if hval_type==2, d
di in red "summary stats TENT irent vs. actual"
	sum irent_t, d
	sum h_val if hval_type==3, d

*Generate predicted housing values
gen hval_afc =.
replace hval_afc = irent_u if hval_type ==1
replace hval_afc = irent_r if hval_type ==2
replace hval_afc = irent_t if hval_type ==3
label var hval_afc "predicted housing values"

*****************************************
** 4) Substitute imputed housing value w/ PSU or district median*
*****************************************
su hval_afc
bysort cid: egen medhval = median(hval_afc)
replace hval_afc = medhval if hval_afc == .
//CW: cid 2800 does not have a median value - none of the observations indicated an age
*N.B. New in 2016-17, include an additional hierarchi, if cid median n.a., use district median by urban/rural/tent
replace District_Code = Province_Code*100 + District_Code 
bysort District_Code hval_type: egen medhval_d=median(hval_afc)
replace hval_afc = medhval_d if hval_afc == .

*****************************************
** 5) Tabulate results:					*
*****************************************
*Tabulate results: hval_afcx
tabstat h_val hval_afc, by(q4_1)
tabstat h_val hval_afc if h_val!=., by(hval_type) s(mean median n)
table hval_type, c(n h_val mean h_val median h_val mean hval_afc median hval_afc) format(%9.0fc)

*****************************************
** 6) Convert housing value to rent     *
*****************************************
* 7.1 find a sensible interest rate and depreciation rate
* compare different scenarios of interest and dep rates
 gen rent_imp4 = (0.04*hval_afc)/12
 gen rent_imp45 = (0.045*hval_afc)/12
 gen rent_imp5 = (0.05*hval_afc)/12
 gen rent_imp55 = (0.055*hval_afc)/12
 gen rent_imp6=(0.06*hval_afc)/12
 tabstat  rent  rent_imp4 rent_imp45 rent_imp5 rent_imp55 rent_imp6 if rent!=., by(hval_type) s(mean median n)

/*Summary statistics: mean, p50, N
  by categories of: hval_type 

     hval_type |      rent  rent_i~4  rent_~45  rent_~p5  rent_~55  rent_i~6
---------------+------------------------------------------------------------
Urban dwelling |  4630.185  6282.333  7067.624  7852.916  8638.207  9423.499
               |      3000  4702.968  5290.839   5878.71  6466.581  7054.452
               |       895       895       895       895       895       895
---------------+------------------------------------------------------------
Rural dwelling |  2830.648  2003.619  2254.071  2504.523  2754.975  3005.428
               |      2000  1693.011  1904.637  2116.264   2327.89  2539.516
               |       244       244       244       244       244       244
---------------+------------------------------------------------------------
         Tents |      3050  159.4817  179.4169  199.3521  219.2873  239.2225
               |      2500   123.461  138.8936  154.3262  169.7588  185.1915
               |        10        10        10        10        10        10
---------------+------------------------------------------------------------
         Total |  4234.285  5320.422  5985.475  6650.528  7315.581  7980.634
               |      3000  3894.674  4381.508  4868.342  5355.176   5842.01
               |      1149      1149      1149      1149      1149      1149
----------------------------------------------------------------------------
*/

*Lacking a developed rental market for rural areas, the consistency between estimated and actual 
*rents in urban areas was deemed to be the appropriate robustness check

*in 2011-12, the following was used: 
*Use sensible interest and depreciation rates
*d=1.5% and r=2.5%
*given that housing characteristics of owner's house are better than renter's house. We use the best available rate which is 4% 
*7.2 imputing rents
gen rent_imp = (0.04*hval_afc)/12
label var rent_imp "Monthly imputed rent, assuming d=1.5% and r=2.5%"
tabstat  rent  rent_imp if rent!=., by(hval_type) s(mean median n)
* ALTERNATIVE SCENARIO
gen rent_imp_alt = (0.045*hval_afc)/12						//This was specification in the past
label var rent_imp_alt "Monthly imputed rent, assuming d=1.5% and r=3%"
tabstat  rent  rent_imp_alt if rent!=., by( hval_type) s(mean median n)

** For urban hhs, Impute rent when household did not report rent, keep actual reported rent
gen rent_fin = rent if hval_type==1
replace rent_fin = rent_imp if rent==. & hval_type==1
*NEW in 2016-17: We do not use actual rents for rural areas and tents due to non-existing rental market and too 
*few observations. We therefore use imputed rent for hval_type==2 and hval_type==3
replace rent_fin = rent_imp if hval_type==2 | hval_type==3
label var rent_fin "Monthly rent (final), assuming d=1.5% and r=2.5%"

* ALTERNATIVE SCENARIO;
gen rent_fin_alt = rent if hval_type==1
replace rent_fin_alt = rent_imp_alt if rent==. & hval_type==1
*rural and tent hhs, rent data not trusted. Instead, we opt for imputed rents  
replace rent_fin_alt = rent_imp_alt if hval_type==2 | hval_type==3
label var rent_fin_alt "Alternative monthly rent (final), assuming d=1.5% and r=3%"

* Top and bottom code rents
sum rent_fin, d
replace rent_fin = r(p1) if rent_fin < r(p1)						//180 replaced
replace rent_fin = r(p99) if rent_fin > r(p99) & rent_fin !=.		//198 replaced

*7.3: validate the results
** Validation #1: by regressing imputed and actual rents and looking for corrrelation
reg rent rent_imp

** Validation #2: Regress housing value on rent (reported actual rent)
reg  rent hval_afc

**********
keep hhid rent_fin rent_fin_alt
sort hhid
compress
saveold "$output\temp_rent", version(13) replace
log close
