/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	September 7, 2021
Last udpate on: 

Written by:  	Yulia Belyakova			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Cleans the psychological well being variables for the endline


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - General Cleaning
				Part 2 - Cleaning and checking the time variables linked to the cortisol analysis 
				Part 3 - Recoding psychological well being questions and creating variables to allow comparisons
				Part 4 - Invert so that "positive" outcomes go with higher values for all variables (this requires to look into individual questions for each measure)
				Part 5 - Saving dataset
							

				INPUTS:      	"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
				
				OUTPUT: 		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_wellbeing_clean_nopii_fl1.dta"
				

*******************************************************************************/

* Inputs
global 	phone_svy_raw_r1 		"${TUP_DB}/Phone_Survey/DataSets/Deidentified/phone_svy_raw_nopii_r1.dta"
global 	id_map					"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/hhid_mapping.dta"
global 	profile_info 			"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"

* Outputs 
global  phone_svy_clean_r1		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r1.dta"


use "${phone_svy_raw_r1}", clear 

*********************************************************************************
* 1. For partial interveiws, drop those that were later submitted as complete 
*********************************************************************************
	tab call_status if inlist(field_hhid,"T0290","T0983","T0586","T1432","T0164")
	drop if inlist(field_hhid,"T0290","T0983","T0586","T1432","T0164") & call_status == 2 // all these were later completed
	
	replace call_status = 2 if field_hhid == "T0065" // this interview is wrongly marked as Complete; it only has Mobile data section complete
	
*********************************************************************************
* 2. Merge on fl1 hhid and other profile data 
*********************************************************************************	
	* Merge hhid mapping to get the follow-up ID   
	merge m:1 field_hhid using "${id_map}", keepusing(hhid) assert(2 3) keep(3) nogen   
	  
	* Merge with treatment status vars using follow-up ID   
	merge m:1 hhid using "${profile_info}", keepusing(treatment ultra_poor PRA_lottery) assert(2 3) keep(3) nogen  
	
	* Drop weird HHs with 0 in food conusmption only or in total consumption
	drop if inlist(hhid,5196,1637,1662,2184,6119)

	
*********************************************************************************
* 3. Drop SCTO variables not pertaining to the survey --- UPDATE
*********************************************************************************	

	/* Keep previous survey completion flags just in case (incomplete_hh narc_complete ammc_r1_complete ammc_r2_complete)
	
	keep date - a3_v incomplete_hh narc_complete ammc_r1_complete ammc_r2_complete hh_id hh_id_confirm corr_respondent - q7 date_a field_hhid village a5 hhid - tpm_correction */
	
	
*********************************************************************************
* 4. Apply 99/-99 corrections and high value corrections
*********************************************************************************	
	rename (know_pm_age_warning know_lhh_age_warning know_mem_age_warning) (know_pm_age_99_warning know_lhh_age_99_warning know_mem_age_99_warning)

	local 99vars know_pm_age know_lhh_age know_mem_age c12_7	c13_1	c13_16	c13_17	c13_18	k30_1_earn ///
		k30_1_m	k38_1	k38_2	k38_3	k38_4 k32_1	k32_2	k32_3	k45_2	k45_1	///
		m5_1	m5_2	m5_3	m20_1	m20_2	m20_3	d9_1 d9_2	d9_3	d9a_1	d9a_2	d9a_3
	
	destring `99vars', replace 

	foreach 99var in `99vars' {
		replace `99var' = `99var'_99_warning if inlist(`99var'_99_warning,-99,-98,1) // 0 = value entered; 1 = issues from pilot when everyone confirmed a mistake to move on 
	}

	* Sum 3-field variables again after 99/.99 correction is appleid to individual values
	* Need to fix in pilot 1 since 99/.99 warnings were not implemented there
	 
	foreach var in k32 m5 m20 d9 d9a { 
		egen `var'_tot = rsum(`var'_1 `var'_2 `var'_3) 
		replace `var'_tot = . if mi(`var') 
		drop `var' 
		rename `var'_tot `var' 
	} 
	
			order k32, after(k32_3)
			order m5, after(m5_3)
			order m20, after(m20_3)
			order d9, after(d9_3)
			order d9a, after(d9a_3)
	
	local confirm_var c12_7 c13_1 c13_16 c13_17 c13_18 k32 m5 m20 d9 d9a 
	 
	foreach confirm_var in `confirm_var' { 
		gen `confirm_var'_corr = `confirm_var'
			replace `confirm_var'_corr = `confirm_var'_confirm if `confirm_var'_confirm_val == 2 // if Value 2 is correct  
			label var `confirm_var'_corr "Var with correction for potentially high value" 
			order `confirm_var'_corr, after(`confirm_var') 
	} 
	

*********************************************************************************
* 5. Other cleaning 
*********************************************************************************
	forval i = 1/3  {
			label val v3_`i' v3_current
		}
	
	lab var consent_phone "Consented to mobile date module"
	label var v3_1 "Lady of the Household (Self)"
	label var v3_2 "Primary Man"
	label var v3_3 "Other household member"
	
	forval i = 1/3  {
		label var k24_`i'_3 "Primary female is Owner of a HH non-agricultural bussiness"
		label var k24_`i'_2 "Primary female is Manager of a HH non-agricultural bussiness"
		label var k24_`i'_1 "Primary female is Worker of a HH non-agricultural bussiness"
		label var k24_`i'_4 "Primary female Helps Occasionally in a HH non-agricultural bussiness"
		label var k24_`i'_0 "Primary female Do not participate in a HH non-agricultural bussiness"
	}
	
	label var c14_1 "No food to eat due to lack of resources (last month)"
	label var c14_3 "Cut adult size of meals or skip meals due to lack of resources (last month)"
	label var c14_5 "Cut child size of meals or skip meals due to lack of resources (last month)"
	
	label var k30_1 "Activity: Tend any animals owned or leased by the household"
	label var k30_2 "Activity: Farm land owned or sharecropped by the household"
	label var k30_3 "Activity: Work on business owned by household other than farm/animals"
	label var k30_9 "Activity: Work on household chores"
	label var k30_4 "Activity: Work as an agricultural laborer outside household"
	label var k30_5 "Activity: Do housework in someone else's home"
	label var k30_6 "Activity: Work as a non-agricultural laborer outside the household"
	label var k30_7 "Activity: Work in salaried/formal employment"
	label var k30_8 "Activity: Do any other work for pay"
	label var k30_0 "Activity: None"
	label var k30__98 "Activity: DA"
	
	label var k32	"Combined businesses revenues in the last 4 weeks"
	
	label var 	m5		"What is the total value of outstanding cash loans taken out by your household?"
	label var 	m20 	"What is the total savings balance of your household right now?"
		
	label var 	no_pm	"100 = No PM in HH [var needs to be looked at]"
	
	label var	z1_1	"LHH done activity: Open an account in a bank, a microfinance institution or join VSLA"
	label var	z1_2	"LHH done activity: Buy or register a SIM card"
	label var	z1_3	"LHH done activity: Vote in the last presidential election"
	label var	z1_4	"LHH done activity: Register land or property"
	label var	z1_5	"LHH done activity: Access health services"
	label var	z1_6	"LHH done activity: Receive assistance from the government "
	label var	z1_0	"LHH done activity: None of the above"

	label var	z4_1	"LHH used Tazkira for activity: Open an account in a bank, a microfinance institution or join VSLA"
	label var	z4_2	"LHH used Tazkira for activity: Buy or register a SIM card"
	label var	z4_3	"LHH used Tazkira for activity: Vote in the last presidential election"
	label var	z4_4	"LHH used Tazkira for activity: Register land or property"
	label var	z4_5	"LHH used Tazkira for activity: Access health services"
	label var	z4_6	"LHH used Tazkira for activity: Receive assistance from the government "
	label var	z4_0	"LHH used Tazkira for activity: Did not use my tazkira card"
	
	label var	z5_1	"Main reason for not having Tazkira: I applied but haven’t received it"
	label var	z5_2	"Main reason for not having Tazkira: I do not know how to apply"
	label var	z5_3	"Main reason for not having Tazkira: It costs too much to apply"
	label var	z5_4	"Main reason for not having Tazkira: I would need to travel too far to apply "
	label var	z5_5	"Main reason for not having Tazkira: The application process is too complicated"
	label var	z5_6	"Main reason for not having Tazkira: I need someone to go with me to apply"
	label var	z5_7	"Main reason for not having Tazkira: I don’t want to take or someone taking a picture of my face"
	label var	z5_0	"Main reason for not having Tazkira: I don’t need an ID"
	
	label var 	z6		"LHH Tazkira a paper card or the electronic Tazkira (e Tazkira)"
	label var 	z7		"PM Tazkira a paper card or the electronic Tazkira (e Tazkira)"

	
/*********************************************************************************
* 6. Rosters
*********************************************************************************
	
  * HH roster - for children's age -- should merge / combine with the schooling data below 
	 hh_mem - schoolchild_age_20_calc
	 
	 * consumption
	 c3 - c13_18_99_warning
	 
	 * labor / time use - not a roster really 
	 k5_1 - k30_1_m_99_warning
	 
	 * livestock
	 k7_1 - k39_4__97
	 
	 /* non-ag biz is asked in the aggregate, so it is not a roster - leave in main data 
	 k23_a - k32_confirm_val
	 
	 * lhh role in biz - leave in main data though it is for up to 3 businesses
	 k24_1 - k24_3_0 */
	 
	 * shocks 
	 g1 - g2__98, maybe g3
	 
	 * schooling - this is a roster by child 
	 age_learning_count - x7a_18
	 
	 * credit - not a roster, since we ask for total balances
	 
	 * phones (this excludes phone numbers for now)
	 v1 - v4_crisis_4
	 
	
		
*********************************************************************************
* X. Drop roster variables 
*********************************************************************************/

	 
	* Replace missings and Other  
	*mvdecode *, mv(-99 = .d / -98 = .r / -97 = .o / -96 = .n) 
	
	save "${phone_svy_clean_r1}", replace 
