/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	September 7, 2021
Last udpate on: November 1, 2021

Written by:  	Yulia Belyakova			

Revision: 		

********************************************************************************	

THIS DO FILE: 	This do-file creates a "profile" dataset for the phone survey.

It inlcudes all HHs surveyed in fl1 (2,495) and corresponding status from phone survey rounds if the HH was surveyed.
There are 2 status vars for each round:

	- call_status_r*: simplified call status with 4 categories
	       1 Complete
           2 Partial
           3 Refused
           4 Other (not surveyed)

	- detail_call_status_r*: detailed call status with 15 categories that can be referenced if detail on "other (not surveyed)" 
		from the simplified status is needed; the categories include
		
		   1 Complete interview
           2 Respondent does not know LHH
           3 Phone is permanently off
           4 Arabic / Turkmani / Uzbik-speaking HH
           5 HH moved form the area
           6 LHH is not available and cannot be replaced
           7 No answer
           8 No response after 7 contact attempts / Closed
           9 Partially complete interview (to follow-up)
          10 Partially complete interview (refused to continue)
          11 HH temporarily out of the area (can reach later)
          12 Refusal (no consent, picks up but refuses to talk)
          13 Rescheduled interview
          14 Number identified as valid - awaiting callback
          15 Same HH presumably listed under 2 IDs

Additionally, dataset includes flags for HHs that:
	
	- fl1_sample: HH in follow-up 1 analysis sample [2,495]
	- phone_fl1: reported having a phone at fl1 [2,022]
	- phone_anytime: reported ever having a phone [2,398]
	- phone_initial_sample: were verified by MISFA and were the starting point of the phone svy sample [2,150]
	- phone_verified: had a working phone number and verified household in at least one of the rounds [2,065];
		verified = complete, partial, refused, language, temporarily away
	- attrited HH (anyone who (1) reported having a phone at fl1 and (2) does not have a complete interview in either of R1/R2 (or both))
	
Other identifiers include:
	- pilot_r1: identifies HHs surveyed by NARC in pilot rounds (this is because the first pilot was done by them w/o Mohammad and was messy)
	- ramadan_r#: identifies HHs surveyed during Ramadan [mostly Round 3, with a handful in R1]
	- rand_treatment: is a random binary 0/1 indicator for UP HHs to use in lieau of the treatment indicator before the PAP is finalized 

		INPUTS:      	"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R4/Inputs/LHH_hh_status_all_rounds.dta"
						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/phones_wide.dta"
						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/all_phones_wide.dta" // 2150
						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/hhid_mapping.dta"
						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R4/Inputs/LHH_hh_status_all_rounds.dta"
										
		OUTPUT: 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
		

*******************************************************************************/

* Inputs

* TUP_Afghanistan Dropbox files
global  status_all_rounds 			"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R4/Inputs/LHH_hh_status_all_rounds.dta"
global	phones_wide     			"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/phones_wide.dta"
global  all_phones_wide				"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/all_phones_wide.dta" // 2150
global 	id_map						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/hhid_mapping.dta"
global  status_all_rounds 			"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R4/Inputs/LHH_hh_status_all_rounds.dta"

global 	phone_svy_clean_r1			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r1.dta" 
global 	phone_svy_clean_r2 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r2.dta" 
global 	phone_svy_clean_r3 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r3.dta" 
global 	phone_svy_clean_r4 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r4.dta" 
global 	phone_svy_raw_r4 			"${TUP_DB}/Phone_Survey/DataSets/Deidentified/phone_svy_raw_nopii_r4.dta"

* Outputs 
global 	phone_svy_profile_clean		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile_clean.dta"

	use "${phones_wide}", clear  // 2,022 - report having a phone at fl1
		keep field_hhid 
		gen phone_fl1 = 1  
		label var phone_fl1 "Reported having a phone at fl1 (2022)" 
		merge 1:1 field_hhid using "${all_phones_wide}", force // merge on 2,150 - initial MISFA verification / collection; 376 of these are new (did not have a phone at fl1)
		tab _merge
		
		/*       _merge |      Freq.     Percent        Cum.
------------------------+-----------------------------------
        master only (1) |        248       10.34       10.34 - fl1 phones not verified by MISFA
         using only (2) |        376       15.68       26.02 - new phones collected by MISFA 
            matched (3) |      1,774       73.98      100.00 - fl1 phones verified by MISFA 
------------------------+-----------------------------------
                  Total |      2,398      100.00 
				  
		 (3) 1774 + (2) 376 = 2150 HHs that constitute initial NARC sample */
		 
		 gen phone_initial_sample = (_merge == 2 | _merge == 3) 
			label var phone_initial_sample "HH in initial R1 sample verified by MISFA (2150)"
			drop _merge

		keep field_hhid phone_fl1 phone_initial_sample
		gen phone_anytime = 1 // 2,398
		label var phone_anytime "Reported having a phone at any time (2398)"
	
	* Merge on fl1 HHID and fl1 data 
		merge m:1 field_hhid using 	"${id_map}", keepusing(hhid) assert(2 3) keep(3) nogen
		
		replace phone_fl1 = 			0 if mi(phone_fl1)
		replace phone_anytime = 		0 if mi(phone_anytime)
		replace phone_initial_sample = 	0 if mi(phone_initial_sample)
	
	* Merge on call status from all rounds [including non-Complete interviews, refusals, etc.]
	merge 1:1 hhid using "${status_all_rounds}", keepusing(narc - ammc_r3) nogen
	
	* Merge on Phone svy rounds [this is to check final call status for Complete and Partial interviews agianst that in the status_all_rounds data]
	merge 1:1 hhid using "${phone_svy_clean_r1}", keepusing(call_status pilot1_flag pilot2_flag date a2 a11 a11_o) nogen
		rename (call_status date a2 a11 a11_o) (call_status_r1 date_r1 enu_r1 a11_r1 a11_o_r1)
	merge 1:1 hhid using "${phone_svy_clean_r2}", keepusing(call_status date a2 a11 a11_o) nogen
		rename (call_status date a2 a11 a11_o) (call_status_r2 date_r2 enu_r2 a11_r2 a11_o_r2)
	merge 1:1 hhid using "${phone_svy_clean_r3}", keepusing(call_status date a2 a11 a11_o) nogen
		rename (call_status date a2 a11 a11_o) (call_status_r3 date_r3 enu_r3 a11_r3 a11_o_r3)
	merge 1:1 hhid using "${phone_svy_clean_r4}", keepusing(call_status date a2 a11 a11_o incomplete_hh) nogen
		rename (call_status date a2 a11 a11_o incomplete_hh) (call_status_r4 date_r4 enu_r4 a11_r4 a11_o_r4 survey_type_r4)

	tab narc 	call_status_r1, m // 1,736 + 7 partial = 1,743
	tab ammc_r1 call_status_r2, m // 1,671 + 2 partial = 1,672	
	tab ammc_r2 call_status_r3, m // 1,652
	tab ammc_r3 call_status_r4, m // 1,676 + 6 partial = 1,682
	
	* Simplify call status into 4 categories: Complete, Partial, Refused, Other (not surveyed)
	label define call_status 4 "Other (not surveyed)", modify 
	
	replace call_status_r1 = 3 if inlist(narc,12)
	replace call_status_r1 = 4 if !inlist(narc,1,9,10,12,.) 
	
	replace call_status_r2 = 3 if inlist(ammc_r1,12)
	replace call_status_r2 = 4 if !inlist(ammc_r1,1,9,10,12,.) 
		br if mi(call_status_r2) & ammc_r1 == 10 // T1711 has been IDed as partial, refused to continue in lastcall data, but it was really a language issue so categorize it as "Other"
	replace call_status_r2 = 4 if field_hhid == "T1711"
	
	replace call_status_r3 = 3 if inlist(ammc_r2,12)
	replace call_status_r3 = 4 if !inlist(ammc_r2,1,9,10,12,.) 

	replace call_status_r4 = 3 if inlist(ammc_r3,12)
	replace call_status_r4 = 4 if !inlist(ammc_r3,1,9,10,12,.) 
	
	* These variables have a "detailed" call tatus for the "Other (not surveyed)" call status category
	rename (narc ammc_r1 ammc_r2 ammc_r3) (detail_call_status_r1 detail_call_status_r2 detail_call_status_r3 detail_call_status_r4)
	order detail_call_status_r1 - detail_call_status_r4, after(call_status_r4)
	
	forval i = 1/4 {
		label var call_status_r`i'		  "Round `i' call status"
		label var detail_call_status_r`i' "Round `i' call status detail for 'Other (not surveyed)' category"
		label var enu_r`i' 				  "Round `i' enumerator"
		label val enu_r`i' .
		label var date_r`i'				 "Round `i' survey date"
	}
	
	* Clean pilot flags for NARC round
	gen pilot_r1 = 1 if pilot1_flag == 1 
		replace pilot_r1 = 2 if pilot2_flag == 1
		label define pilot 1 "NARC pilot 1" 2 "NARC pilot 2"
		label val pilot_r1 pilot 
		label var pilot_r1 "HH surveyed in R1 (NARC) pilot"
		drop pilot1_flag pilot2_flag
	
* Get district and village vars
	preserve 
		forval round = 1/4 {
			use "${phone_svy_clean_r`round'}", clear 
				keep hhid a5 village
				rename village a6
				label drop a5_lab
				tempfile loc_`round'
				save `loc_`round''
		}
			append using "`loc_2'"
			append using "`loc_3'"
			append using "`loc_1'"
			
			duplicates drop
			
			tempfile loc_all
			save `loc_all'
	restore 
	
	merge 1:1 hhid using "`loc_all'", assert(1 3)
		cap noi assert _merge == 1 if no_round == 1 // 2 HHs partially complete (refused to contunie) - so not counted as surveyed 
		drop _merge 	
	
	* Save data
	save "${phone_svy_profile_clean}", replace
	
	