/*******************************************************************************	 
 
Project:  		AFG-TUP 
Created on:  	Feb 10, 2020 
Last modified:  October 21, 2021
 
Written by:  	Thomas Escande			 
 
Revision: 		Yulia Belyakova 
 
********************************************************************************	 
 
THIS DO FILE: 	Looks at outliers in the time use roster using consistency checks, replacing as .o all potential outliers 
 
 
CONTENT:		Part 1 - Looking at unusual data like type of missing and negative values for all variables 
				Part 2 - Identify potential outliers 
				
				NB: Outliers for total earnings are defined as being 4 SDs away from the mean. In fl1, this was based on hourly 
					wage for each activity (by UP/NUP and gender of HH member). In the Phone Survey, we only have the total earnings from all activities
					for the PM and PW separately, so the cleaning is done by computing the mean and SD for total earnings by UP/NUP in each round for
					the PW and the PM. 
				
				TO DO: "earn", earnings for all adults other than PM/PF collected in R4 is not yeat cleaned in this do-file. 
					Need to check it at some point.
 
OUTPUTS:     	 
				 
 
Note: 			This do file does not call or save any dataset, it is exclusively used within the "timeuse_roster_clean" do file.  
 
*******************************************************************************/ 
 
 		global roster_phonesvy			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"
 
********************************************************************************************* 
** Part 1: Looking at unusual data like type of missing and negative values for all variables 
********************************************************************************************* 
	merge m:1 hhid using "${phone_svy_profile}", assert(2 3) keep(3) keepusing(ultra_poor treatment) nogen 
	
		* Get HH size to be used later for imputation of "earn" (earnings of other adults in HH in R4)	
	preserve 
		use "${roster_phonesvy}", clear 
			keep hhid round hh_mem numadult
			keep if round == 4
			duplicates drop 
		
		tempfile numadult
		save `numadult'
	restore 
	
	merge m:1 hhid round using "`numadult'", keepusing(numadult) keep(1 3)

	
	gen earn_pc = earn/numadult
	
	keep hhid ultra_poor round k30_1 k30_1_m earn_pc earn
	
	duplicates drop 
	
/* 
Main issues identified: In earnings, need to replace with the values of in kind 
There are a few 0.99, 99 and 98 that are likely to be -99 and -98 as they are not round numbers while all the others are 
*/ 
	foreach suffix in "" "_m" { 
		replace k30_1`suffix' = .d 	if k30_1`suffix' == 99 | (k30_1`suffix' > 0.989 & k30_1`suffix'<0.999)
		*The 0.99 is rounded so it won't work if we do =0.99 
	} 
	 
******************************************************************************** 
** Part 2: Identify potential outliers in earnings for PM and PF 
******************************************************************************** 

*Keep the outliers for later 
	gen k30_1_with_outliers = k30_1 
	gen k30_1_m_with_outliers = k30_1_m
	
*k30_1 	: How much did member i earn in the last 4 weeks 
*Checking the high / low values and look for consistencies with time spent doing the activity 
	bys round: sum k30_1 k30_1_m 
	bys round: tab k30_1, m 
	bys round: tab k30_1_m, m 
/*	
	hist k30_1 if k30_1 !=0  & round == 1, freq 
	hist k30_1 if k30_1 !=0  & round == 3, freq 
	hist k30_1 if k30_1 !=0  & round == 4, freq 

	hist k30_1_m if k30_1_m !=0 & round == 1, freq 
	hist k30_1_m if k30_1_m !=0 & round == 3, freq 
	hist k30_1_m if k30_1_m !=0 & round == 4, freq 
 */
	local tot_tot     = 0 
	local tot_outlier = 0 
	 

	foreach suffix in "" "_m" { 
		forvalues	 up = 0/1 	{ 
			foreach  round of numlist 1 3/4 {
				*Computing mean and standard deviation of total earnings 
				quietly sum k30_1`suffix' if k30_1`suffix' > 0 &  ultra_poor == `up' & round == `round'
				local tot = `r(N)' 
				local mean= `r(mean)' 
				*Computing mean and standard deviation of tot earnings without its maximum. It is useful when the sample is small with a high outlier, the standard deviation will be so high that it will miss the outlier most of the time.  
				quietly sum k30_1`suffix' if k30_1`suffix' > 0 & ultra_poor == `up' & round == `round' & k30_1`suffix' != `r(max)' 
				 
				quietly gen dist_mean = (k30_1`suffix' - `mean')/`r(sd)' 
				*Outliers if k30_1 is more than 4 standard deviations away from mean. If wages follow a binomial distribution, values after that threshold are extremly unlikely  
				quietly count 			           if k30_1`suffix' >  0 & ultra_poor == `up' & round == `round' & dist_mean > 4 & !mi(dist_mean)	 
				quietly replace k30_1`suffix' = .o if k30_1`suffix' >  0 & ultra_poor == `up' & round == `round' & dist_mean > 4 & !mi(dist_mean)
				
				local percent : disp %9.2fc `r(N)'/`tot'*100
				
				*Checking the percentage of observations changed to outlier 
				disp "UP `up': `r(N)' or `percent'% sent to missing as outliers for k30_1`suffix' round `round'" 
				local tot_tot = `tot_tot' + `tot' 
				local tot_outlier = `tot_outlier' + `r(N)'	 
				drop dist_mean 
			}
		}	 
	}
	
	*Total number of observations changed to outlier 
	local percent_f : disp %9.2fc `tot_outlier'/`tot_tot'*100 
	disp "Total changed `tot_outlier' or `percent_f'%"	    
	
	* Checking for outliers after the treatment above - everything looks quite consistent 
	/*hist k30_1 if k30_1 !=0  & round == 1, freq 
	hist k30_1 if k30_1 !=0  & round == 3, freq 
	hist k30_1 if k30_1 !=0  & round == 4, freq 

	hist k30_1_m if k30_1_m !=0 & round == 1, freq 
	hist k30_1_m if k30_1_m !=0 & round == 3, freq 
	hist k30_1_m if k30_1_m !=0 & round == 4, freq 
*/	 
	 
******************************************************************************** 
** Part 3: Identify potential outliers in earnings for other adults, just for round 4 so we will only look at graphs 
******************************************************************************** 	 
	 
* tw (hist earn_pc if  round==4 & ultra_poor == 1 & earn_pc > 0 & activity == 1, freq) || (hist earn_pc if round==4 &  ultra_poor == 0 & earn_pc > 0 & activity == 1, freq color(red%30))
* Excluding a single value in the NUP with revenues around 8 000 while the next one is around 4 000
	replace earn = .o if earn_pc > 7000  & ultra_poor == 1 & !mi(earn_pc ) /*1 household out of 477*/		 
	 
	 drop earn_pc 
	 
*Dropping all variables and graphs - to comment if want to look precisely at outliers 
graph drop _all 
*********************************************end of do file*********************************** 
