/* Labor and time use

	1. Round 1 roster prep
	2. Round 3 roster prep
	3. Round 4 roster prep
	4. Compile cross-section/panel data
	5. Clean outliers (time_activities_outliers_clean.do)
	6. Check for weird missingness 
	
	
	Issues & notes (on missingness):
	
		1. In R1, 6 HHs had issues with no_pm flag so the PM questions were not asked. For these HHs, all PM questions 
				are recoded to ".u" (for unexplained) instead of ".".
		2. In R4, HHID 5891 (Short survey) is missing "earn" variable (".") because it is missing roster data so "earn" was not
				asked since the relevance in SCTO was not triggered. It is replaced with ".u" for "unexplained" missingness. 
		3. In R4, due to a coding mistake, earnings k30_1 were not asked when activity 8 was selected, so there is some missingness there.
				This affects: 24 HHs for the PW k30_1 and 16 HHs for the PM k30_1_m 
				It is also missing for HHID 1681 in R4 for no apparent reason 
				These 41 (24+16+1) instances are replaced with ".u" for "unexplained" instead of ".".
				
		On outliers: "earn", earnings for all adults other than PM/PF collected in R4 is not yeat cleaned in the current version of the outlier do-file. 
					Need to check it at some point.

*/

 

* Inputs 
global 	phone_svy_clean_r1			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r1.dta" 
global 	phone_svy_raw_r1_pilot		"${TUP_DB}\Phone_Survey\DataSets\Deidentified\phone_svy_raw_nopii_r1_pilot.dta" // consumption section from the 2 pilots 
global 	phone_svy_clean_r3 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r3.dta" 
global 	phone_svy_clean_r4 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r4.dta" 
global 	phone_svy_profile			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_profile.dta"
global  roster_phonesvy				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"

* Outputs
global 	timeuse				     	"${TUP_DB}\Phone_Survey\DataSets\Intermediate\timeuse_roster_phonesvy.dta"


*********************************************************************************
* Round 1: k5_1 k5_1_m k30 k30_m k30_1 k30_1_m
*********************************************************************************

use "${phone_svy_clean_r1}", clear 
	keep hhid call_status k5_1 - k30_1_m_99_warning k30_1_earn
	 
	 /* Combine "other" in activity vars
		 افسر پولیس = police officer -- recode as salaried employee (7)
		 باغبان = gardener -- recode as ag laborer in someone else's HH (4)
		 معلم = teacher -- recode as salaried employee (7) */
	tab k30_o_m
	replace k30_m = "7" if inlist(k30_o_m,"افسر پولیس","معلم")
	replace k30_m = "4" if inlist(k30_o_m,"باغبان")
	
	tab k30_o // "Kar katdan dar khana arbab" - do not know how to recode, leave for now and ask Mohammad 
	
	* Drop vars we don't need 
	drop k30_o_m k30_o *_warning
	
	* Reshape long (unit of obs is activity)
	rename (*__97 *__98) (*_97 *_98)  
	
	reshape long k30_ k30_m_, i(hhid) j(activity)
	
	drop k30_m k30
	rename *_ *
	rename k30_1_earn k30_1

	* Create round flag
	gen round = 1 
	
	tempfile timeuse_r1
	save `timeuse_r1'
	

*********************************************************************************
* Round 3: k5_1 k5_1_m k30 k30_m k30_1 k30_1_m

* NB: k30_out_ k30_out_m_ k30_in_ k30_in_m_ treated in a separate do-file 
*********************************************************************************	
	
use "${phone_svy_clean_r3}", clear 	
	keep hhid call_status k5_1 - k30__98 k30_1_earn - k30_m__98 k30_1_m
	
	* Drop vars we don't need 
	drop *warning 
	
	* Reshape long (unit of obs is activity)
	rename *__98 *_98
	
	reshape long k30_ k30_m_, i(hhid) j(activity)
	
	drop k30_m k30
	rename *_ *
	rename k30_1_earn k30_1
	
	* Create round flag
	gen round = 3
	
	tempfile timeuse_r3
	save `timeuse_r3'
	
	
*********************************************************************************
* Round 4: k5_1 k5_1_m k30 k30_m k30_1 k30_1_m earn [earn is not a panel but related outcome]
*********************************************************************************		

use "${phone_svy_clean_r4}", clear 	
	keep hhid call_status incomplete_hh k5_1 - earn_3_99_warning
	
	* Drop vars we don't need 
	drop *warning *tot earn_*
	
	* Reshape long (unit of obs is activity)
	rename *__98 *_98
	
	reshape long k30_ k30_m_, i(hhid) j(activity)
	
	drop k30_m k30
	rename *_ *
	rename k30_1_earn k30_1
	
	* Create round flag
	gen round = 4
	
	tempfile timeuse_r4
	save `timeuse_r4'

	
*********************************************************************************
* Combine rounds
*********************************************************************************	
	use "`timeuse_r1'"
		append using "`timeuse_r3'"
		append using "`timeuse_r4'"
		
	recode activity (97 = -97) (98 = -98)
	
	* Label
	label var k30		"Did you do any of these activities in the last 4 weeks?"
	label var k5_1_m	"Did the PM try to find work outside the home in the past 2 weeks?"
	label var k30_m		"Did the PM do any of these activities in the last 4 weeks?"
	label var k30_1_m	"How much did the PM earn for paid work outside the home in the last 4 weeks?"
	label var k30_1		"How much did you earn for paid work outside the home in the last 4 weeks?"
	label var earn		"Adult earnings (excluding LHH and PM) outside the home in the last 4 weeks"
	label var round 	"Phone survey round"
	
	#delimit;
	lab def activity_lab
	1 "1: Tend any animals owned or leased by the household" 
	2 "2: Farm land owned or sharecropped by the household"
	3 "3: Work on business owned by household other than farm/animals (e.g. shop, crafts)"
	4 "4: Work as an agricultural laborer outside household"
	5 "5: Do housework in someone else's home"
	6 "6: Work as a non-agricultural laborer outside the household (other than housework)"
	7 "7: Work in salaried/formal employment"
	8 "8: Do any other work for pay  (money or in-kind)"
	9 "9: Work on household chores (e.g. collecting water, cooking, cleaning) in your household"
	0 "0: None"
  -97 "-97: Other"
  -98 "-98: Don't answer";
  #delimit cr
	
	lab val activity activity_lab
		
	mvdecode *, mv(-99 = .d \ -98 = .r \ -97 = .n)	 
	
	
*********************************************************************************
* Clean outliers
*********************************************************************************	
	
	preserve 
		do "${Phone_Survey_do}\Cleaning\time_activities_outliers_clean.do"
		
		tempfile temp k30_1_cleaned
		save `k30_1_cleaned'
	restore 
	
		drop k30_1 k30_1_m earn 
		
		merge m:1 hhid round using "`k30_1_cleaned'", keepusing(k30_1 k30_1_m k30_1_with_outliers k30_1_m_with_outliers earn) nogen assert(3)
	
	
*********************************************************************************
*  Check for missingness in R1, R3 
*********************************************************************************		
		* First, get a clean no_pm variable 
			preserve 
				use "${roster_phonesvy}", clear 
					keep hhid round no_pm hh_mem numadult
					duplicates drop 
				
				tempfile no_pm
				save `no_pm'
			restore 
		
			merge m:1 hhid round using "`no_pm'", keepusing(no_pm hh_mem numadult) assert(2 3)
				assert round == 2 if _merge == 2
				keep if _merge == 3
				drop _merge
	
	assert k5_1!=. 	if call_status == 1 & inlist(round,1,3)
	assert k30!=.  	if call_status == 1 & inlist(round,1,3)
		* (so far only in partal interviews)
	
	cap noi assert k5_1_m!=. if call_status == 1 & no_pm == 0 & inlist(round,1,3) // 72 contradictions or 6 HHIDs in R1
	cap noi assert k30_m!=.	 if call_status == 1 & no_pm == 0 & inlist(round,1,3) // 72 contradictions or 6 HHIDs in R1 

		* 6 HHs had issues with no_pm flag so the PM questions were not asked 
		foreach var of varlist k5_1_m k30_m {
			replace `var' = .u if `var'==. & call_status == 1 & no_pm == 0 & inlist(round,1,3)
		}
		replace k30_1_m = .u if k30_1_m == . & call_status == 1 & inlist(activity,4,5,6,7,8) & k30_m == .u & no_pm == 0 & inlist(round,1,3)

	assert k30_1!=. if call_status == 1 & inlist(activity,4,5,6,7,8) & k30 == 1 & inlist(round,1,3)
	assert k30_1_m!=. if call_status == 1 & inlist(activity,4,5,6,7,8) & k30_m == 1 & inlist(round,1,3)
	
	
*********************************************************************************
*  Check for missingness in R4 since it is different due to the 2 types of surveys (short and long)
*********************************************************************************	
	assert k5_1!=. 	if incomplete_hh == 1 & call_status == 1 & round == 4
	assert k30!=. 	if incomplete_hh == 1 & call_status == 1 & round == 4 
	assert k5_1_m!=. if incomplete_hh == 1 & call_status == 1 & no_pm == 0 & round == 4
	assert k30_m!=.	 if incomplete_hh == 1 & call_status == 1  & no_pm == 0 & round == 4
		* (so far only in partal interviews)
		
	cap noi assert k30_1!=. if incomplete_hh == 1 & call_status == 1 & inlist(activity,4,5,6,7,8) & k30 == 1 & round == 4 // 24 issues for the PW 
	cap noi assert k30_1_m!=. if incomplete_hh == 1 & call_status == 1 & inlist(activity,4,5,6,7,8) & k30_m == 1 & round == 4 // 17 issues for the PM 
	* Due to a coding mistake, in R4, earnings k30_1 were not asked when activity 8 was selected, so there is some missingness there.
		unique hhid if k30_1==. & inlist(activity,4,5,6,7,8) & k30 == 1 & round == 4 
		unique hhid if k30_1_m==. & inlist(activity,4,5,6,7,8) & k30_m == 1 & no_pm == 0 & round == 4
			* This affects: 24 HHs for the PW k30_1 and 16 HHs for the PM k30_1_m 
			* It is also missing for HHID 1681 in R4 for no apparent reason 
			* Replace these instances with .u for "unexplained"
			replace k30_1 = .u if k30_1==. & inlist(activity,4,5,6,7,8) & k30 == 1 & round == 4
			replace k30_1_m = .u if k30_1_m==. & inlist(activity,4,5,6,7,8) & k30_m == 1 & no_pm == 0 & round == 4
		
	*Checking for missing in "earn"	
	cap noi assert earn != . if ((no_pm == 0 & numadult > 2) | (no_pm == 100 & numadult > 1)) & round == 4 // 11 contradicitons / 1 HHID 
	br if earn == . & ((no_pm == 0 & numadult > 2) | (no_pm == 100 & numadult > 1)) & round == 4
	* HHID 5891 (Short survey) is missing roster data so "earn" was not asked since the relevance in SCTO was not triggered 
		replace earn = .u if hhid == 5891 & round == 4
	
	* Drop extra vars 
	drop hh_mem numadult no_pm call_status

	* Make k30 and k30_m activity indicators missing across all activites in long format if missing was selected 
	foreach var in k30 k30_m {
		gen `var'_miss_r = (activity == .r & `var' == 1)
		gen `var'_miss_d = (activity == .d & `var' == 1)
		gen `var'_miss_n = (activity == .n & `var' == 1) // "other"
		
		bys hhid round: egen `var'_tot_miss_r = total(`var'_miss_r)
		bys hhid round: egen `var'_tot_miss_d = total(`var'_miss_d)
		bys hhid round: egen `var'_tot_miss_n = total(`var'_miss_n)
		
		replace `var' = .r if `var'_tot_miss_r == 1 
		replace `var' = .d if `var'_tot_miss_d == 1 
		replace `var' = .n if `var'_tot_miss_n == 1 
	}
	
	drop *miss*
	
	* Order
	order hhid round, first
	order k30_1, after(k30)
	
	* Sort
	sort hhid round activity

	* Save data
	save "${timeuse}", replace 
	
	