/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	March 7, 2019
Last udpate on: November 21, 2021
Written by:  	Thomas Escande			

Revision: 		Yulia Belyakova

********************************************************************************	

THIS DO FILE: 	Construct the financial inclusion index and saving behavior 


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Constructing new variables
				Part 2 - Treating outliers at the individual level before we sum: winsorize and replace the .o with median
				Part 3 - Constructing financial index 							
				
INPUTS:     	

		Original data 				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
		Profile data 				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
		Original data (HH roster) 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"
						
OUTPUTS:     	
			
		SES (UP + NUP) data (wide) 					 "${TUP_DB}/Phone_Survey/DataSets/Intermediate/finance_index_ses_phonesvy.dta"
		UP only data (wide)  						 "${TUP_DB}/Phone_Survey/DataSets/Intermediate/finance_index_up_phonesvy.dta"
		UP only data (long, savings and loans panel) "${TUP_DB}/Phone_Survey/DataSets/Intermediate/finance_index_long.dta"
			
				

Note: 			You will need to save the ado file that Johannes created (_gweightave.ado), which is an extension to
				egen, in your personal ado folder (find it by typing "sysdir"). Then you will be able to use
				For Mac you should be able to get there by: (1) opening Finder; (2) click ÔGoÕ in the menu bar; (3) press ÔoptionÕ - this will make ÔLibraryÕ 
				appear; and (4) follow the path indicated in the ÔPERSONALÕ directory (if personal doesn't exist, just create it.)
				For information on the command search for the _gweightave instructions.docx in Dropbox (egen indexvariable = weightave(varlist), normby(vartostandardize))
				You can also refer to Anderson (2008), p. 1485, and the GD paper's pre-analysis plan (the version online, p. 13).

		Notes & issues:
			1. If using R4 data, the index only has 2 components: total savings and access to formal credit.
					If only using R1 and R2 data, we do not have an index since we only have one component: savings.
					We only have an index in R4.
			3. Replacing .o for gross outliers for saving and loan with the median per ultra poor and treatment. In fl1, this was done 
				on a per loan basis, but now we ask in the aggregate for all loans.
			4. Data with constructed variables is reshaped wide to preserve indicators in multiple rounds.

				
				
*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off
set maxvar 20000

	* Input files
		gl all_hhlevel_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
		gl phone_svy_profile   		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
		gl roster					"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"
		
	* Output files: 
		global finance_index_ses 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/finance_index_ses_phonesvy.dta"
		global finance_index_up  	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/finance_index_up_phonesvy.dta"

		* Panel data on loans and savings 
		global finance_index_long 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/finance_index_long.dta"
		
************************************************************************************************************
** Part 1: Constructing Variables for Financial Index
************************************************************************************************************
use "${all_hhlevel_phonesvy}", clear 

* Merge on profile data 
merge m:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment attrition_r1 attrition_r2 attrition_r1_or_r2 attrition_r4 survey_type_r4) keep(3) nogen
	replace survey_type_r4 = . if round != 4
	assert survey_type_r4 == incomplete_hh
	
* Keep only relevant variables 	
keep hhid treatment ultra_poor round incomplete_hh survey_type_r4 m5 m20 m3* m22* am1 am2 attrition_r4

* A little cleaning for m3 and m22 
forval i = 1/11 {
    replace m3_`i' = .r if m3__98 == 1
}

forval i = 0/10 {
    replace m22_`i' = .r if m22__98 == 1
	replace m22_`i' = .d if m22__99 == 1
}

drop m3__98 m22__98 m22__99

preserve
	use "${roster}", clear

	keep hhid round hh_mem numchild schoolchild round
	gen numadult = hh_mem - numchild // in R1, we do not ask for the number of children in the pilot but for the number of school children 
		replace numadult = hh_mem - schoolchild if mi(numadult)
	replace numchild = schoolchild if mi(numchild)
	duplicates drop hhid round, force
	
	tempfile hh_mem
	save	`hh_mem'
restore
	
	merge m:1 hhid round using `hh_mem', keepusing(hh_mem numadult numchild) nogen
	
* Gen HHsize - per adult equivaleng
	gen HHsize = 0.5*numchild + numadult
	* replace with total HH size in case missing the child / adult split 
	replace HHsize = hh_mem if mi(HHsize)

* We have data from R1, R3 and R4	
	drop if round == 2 	

* R4 only variable 	
preserve 	
	keep hhid round m22*
	keep if round == 4 
	drop round 
	drop if m22_0 == .
	
	tempfile r4_var
	save `r4_var'
restore 	

* R4 only - short survey vars 
preserve 	
	keep hhid round am1 am2 
	keep if round == 4 
	drop round 
	drop if am1 == .
	
	tempfile r4_var_short
	save `r4_var_short'
restore 

* R3 only variable 
preserve	
	keep hhid round m3* 
	keep if round == 3  
	drop round 
	drop if m3_1 == .
	
	tempfile r3_var
	save `r3_var'
restore 	
	
/*Questions of importance for index: 
m21 : knows different places where to save
m23: have a saving account
m22 : Ability to get money if needed
 --- > m5 : outstanding cash loans
m16 : Anyone saved money in last 4 weeks
m19 : total amount saved over the last 4 weeks
 --- > m20 : total savings

secondary
m1 : Whether anyone has an outstanding loan
m2 : Whether loan from a formal institution

*/
	drop m3* m22* am*
	
	merge m:1 hhid using `r4_var', nogen
	merge m:1 hhid using `r4_var_short', nogen
	merge m:1 hhid using `r3_var', nogen
	

****Constructing the variables that will be used for the analysis (not replacements)
	clonevar saving = m20
	label var saving "HH total saving"

	gen saving_dummy = (saving>0 & !mi(saving))
	replace saving_dummy = saving if mi(saving)
	label var saving_dummy 	"Whether anyone in the HH saved"

	clonevar loan = m5
	label var loan "Total outstand cash loans"

	gen loan_dummy = (loan>0 & !mi(loan))
	replace loan_dummy = loan if mi(loan)
	label var loan_dummy "Whether anyone in the HH have any kind of outstanding loan"

	gen access_credit = 0 if m22_1 != .
	label var access_credit "Can access formal credit if needed"

	foreach i in 1 2 { /*Formal credit from Formal Banks, Microfinancial institutions*/
		replace access_credit =  0 if m22_`i' == 1 
		replace access_credit = 1 if m22_`i' == 1
		replace access_credit = .d if m22_`i' == .d
	}


************************************************************************************************************
** Part 2: Treating outliers at the individual level before we sum: winsorize and replace the .o with mean
************************************************************************************************************
		*Replacing .o for gross outliers for saving and loan. Impute with the mean per ultra poor - treatment - round 
		egen mean_loan = mean(loan) if loan > 0 , by(ultra_poor treatment round)
		replace loan = mean_loan if loan == .o 
		drop  mean_loan
		
		*For savings 
		egen mean_saving = mean(saving) if saving > 0 , by(ultra_poor treatment round)
		replace saving = mean_saving if saving == .o 
		drop  mean_saving
		
	
		*Winsorizing for loan, saving
		*All the 0 become missings which is an issue and should be corrected
		* 25K max for savings in T, 300 in C in Round 1 
		bys treatment: sum saving if round == 1, d 
		//hist saving if saving <30000 & round == 1 , by(treatment) freq
		//hist saving_win if round == 1 , by(treatment) freq

		* By UP
		foreach var in saving {
			local lab : variable label `var'
			winsor2 `var', s(_win) c(0 98) by(ultra_poor round) 
			replace `var'_win = 0 if  `var' == 0
			label var `var'_win "98% Winsorized (by UP) `lab'"
		}
		
		* 250K max for loans in T, 200K in C in Round 1
		foreach var in loan {
			local lab : variable label `var'
			winsor2 `var', s(_win) c(0 97) by(ultra_poor round) 
			replace `var'_win = 0 if  `var' == 0
			label var `var'_win "97% Winsorized (by UP) `lab'"
		}
		
		* Now, by treatment
		foreach var in saving {
			local lab : variable label `var'
			winsor2 `var', s(_win_t) c(0 98) by(treatment round) 
			replace `var'_win = 0 if  `var' == 0
			label var `var'_win "98% Winsorized (by treatment) `lab'"
		}
		
		* 250K max for loans in T, 200K in C in Round 1
		foreach var in loan {
			local lab : variable label `var'
			winsor2 `var', s(_win_t) c(0 97) by(treatment round) 
			replace `var'_win = 0 if  `var' == 0
			label var `var'_win "97% Winsorized (by treatment) `lab'"
		}

* Save the "long" version of the data for panel regression
preserve 
	keep hhid round m20 m5 access_credit saving_dummy saving saving_win* loan_dummy loan loan_win*
	
	if	`c(stata_version)'>=14	{
		saveold "${finance_index_long}", replace v(13)
	}
	else {
		save "${finance_index_long}", replace
	}	
restore 

*Reshape wide (m5 m20 are the panel data variables)
	keep hhid round m5 m20 saving saving_dummy loan loan_dummy access_credit saving_win* loan_win* am1 am2 m22* m3* 
	
	qui ds
	foreach var in `r(varlist)' {
		local `var'_lab: var label `var'
	}
	
	rename * *_
	rename (hhid_ round_) (hhid round)
	
	reshape wide m5_ m20_ saving_ saving_dummy_ loan_ loan_dummy_ saving_win_ saving_win_t_ loan_win_ loan_win_t_, i(hhid) j(round)
	
	rename *_ *
	
	foreach var in m20 m5 saving saving_dummy loan loan_dummy saving_win saving_win_t loan_win loan_win_t {
		foreach i in 1 3 4 {
			label var `var'_`i' "``var'_lab' (round `i')"
		}
	}
	
	foreach round in 1 3 {
		foreach var in m20 m5 saving saving_dummy loan loan_dummy saving_win saving_win_t loan_win loan_win_t {
			local `var'_`round'_l: var label `var'_`round'
			
			gen 	`var'_all_`round' = `var'_`round'
			replace `var'_all_`round' = `var'_4 if mi(`var'_all_`round')
			
			lab var `var'_all_`round' "``var'_`round'_l', all"
		}
	}
	
	missings dropvars, force 
	
	* Merge on profile data 
	merge m:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment attrition_r4) keep(3) nogen
		
	* Creating a variable =1 if loan & for productive reasons but not conditional on having a loan
	forval i = 1/11 {
		assert mi(m3_`i') if loan_3 == 0
		clonevar m3_`i'_nocond = m3_`i'
		replace m3_`i'_nocond = 0 if loan_3 == 0
	}
	
		assert mi(m3__97) if loan_3 == 0
		clonevar m3__97_nocond = m3__97
		replace m3__97 = 0 if loan_3 == 0
		
	egen prod_loan = rowtotal(m3_4_nocond m3_5_nocond m3_6_nocond m3_7_nocond m3_10_nocond m3_11_nocond), missing 	
		replace prod_loan = 1 if prod_loan > 1 & !mi(prod_loan)
		lab var prod_loan "HH Took Loan for Productive Purpose"
		assert prod_loan == . if mi(loan_3)
	
********************************************************************************************************************************************
** Part 3: Constructing the index and saving dataset
********************************************************************************************************************************************
 
global financial_index saving access_credit
global financial_index_all saving_all access_credit_all

preserve 
	*Constructing the index - we have 2 elements only if using R4 data, otherwise we only have 1 component and there cannot be an index 
		foreach suffix in "_1" "_3" "_all_1" "_all_3" "_win_1" "_win_t_1" "_win_3" "_win_t_3" "_win_all_1" "_win_t_all_1" "_win_all_3" "_win_t_all_3" {
		
			egen fin_index_sdUP`suffix' = weightave(saving`suffix' access_credit) if attrition_r4 == 0, normby(ultra_poor)
				replace fin_index_sdUP`suffix' = . if attrition_r4 == 1 

			label var fin_index_sdUP`suffix' "Financial Inclusion Index, Standardized by Ultra Poor (2 components) (`suffix')"		
		}
		
	* Keep the relevant variables 
		keep hhid fin_index_sdUP* access_credit saving_dummy_* saving_* saving_win_* loan_dummy_* loan_* loan_win_* m3* m22* am1 am2 prod_loan  
		

	**********************Saving the bigger sample
				if	`c(stata_version)'>=14	{
					saveold "${finance_index_ses}", replace v(13)
				}
				else {
					save "${finance_index_ses}", replace
				}	

restore 

	keep if ultra_poor == 1
	gen control = (treatment == 0)
	
	preserve 
		keep if attrition_r4 == 0
		
			foreach suffix in "_1" "_3" "_all_1" "_all_3" "_win_1" "_win_t_1" "_win_3" "_win_t_3" "_win_all_1" "_win_t_all_1" "_win_all_3" "_win_t_all_3" {
			
				egen fin_index_sdC`suffix' = weightave(saving`suffix' access_credit), normby(control)

				label var fin_index_sdC`suffix' "Financial Inclusion Index, Standardized by Ultra Poor (2 components) (`suffix')"		
			}
				
			keep hhid fin_index_sdC*
			tempfile indices
			save `indices'
	restore
	
		merge 1:1 hhid using "`indices'", nogen
				
	* Keep the relevant variables 
		keep hhid fin_index_sdC* access_credit saving_dummy_* saving_* saving_win_* loan_dummy_* loan_* loan_win_* m3* m22* am1 am2 prod_loan

*Saving
			if	`c(stata_version)'>=14	{
				saveold "${finance_index_up}", replace v(13)
			}
			else {
				save "${finance_index_up}", replace
			}	
