/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	February 12, 2019
Last udpate on: November 30, 2021

Written by:  	Thomas Escande			

Revision: 		Yulia Belyakova 

********************************************************************************	

THIS DO FILE: 	Construct the psychological well being index for Phone Survey R1 & R2
	


CONTENT:		Part 0 - Create globals for directories and files 
				Part 0A,B - Recoding and inverting scales 
				Part 1 - Constructing Cortisol variables, naive one and as the residuals of the regression of cortisol on confounders 
				Part 2 - Psychological Well Being Indices Construction - General
				Part 3 - Constructing Index for ultra poor only, standardized by control group
				Part 4 - Constructing Index for ultra poor only, standardized by female [not included for Phone Survey]
				


INPUTS:  
				Original data 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
				Roster 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"
				Profile data 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
										
OUTPUTS:     	
				Psy well-being index (SES, full sample)  	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/wellbeing_index_ses_phonesvy.dta"
				Psy well-being index (UP)					"${TUP_DB}/Phone_Survey/DataSets/Intermediate/wellbeing_index_up_phonesvy.dta"
				Psy well-being index (NUP,  control) 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/wellbeing_index_nup_phonesvy.dta"


Note: 			You will need to save the ado file that Johannes created (_gweightave.ado), which is an extension to
				egen, in your personal ado folder (find it by typing "sysdir"). Then you will be able to use
				For Mac you should be able to get there by: (1) opening Finder; (2) click ÔGoÕ in the menu bar; (3) press ÔoptionÕ - this will make ÔLibraryÕ 
				appear; and (4) follow the path indicated in the ÔPERSONALÕ directory (if personal doesn't exist, just create it.)
				For information on the command search for the _gweightave instructions.docx in Dropbox (egen indexvariable = weightave(varlist), normby(vartostandardize))
				You can also refer to Anderson (2008), p. 1485, and the GD paper's pre-analysis plan (the version online, p. 13).
				
				
			Notes & Issues: 	
				1. We have a full set of observations for Life Satisfaction and Happiness in R1 and R2
					In R3, we have only a few because we later decided to not ask these question.
					We ask them in the "full survey" of R4.
				2. Variables without a suffix indicate the average of R1 and R2 which we use for analysis primarily.
				

*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off

	* Input files
		gl all_hhlevel_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
		gl phone_svy_profile   		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
		gl roster_phonesvy			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"
		

	* Output files: 
		gl wellbeing_index_ses_phonesvy "${TUP_DB}/Phone_Survey/DataSets/Intermediate/wellbeing_index_ses_phonesvy.dta"
		gl wellbeing_index_up_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/wellbeing_index_up_phonesvy.dta"
		gl wellbeing_index_nup_phonesvy "${TUP_DB}/Phone_Survey/DataSets/Intermediate/wellbeing_index_nup_phonesvy.dta"
		
		gl wellbeing_ses_long_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/wellbeing_index_ses_long_phonesvy.dta"
		gl wellbeing_up_long_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/wellbeing_index_up_long_phonesvy.dta"
		gl wellbeing_nup_long_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/wellbeing_index_nup_long_phonesvy.dta"

	
***********************************************************************************************************************
** Part 0A: Recoding psychological well being questions and creating variables to allow comparisons
***********************************************************************************************************************

use "${all_hhlevel_phonesvy}", clear
	merge m:1 hhid using "${phone_svy_profile}", keepusing(attrition_r1 attrition_r2 attrition_r4 all_rounds) keep(3) nogen
	
	keep hhid round i5 i27 i7 i10 i11 i12 i16  i23 i25 treatment ultra_poor PRA_lottery attrition_r* all_rounds
		
	* Setting globals for constructing scales 
	global satisf_wvs i5
	global cesd i7 i10 i11 i12 i16 i23 i25
	global hap_wvs i27
	
*CESD international comparison: from 0 to 21, higher score meaning higher depression
	label define cesdint 0 "Rarely or none of the time ( < 1 day)" 1 "Some or a little of the time (1-2 days)" 2 "Occasionally or a moderate amount of ti" 3 "All of the time (5-7 days)" 

	foreach var in $cesd {
		recode `var' (4 = 3) (3 = 2) (2 = 1) (1 = 0) , pre(int_score_) test

		lab values int_score_`var' cesdint
		label var int_score_`var' 	"CESD `var' for international comparison (0 to 3)"
	}

	*Happiness for international comparison: dummy = 1 if chose "Quite happy" or "Very happy"
	foreach var in $hap_wvs {
		gen happy = (`var'<=2) if !mi(`var')
		lab var happy  "LHH Very happy or quite happy (1/0)"		
	}
	
*******************************************************************************************************
** Part 0B: Invert so that "positive" outcomes go with higher values for all variables (this requires to look into individual questions for each measure)
*******************************************************************************************************
*Details

	* satisf_wvs: 10 = very satisfied, 1 = very dissatisfied - No change needed

	* cesd: 1 = rarely or none of the time to 4 = all of the time - 
	*		i7 : inverse / i10 : inverse / i11 : inverse / i12 : inverse / i16 : inverse / i23 : inverse / i25: inverse

	*hap_wvs: 1 = very happy to 4 = Not at all happy - inverse

	*Invert for cesd
		lab define cesd_inv 4 "Rarely or none of the time (<1 day)" 3 "Some or a little of the time (1-2 days)" 2 "Occasionally or a moderate (amount of time (3-4 days))" 1 "All of the time (5-7 days)"

	foreach var in $cesd {
		rename 	`var' 		`var'_origin

		gen `var'		= 5 - `var'_origin
			
		label values `var' 		cesd_inv
		label var    `var' 		"cesd inversed for index computation"
	}
						
	*Invert Happiness
		lab define hap_inv 4 "Very happy" 3	"Quite happy" 2	"Not very happy" 1	"Not at all happy"
	
		foreach var in $hap_wvs {
			rename 	`var' 		`var'_origin

			gen `var'		= 5 - `var'_origin
				
			label values `var' 		hap_inv
			label var    `var' 		"Happiness inversed for index computation"
		}
	
	
***********************************************************************************************************************
** Part 1: Psychological Well Being Indices Construction 
***********************************************************************************************************************
	*Setting globals with variables included in main indices
		global id  hhid survey

		global satisf 		i5
		global cesd 		i7 i10 i11 i12 i16  i23 i25
		global hap 			i27

		global psy_f i5 i7 i10 i11 i12 i16 i23 i25 i27
		
		*Creating control variable to use with the gweightave function
		gen 	control = 0 if treatment == 1
		replace control = 1 if treatment == 0 

	*Construction of  specific CESD index for international comparison: from 0 to 21, higher score meaning higher depression
	*Construction is made with a gen so that if any of the variables is missing, the whole index goes to missing (10 out of 2500 in total / 7 UP out of 1159 )
		gen cesd_ts 	= int_score_i7 + int_score_i10 + int_score_i11 + int_score_i12 + int_score_i16 + int_score_i23 + int_score_i25

	*Dummy for international comparison: Major depression is defined as CESD score being more than 8
		gen cesd_md = 1 	if (cesd_ts >= 8 & !mi(cesd_ts))
		replace cesd_md = 0 if (cesd_ts < 8 & !mi(cesd_ts))
			
		lab var cesd_ts 	"CESD total score (0-21)"
		lab var cesd_md 	"CESD Major depression 1/0 (=1 if score>=8) "	

		global allcategories satisf hap cesd

	*Creating a single score per category by adding all the questions
	
		global psy_score
		
		foreach groupvar in $allcategories  {
			
			gen `groupvar'_score = 0

			global psy_score $psy_score `groupvar'_score

			foreach var of global `groupvar' {
				replace `groupvar'_score = `groupvar'_score + `var' /*Score is missing if one question is missing*/
			}	

				*Labelization of scores
			if "`groupvar'"=="satisf" {
				global detail "Life satisfaction (WVS)"
			}
			if "`groupvar'"=="cesd" {
				global detail "Depression (CESD)"
			}
			if "`groupvar'"=="hap" {
				global detail "Happiness (WVS)"
			}
		
			label var `groupvar'_score "$detail total score" 
		}
			

	*Replacing for scores with just one variable
		replace satisf_score = i5
		replace hap_score = i27
		
	*standardization of indices - Different standardization: non UP vs UP, treated vs non treated (in ultra poor sample), male vs female (later)
	*non UP vs UP /*For Head of the household, only ultra poors are being asked that question so the indices here for _m are not very interesting*/
	
			foreach groupvar in $allcategories  {					
			    
				egen `groupvar'_z_sdUP = weightave(`groupvar'_score), normby(ultra_poor)

			*Labelization of scores
				if "`groupvar'"=="satisf" {
					global detail "Life satisfaction (WVS)"
				}
				if "`groupvar'"=="cesd" {
					global detail "Depression (CESD)"
				}
				if "`groupvar'"=="hap" {
					global detail "Happiness (WVS)"
				}
				
				label var `groupvar'_z_sdUP "$detail standardized score (ultrapoor)" 		
			}
			
			
		preserve
			* Only keep a subset of HHs with non-missing Depression (i.e., survyed in R2)
			keep if attrition_r1 == 0 & attrition_r2 == 0 
			
			*Creating the index with 3 items (all available). Standardized with respect to ultra poor. 
			egen psy_index3_sdUP = weightave(satisf_z_sdUP hap_z_sdUP cesd_z_sdUP) , normby(ultra_poor)
			* 2 items only 
			egen psy_index2_sdUP = weightave(satisf_z_sdUP hap_z_sdUP), normby(ultra_poor)
			
			*Label final variables
			label var psy_index3_sdUP 		"Psychological Well-being Index(3 item) sd(ultrapoor)"
			label var psy_index2_sdUP 		"Psychological Well-being Index(2 item) sd(ultrapoor)"
		
			keep hhid round psy_index*_sdUP
			tempfile index
			save `index'
		restore 		
		
		merge 1:1 hhid round using `index', assert(1 3) nogen
		
*This time, standardizing by control ultra poor to have it comparable 
gen      ultra_poor_control = 0 
replace  ultra_poor_control = 1 if control == 1 &  ultra_poor == 1

		foreach groupvar in $allcategories {

			egen `groupvar'_z_sdUP_C = weightave(`groupvar'_score), normby(ultra_poor_control)

		*Labelization of scores
			if "`groupvar'"=="satisf" {
				global detail "Life satisfaction (WVS)"
			}
			if "`groupvar'"=="cesd" {
				global detail "Depression (CESD)"
			}
			if "`groupvar'"=="hap" {
				global detail "Happiness (WVS)"
			}
			
				
			label var `groupvar'_z_sdUP_C "$detail standardized score (ultra_poor_control)"
		}
		
		preserve 	
			* Only keep a subset of HHs with non-missing Depression (i.e., survyed in R2)
			keep if attrition_r1 == 0 & attrition_r2 == 0 
			
		*Creating the index with 3 items (all available). Standardized with respect to ultra poor. 
			egen psy_index3_sdUP_C = weightave(satisf_z_sdUP_C hap_z_sdUP_C cesd_z_sdUP_C), normby(ultra_poor_control)
			egen psy_index2_sdUP_C = weightave(satisf_z_sdUP_C hap_z_sdUP_C), normby(ultra_poor_control)
			
		*Label final variables
			label var psy_index3_sdUP_C 		"Psychological Well-being Index(3 item) sd(ultra_poor_control)"
			label var psy_index2_sdUP_C 		"Psychological Well-being Index(2 item) sd(ultra_poor_control)"
			
			keep hhid round psy_index*_sdUP_C
			tempfile index
			save `index'
		restore 		
		
		merge 1:1 hhid round using `index', assert(1 3) nogen
		
		*Saving dataset with index including ultra poor and non ultra poor standardized by ultra poor
				if	`c(stata_version)'>=14	{
				saveold "${wellbeing_ses_long_phonesvy}", replace v(13)
			}
				else {
				save "${wellbeing_ses_long_phonesvy}", replace
			}	
			

***********************************************************************************************************************
** Part 3: Constructing Index for ultra poor only, standardized by control group
***********************************************************************************************************************
	drop *_sd* 

	* Save temp file 
	tempfile long_data
	save `long_data'
 
	*Keep only ultra poor as comamnd weightave does not deal well with the 'if' condition
		keep if ultra_poor == 1

	*Control vs treatment
		foreach groupvar in $allcategories {
			egen `groupvar'_z_sdC = weightave(`groupvar'_score), normby(control)

			*Labelization of scores
			if "`groupvar'"=="satisf" {
				global detail "Life satisfaction (WVS)"
			}
			if "`groupvar'"=="cesd" {
				global detail "Depression (CESD)"
			}
			if "`groupvar'"=="hap" {
				global detail "Happiness (WVS)"
			}
			
			label var `groupvar'_z_sdC "$detail standardized score (control)" 
		}
		
		preserve 	
			* Only keep a subset of HHs with non-missing Depression (i.e., survyed in R2)
			keep if attrition_r1 == 0 & attrition_r2 == 0 
		
		*Creating the index with 3 items (all available). Standardized with respect to the control group. 				
			egen psy_indexC_sdC = weightave(satisf_z_sdC hap_z_sdC cesd_z_sdC), normby(control)
			egen psy_index2_sdC = weightave(satisf_z_sdC hap_z_sdC), normby(control)
		
		*Labelling final variables
			label var psy_indexC_sdC 		"Psychological Well-being Index(3 items) sd(control)"
			label var psy_index2_sdC 		"Psychological Well-being Index(2 items) sd(control)"

			keep hhid round psy_index*_sdC
			tempfile index
			save `index'
		restore 		
		
		merge 1:1 hhid round using `index', assert(1 3) nogen
		
			
	*Saving dataset with index for ultra poor only standardized by control group
		if	`c(stata_version)'>=14	{
			saveold "${wellbeing_up_long_phonesvy}", replace v(13)
		}
		else {
			save "${wellbeing_up_long_phonesvy}", replace
		}	
	
	
***********************************************************************************************************************
** Part 4: Constructing Index for NUP and control ultra poor only, standardized by control group and then by treatment
***********************************************************************************************************************

	use `long_data', clear 		

	*Control vs treatment
		foreach groupvar in $allcategories {
			egen `groupvar'_z_sdC_NUP = weightave(`groupvar'_score), normby(control)

			*Labelization of scores
			if "`groupvar'"=="satisf" {
				global detail "Life satisfaction (WVS)"
			}
			if "`groupvar'"=="cesd" {
				global detail "Depression (CESD)"
			}
			if "`groupvar'"=="hap" {
				global detail "Happiness (WVS)"
			}
			
			label var `groupvar'_z_sdC_NUP "$detail standardized score (control)" 
				
		} 
		
		preserve 	
		* Only keep a subset of HHs with non-missing Depression (i.e., survyed in R2)
			keep if attrition_r1 == 0 & attrition_r2 == 0 
			
		*Creating the index with 5 items (all available). Standardized with respect to the control group. 				
			egen psy_indexC_sdC_NUP = weightave(satisf_z_sdC_NUP hap_z_sdC_NUP cesd_z_sdC_NUP), normby(control)
			egen psy_index2_sdC_NUP = weightave(satisf_z_sdC_NUP hap_z_sdC_NUP), normby(control)

		*Labelling final variables
			label var psy_indexC_sdC_NUP	"Psychological Well-being Index(3 items) sd(control)"
			label var psy_index2_sdC_NUP	"Psychological Well-being Index(2 items) sd(control)"

		keep hhid round psy_index*_sdC_NUP
			tempfile index
			save `index'
		restore 		
		
		merge 1:1 hhid round using `index', assert(1 3) nogen
			
	*Saving dataset with index for ultra poor only standardized by control group
		if	`c(stata_version)'>=14	{
			saveold "${wellbeing_nup_long_phonesvy}", replace v(13)
		}
		else {
			save "${wellbeing_nup_long_phonesvy}", replace
		}	
	
	
***********************************************************************************************************************
** Following the same steps for wide data 
***********************************************************************************************************************
	
use "${all_hhlevel_phonesvy}", clear
	merge m:1 hhid using "${phone_svy_profile}", keepusing(attrition_r1 attrition_r2 attrition_r4 all_rounds) keep(3) nogen
	
	keep hhid round i5 i27 i7 i10 i11 i12 i16  i23 i25 treatment ultra_poor PRA_lottery attrition_r* all_rounds
		
	* Reshape wide 
	unab varlist: i5 - i25
	 
	foreach var in `varlist' { 
		local l`var' : variable label `var' 
	}	 	
	
	rename * *_
	rename (hhid_ round_ treatment_ PRA_lottery_ ultra_poor_ attrition_r1_ attrition_r2_ attrition_r4_ all_rounds_) (hhid round treatment PRA_lottery ultra_poor attrition_r1 attrition_r2 attrition_r4 all_rounds)
	reshape wide i5_ i27_ i7_ i10_ i11_ i12_ i16_ i23_ i25_ , i(hhid) j(round)
	
	foreach var in i5 i27 i7 i10 i11 i12 i16 i23 i25 { 
		label var `var'_1 "`l`var''" 
		label var `var'_2 "`l`var''" 
		label var `var'_3 "`l`var''" 
		label var `var'_4 "`l`var''" 
	}	 	
	
	missings dropvars, force 
	
	* Drop R4, as there are only ~80 observations (we started with asking these questions and then decied to cut them) 
	drop *_3 

	* "Fill" in missingness by including data from R4 (the full survey)
	foreach var in i5 i27 {
		gen 	`var'_1_all = `var'_1
		replace `var'_1_all = `var'_4 if mi(`var'_1_all) & !mi(`var'_4)
		
		gen 	`var'_2_all = `var'_2
		replace `var'_2_all = `var'_4 if mi(`var'_2_all) & !mi(`var'_4)
	} 
	
* Create R1,3,4 variables for CESD that are equal to R2 for ease of construction below	
	foreach var in i7 i10 i11 i12 i16  i23 i25 {
		local l`var'_2: variable label `var'_2
		gen `var'_1 = `var'_2
		lab var `var'_1 "`l`var'_2' (fake)"
	}
			
* Setting globals for constructing scales 
	global satisf_wvs i5
	global cesd i7 i10 i11 i12 i16 i23 i25
	global hap_wvs i27
	
*CESD international comparison: from 0 to 21, higher score meaning higher depression
	label define cesdint 0 "Rarely or none of the time ( < 1 day)" 1 "Some or a little of the time (1-2 days)" 2 "Occasionally or a moderate amount of ti" 3 "All of the time (5-7 days)" 
	forval round = 1/2 {
		foreach var in $cesd {
			recode `var'_`round' (4 = 3) (3 = 2) (2 = 1) (1 = 0) , pre(int_score_) test

			lab values int_score_`var'_`round' cesdint
			label var int_score_`var'_`round' 	"CESD `var' for international comparison (0 to 3)"
		}
	}

	*Happiness for international comparison: dummy = 1 if chose "Quite happy" or "Very happy"
	foreach round in "1" "2" "1_all" "2_all"  {
		foreach var in $hap_wvs {
			gen happy_`round' = (`var'_`round'<=2) if !mi(`var'_`round')
			lab var happy_`round'  "LHH Very happy or quite happy (1/0) (round `round')"		
		}
	}
	
	egen happy = rowmean(happy_1 happy_2) 
	egen happy_all = rowmean(happy_1_all happy_2_all) 
	lab var happy_all "LHH Very happy or quite happy (1/0) (R1 and R2 average, all)"
	
*******************************************************************************************************
** Part 0B: Invert so that "positive" outcomes go with higher values for all variables (this requires to look into individual questions for each measure)
*******************************************************************************************************
*Details

	* satisf_wvs: 10 = very satisfied, 1 = very dissatisfied - No change needed

	* cesd: 1 = rarely or none of the time to 4 = all of the time - 
	*		i7 : inverse / i10 : inverse / i11 : inverse / i12 : inverse / i16 : inverse / i23 : inverse / i25: inverse

	*hap_wvs: 1 = very happy to 4 = Not at all happy - inverse

	*Invert for cesd
		lab define cesd_inv 4 "Rarely or none of the time (<1 day)" 3 "Some or a little of the time (1-2 days)" 2 "Occasionally or a moderate (amount of time (3-4 days))" 1 "All of the time (5-7 days)"

	forval round = 1/2 {		
		foreach var in $cesd {
			rename 	`var'_`round' 		`var'_origin_`round'

			gen `var'_`round'		= 5 - `var'_origin_`round'
				
			label values `var'_`round' 		cesd_inv
			label var    `var'_`round' 		"cesd inversed for index computation"
		}
	}
						
	*Invert Happiness
		lab define hap_inv 4 "Very happy" 3	"Quite happy" 2	"Not very happy" 1	"Not at all happy"
	
	foreach round in "1" "2" "1_all" "2_all" {
		foreach var in $hap_wvs {
			rename 	`var'_`round' 		`var'_origin_`round'

			gen `var'_`round'		= 5 - `var'_origin_`round'
				
			label values `var'_`round' 		hap_inv
			label var    `var'_`round' 		"Happiness inversed for index computation (round `round')"
		}
	}	
	
***********************************************************************************************************************
** Part 1: Psychological Well Being Indices Construction 
***********************************************************************************************************************
	*Setting globals with variables included in main indices
		global id  hhid survey

		global satisf 		i5
		global cesd 		i7 i10 i11 i12 i16  i23 i25
		global hap 			i27

		global psy_f i5 i7 i10 i11 i12 i16 i23 i25 i27
		
		*Creating control variable to use with the gweightave function
		gen 	control = 0 if treatment == 1
		replace control = 1 if treatment == 0 

	*Construction of  specific CESD index for international comparison: from 0 to 21, higher score meaning higher depression
	*Construction is made with a gen so that if any of the variables is missing, the whole index goes to missing (10 out of 2500 in total / 7 UP out of 1159 )
		gen cesd_ts 	= int_score_i7_2 + int_score_i10_2 + int_score_i11_2 + int_score_i12_2 + int_score_i16_2 + int_score_i23_2 + int_score_i25_2

	*Dummy for international comparison: Major depression is defined as CESD score being more than 8
		gen cesd_md = 1 	if (cesd_ts >= 8 & !mi(cesd_ts))
		replace cesd_md = 0 if (cesd_ts < 8 & !mi(cesd_ts))
			
		lab var cesd_ts 	"CESD total score (0-21)"
		lab var cesd_md 	"CESD Major depression 1/0 (=1 if score>=8) "	

		global allcategories satisf hap cesd

	*Creating a single score per category by adding all the questions
	
		global psy_score
		
		foreach groupvar in $allcategories  {
			
			if "`groupvar'" == "cesd" {
				local round "1 2"
			}
			else {
				local round "1 2 1_all 2_all"
			}
			
			foreach round in `round' { 
			
				gen `groupvar'_score_`round' = 0

				global psy_score $psy_score `groupvar'_score_`round'

				foreach var of global `groupvar' {
					replace `groupvar'_score_`round' = `groupvar'_score_`round' + `var'_`round' /*Score is missing if one question is missing*/
				}	

					*Labelization of scores
				if "`groupvar'"=="satisf" {
					global detail "Life satisfaction (WVS)"
				}
				if "`groupvar'"=="cesd" {
					global detail "Depression (CESD)"
				}
				if "`groupvar'"=="hap" {
					global detail "Happiness (WVS)"
				}
			
				label var `groupvar'_score_`round' "$detail total score (round `round')" 
				}
			}

	*Replacing for scores with just one variable
		foreach round in "1" "2" "1_all" "2_all" {
			replace satisf_score_`round' = i5_`round'
			replace hap_score_`round' = i27_`round'
		}	
		
		* Average out Happiness and Satisfaction from R1 + R2 to have a composite index 
		egen satisf_score = rowmean(i5_1 i5_2)
		egen hap_score = rowmean(i27_1 i27_2) 
		egen satisf_score_all = rowmean(i5_1_all i5_2_all)
		lab var satisf_score_all "Life satisfaction (WVS) total score (R1 and R2 average, all)"
		egen hap_score_all = rowmean(i27_1_all i27_2_all) 
		clonevar  cesd_score = cesd_score_2
		
		clonevar  cesd_score_1_all = cesd_score_2
		clonevar  cesd_score_2_all = cesd_score_2
		clonevar  cesd_score_all = cesd_score_2
		
		* Only keep a subset of HHs with non-missing Depression (i.e., survyed in R2)
		keep if attrition_r1 == 0 & attrition_r2 == 0
		
	*standardization of indices - Different standardization: non UP vs UP, treated vs non treated (in ultra poor sample), male vs female (later)
	*non UP vs UP /*For Head of the household, only ultra poors are being asked that question so the indices here for _m are not very interesting*/
	
		foreach round in "_1" "_2" "_1_all" "_2_all" "" "_all" { 
			foreach groupvar in $allcategories  {					
			    
				egen `groupvar'_z_sdUP`round' = weightave(`groupvar'_score`round'), normby(ultra_poor)

			*Labelization of scores
				if "`groupvar'"=="satisf" {
					global detail "Life satisfaction (WVS)"
				}
				if "`groupvar'"=="cesd" {
					global detail "Depression (CESD)"
				}
				if "`groupvar'"=="hap" {
					global detail "Happiness (WVS)"
				}
				
				label var `groupvar'_z_sdUP`round' "$detail standardized score (ultrapoor) (round `round')" 		
			}
			
			*Creating the index with 5 items (all available). Standardized with respect to ultra poor. 
			egen psy_index3_sdUP`round' = weightave(satisf_z_sdUP`round' hap_z_sdUP`round' cesd_z_sdUP`round'), normby(ultra_poor)
			egen psy_index2_sdUP`round' = weightave(satisf_z_sdUP`round' hap_z_sdUP`round'), normby(ultra_poor)

			*Label final variables
			label var psy_index3_sdUP`round' 		"Psychological Well-being Index(3 item) sd(ultrapoor) (round `round')"
			label var psy_index2_sdUP`round' 		"Psychological Well-being Index(2 item) sd(ultrapoor) (round `round')"
			
		}
			
*This time, standardizing by control ultra poor to have it comparable 
gen      ultra_poor_control = 0 
replace  ultra_poor_control = 1 if control == 1 &  ultra_poor == 1

		foreach round in "_1" "_2" "_1_all" "_2_all" "" "_all" { 
			foreach groupvar in $allcategories {

				egen `groupvar'_z_sdUP_C`round' = weightave(`groupvar'_score`round'), normby(ultra_poor_control)

			*Labelization of scores
				if "`groupvar'"=="satisf" {
					global detail "Life satisfaction (WVS)"
				}
				if "`groupvar'"=="cesd" {
					global detail "Depression (CESD)"
				}
				if "`groupvar'"=="hap" {
					global detail "Happiness (WVS)"
				}
				
					
					label var `groupvar'_z_sdUP_C`suffix'`round' "$detail standardized score (ultra_poor_control)"
			} 
			*Creating the index with 5 items (all available). Standardized with respect to ultra poor. 
			egen psy_index3_sdUP_C`round' = weightave(satisf_z_sdUP_C`round' hap_z_sdUP_C`round' cesd_z_sdUP_C`round'), normby(ultra_poor_control)
			egen psy_index2_sdUP_C`round' = weightave(satisf_z_sdUP_C`round' hap_z_sdUP_C`round'), normby(ultra_poor_control)			
			
			*Label final variables
			label var psy_index3_sdUP_C`round' 		"Psychological Well-being Index(3 item) sd(ultra_poor_control)  (round `round')"
			label var psy_index2_sdUP_C`round' 		"Psychological Well-being Index(2 item) sd(ultra_poor_control)  (round `round')"

		}
		
		*Saving dataset with index including ultra poor and non ultra poor standardized by ultra poor
				if	`c(stata_version)'>=14	{
				saveold "${wellbeing_index_ses_phonesvy}", replace v(13)
			}
				else {
				save "${wellbeing_index_ses_phonesvy}", replace
			}	
			

***********************************************************************************************************************
** Part 3: Constructing Index for ultra poor only, standardized by control group
***********************************************************************************************************************

	*Keep only ultra poor as comamnd weightave does not deal well with the 'if' condition
		keep if ultra_poor == 1

	*Control vs treatment
		foreach round in "_1" "_2" "_1_all" "_2_all" "" "_all" { 
			foreach groupvar in $allcategories {
				egen `groupvar'_z_sdC`round' = weightave(`groupvar'_score`round'), normby(control)

				*Labelization of scores
				if "`groupvar'"=="satisf" {
					global detail "Life satisfaction (WVS)"
				}
				if "`groupvar'"=="cesd" {
					global detail "Depression (CESD)"
				}
				if "`groupvar'"=="hap" {
					global detail "Happiness (WVS)"
				}
				
				label var `groupvar'_z_sdC`round' "$detail standardized score (control) (round `round')" 
					
			} 
			
			*Creating the index with 5 items (all available). Standardized with respect to the control group. 				
				egen psy_indexC_sdC`round' = weightave(satisf_z_sdC`round' hap_z_sdC`round' cesd_z_sdC`round'), normby(control)
				egen psy_index2_sdC`round' = weightave(satisf_z_sdC`round' hap_z_sdC`round'), normby(control)

			*Labelling final variables
				label var psy_indexC_sdC`round' 		"Psychological Well-being Index(3 items) sd(control) (round `round')"
				label var psy_index2_sdC`round' 		"Psychological Well-being Index(2 items) sd(control) (round `round')"
		
		}
		
		preserve
			drop *index*
			
			* Keep only when Depression was collected 
			keep if all_rounds == 1
			
			foreach round in "_1" "_2" "" { 
			foreach groupvar in $allcategories {
				egen `groupvar'_z_sdC`round'_allr = weightave(`groupvar'_score`round'), normby(control)

				*Labelization of scores
				if "`groupvar'"=="satisf" {
					global detail "Life satisfaction (WVS)"
				}
				if "`groupvar'"=="cesd" {
					global detail "Depression (CESD)"
				}
				if "`groupvar'"=="hap" {
					global detail "Happiness (WVS)"
				}
				
				label var `groupvar'_z_sdC`round'_allr "$detail standardized score (control) (round `round') (all rounds)" 
					
			} 
			
			*Creating the index with 5 items (all available). Standardized with respect to the control group. 				
				egen psy_indexC_sdC`round'_allr = weightave(satisf_z_sdC`round'_allr hap_z_sdC`round'_allr cesd_z_sdC`round'_allr), normby(control)
				egen psy_index2_sdC`round'_allr = weightave(satisf_z_sdC`round'_allr hap_z_sdC`round'_allr), normby(control)

			*Labelling final variables
				label var psy_indexC_sdC`round'_allr 		"Psychological Well-being Index(3 items) sd(control) (round `round') (all rounds)"
				label var psy_index2_sdC`round'_allr 		"Psychological Well-being Index(2 items) sd(control) (round `round') (all rounds)"
		
		}
			keep hhid psy_index*_allr
			tempfile index_allr
			save `index_allr'
		restore 		
		
		merge 1:1 hhid using `index_allr', assert(1 3) nogen

	*Saving dataset with index for ultra poor only standardized by control group
		if	`c(stata_version)'>=14	{
			saveold "${wellbeing_index_up_phonesvy}", replace v(13)
		}
		else {
			save "${wellbeing_index_up_phonesvy}", replace
		}	


***********************************************************************************************************************
** Part 4: Constructing Index for NUP and control ultra poor only, standardized by control group
***********************************************************************************************************************
	use "${wellbeing_index_ses_phonesvy}", clear 
	
	preserve
	
	gen      control_nup = 0 
			replace  control_nup = 1 if treatment == 0 &  ultra_poor == 1	 
	*Control vs treatment
		foreach round in "_1" "_2" "_1_all" "_2_all" "" "_all" { 
			foreach groupvar in $allcategories {
				egen `groupvar'_z_sdC_NUP`round' = weightave(`groupvar'_score`round'), normby(control_nup)

				*Labelization of scores
				if "`groupvar'"=="satisf" {
					global detail "Life satisfaction (WVS)"
				}
				if "`groupvar'"=="cesd" {
					global detail "Depression (CESD)"
				}
				if "`groupvar'"=="hap" {
					global detail "Happiness (WVS)"
				}
				
				label var `groupvar'_z_sdC_NUP`round' "$detail standardized score (control_nup) (round `round')" 
					
			} 
			
			*Creating the index with 5 items (all available). Standardized with respect to the control group. 				
				egen psy_indexC_sdC_NUP`round' = weightave(satisf_z_sdC_NUP`round' hap_z_sdC_NUP`round' cesd_z_sdC_NUP`round'), normby(control_nup)
				egen psy_index2_sdC_NUP`round' = weightave(satisf_z_sdC_NUP`round' hap_z_sdC_NUP`round'), normby(control_nup)

		
			*Labelling final variables
				label var psy_indexC_sdC_NUP`round' 		"Psychological Well-being Index(3 items) sd(control_nup) (round `round')"
				label var psy_index2_sdC_NUP`round' 		"Psychological Well-being Index(2 items) sd(control_nup) (round `round')"
		
		}
		
			keep hhid *sdC_NUP* treatment 
			tempfile sdC_NUP
			save `sdC_NUP'
		restore 
		
		* Now, standardize by Treatment 
		preserve 
			gen      treat_nup = 0 
			replace  treat_nup = 1 if treatment == 1 &  ultra_poor == 1	 
			
			foreach round in "_1" "_2" "_1_all" "_2_all" "" "_all" { 
			foreach groupvar in $allcategories {
				egen `groupvar'_z_sdT_NUP`round' = weightave(`groupvar'_score`round'), normby(treat_nup)

				*Labelization of scores
				if "`groupvar'"=="satisf" {
					global detail "Life satisfaction (WVS)"
				}
				if "`groupvar'"=="cesd" {
					global detail "Depression (CESD)"
				}
				if "`groupvar'"=="hap" {
					global detail "Happiness (WVS)"
				}
				
				label var `groupvar'_z_sdT_NUP`round' "$detail standardized score (treatment) (round `round')" 
					
			} 
			
			*Creating the index with 5 items (all available). Standardized with respect to the control group. 				
				egen psy_indexC_sdT_NUP`round' = weightave(satisf_z_sdT_NUP`round' hap_z_sdT_NUP`round' cesd_z_sdT_NUP`round'), normby(treat_nup)
				egen psy_index2_sdT_NUP`round' = weightave(satisf_z_sdT_NUP`round' hap_z_sdT_NUP`round'), normby(treat_nup)

		
			*Labelling final variables
				label var psy_indexC_sdT_NUP`round' 		"Psychological Well-being Index(3 items) sd(treatment) (round `round')"
				label var psy_index2_sdT_NUP`round' 		"Psychological Well-being Index(2 items) sd(treatment) (round `round')"
		
		}
				keep hhid *sdT_NUP*
				tempfile sdT_NUP
				save `sdT_NUP'
		restore 
		
		merge 1:1 hhid using "`sdC_NUP'", assert(1 3) nogen
		merge 1:1 hhid using "`sdT_NUP'", assert(1 3) nogen
		
	*Saving dataset with index for ultra poor only standardized by control group
		if	`c(stata_version)'>=14	{
			saveold "${wellbeing_index_nup_phonesvy}", replace v(13)
		}
		else {
			save "${wellbeing_index_nup_phonesvy}", replace
		}


*********************************End of dofile***********************************************************************
