/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	March 9, 2019
Last udpate on: November 21, 2021

Written by:  	Thomas Escande			

Revision: 		Yulia Belyakova

********************************************************************************	

THIS DO FILE: 	Construct the wealth index based on asset ownership using Principal Component Analysis (PCA)

			Issues & notes:

				1. Property-based index is generated without the house ownership component (own_dwelling) since
					the question about dwelling ownership status is not asked directly in the Phone Survey
				2. Includes R2 and R4 DHS asset construction. R3 includes questions on other types of productive assets not analyzed here.   
				
				


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Basic cleaning and preparation of the dataset
				Part 2 - Creating Index for the whole sample
				Part 3 - Creating Index for the ultra poor sample only


				INPUTS:     "${TUP_DB}/Phone_Survey/DataSets/Intermediate/assets_roster_phonesvy.dta"
							"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
							"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"

						
OUTPUTS:     		 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/asset_index_ses_phonesvy.dta"
							"${TUP_DB}/Phone_Survey/DataSets/Intermediate/asset_index_up_phonesvy.dta"
Note: 			

*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off
set maxvar 20000

	* Input files
		global assets_data        		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/assets_roster_phonesvy.dta"
		global phone_svy_profile  		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
		global inputdata 	       		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"

		* Output files: 
		* Wide data
		global asset_index_ses 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/asset_index_ses_phonesvy.dta"
		global asset_index_up 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/asset_index_up_phonesvy.dta"
		global asset_index_nup			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/asset_index_nup_phonesvy.dta"
		
		* Long data for panel regressions 
		global asset_index_ses_long 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/asset_index_ses_phonesvy_long.dta"
		global asset_index_up_long 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/asset_index_up_phonesvy_long.dta"
		global asset_index_nup_long			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/asset_index_nup_phonesvy_long.dta"
		
********************************************************************************
	** Part 1: Basic cleaning and preparation of the dataset [R2 and R4]
********************************************************************************
	
	use "${assets_data}", clear
	
	*Merging to get ultrapoor id
	merge m:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment PRA_lottery attrition_r2 attrition_r4 all_rounds) assert(2 3) keep(3) nogen
	
	* Keep DHS assets only for now (and "none", asset == 0)
	keep if dhs == 1 | asset == 0 
	drop dhs l1_a l1_b // these variables is for non-DHS asset quantities
	drop if round == 3 	
		
	* Only keeping families which owns at least one of the asset to facilitate later analysis
	bys hhid round: gen no_asset = (l1 == 1 & asset == 0)
	bys hhid round: egen no_asset_max = max(no_asset) // only 4 HHs 
	drop no_asset
	
	tab no_asset_max
	unique hhid if no_asset_max == 1 
	
	keep if no_asset_max == 0
	
	keep if l1 == 1  
		
	* Standardize land values to hectares
	gen l3 	   = l3_house * $jerib
	replace l3 = l3_land  * $biswa if mi(l3)
	replace l3 = .u if (l3_land == .u | l3_house == .u)
	replace l3 = .d if (l3_land == .d | l3_house == .d)
	replace l3 = .r if (l3_land == .r | l3_house == .r)
	label var l3 "Total size of land (hectares)"
	drop l3_house l3_land
		
	* Winsorize land size (ask Mohammad about this)
	winsor2 l3, cuts(1 99) suffix(_win) by(ultra_poor)
	lab var l3_win "Total size of land (hectares) - 1-99 pct winsorized"
	
	*Reshape to get one variable per asset
	
	* Rename suffix for each item
	rename (l1 l2 l3 l3_win) (l1_ l2_ l3_ l3_win_)

	reshape wide l1_ l2_ l3_ l3_win_, i(hhid round) j(asset)
 	
	
	*Creating local per type of asset
		loc	asset1	radio_CD
		loc	asset2	TV
		loc	asset3	DishTV
		loc	asset4	VCR_DVD
		loc	asset5	house_Land
		loc	asset6	nonHouse_Land
		loc	asset7	othHouse
		loc	asset8	fridge
		loc	asset9	generator
		loc	asset10	matress
		loc	asset11	mobile_phone
		loc	asset12	non_mobilephone
		loc	asset13	iron
		loc	asset14	bedframe
		loc	asset15	jewelry
		loc	asset16	mosquitonet
		loc	asset17	mosq_repel_candle
		loc	asset18	fan
		loc	asset19	camera

	*Creating dummy for ownership and a variable for the number owned of each asset
	forval	assetnum=1/19	{
		gen	own_`asset`assetnum''		= 0
		replace own_`asset`assetnum'' 	= 1 if l1_`assetnum' == 1 
		lab	var	own_`asset`assetnum''	"Household owns any `asset`assetnum''"

		gen num_`asset`assetnum'' 		= 0
		replace num_`asset`assetnum''   = l1_`assetnum' * l2_`assetnum' if !mi(l1_`assetnum')
		lab	var	num_`asset`assetnum''	"Number of `asset`assetnum'' owned by the household"
	}
	
	*Checking whether there can be issues when multiplying l1*l2 with one missing and not the other. Only issues are lands for which we don't ask
		forval	assetnum=1/19	{
			di "`asset`assetnum''_`round'"
			count if mi(l1_`assetnum') & !mi(l2_`assetnum')
			count if !mi(l1_`assetnum') & mi(l2_`assetnum')
		}

	replace num_house_Land 		= l1_5 * l3_5
		replace num_house_Land = l3_5 if mi(num_house_Land) & l3_5!=. // add back missing
		replace num_house_Land = 0 if l1_5 == 0 // make this question unconditional
	replace num_nonHouse_Land 	= l1_6 * l3_6 
		replace num_nonHouse_Land = l3_6 if mi(num_nonHouse_Land) & l3_6!=. // add back missing
		replace num_nonHouse_Land = 0 if l1_6 == 0 // make this question unconditional
	lab	var	num_house_Land		"Size of land on which the dwelling is"
	lab	var	num_nonHouse_Land	"Size of land owned by household, excluding land on which the house is"
	
	* Winsorized land 
	gen num_house_Land_win 		= l1_5 * l3_win_5
		replace num_house_Land_win = l3_5 if mi(num_house_Land_win) & l3_5!=. // add back missing
		replace num_house_Land_win = 0 if l1_5 == 0 // make this question unconditional	
	gen num_nonHouse_Land_win 	= l1_6 * l3_win_6 
		replace num_nonHouse_Land_win = l1_6 if mi(num_house_Land_win) & l1_6!=. // add back missing
		replace num_nonHouse_Land_win = 0 if l1_6 == 0 // make this question unconditional
	lab	var	num_house_Land_win		"Size of land on which the dwelling is - 1/95% winsorized"
	lab	var	num_nonHouse_Land_win	"Size of land owned by household, excluding land on which the house is - 1/95% winsorized"
			
	*Standardizing the asset index to the control group to have similar type of index to present  
	gen control = (treatment == 0)
	
	tempfile assets_long
	save `assets_long'
	
	
********************************************************************************
	** Part 2: Creating Index for the whole sample (all rounds panel)
********************************************************************************
	
	*Putting in locals all the assets used in the construction of the index
	loc assets num_radio_CD  num_TV  num_DishTV  num_VCR_DVD  num_fridge  num_generator  num_matress  ///			
		num_mobile_phone  num_non_mobilephone num_iron  num_bedframe  num_jewelry  num_mosquitonet  /// 
		num_mosq_repel_candle  num_fan  num_camera

	loc property own_house_Land own_nonHouse_Land own_othHouse

	*Generates the wealth index "wealthscore" based on asset ownership
	pca `assets', mineigen(1) means 
		predict wealth_score, score 
	lab var wealth_score "Asset-based wealth index (PCA) (hh assets excluding land/property) - Whole sample" 
		
	*Standardizing 
	egen wealth_score_sdUP = weightave(wealth_score), normby(control) 
	local lab_wealth_score_sdUP : variable label wealth_score
	label var wealth_score_sdUP "Standardized `lab_wealth_score_sdUP'" 
	
	*Generates the property index separately, as specified in PAP	
	pca `property', mineigen(1) means 	
		predict property_score, score 
		lab var property_score "Property-based index (PCA), owning dwelling and land - Whole sample"
		
		*Saving dataset with wealth index for whole sample (long)	
		if	`c(stata_version)'>=14	{
			saveold "${asset_index_ses_long}", replace v(13)
		}
		else {
			save "${asset_index_ses_long}", replace
		}
		
********************************************************************************
	** Part 3: Creating Index for the ultra poor sample only
********************************************************************************

	drop wealth_score* property_score*
		
	*Keep only ultra poor
	keep if ultra_poor == 1

	*Generates the wealth index "wealthscore" based on asset ownership
		pca `assets', mineigen(1) means 
			predict wealth_score, score 
		lab var wealth_score "Asset-based wealth index (PCA) (hh assets excluding land/property) - UP only" 
		
	*Standardizing 
	egen wealth_score_sdC = weightave(wealth_score), normby(control) 
	local lab_wealth_score_sdC : variable label wealth_score
	label var wealth_score_sdC "Standardized `lab_wealth_score_sdC'" 	

	*Generates the property index separately, as specified in PAP	
	pca `property', mineigen(1) means 	
		predict property_score, score 
		lab var property_score "Property-based index (PCA), owning dwelling and land  - UP only" 

	* Generate the wealth index for a subsample of HHs surveyed in all rounds (for a rubustness check)
	preserve 
		drop *score* *sd*
		
		keep if all_rounds == 1 
		
		pca `assets', mineigen(1) means 
			predict wealth_score_allrounds, score 
		lab var wealth_score_allrounds "Asset-based wealth index (PCA) (hh assets excluding land/property) - All HHs" 
			
		*Standardizing 
		egen wealth_score_sdC_allrounds = weightave(wealth_score_allrounds), normby(control) 
		local lab_wealth_score_sdC_allrounds : variable label wealth_score_sdC_allrounds
		label var wealth_score_sdC_allrounds "Standardized `lab_wealth_score_sdC_allrounds'"
		
		keep hhid round wealth_score_allrounds wealth_score_sdC_allrounds 
		
		tempfile wealth_allrounds
		save `wealth_allrounds'
	restore 
	
	merge 1:1 hhid round using "`wealth_allrounds'", assert(1 3) nogen
		
	*Saving dataset with wealth index for ultra poor only (long)	
			if	`c(stata_version)'>=14	{
				saveold "${asset_index_up_long}", replace v(13)
			}
			else {
				save "${asset_index_up_long}", replace
			}	
	
	
********************************************************************************
	** Part 4: Creating Index for the NUP sample only
********************************************************************************
	use `assets_long', clear 
				
	*Keep only non-ultra poor and control 
	drop if treatment == 1

	*Generates the wealth index "wealthscore" based on asset ownership
	pca `assets', mineigen(1) means 
		predict wealth_score, score 
	lab var wealth_score "Asset-based wealth index (PCA) (hh assets excluding land/property) - NUP sample" 
	
	*Standardizing 
	egen wealth_score_sdNUP = weightave(wealth_score), normby(control) 
	local lab_wealth_score_sdNUP : variable label wealth_score
	label var wealth_score_sdNUP "Standardized `lab_wealth_score_sdNUP'" 
		
	*Generates the property index separately, as specified in PAP	
			pca `property', mineigen(1) means 	
				predict property_score, score 
				lab var property_score "Property-based index (PCA), owning dwelling and land - NUP sample" 
		
		
	*Saving dataset with wealth index for ultra poor only (long)
				if	`c(stata_version)'>=14	{
				saveold "${asset_index_nup_long}", replace v(13)
			}
			else {
				save "${asset_index_nup_long}", replace
			}	
	
********************************************************************************
	** Part 5: Creating Index for the whole sample (separate for each round)
********************************************************************************	
	use `assets_long'
	
	keep hhid round attrition_r2 attrition_r4 PRA_lottery treatment ultra_poor control `assets' `property'  num_house_Land num_house_Land_win num_nonHouse_Land num_nonHouse_Land_win

	* Reshape wide 
	unab varlist: num_radio_CD - num_camera num_nonHouse_Land* num_house_Land*
	
	foreach var in `varlist' { 
		local l`var' : variable label `var' 
	}	
	
	rename (num_radio_CD  num_TV  num_DishTV  num_VCR_DVD  num_fridge  num_generator  num_matress  ///			
		num_mobile_phone  num_non_mobilephone num_iron  num_bedframe  num_jewelry  num_mosquitonet  /// 
		num_mosq_repel_candle  num_fan  num_camera own_house_Land own_nonHouse_Land own_othHouse ///
		num_house_Land num_house_Land_win num_nonHouse_Land num_nonHouse_Land_win) ///
		(num_radio_CD_  num_TV_  num_DishTV_  num_VCR_DVD_  num_fridge_  num_generator_  num_matress_  ///			
		num_mobile_phone_  num_non_mobilephone_ num_iron_  num_bedframe_  num_jewelry_  num_mosquitonet_  /// 
		num_mosq_repel_candle_  num_fan_  num_camera_ own_house_Land_ own_nonHouse_Land_ own_othHouse_ ///
		num_house_Land_ num_house_Land_win_ num_nonHouse_Land_ num_nonHouse_Land_win_)
		
	reshape wide num_radio_CD_  num_TV_  num_DishTV_  num_VCR_DVD_  num_fridge_  num_generator_  num_matress_  ///			
		num_mobile_phone_  num_non_mobilephone_ num_iron_  num_bedframe_  num_jewelry_  num_mosquitonet_  /// 
		num_mosq_repel_candle_  num_fan_  num_camera_ own_house_Land_ own_nonHouse_Land_ own_othHouse_ ///
		num_house_Land_ num_house_Land_win_ num_nonHouse_Land_ num_nonHouse_Land_win_, i(hhid) j(round)
		
	foreach var in num_radio_CD  num_TV  num_DishTV  num_VCR_DVD  num_fridge  num_generator  num_matress  ///			
		num_mobile_phone  num_non_mobilephone num_iron  num_bedframe  num_jewelry  num_mosquitonet  /// 
		num_mosq_repel_candle  num_fan  num_camera own_house_Land own_nonHouse_Land own_othHouse ///
		num_house_Land num_house_Land_win num_nonHouse_Land num_nonHouse_Land_win { 
		label var `var'_2 "`l`var''" 
		label var `var'_4 "`l`var''" 
	}	 	
	
	tempfile assets_wide
	save `assets_wide'
	
	loc	assets_2	num_radio_CD_2  num_TV_2  num_DishTV_2  num_VCR_DVD_2  num_fridge_2  num_generator_2  num_matress_2  /// 
		num_mobile_phone_2  num_non_mobilephone_2 num_iron_2  num_bedframe_2  num_jewelry_2  num_mosquitonet_2  ///  
		num_mosq_repel_candle_2  num_fan_2  num_camera_2 
	loc assets_4 num_radio_CD_4  num_TV_4  num_DishTV_4  num_VCR_DVD_4  num_fridge_4  num_generator_4  num_matress_4  ///			 
		num_mobile_phone_4  num_non_mobilephone_4 num_iron_4  num_bedframe_4  num_jewelry_4  num_mosquitonet_4  ///  
		num_mosq_repel_candle_4  num_fan_4  num_camera_4 

	loc property_2 own_house_Land_2 own_nonHouse_Land_2 own_othHouse_2  
	loc property_4 own_house_Land_4 own_nonHouse_Land_4 own_othHouse_4  	
	
	*Generates the wealth index "wealthscore" based on asset ownership
	foreach round in 2 4 {
		pca `assets_`round'', mineigen(1) means 
			predict wealth_score_`round', score 
		lab var wealth_score_`round' "Asset-based wealth index (PCA) (hh assets excluding land/property) - Whole sample (round `round')" 
		
		*Standardizing 
		egen wealth_score_sdUP_`round' = weightave(wealth_score_`round'), normby(control) 
		local lab_wealth_score_sdUP_`round' : variable label wealth_score_`round'
		label var wealth_score_sdUP_`round' "Standardized `lab_wealth_score_sdUP_`round'' (round `round')" 
		
		*Generates the property index separately, as specified in PAP	
		pca `property_`round'', mineigen(1) means 	
			predict property_score_`round', score 
			lab var property_score_`round' "Property-based index (PCA), owning dwelling and land - Whole sample (round `round')"
	}
		*Saving dataset with wealth index for whole sample (wide)	
		if	`c(stata_version)'>=14	{
			saveold "${asset_index_ses}", replace v(13)
		}
		else {
			save "${asset_index_ses}", replace
		}
		
********************************************************************************
	** Part 6: Creating Index for the ultra poor sample only (separate for each round)
********************************************************************************
		
		use `assets_wide', clear 
		
		*Keep only ultra poor
		keep if ultra_poor == 1
		
		*Generates the wealth index "wealthscore" based on asset ownership
		foreach round in 2 4 {
			pca `assets_`round'', mineigen(1) means 
				predict wealth_score_`round', score 
			lab var wealth_score_`round' "Asset-based wealth index (PCA) (hh assets excluding land/property) - UP only (round `round')" 
			
			*Standardizing 
			egen wealth_score_sdC_`round' = weightave(wealth_score_`round'), normby(control) 
			local lab_wealth_score_sdC_`round' : variable label wealth_score_`round'
			label var wealth_score_sdC_`round' "Standardized `lab_wealth_score_sdC_`round'' - UP only (round `round')" 
			
			*Generates the property index separately, as specified in PAP	
			pca `property_`round'', mineigen(1) means 	
				predict property_score_`round', score 
				lab var property_score_`round' "Property-based index (PCA), owning dwelling and land - UP only(round `round')"
		}
		*Saving dataset with wealth index for whole sample (wide)	
		if	`c(stata_version)'>=14	{
			saveold "${asset_index_up}", replace v(13)
		}
		else {
			save "${asset_index_up}", replace
		}
		
********************************************************************************
	** Part 7: Creating Index for the NUP sample only (separate for each round)
********************************************************************************
	use `assets_wide', clear 
				
	*Keep only non-ultra poor and control 
	drop if treatment == 1

	*Generates the wealth index "wealthscore" based on asset ownership
	foreach round in 2 4 {
		pca `assets_`round'', mineigen(1) means 
			predict wealth_score_`round', score 
		lab var wealth_score_`round' "Asset-based wealth index (PCA) (hh assets excluding land/property) - NUP only (round `round')" 
		
		*Standardizing 
		egen wealth_score_sdNUP_`round' = weightave(wealth_score_`round'), normby(control) 
		local lab_wealth_score_sdNUP_`round' : variable label wealth_score_`round'
		label var wealth_score_sdNUP_`round' "Standardized `lab_wealth_score_sdNUP_`round'' - NUP only (round `round')" 
		
		*Generates the property index separately, as specified in PAP	
		pca `property_`round'', mineigen(1) means 	
			predict property_score_`round', score 
			lab var property_score_`round' "Property-based index (PCA), owning dwelling and land - NUP only (round `round')"
	}
	
		*Saving dataset with wealth index for whole sample (wide)	
		if	`c(stata_version)'>=14	{
			saveold "${asset_index_nup}", replace v(13)
		}
		else {
			save "${asset_index_nup}", replace
		}
		
*********************************End of dofile***********************************************************************
