/*******************************************************************************	
Project:  		TUP - Afghanistan
Created on:  	Feb 20, 2019
Last udpate on: November 2, 2021

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)
Revision: 		Yulia Belyakova

********************************************************************************			

THIS DO FILE: 	Creates the consumption variable, the consumption consistent with ALCS, and the below the poverty line.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

		Notes & issues:
			1. Sayed's corrections are applied to non-food data without any further winsorization or treatment of outliers.
			2. As in fl1, missing values are replaced by mean at the item-ultra_poor-HH size-round level.

		
	NB: Move this piece to the globals do-file eventually:
			cpi_food_bl, cpi_food_fl1, cpi_food_phone globals are saved in the following do-files: 		Github/AFG-TUP/DataWork/Phone_Survey/Dofiles/Analysis/consumption_cpi_calculation_bl.do */

			 * CPI calcualtion do-files runs within this do-file 
				*do "${Phone_Survey_do}/Analysis/consumption_cpi_calculation_bl.do"
			
			
*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off
set maxvar 20000

* Inputs
	gl food_consumption					"${TUP_DB}/Phone_Survey/DataSets/Intermediate/foodcons_roster_phonesvy.dta" 
	gl current_roster_phonesvy 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"
	gl all_hhlevel_phonesvy 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
	gl market_imputed_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/market_imputed_fl1.dta"
	gl market_imputed_phonesvy 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/market_imputed_phonesvy.dta"
	gl nonfood_consumption_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/nonfoodcons_roster_phonesvy.dta"
	gl phone_svy_profile				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
	gl market_imputed_fl1				"${TUP_DB}/Followup_1/DataSets/Intermediate/market_imputed_fl1.dta"
	
* Outputs
	gl total_expenditure				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/total_expenditure_phonesvy.dta"
	gl food_consumption_all				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/food_consumption_all_phonesvy.dta"
	gl nonfood_consumption_all			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/nonfood_consumption_all_phonesvy.dta"
	gl total_expenditure_long			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/total_expenditure_long_phonesvy.dta"

	
********************************************************************************
	** Part 1: Food items
********************************************************************************
	
	use "${food_consumption}", clear
	
	* Get ultra-poor variable 
	merge m:1 hhid using "${phone_svy_profile}", keep(3) nogen keepus(a5 ultra_poor treatment)
		
	* Get number of HH members
		preserve
			use "${current_roster_phonesvy}", clear
			keep hhid hh_mem round
			duplicates drop hhid round, force
			tempfile hh_mem
			save	`hh_mem'
		restore
		cap drop _merge 
		merge m:1 hhid round using `hh_mem', keep(3) nogen	// 2 = R2 HHs

	* Generate consumption per capita
		*br hhid item consumed consumed_qty
		rename (c c_a) (consumed consumed_qty)
		replace consumed_qty = 0 if consumed==0
		gen consumed_qty_pc = consumed_qty/hh_mem
		replace consumed_qty_pc = consumed_qty if mi(consumed_qty) & mi(consumed_qty_pc)
		lab var consumed_qty_pc "Quantity consumed per capita" 
		
	*--------------------------------------------------------------*			
	* Replacing missings by mean    *
	*--------------------------------------------------------------*	
	
	* Rename variable
		rename consumed_qty_pc consumed_qty_pc_raw
		clonevar consumed_qty_pc = consumed_qty_pc_raw
		
	* Replace missings with group averages (grouped by HH size and Treatment)
		*br item ultra_poor hh_mem consumed_qty_pc_raw
		bys item treatment hh_mem round: egen consumed_mean_pc = mean(consumed_qty_pc) if consumed_qty_pc>0
		bys item treatment hh_mem round: egen consumed_mean_pc_2 = mean(consumed_qty_pc) 
		bys item treatment hh_mem round: egen qty_mean_pc = mean(consumed_mean_pc) //Putting mean value in all the observations of the same group
		sum consumed_mean_pc_2 if mi(qty_mean_pc) // it would be zero
		assert `r(mean)' == 0
		replace qty_mean_pc = consumed_mean_pc_2 if mi(qty_mean_pc) 

		tabmiss qty_mean_pc // 10 missing (partly due to outliers)
		
		/* There are still a few missings, so try to impute for a range of HH size (instead of specific HH size) 
		preserve 
			keep round hh_mem
			duplicates drop 
			bys round (hh_mem): generate hh_mem_bin = ceil(10 * _n/_N)
			replace hh_mem_bin = . if mi(hh_mem)
		
			tempfile hh_mem_bins
			save `hh_mem_bins'
		restore 	
		
		merge m:1 round hh_mem using `hh_mem_bins', keepusing(hh_mem_bin) assert(3) nogen
		
		bys item ultra_poor hh_mem_bin round: egen consumed_mean_pc_3 = mean(consumed_qty_pc)
		
		sum consumed_mean_pc_3 if mi(qty_mean_pc)
		replace qty_mean_pc = consumed_mean_pc_3 if mi(qty_mean_pc) */
		replace consumed_qty_pc = qty_mean_pc if mi(consumed_qty_pc) 
		
		gen food_impute = (mi(consumed_qty_pc))
		bys hhid round: egen food_impute_tot = sum(food_impute)
			replace food_impute_tot = 1 if food_impute_tot > 1 & !mi(food_impute_tot)
			lab var food_impute_tot "Food item quantity was imputed (at least one)"
		
		drop qty_mean_pc consumed_mean_pc consumed_mean_pc_*
	
		
	*--------------*
	* Merge prices *
	*--------------*
	
			preserve 
				use "${market_imputed_phonesvy}", clear 
			
				keep district item round price_mean price_midlinecomp_mean
				duplicates drop
				
				* Since R1 is missing info on Dawlatabad, take info from R2  
				expand 2 if district == 1 & round == 2, gen(expand)
				replace round = 1 if expand == 1 
				
				drop expand
				
				* Using R2 market prices instead of R1 for R1 consumption data 
				reshape wide price_mean price_midlinecomp_mean, i(district item) j(round)
				
				replace price_mean1 = price_mean2 if item != 80
				* Fill in prices for Mango from R1 market survey 
				replace price_mean2 = price_mean1 if item == 80
				replace price_mean3 = price_mean1 if item == 80
				replace price_mean4 = price_mean1 if item == 80
				
				* Do the same for the inflation variable
				replace price_midlinecomp_mean1 = price_midlinecomp_mean2 if item != 80
				* Fill in prices for Mango from R1 market survey 
				replace price_midlinecomp_mean2 = price_midlinecomp_mean1 if item == 80
				replace price_midlinecomp_mean3 = price_midlinecomp_mean1 if item == 80
				replace price_midlinecomp_mean4 = price_midlinecomp_mean1 if item == 80
				
				reshape long price_mean price_midlinecomp_mean, i(district item) j(round)
				
				tempfile prices 
				save `prices'
			restore 
	
			rename a5 district 
			cap drop _merge
			merge m:1 district item round using "`prices'", keep(1 3) keepusing(price_mean price_midlinecomp_mean)
			
			tab item round if _merge==1
		
/*                    |        Phone survey round
            Food item |         1          3          4 |     Total
----------------------+---------------------------------+----------
           Other meat |         0      1,652      1,682 |     3,334 // this is expected as we do not collect any detail on Other meat
                Mango |       520      1,652      1,682 |     3,854 // mango missing in Dawlatabad in R1 as we are using R2 data (which doesn't have mango)
----------------------+---------------------------------+----------
                Total |       520      3,304      3,364 |     7,188 */	
			
		* Price for Mango was not collected in Dawlatabad in R1, so take the average Mango price from the 3 other districts 
			bys item: egen price_mean_mango = mean(price_mean) if item == 80
			replace price_mean = price_mean_mango if mi(price_mean) & item == 80	
			assert item == 22 if mi(price_mean) // now price is only missing for "Other meat"
			drop price_mean_mango
			
		* Rename 
			rename price_mean price 
	
		/** AS A TEST, USE FL1 PRICES  
		
		**************** Midline prices 
		* Merge fl1 prices 
			preserve 
				use "${market_imputed_fl1}", clear
				rename price fl1_price
				tempfile fl1_prices
				save `fl1_prices'
			restore
		
			merge m:1 district item using "`fl1_prices'", keepusing(fl1_price) keep(3)  nogen
		****************
		
			rename a5 district
			merge m:1 district item using "${market_imputed_fl1}", keep(1 3) keepusing(price) */
		
	*-------------------------*
	* Consumption expenditure *
	*-------------------------*

		* Monthly expenditure - endline prices ((30.5*7) is a conversion factor from weekly to monthly)
			gen exp_f_m_pc_item = consumed_qty_pc * price * (30.5/7) 
			lab var exp_f_m_pc_item "Expenditure (Afghani, per capita, per month))"
	
		* Expenditure by item_type
			bys hhid item_type round: egen exp_f_m_pc = sum(exp_f_m_pc_item)	
		
		* Save intermediate dataset here to save all the information for all the items
			sort hhid item round
			save "${food_consumption_all}", replace
			
preserve 
	/* Move this piece to the globals do-file eventually:
			cpi_food_bl, cpi_food_fl1, cpi_food_phone globals are saved in the following do-files: 		Github/AFG-TUP/DataWork/Phone_Survey/Dofiles/Analysis/consumption_cpi_calculation_bl.do */

			 * CPI calcualtion
				do "${Phone_Survey_do}/Analysis/consumption_cpi_calculation_bl.do"
restore			

		* Keep one observation per household-item_type
			duplicates drop hhid item_type round, force
			keep hhid round item_type exp_f_m_pc* hh_mem ultra_poor food_impute_tot
			
			drop exp_f_m_pc_item*
			
			label val item_type .
			tostring item_type, replace 
			replace item_type = "grain" if item_type=="3"
			replace item_type = "meat_fish" if item_type=="4"
			replace item_type = "dairy" if item_type=="5"
			replace item_type = "veg" if item_type=="7"
			replace item_type = "fruit" if item_type=="8"
			replace item_type = "_"+lower(item_type)
			
		* Calculate in-house food expenditure	
			bys hhid round: egen exp_f_tot_m_pc = sum(exp_f_m_pc)
			
		* Reshape
			reshape wide exp_f_m_pc*, i(hhid round) j(item_type) s

		* Labels
			lab var exp_f_m_pc_grain  "Grains/legumes/breads expenditure (Afghanis, per capita) `label_`var''"
			lab var exp_f_m_pc_dairy "Dairy products expenditure (Afghani, per capita, per month) `label_`var''"
			lab var exp_f_m_pc_fruit  "Fruits & nuts expenditure (Afghani, per capita, per month) `label_`var''"
			lab var exp_f_m_pc_meat_fish  "Meat & fish expenditure (Afghani, per capita, per month) `label_`var''"
			lab var exp_f_m_pc_veg "Vegetables expenditure (Afghani, per capita, per month) `label_`var''"
			rename  exp_f_m_pc_* exp_f_m_pc_*
			lab var exp_f_tot_m_pc "Food expenditure (Afghani, per capita, per month)"
		
		drop hh_mem 
		tempfile food_exp
		save	`food_exp'
		
********************************************************************************
	** Part 2: Non-food items
********************************************************************************

	use "${nonfood_consumption_phonesvy}", clear
	
	* Bring ultra-poor variable 
		merge m:1 hhid using "${phone_svy_profile}", keep(3) nogen keepus(ultra_poor treatment)

	* Get number of HH members
		preserve
			use "${current_roster_phonesvy}", clear
			keep hhid hh_mem round
			duplicates drop hhid round, force
			tempfile hh_mem
			save	`hh_mem'
		restore
		merge m:1 hhid round using `hh_mem', nogen keep(3)
		
	* Generate monthly expenditure
	
		gen 	exp_nf_m = c12 if item <= 20
		replace exp_nf_m = c13/12 if item > 20
		replace exp_nf_m = .d if c13 == .d
		replace exp_nf_m = .o if c13 == .o
		replace exp_nf_m = .r if c13 == .r
		
	* Generate monthly expenditure per capita
		gen 	exp_nf_m_pc = exp_nf_m/hh_mem		
	
	*--------------------------------------------------------------*
	* Replacing missings by mean and winsorizing health 		   *
	*--------------------------------------------------------------*	
	
	* Rename variable
		rename exp_nf_m_pc exp_nf_m_pc_raw
		clonevar exp_nf_m_pc = exp_nf_m_pc_raw	
	
	* Winsorize health 97% item (by treatment group, item, round)			
		winsor2 exp_nf_m_pc, by(item treatment round) cuts(0 97) suff(_w97t)
		replace exp_nf_m_pc_w97t = exp_nf_m_pc if mi(exp_nf_m_pc_w97t)
		local l_exp_nf_m_pc : variable label exp_nf_m_pc
		lab var exp_nf_m_pc_w97t "`l_exp_nf_m_pc - Treatment Winsorized (97%)"
	
	* Replace health with winsorized version in the main variable before the imputation
		replace exp_nf_m_pc = exp_nf_m_pc_w97t if item == 38
	
	* Replace missings with group averages (grouped by HH size and Treatment)
		bys item ultra_poor hh_mem round: egen exp_mean_pc = mean(exp_nf_m_pc) if exp_nf_m_pc>0
		bys item ultra_poor hh_mem round: egen exp_mean_pc_2 = mean(exp_nf_m_pc)
		bys item ultra_poor hh_mem round: egen exp_pc_mean = mean(exp_mean_pc)
		sum exp_mean_pc_2 if mi(exp_pc_mean) // it would be zero
		assert `r(mean)' == 0
		
		replace exp_pc_mean = exp_mean_pc_2 if mi(exp_pc_mean)
		tabmiss exp_pc_mean // 10 missing 
		
		/* There are still a few missings, so try to impute for a range of HH size (instead of specific HH size) 
		preserve 
			keep round hh_mem
			duplicates drop 
			bys round (hh_mem): generate hh_mem_bin = ceil(10 * _n/_N)
			replace hh_mem_bin = . if mi(hh_mem)
		
			tempfile hh_mem_bins
			save `hh_mem_bins'
		restore 	
		
		merge m:1 round hh_mem using `hh_mem_bins', keepusing(hh_mem_bin) assert(3) nogen
		
		bys item ultra_poor hh_mem_bin round: egen exp_mean_pc_3 = mean(exp_nf_m_pc)
		
		
		sum exp_mean_pc_3 if mi(exp_pc_mean)
		replace exp_pc_mean = exp_mean_pc_3 if mi(exp_pc_mean)*/
		
		* Create a dummy for when at least one non-food expenditure item is imputed (we end up imputing quite a few)
		gen non_food_impute = (mi(exp_nf_m_pc))
		bys hhid round: egen non_food_impute_tot = sum(non_food_impute)
			replace non_food_impute_tot = 1 if non_food_impute_tot > 1 & !mi(non_food_impute_tot)
		lab var non_food_impute_tot "Non-food item expense was imputed (at least one)"
		
		drop non_food_impute
		
		* Impute missings with the mean
		replace exp_nf_m_pc = exp_pc_mean if mi(exp_nf_m_pc) 
		
		drop exp_mean_pc exp_pc_mean exp_mean_pc_* 	

		lab var exp_nf_m "Montly expenditure per item"
		lab var exp_nf_m_pc "Montly expenditure per capita per item"
	
		* Save temporary dataset for non-food all items
			save "${nonfood_consumption_all}", replace
			
	*-------------------------------------*
	* Generate total non-food consumption *
	*-------------------------------------*
	
		* Include soap and health (everything); health winsowized at 97th percentile 
		bys hhid round: egen exp_nf_tot_m_pc = sum(exp_nf_m_pc)
		lab var exp_nf_tot_m_pc "Non-food expenditure (Afghani, per capita, per month)"
	
		* Exclude soap 
		preserve 
			drop if item == 7
			
			bys hhid round: egen exp_nf_tot_m_pc_nos = sum(exp_nf_m_pc)
			lab var exp_nf_tot_m_pc_nos "Non-food expenditure (Afghani, per capita, per month) - no soap"
		
			keep hhid round exp_nf_tot_m_pc_nos
			duplicates drop
		
			tempfile nosoap
			save `nosoap'
	
		restore 
		
		merge m:1 hhid round using `nosoap', assert(3) nogen
		
		* Exclude health 
		preserve 
			drop if item == 38
			
			bys hhid round: egen exp_nf_tot_m_pc_noh = sum(exp_nf_m_pc)
			lab var exp_nf_tot_m_pc_noh "Non-food expenditure (Afghani, per capita, per month) - no health"
		
			keep hhid round exp_nf_tot_m_pc_noh
			duplicates drop
		
			tempfile noh
			save `noh'
	
		restore 
		
		merge m:1 hhid round using `noh', assert(3) nogen
		
		* Winsorizations for non-food 
		* Create winsorization for robustness check
		foreach var in exp_nf_tot_m_pc exp_nf_tot_m_pc_noh exp_nf_tot_m_pc_nos {
		
			winsor2 `var', by(ultra_poor) cuts(0 95) suff(_w95)
			replace `var'_w95 = `var' if mi(`var'_w95)
			local l_`var' : variable label `var'
			lab var `var'_w95 "`l_`var'' - UP Winsorized (95%)"
			
			winsor2 `var', by(ultra_poor) cuts(0 97) suff(_w97)
			replace `var'_w97 = `var' if mi(`var'_w97)
			local l_`var' : variable label `var'
			lab var `var'_w97 "`l_`var'' - UP Winsorized (97%)"
			
			winsor2 `var', by(ultra_poor) cuts(0 99) suff(_w99)
			replace `var'_w99 = `var' if mi(`var'_w99)
			local l_`var' : variable label `var'
			lab var `var'_w99 "`l_`var'' - UP Winsorized (99%)"
			
			* By treatment 
			winsor2 `var', by(treatment) cuts(0 95) suff(_w95t)
			replace `var'_w95t = `var' if mi(`var'_w95t)
			local l_`var' : variable label `var'
			lab var `var'_w95t "`l_`var'' - Treatment Winsorized (95%)"
			
			winsor2 `var', by(treatment) cuts(0 97) suff(_w97t)
			replace `var'_w97t = `var' if mi(`var'_w97t)
			local l_`var' : variable label `var'
			lab var `var'_w97t "`l_`var'' - Treatment Winsorized (97%)"
			
			winsor2 `var', by(treatment) cuts(0 99) suff(_w99t)
			replace `var'_w99t = `var' if mi(`var'_w99t)
			local l_`var' : variable label `var'
			lab var `var'_w99t "`l_`var'' - Treatment Winsorized (99%)"
		}	

		* Gen type of item
			gen item_type = .
			lab def item_type 1 "edu" 2 "hhrepair" 3 "medical" 4 "hh_items" 5 "wedd" 6 "tempt" 7 "transp" 8 "celeb"
			lab value item_type item_type
				replace item_type = 2 if inlist(item, 21)
				replace item_type = 3 if inlist(item, 38)
				replace item_type = 4 if inlist(item, 7)
				replace item_type = 5 if inlist(item, 36)
				replace item_type = 8 if inlist(item, 37)
			decode item_type, gen(item_type_s)
			
			* Missing for a number of partial interviews and interferes with the reshape below 
			drop if mi(item_type_s) 		
			
		* Generate consumption by type of item
			preserve
			
				bys hhid item_type round: egen exp_nf_m_type = sum(exp_nf_m_pc)
			
				duplicates drop hhid round item_type, force
				replace item_type_s = "soap" if item_type_s == "hh_items"
				replace item_type_s = "med" if item_type_s == "medical"
				
				sort item_type
				
				keep hhid round item_type_s exp_nf_m_type* ultra_poor treatment 
				rename exp_nf_m_type* exp_nf_m_type*_
				reshape wide exp_nf_m_type*, i(hhid round) j(item_type_s) s
				
				rename exp_nf_m_type_* exp_nf_m_*_pc

				lab var exp_nf_m_soap_pc "Soap `label_`var''"
				lab var exp_nf_m_hhrepair_pc "Household repairs `label_`var''"
				lab var exp_nf_m_med_pc "Medical expenses `label_`var''"
				lab var exp_nf_m_wedd_pc "Weddings and funerals, haj `label_`var''"
				lab var exp_nf_m_celeb_pc "Annual celebrations `label_`var''"
			
				gen exp_nf_m_hhrepair_pc_ca18 = exp_nf_m_hhrepair_pc * ($cpi_non_food_fl1 / $cpi_non_food_phone)
				gen exp_nf_m_med_pc_ca18 = exp_nf_m_med_pc * ($cpi_non_food_fl1 / $cpi_non_food_phone)
				gen exp_nf_m_wedd_pc_ca18 = exp_nf_m_wedd_pc * ($cpi_non_food_fl1 / $cpi_non_food_phone)
				gen exp_nf_m_celeb_pc_ca18 = exp_nf_m_celeb_pc * ($cpi_non_food_fl1 / $cpi_non_food_phone)
				gen exp_nf_m_soap_pc_ca18 = exp_nf_m_soap_pc * ($cpi_non_food_fl1 / $cpi_non_food_phone)
				
				foreach var in exp_nf_m_med_pc exp_nf_m_med_pc_ca18 exp_nf_m_soap_pc exp_nf_m_soap_pc_ca18 {
		
					winsor2 `var', by(ultra_poor) cuts(0 95) suff(_w95)
					replace `var'_w95 = `var' if mi(`var'_w95)
					local l_`var' : variable label `var'
					lab var `var'_w95 "`l_`var'' - UP Winsorized (95%)"
					
					winsor2 `var', by(ultra_poor) cuts(0 97) suff(_w97)
					replace `var'_w97 = `var' if mi(`var'_w97)
					local l_`var' : variable label `var'
					lab var `var'_w97 "`l_`var'' - UP Winsorized (97%)"
					
					winsor2 `var', by(ultra_poor) cuts(0 99) suff(_w99)
					replace `var'_w99 = `var' if mi(`var'_w99)
					local l_`var' : variable label `var'
					lab var `var'_w99 "`l_`var'' - UP Winsorized (99%)"
					
					* By treatment 
					winsor2 `var', by(treatment) cuts(0 95) suff(_w95t)
					replace `var'_w95t = `var' if mi(`var'_w95t)
					local l_`var' : variable label `var'
					lab var `var'_w95t "`l_`var'' - Treatment Winsorized (95%)"
					
					winsor2 `var', by(treatment) cuts(0 97) suff(_w97t)
					replace `var'_w97t = `var' if mi(`var'_w97t)
					local l_`var' : variable label `var'
					lab var `var'_w97t "`l_`var'' - Treatment Winsorized (97%)"
					
					winsor2 `var', by(treatment) cuts(0 99) suff(_w99t)
					replace `var'_w99t = `var' if mi(`var'_w99t)
					local l_`var' : variable label `var'
					lab var `var'_w99t "`l_`var'' - Treatment Winsorized (99%)"
				}	
				
				tempfile exp_nf_type
				save	`exp_nf_type'
			restore
			
		* Keep only one obs per HH
			keep if item == 21
			keep hhid round item exp_nf_tot_m_pc* treatment non_food_impute_tot
			merge 1:1 hhid round using `exp_nf_type', assert(3) nogen
			
			
			tempfile non_food_exp
			save	`non_food_exp'	
				
********************************************************************************
	** Part 3: Total consumption
********************************************************************************

	* Merge food consumption
		merge 1:1 hhid round using `food_exp', assert(2 3) keep(3) nogen	// do not include partail interviews
		
	*---------------------------*
	* Consistent with other TUP * 
	*---------------------------*
	
	* Apply CPI (constant 2018 AFN)
		gen exp_f_tot_m_pc_ca18 = exp_f_tot_m_pc * ($cpi_food_fl1 / $cpi_food_phone)
		lab var exp_f_tot_m_pc_ca18 "Total food monthly expenditure per capita (2018 AFN)"	

		foreach suffix in "" "_w99" "_w99t" "_w97" "_w97t" "_w95" "_w95t" {
			gen exp_nf_tot_m_pc`suffix'_ca18 = exp_nf_tot_m_pc`suffix' * ($cpi_non_food_fl1 / $cpi_non_food_phone)
			gen exp_nf_tot_m_pc_noh`suffix'_ca18 = exp_nf_tot_m_pc_noh`suffix' * ($cpi_non_food_fl1 / $cpi_non_food_phone)
			gen exp_nf_tot_m_pc_nos`suffix'_ca18 = exp_nf_tot_m_pc_nos`suffix' * ($cpi_non_food_fl1 / $cpi_non_food_phone)
			
			lab var exp_nf_tot_m_pc`suffix'_ca18 "Total non-food monthly expenditure per capita (2018 AFN) (`suffix')"	
			lab var exp_nf_tot_m_pc_noh`suffix'_ca18 "Total non-food monthly expenditure per capita (2018 AFN) - no health (`suffix')"	
			lab var exp_nf_tot_m_pc_nos`suffix'_ca18 "Total non-food monthly expenditure per capita (2018 AFN) - no soap (`suffix')"	
		}
		
		foreach suffix in "" "_w99" "_w99t" "_w97" "_w97t" "_w95" "_w95t" {
			egen exp_tot_m_pc`suffix' = rowtotal(exp_f_tot_m_pc exp_nf_tot_m_pc`suffix')
			lab var exp_tot_m_pc`suffix' "Total (food & non-food) monthly expenditure per capita (`suffix')"
			
			egen exp_tot_m_pc`suffix'_ca18 = rowtotal(exp_f_tot_m_pc_ca18 exp_nf_tot_m_pc`suffix'_ca18)
			lab var exp_tot_m_pc`suffix'_ca18 "Total (food & non-food) monthly expenditure per capita, 2018 AFN (`suffix')"	
			
			egen exp_tot_m_pc_noh`suffix' = rowtotal(exp_f_tot_m_pc exp_nf_tot_m_pc_noh`suffix')
			lab var exp_tot_m_pc_noh`suffix' "Total (food & non-food) monthly expenditure per capita - no health (`suffix')"
			
			egen exp_tot_m_pc_noh`suffix'_ca18 = rowtotal(exp_f_tot_m_pc_ca18 exp_nf_tot_m_pc_noh`suffix'_ca18)
			lab var exp_tot_m_pc_noh`suffix'_ca18 "Total (food & non-food) monthly expenditure per capita, 2018 AFN - no health (`suffix')"	
			
			egen exp_tot_m_pc_nos`suffix' = rowtotal(exp_f_tot_m_pc exp_nf_tot_m_pc_nos`suffix')
			lab var exp_tot_m_pc_nos`suffix' "Total (food & non-food) monthly expenditure per capita - no soap (`suffix')"
			
			egen exp_tot_m_pc_nos`suffix'_ca18 = rowtotal(exp_f_tot_m_pc_ca18 exp_nf_tot_m_pc_nos`suffix'_ca18)
			lab var exp_tot_m_pc_nos`suffix'_ca18 "Total (food & non-food) monthly expenditure per capita, 2018 AFN - no soap (`suffix')"	
		}
		
		* Winsorize just the NUP total consumption at 99% 
		
		foreach var in exp_tot_m_pc_noh_ca18 {
			winsor2 `var', by(ultra_poor) cuts(0 99) suff(_w99)
			replace `var'_w99 = `var' if mi(`var'_w99)
			local l_`var' : variable label `var'
			lab var `var'_w99 "`l_`var'' - UP Winsorized (99%)"
		}
		
		replace exp_tot_m_pc_noh_ca18 = exp_tot_m_pc_noh_ca18_w99 if treatment == .	
			drop exp_tot_m_pc_noh_ca18_w99
		
* Merging treatment and PRA
	merge m:1 hhid using "${phone_svy_profile}", keepus(treatment PRA_lottery) keep(1 3) nogen
	
* Save long dataset for panel regressions 	
	if	`c(stata_version)'>=14	{
		saveold "${total_expenditure_long}", replace v(13)
	}
	else {
		save "${total_expenditure_long}", replace
	}		

	
* Reshape wide to get an indicator for each round 		
		drop item PRA_lottery treatment ultra_poor

		qui ds 
		foreach var in `r(varlist)' {
			local `var'l: var label `var'
		}

		rename * *_ 
		rename (hhid_ round_) (hhid round)
		
		qui ds
		local allvars `r(varlist)'
		local id hhid round item
		local expense_vars: list local allvars - local id
		
		reshape wide `expense_vars', i(hhid) j(round)
		
		foreach var in `expense_vars' {
			foreach i of numlist 1 3 4 {
				label var `var'`i' "``var'l' (round `i')"
			}
		}	
		
	rename *_ca18_* *_*_ca18
	 
* Save
	if	`c(stata_version)'>=14	{
		saveold "${total_expenditure}", replace v(13)
	}
	else {
		save "${total_expenditure}", replace
	}

	
	
