/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Apr 23, 2019
Last udpate on: November 22, 2021

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		Yulia Belyakova

********************************************************************************			

THIS DO FILE: 	Creates female empowerment index based on discussion with Lupe and 
				in the following file: TUP_Afghanistan/Data Analysis/Others/Empowerment/female_empowerment_indicators_23Apr2019_adjusted2available.xlsx
				
				NB: 
					1. Aspirations for Daughters Index collected in R4, so the code is commented out for now (Social norms dimension of the index is 
						excluded).
					2. Political Involvement excludes membership in a political party (s10) as the question was deemed too sensitive.
					3. PW has a mobile phone account [mobile_yes_pf] is defined as PW having a phone in either R1 *or* R2 (for Access to Inputs Index).
					4. Primary female has a loan in her name [loan_yes_pf] is not constructed as these data were not collected in the phone survey. This 
						variable does not appear to be part of any index [double-check that this is how it should be].
					5. We merge on "no_pm" flag from the roster dataset as it is most up to date there to create HHH gender variable to ID male-headed HHs.
					
					
					K24 owner manager of a business:
						Instead of "filling in" values, we could construct a variable where the PW was EVER a manager/owner -
						either in R1 or R4 in cases where we have both [which is just 8 HHs]


CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl all_hhlevel_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
	gl phone_svy_profile   		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
	gl mobile_phonesvy			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/mobile_roster_phonesvy.dta"
	gl schooling_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/schooling_phonesvy.dta"
	gl timeuse_ses_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_ses_phonesvy.dta"
	gl hh_composition			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/hh_composition_phonesvy.dta"

* Outputs
	gl f_empowerment_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/f_empowerment_phonesvy.dta"
	gl f_empowerment_ses_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/f_empowerment_ses_phonesvy.dta"
	gl f_empowerment_nup_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/f_empowerment_nup_phonesvy.dta"
 
********************************************************************************
	** Part 0: Prepare dataset
********************************************************************************

use "${all_hhlevel_phonesvy}", clear

* Merging treatment and PRA
	merge m:1 hhid using "${phone_svy_profile}", keepus(treatment PRA_lottery ultra_poor attrition_r1 attrition_r2 attrition_r4) assert(2 3) keep(3) nogen update replace 
	
********************************************************************************
	** Part 1: Household expenses [R2]
********************************************************************************
	
/* Includes:
	h1: What to cook on a daily basis
	h2: Buying groceries
	h3: Buying clothing
	h4: Buying expensive items (i.e. carpet, jewelry)
	h5: Buying small items (i.e. detergent, soap)
	h6: Buying or selling land or property
	h7: Managing household finances
	h8: Making home improvements/repair */
	
preserve 	
	* Keep R2 as these outcomes are asked in R2 only 
	keep if round == 2
	
/* 1. Major Say in Food Expenditures and What to Cook (2):

	h1: What to cook on a daily basis
	h2: Buying groceries */
	
* Local for survey vars related 
	loc foodexp_survey_vars "h1 h2"
	loc foodexp_vars "h1_ac h2_ac"
	loc foodexp_vars_r "h1_ac_r h2_ac_r"
	tabm `foodexp_survey_vars', m
	
/* 2. Major Say in Home Improvements/Repairs (1):

	h8: Making home improvements/repair
*/
	loc homeexp_survey_vars "h8"
	loc homeexp_vars "h8_ac"
	loc homeexp_vars_r "h8_ac_r"
	tab `homeexp_survey_vars', m

/* 3. Major Say in Managing Household Finances (1):
		
	h7: Managing household finances
*/
	loc homefin_survey_vars "h7"
	loc homefin_vars "h7_ac"
	loc homefin_vars_r "h7_ac_r"
	tab `homefin_survey_vars', m

/* 4. Major Say in Children's School Attendance (2):

	h9: Whether your daughter should attend school
	h10: Whether your son should attend school
*/
	loc chischool_survey_vars "h9 h10"
	loc chischool_vars "h9_ac h10_ac"
	loc chischool_vars_r "h9_ac_r h10_ac_r"
	tabm `chischool_survey_vars', m

/* 5. Major Say in Children's Health Seeking (1):

	h13: Consulting a doctor when your child is ill
*/
	loc chihealth_survey_vars "h13"
	loc chihealth_vars "h13_ac"
	loc chihealth_vars_r "h13_ac_r"	
	tab `chihealth_survey_vars', m

/* 6. Major Say in Children's Marriage (2):

	h11: Marriage of daughters
	h12: Marriage of sons
*/
	loc chimarr_survey_vars "h11 h12"
	loc chimarr_vars "h11_ac h12_ac"
	loc chimarr_vars_r "h11_ac_r h12_ac_r"
	tabm `chimarr_survey_vars', m

/* 7. Major Say in Buying or Selling Land or Property (1):

	h6: Buying or selling land or property
*/
	loc homesale_survey_vars "h6"
	loc homesale_vars "h6_ac"
	loc homesale_vars_r "h6_ac_r"
	tab `homesale_survey_vars', m

/* 8. Major Say in Clothing and Other Non-food Expenditures (3):

	h3: Buying clothing
	h4: Buying expensive items (i.e. carpet, jewelry)
	h5: Buying small items (i.e. detergent, soap)
*/
	loc otherexp_survey_vars "h3 h4 h5"
	loc otherexp_vars "h3_ac h4_ac h5_ac"
	loc otherexp_vars_r "h3_ac_r h4_ac_r h5_ac_r"
	tabm `otherexp_survey_vars', m

	loc decide_survey_vars_r2 `foodexp_survey_vars' `homeexp_survey_vars' `homefin_survey_vars' `homesale_survey_vars' ///
		`chischool_survey_vars' `chihealth_survey_vars' `chimarr_survey_vars' `otherexp_survey_vars'
	
	keep hhid `decide_survey_vars_r2'

* Generate variables for index. = 1 if always consulted or always consulted and followed decision
	foreach var of local decide_survey_vars_r2 {
		local 	`var'_ac_l : variable label `var'
		gen 	`var'_ac = 1 if `var' == 3 | `var' == 4
		replace `var'_ac = 0 if `var'_ac != 1
		replace `var'_ac = . if mi(`var') | `var' == -96 // not applicable 
		lab var `var'_ac "``var'_ac_l'"
	}
	
* Generate variables for Robustness Checks. = 1 if always consulted AND followed decision
	foreach var of local decide_survey_vars_r2 {
		local 	`var'_ac_r_l : variable label `var'
		gen 	`var'_ac_r = 1 if `var' ==  4
		replace `var'_ac_r = 0 if `var'_ac_r != 1
		replace `var'_ac_r = . if mi(`var') | `var' == -96 // not applicable
		lab var `var'_ac_r "``var'_ac_r_l'"
	}	
	
	tempfile r2_indicators
	save `r2_indicators'

restore 		

********************************************************************************
	** Part 3: Women's decisions related to her body or economic opportunities 
	** 		   (access to assets, accounts, etc.) [R1, R4 completion]
********************************************************************************
	
/* Includes:
	h14: How many children to have 
	h28: If you wanted to take out a loan
	h31: If you wanted to pursue a job outside the home
	h24: If you wanted to open a new business
	Primary female has a mobile phone account 
	Primary female has a loan in her name
	h30: Primary female has savings/loans/other financial assets in your own name and separate from other */

preserve	

* This was asked in R1 and in R4 in the "long" survey
	keep if inlist(round,1,4) 
	keep hhid round h14 h28 h31 h24 h30 has_daughter
	
	* Generate variables for index. = 1 if always consulted or always consulted and followed decision
	foreach var in h14 h24 h28 h30 h31 {
		local 	`var'_ac_l : variable label `var'
		gen 	`var'_ac = 1 if `var' == 3 | `var' == 4
		replace `var'_ac = 0 if `var'_ac != 1
		replace `var'_ac = . if mi(`var') | `var' == -96 // not applicable 
		lab var `var'_ac "``var'_ac_l'"
	}
	
* Generate variables for Robustness Checks. = 1 if always consulted AND followed decision
	foreach var in h14 h24 h28 h30 h31 {
		local 	`var'_ac_r_l : variable label `var'
		gen 	`var'_ac_r = 1 if `var' ==  4
		replace `var'_ac_r = 0 if `var'_ac_r != 1
		replace `var'_ac_r = . if mi(`var') | `var' == -96 // not applicable
		lab var `var'_ac_r "``var'_ac_r_l'"
	}	
	
	foreach var in h14 h14_ac h14_ac_r h28 h28_ac h28_ac_r h31 h31_ac h31_ac_r h24 h24_ac h24_ac_r h30 h30_ac h30_ac_r has_daughter {
        local l`var' : variable label `var'
	}
	
* Reshape wide 
	rename * *_
	rename (hhid_ round_) (hhid round)
	reshape wide h14_ h14_ac_ h14_ac_r_ h28_ h28_ac_ h28_ac_r_ h31_ h31_ac_ h31_ac_r_ h24_ h24_ac_ h24_ac_r_ h30_ h30_ac_ h30_ac_r_ has_daughter_, i(hhid) j(round)

	foreach var in h14 h14_ac h14_ac_r h28 h28_ac h28_ac_r h31 h31_ac h31_ac_r h24 h24_ac h24_ac_r h30 h30_ac h30_ac_r has_daughter {
	    lab var `var'_1 "`l`var'' (round 1)"
		lab var `var'_4 "`l`var'' (round 4)"	
	}
	
	drop has_daughter_1 
	rename has_daughter_4 has_daughter
	
* "Fill" in missingness by including data from R4 (the full survey)
	foreach var in h14 h14_ac h14_ac_r h28 h28_ac h28_ac_r h31 h31_ac h31_ac_r h24 h24_ac h24_ac_r h30 h30_ac h30_ac_r {
		gen 	`var'_all = `var'_1
		replace `var'_all = `var'_4 if mi(`var'_all) & !mi(`var'_4) // this gets filled in for HHs *only* surveyed in R4
		lab var `var'_all "`l`var'' (all)"
	}
	
/* 9. Major Say in Her Fertility (1):

		h14: How many children to have
*/
	loc fert_all_survey_vars "h14_all"
	loc fert_all_vars "h14_all_ac"
	loc fert_all_vars_r "h14_all_ac_r"
	tab `fert_all_survey_vars', m
	
	loc fert_1_survey_vars "h14_1"
	loc fert_1_vars "h14_ac_1"
	loc fert_1_vars_r "h14_ac_r_1"
	tab `fert_1_survey_vars', m
	
	loc fert_4_survey_vars "h14_4"
	loc fert_4_vars "h14_ac_4"
	loc fert_4_vars_r "h14_ac_r_4"
	tab `fert_4_survey_vars', m

/* 10. Major Say in Her Taking a Loan, Opening a Business, and Working Outside of Home (3):

	h28: If you wanted to take out a loan
	h31: If you wanted to pursue a job outside the home
	h24: If you wanted to open a new business
*/

	loc h24_all_survey_vars "h24_all"
	loc h24_all_vars "h24_all_ac"
	loc h24_all_vars_r "h24_all_ac_r"
	loc h28_all_survey_vars "h28_all"
	loc h28_all_vars "h28_all_ac"
	loc h28_all_vars_r "h28_all_ac_r"
	loc h31_all_survey_vars "h31_all"
	loc h31_all_vars "h31_all_ac"
	loc h31_all_vars_r "h31_all_ac_r"
	
	loc h24_1_survey_vars "h24_1"
	loc h24_1_vars "h24_ac_1"
	loc h24_1_vars_r "h24_ac_r_1"
	loc h28_1_survey_vars "h28_1"
	loc h28_1_vars "h28_ac_1"
	loc h28_1_vars_r "h28_ac_r_1"
	loc h31_1_survey_vars "h31_1"
	loc h31_1_vars "h31_ac_1"
	loc h31_1_vars_r "h31_ac_r_1"
	
	loc h24_4_survey_vars "h24_4"
	loc h24_4_vars "h24_ac_4"
	loc h24_4_vars_r "h24_ac_r_4"
	loc h28_4_survey_vars "h28_4"
	loc h28_4_vars "h28_ac_4"
	loc h28_4_vars_r "h28_ac_r_4"
	loc h31_4_survey_vars "h31_4"
	loc h31_4_vars "h31_ac_4"
	loc h31_4_vars_r "h31_ac_r_4"
	
	loc decide_survey_vars_r1 `fert_1_survey_vars' `h24_1_survey_vars' `h28_1_survey_vars' `h31_1_survey_vars'
	loc decide_survey_vars_r4 `fert_4_survey_vars' `h24_4_survey_vars' `h28_4_survey_vars' `h31_4_survey_vars'
	
	keep hhid `decide_survey_vars_r1' `decide_survey_vars_r4' h14_* h28_* h31_* h24_* h30_* has_daughter

	* Labels
	foreach round in 1 4 {
		lab var h28_ac_`round' "If you wanted to take out a loan (`round')"
		lab var h31_ac_`round' "If you wanted to pursue a job outside the home (`round')"
		lab var h24_ac_`round' "If you wanted to open a new business (`round')"
		lab var h30_`round'    "Have savings/loans/other financial assets in your own name and separate from other household members (`round')"	
	}
	
	tempfile r1_r4_indicators
	save `r1_r4_indicators'
restore 

	*---------------------------------------------------------------*
	* Primary female has a mobile phone account [in either R1 OR R2]*
	*---------------------------------------------------------------*	
	
	preserve
	
	* Open phone roster
		use "${mobile_phonesvy}", clear
		
	* Merge all other HHs
		merge m:1 hhid using "${phone_svy_profile}", keepus(hhid anyround) assert(2 3) nogen
		keep if anyround == 1 
		drop anyround
		
	* Gen dummy for primary female has mobile phone
		gen 	mobile_yes_pf = 1 if v3 == 1
		replace mobile_yes_pf = 0 if v3 != 1
		replace mobile_yes_pf = . if a12_mobile_short == 0
		replace mobile_yes_pf = . if v3 == . 
		replace mobile_yes_pf = .d if v1 == .d
		replace mobile_yes_pf = .r if v1 == .r
		
		collapse (max) mobile_yes_pf, by(hhid)
		lab var mobile_yes_pf "Primary female has a mobile phone"
		tempfile mobile_yes_pf
		save 	`mobile_yes_pf'
	
	restore
	
	* Merge on indicators from various rounds 	
	use "`r1_r4_indicators'", clear 
		merge 1:1 hhid using "`r2_indicators'", nogen
		merge 1:1 hhid using "`mobile_yes_pf'", nogen	
	

********************************************************************************
	** Part 4: Taking advantage of economic opportunities
********************************************************************************
	
/* Includes:
	Engaged in productive activities
	Engaged in paid productive activities 
	k24: Primary female is owner or manager of a HH non-agricultural bussiness */
	
	*---------------------------------------------------------------------------------------------------------*
	* Engaged in productive activities and in paid productive activities [R1, R3 full rounds, R4 completion]  *
	*---------------------------------------------------------------------------------------------------------*	

	preserve
	
	* Open dataset for productive activities 	
		use "${timeuse_ses_phonesvy}", clear
	* Keep only primary female (member 1 of 2 in our setup in timeuse_ses file)
		keep if member == 1
		isid hhid  
		keep hhid did_labor_nohh_1 did_labor_nohh_3 did_labor_nohh_all_1 did_labor_nohh_all_3 did_labor_nohh_4 ultra_poor treatment
		
		rename (did_labor_nohh_all_1 did_labor_nohh_all_3) (did_labor_nohh_1_all did_labor_nohh_3_all)
				
		tempfile engaged_prod_activities
		save `engaged_prod_activities'
			
	*------------------------------------------------------------------------------------------------*
	* k24: Primary female is owner or manager of a HH non-agricultural bussiness [R1, R4 completion] * 
	*------------------------------------------------------------------------------------------------*	

	* Open businesses roster
		use "${all_hhlevel_phonesvy}", clear
	
	* This was asked in R1 and in R4 in the "long" survey
		keep if inlist(round,1,4) 
		keep hhid round k23_a k24_*
			
		unab varlist: k23_a - k24_3_0
		
		foreach var in `varlist' {
			local l`var' : variable label `var'
		}	
			
	* Reshape wide 
		rename * *_
		rename (hhid_ round_) (hhid round)
		reshape wide k23_a_ k24_1_3_ k24_1_2_ k24_1_1_ k24_1_4_ k24_1_0_ k24_2_3_ k24_2_2_ k24_2_1_ ///
			k24_2_4_ k24_2_0_ k24_3_3_ k24_3_2_ k24_3_1_ k24_3_4_ k24_3_0_ , i(hhid) j(round)
					
		foreach var in k23_a k24_1_3 k24_1_2 k24_1_1 k24_1_4 k24_1_0 k24_2_3 k24_2_2 k24_2_1 k24_2_4 k24_2_0 k24_3_3 k24_3_2 k24_3_1 k24_3_4 k24_3_0 {
			foreach round in 1 4 {
				lab var `var'_`round' "`l`var''"
			}
		}	
	
* Instead of "filling in" values, we could construct a variable where the PW was EVER a 
* manager/owner - either in R1 or R4 in cases where we have both [which is just 8 HHs]
		
	* Create variable if primary female is owner or manager in one of the bussiness
		gen 	owner_manager_pf = 1 if (k24_1_3_1 == 1 | k24_2_3_1 == 1 | k24_3_3_1 == 1) | ///
										(k24_1_2_1 == 1 | k24_2_2_1 == 1 | k24_3_2_1 == 1) | ///
										(k24_1_3_4 == 1 | k24_2_3_4 == 1 | k24_3_3_4 == 1) | ///
										(k24_1_2_4 == 1 | k24_2_2_4 == 1 | k24_3_2_4 == 1)
										
										
		replace owner_manager_pf = 0 if ((k24_1_3_1 == 0 & k24_2_3_1 == 0 & k24_3_3_1 == 0) & ///
										 (k24_1_2_1 == 0 & k24_2_2_1 == 0 & k24_3_2_1 == 0) & ///
										 (k24_1_3_4 == 0 & k24_2_3_4 == 0 & k24_3_3_4 == 0) & ///
										 (k24_1_2_4 == 0 & k24_2_2_4 == 0 & k24_3_2_4 == 0)) | ///
										 ((k24_1_3_1 == 0 & k24_2_3_1 == 0 & k24_3_3_1 == 0) & ///
										 (k24_1_2_1 == 0 & k24_2_2_1 == 0 & k24_3_2_1 == 0) & ///
										 (k24_1_3_4 == . & k24_2_3_4 == . & k24_3_3_4 == .) & ///
										 (k24_1_2_4 == . & k24_2_2_4 == . & k24_3_2_4 == .)) | ///
										((k24_1_3_1 == . & k24_2_3_1 == . & k24_3_3_1 == .) & ///
										 (k24_1_2_1 == . & k24_2_2_1 == . & k24_3_2_1 == .) & ///
										 (k24_1_3_4 == 0 & k24_2_3_4 == 0 & k24_3_3_4 == 0) & ///
										 (k24_1_2_4 == 0 & k24_2_2_4 == 0 & k24_3_2_4 == 0))		
					
		replace owner_manager_pf =  0 if (k23_a_1 == 0  | k23_a_4 == 0) & owner_manager_pf == .
		replace owner_manager_pf = .d if (k23_a_1 == .d | k23_a_4 == .d) & owner_manager_pf == .
		replace owner_manager_pf = .p if (k23_a_1 == .p | k23_a_4 == .p) & owner_manager_pf == .

		duplicates drop hhid, force
		lab var owner_manager_pf "Primary female is owner or manager of a HH non-agricultural bussiness"
		tempfile owner_manager_pf
		save	`owner_manager_pf'
		
	restore
	
	*---------------------------------------------------*
	* Index: Taking advantage of economic opportunities *
	*---------------------------------------------------*
	
	merge 1:1 hhid using `engaged_prod_activities', assert(1 3) nogen
		
/*
	Result                           # of obs.
    -----------------------------------------
    not matched                           127
        from master                       127  
        from using                          0  

    matched                             1,735  
    -----------------------------------------
	
	 rmerge |      Freq.     Percent        Cum.
------------+-----------------------------------
    R1 only |          4        3.15        3.15
    R2 only |        119       93.70       96.85
  R1 and R2 |          4        3.15      100.00
------------+-----------------------------------
      Total |        127      100.00

Of 127, 119 HHs are R2 only, so they will not merge since Productive Activities were collected only in R1.
4 HHs in R1 only that do not merge are partial interviews with no data on Productive Activities, so they were dropped
	from timeuse_ses_phonesvy (1117,2073,5181,5259). */

	merge 1:1 hhid using `owner_manager_pf', assert(1 3) // 16 are master-only 
	//tab rmerge if _merge == 1 // 119 that do not merge are R2 only, which is correct (no Business data was collected in R2)
	
	loc work_1_vars owner_manager_pf did_labor_nohh_1 // using R1 female mkt work participation
	loc work_3_vars owner_manager_pf did_labor_nohh_3 // using R3 female mkt work participation
	loc work_nomkt_vars owner_manager_pf  // excluding mkt work participation
	loc inputs_1_vars h30_1 mobile_yes_pf
	loc inputs_4_vars h30_4 mobile_yes_pf
	
********************************************************************************
	** Part 5: Aspirations for daughters / Social norms [R4]
********************************************************************************
	
/* Includes:
	i1_d: What is the highest education level that you would like ${name_youngest_daughter} to complete?
	i2_d: How will this level of education help ${name_youngest_daughter}?
	i4_d: At what age would you like to see ${name_youngest_daughter} marry? 
	School-age girls are enrolled in school */
    
preserve 
	
	use "${all_hhlevel_phonesvy}", clear
	* This section is only asked in R4
	keep if round == 4 
	
	keep hhid i1_d i2_d* i4_d
	
* i1_d: What is the highest education level that you would like ${name_youngest_daughter} to complete?

	gen 	ed_level_d = i1_d 
	replace ed_level_d = ed_level_d -1 if i1_d>0 & i1_d<=13
	replace ed_level_d = .  if i1_d == -97 // other is missing
	replace ed_level_d = .  if i1_d == 17 // whatever is already completed
	replace ed_level_d = 16 if i1_d == 14 // bachelor
	replace ed_level_d = 18  if i1_d == 15 // masters
	replace ed_level_d = 0  if i1_d == 18 // no education
	replace ed_level_d = 12  if i1_d == 16 // technical	


* i2_d: How will this level of education help ${name_youngest_daughter}? -> 1 if get job/earn money, make him/her wiser

	gen 	ed_help_d = 0 if !mi(i2_d)
	replace ed_help_d = 1 if i2_d_1 == 1
	replace ed_help_d = 1 if i2_d_2 == 1
	replace ed_help_d = .d if i2_d__99 == 1
	replace ed_help_d = .r if i2_d__98 == 1

	
* i4_d: At what age would you like to see ${name_youngest_daughter} marry? 

	gen 	age_marriage_d = 1 if i4_d>18 & !mi(i4_d)
	replace age_marriage_d = 0 if i4_d<=18 & !mi(i4_d)
	replace age_marriage_d = .d if i4_d==.d
	replace age_marriage_d = .r if i4_d==.r
	replace age_marriage_d = .o if i4_d==100 // implausible value (outlier)
	
* In years
	foreach x in d {
		gen 	ed_level_yr_`x' = i1_`x' 
		replace ed_level_yr_`x' = ed_level_yr_`x' -1 if i1_`x'>0 & i1_`x'<=13
		replace ed_level_yr_`x' = .  if i1_`x' == -97 // other is missing
		replace ed_level_yr_`x' = .  if i1_`x' == 17 // whatever is already completed
		replace ed_level_yr_`x' = 16 if i1_`x' == 14 // bachelor
		replace ed_level_yr_`x' = 18  if i1_`x' == 15 // masters
		replace ed_level_yr_`x' = 0  if i1_`x' == 18 // no education
		replace ed_level_yr_`x' = 12  if i1_`x' == 16 // technical	
	}		
	
	lab var ed_level_d 		"Highest Education Level Desired (Bachelor or Above)"
	lab var ed_help_d 		"Education Level Desired Will Help to Get a Better Job and Make Her Wiser"
	lab var age_marriage_d 	"Desired Age for Marriage Is Older Than 18"
	
	loc educ_vars ed_level_yr_d ed_help_d
	loc marriage_vars age_marriage_d
	
	tempfile social_norms
	save `social_norms'
	
restore
	
	merge 1:1 hhid using "`social_norms'", nogen	
	
	
********************************************************************************
	** Part 6: Social Capital/Voice outside of the HH = Political involvement Index
********************************************************************************

/* Includes:
	s21: Has a Tazkira (Afghan national identification card)
	s10: Is a member of a political party -- NOT collected in the phone survey 
	n1: Attended village meetings 
	n2: Approached village leaders about village issue */

preserve 	

		use "${all_hhlevel_phonesvy}", clear
	
	* This was asked in R1 and in R4 in the "long" survey
		keep hhid round z2 z1_3 n1 n2
			
	* Reshape wide 
		rename * *_
		rename (hhid_ round_) (hhid round)
		reshape wide n1_ n2_ z2_ z1_3_ , i(hhid) j(round) 
	
	* Use this rule for now, but we may want to do something like with business ownership above -- i.e., 
	* if PW "ever" spoke to a village leader about an issue - for the nandful of HHs surveyed in more than 1 round with questions n1, n2
	* Tazkira is in theory asked only once; it is asked twice for about 20 HHs (documented this in another do-file - find where);
	* The reponses to this question (z2) are consistent with the exception of 1 HH, for which I assume that the first answer in R1 takes precedence
	* over the second inconsistent answer in a later round 
	
	* "Fill" in missingness by pooling data from all rounds for 
		* Majority of HHs would have answered these questions in R1, so we fill in for the ones that were only surveyed in 
		* later rounds (were missing from R1).
	foreach var in n1 n2 z2 z1_3 {
		gen 	`var'_all = `var'_1 if !mi(`var'_1)
			replace `var'_all = `var'_2 if mi(`var'_all)
			replace `var'_all = `var'_3 if mi(`var'_all)
			replace `var'_all = `var'_4 if mi(`var'_all)
	}
	
	missings dropvars, force 
	
	* z2 (PW Tazkira ownership): 1 = Have it now, 2 = Had it but lost it - combine into a 0/1 dummy 	
	foreach var in z2 {
	    foreach i in "1" "2" "3" "4" "all" {
		    replace `var'_`i' = 1 if `var'_`i' == 2
			label val `var'_`i' .
		}
	} 
	
* Labels
	foreach round in 1 2 3 4 "all" {
		lab var z2_`round' "Ever had a Tazkira (Afghan national identification card) (round `round')"
		cap noi lab var n1_`round' "Attended village meetings (round `round')"
		cap noi lab var n2_`round' "Approached village leaders about village issue (round `round')"
		lab var z1_3_`round' "PW Voted in the Last Presidential Election (round `round')" 
	}
	
	tempfile social_cap
	save `social_cap'
	
restore	
	
	merge 1:1 hhid using "`social_cap'", keep(2 3) nogen

* Local for survey vars related to political involment
	loc tazkira_vars z2_all
	loc political_vars z1_3_all // voted
	loc community_1_vars n1_1 n2_1
	loc community_4_vars n1_4 n2_4
	loc community_vars_all n1_all n2_all
	
********************************************************************************
	** Part 7: Construction of indices
********************************************************************************

* Decisionmaking
	loc foodexp_l		"Food Expenditures and What to Cook"
	loc homeexp_l 		"Home Improvements/Repairs"
	loc homefin_l 		"Managing Household Finances"
	loc chischool_l 	"Children's School Attendance"
	loc chihealth_l 	"Children's Health Seeking"
	loc chimarr_l 		"Children's Marriage"
	loc homesale_l		"Buying or Selling Land or Property"
	loc otherexp_l 		"Other Non-food Expenditures"
	loc fert_l 			"Her Fertility"
	loc h28_l 			"Her Taking a Loan"
	loc h31_l 			"Her Working Outside of Home"
	loc h24_l 			"Her Opening a Business"

	* Econ opp 
	loc work_l 			"Participation in Market Work and Running a Business"
	loc work_nomkt_l "Running a Business"
	loc inputs_l 		"Access to Resources and Inputs"
	
	* Political and Social Capital
	loc tazkira_l		"National ID Ownership"
	loc political_l 	"Political Participation"
	loc community_l 	"Community Participation"
	
	* Aspirations 
	loc educ_l 			"Daughters' Education"
	loc marriage_l 		"Daughter's Marriage in Adulthood"
	
	gl all_mkt     	"foodexp homeexp homefin chischool chihealth chimarr homesale otherexp fert_1 fert_4 h24_1 h28_1 h31_1 h24_4 h28_4 h31_4 work_1 work_3 work_nomkt inputs_1 inputs_4 tazkira community_1 community_4 political"
	gl all			"foodexp homeexp homefin chischool chihealth chimarr homesale otherexp fert_1 fert_4 h24_1 h28_1 h31_1 h24_4 h28_4 h31_4 work_1 work_3 inputs_1 inputs_4 tazkira community_1 community_4 political"

	gl all_dau 		"foodexp homeexp homefin chischool chihealth chimarr homesale otherexp fert_1 fert_4 h24_1 h28_1 h31_1 h24_4 h28_4 h31_4 work_1 work_3 inputs_1 inputs_4 tazkira community_1 community_4 political educ marriage" 

	cap drop _merge 
	merge 1:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment attrition_r1 attrition_r2 attrition_r4 all_rounds) update replace keep(3 4) nogen

	* Control dummy
	*Creating control variable to use with the gweightave function
	gen 	control = 0 if treatment == 1
	replace control = 1 if treatment == 0 
	
	*Standardizing by control ultra poor
	gen      ultra_poor_control = 0 
	replace  ultra_poor_control = 1 if control == 1 &  ultra_poor == 1
	
	* Reflect new grouping for some of the decision-making variables 
	egen foodexp 	= rowmean(h1_ac h2_ac)	
	egen otherexp 	= rowmean(h3_ac h4_ac h5_ac)
	egen chischool 	= rowmean(h9_ac h10_ac)
	egen chimarr 	= rowmean(h11_ac h12_ac)
	
* Keep only HHs surveyed in BOTH R1 & R2 since majority of indicators are coming from these rounds  	
	keep if attrition_r1 == 0 & attrition_r2 == 0
	
	tempfile empowerment
	save `empowerment'
	
	* Define a variable with which to standardize the index	
		* Overall sample first (standardize by UP Control since we want to compare this to )

	global normvar ultra_poor_control 

	* Create indices for each of the sub sub components
		foreach index in $all_mkt {
				display "`index'"
				des ``index'_vars'
				egen index_sdUP_C_`index' = weightave(``index'_vars'), normby(${normvar})
				lab var index_sdUP_C_`index' "``index'_l' Index sd(${normvar})"	
		}

	* Decisionmaking index
	loc decide_index "index_sdUP_C_foodexp index_sdUP_C_homeexp index_sdUP_C_homefin index_sdUP_C_chischool index_sdUP_C_chihealth index_sdUP_C_chimarr index_sdUP_C_homesale index_sdUP_C_otherexp index_sdUP_C_fert_1 index_sdUP_C_h24_1 index_sdUP_C_h28_1 index_sdUP_C_h31_1"
	egen index_sdUP_C_all_decisions = weightave(`decide_index'), normby(${normvar})
	lab var index_sdUP_C_all_decisions "Women's Decisionmaking Index sd(${normvar})"
	
* Econ Opp Index - using R1 mkt work participation
	loc econ_opp_index_1 "index_sdUP_C_work_1 index_sdUP_C_inputs_1"
	egen index_sdUP_C_role_prod_act_1 = weightave(`econ_opp_index_1'), normby(${normvar})
	lab var index_sdUP_C_role_prod_act_1 "Economic Opportunities Index sd(${normvar}), R1 mkt work participation"
	
* Econ Opp Index - using R3 mkt work participation and R4 inputs 
	loc econ_opp_index_3 "index_sdUP_C_work_3 index_sdUP_C_inputs_4"
	egen index_sdUP_C_role_prod_act_3 = weightave(`econ_opp_index_3'), normby(${normvar})
	lab var index_sdUP_C_role_prod_act_3 "Economic Opportunities Index sd(${normvar}), R3 mkt work participation"	
	
* Econ Opp Index - excluding mkt work participation
	loc econ_opp_index_nomkt "index_sdUP_C_inputs_4"
	egen index_sdUP_C_role_prod_act_nomkt = weightave(`econ_opp_index_nomkt'), normby(${normvar})
	lab var index_sdUP_C_role_prod_act_nomkt "Economic Opportunities Index sd(${normvar}), no mkt work participation"	
	
* Social Capital Index
	loc soc_cap_index "index_sdUP_C_tazkira index_sdUP_C_community_1 index_sdUP_C_political"
	egen index_sdUP_C_social_capital = weightave(`soc_cap_index'), normby(${normvar})
	lab var index_sdUP_C_social_capital "Social Capital Index sd(${normvar})"
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital)
	* using R1 mkt work participation
	loc all_index3_1 "index_sdUP_C_all_decisions index_sdUP_C_role_prod_act_1 index_sdUP_C_social_capital"
	egen index_sdUP_C_f_emp_3c_1 = weightave(`all_index3_1'), normby(${normvar})
	lab var index_sdUP_C_f_emp_3c_1 "Women's Empowerment Index sd(${normvar}) (3 dimensions), R1 mkt work participation"
	
	* using R3 mkt work participation
	loc all_index3_3 "index_sdUP_C_all_decisions index_sdUP_C_role_prod_act_3 index_sdUP_C_social_capital"
	egen index_sdUP_C_f_emp_3c_3 = weightave(`all_index3_3'), normby(${normvar})
	lab var index_sdUP_C_f_emp_3c_3 "Women's Empowerment Index sd(${normvar}) (3 dimensions), R1 mkt work participation"
	
	* not using mkt work participation
	loc all_index3_nomkt "index_sdUP_C_all_decisions index_sdUP_C_role_prod_act_nomkt index_sdUP_C_social_capital"
	egen index_sdUP_C_f_emp_3c_nomkt = weightave(`all_index3_nomkt'), normby(${normvar})
	lab var index_sdUP_C_f_emp_3c_nomkt "Women's Empowerment Index sd(${normvar}) (3 dimensions), no mkt work participation"
	
	
	
	**************** Create index Z score to be comparable with Banerjee et al. We take the full index although it does not necessarily has the same variables as in Banerjee ***************** 
*Start directly from the single variables, same as Banerjee 
	loc decide_index 		"h1_ac h2_ac h8_ac h7_ac h9_ac h10_ac h13_ac h11_ac h12_ac h6_ac h3_ac h4_ac h5_ac h14_ac_1 h24_ac_1 h28_ac_1 h31_ac_1"
	loc econ_opp_index_1 	"owner_manager_pf did_labor_nohh_1 h30_1 mobile_yes_pf"
	loc econ_opp_index_3 	"did_labor_nohh_3"
	loc soc_cap_index 		"z2_all z1_3_all n1_1 n2_1"
			
	* For these, computing index similarly as in Banerjee et al. (2015) science paper. Simple Z score
	foreach var in `decide_index' `econ_opp_index_1' `econ_opp_index_3' `soc_cap_index' {
		gen `var'_Z = .
			sum `var' if ultra_poor == 1
			if `r(N)' > 0 {
				replace `var'_Z = (`var' - `r(mean)') / `r(sd)' 
			}
		}

	loc decide_index_Z  		"h1_ac_Z  h2_ac_Z  h8_ac_Z  h7_ac_Z  h9_ac_Z  h10_ac_Z  h13_ac_Z  h11_ac_Z  h12_ac_Z  h6_ac_Z  h3_ac_Z  h4_ac_Z  h5_ac_Z  h14_ac_1_Z  h24_ac_1_Z  h28_ac_1_Z  h31_ac_1_Z "
	loc econ_opp_index_1_Z 		"owner_manager_pf_Z did_labor_nohh_1_Z h30_1_Z mobile_yes_pf_Z"
	loc econ_opp_index_3_Z 		"did_labor_nohh_3_Z"	
	loc soc_cap_index_Z 		"z2_all_Z z1_3_all_Z n1_1_Z n2_1_Z"
	
* Decisionmaking index
	egen index_Z_all_decisions = rowmean(`decide_index_Z')
	lab var index_Z_all_decisions "Women's Decisionmaking Index (Z score)"
	
* Econ Opp Index
	* Using R1 mkt work participation
	egen index_Z_role_prod_act_1 = rowmean(`econ_opp_index_1_Z')
	lab var index_Z_role_prod_act_1 "Economic Opportunities Index (Z score), R1 mkt work participation"
	
	* Using R3 mkt work participation
	egen index_Z_role_prod_act_3 = rowmean(`econ_opp_index_3_Z')
	lab var index_Z_role_prod_act_3 "Economic Opportunities Index (Z score), R3 mkt work participation"
	

* Social Capital Index
	egen index_Z_social_capital = rowmean(`soc_cap_index_Z')
	lab var index_Z_social_capital "Social Capital Index (Z score)"
	

	*Standardization
	foreach var in index_Z_all_decisions index_Z_role_prod_act_1 index_Z_role_prod_act_3 index_Z_social_capital {
		sum `var' if ultra_poor == 1
			if `r(N)' > 0 {
				replace `var' = (`var' - `r(mean)') / `r(sd)' 
			}
	}	

*  Decisionmaking index +  Econ Opp Index
	* Using R1 mkt work participation
	egen index_Z_decisions_eco_1 = rowmean(index_Z_all_decisions index_Z_role_prod_act_1)
	lab var index_Z_decisions_eco_1 "Decision + Economic Opportunities Index (Z score), R1 mkt work participation"
	
	* Using R3 mkt work participation
	egen index_Z_decisions_eco_3 = rowmean(index_Z_all_decisions index_Z_role_prod_act_3)
	lab var index_Z_decisions_eco_3 "Decision + Economic Opportunities Index (Z score), R3 mkt work participation"	
	

*  Decisionmaking index +  Econ Opp Index + Social Capital Index
	* Using R1 mkt work participation
	egen index_Z_f_emp_3c_1 = rowmean(index_Z_all_decisions index_Z_role_prod_act_1 index_Z_social_capital)
	lab var index_Z_f_emp_3c_1 "Women's Empowerment Index (Z score) (3 dimensions), R1 mkt work participation"	
	
	* Using R3 mkt work participation
	egen index_Z_f_emp_3c_3 = rowmean(index_Z_all_decisions index_Z_role_prod_act_3 index_Z_social_capital)
	lab var index_Z_f_emp_3c_3 "Women's Empowerment Index (Z score) (3 dimensions), R3 mkt work participation"	
	
	*Standardization	
	foreach var in index_Z_decisions_eco_1 index_Z_decisions_eco_3 index_Z_f_emp_3c_1 index_Z_f_emp_3c_3 {
		sum `var' if ultra_poor == 1
			if `r(N)' > 0 {
				replace `var' = (`var' - `r(mean)') / `r(sd)' 
			}
	}	

******************* Computing the indices only for household with daughters younger than 12 *****************************
preserve 
keep if has_daughter > 0 & !mi(has_daughter) // keep HHs with a young daughter 
keep if attrition_r4 == 0

	* Create indices
		foreach index in $all_dau {
			display "`index'"
			des ``index'_vars'
			egen index_sdUP_`index'_dau = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdUP_`index'_dau  "``index'_l' Index sd(${normvar} - HH with daughters)"	
		}	

* Decisionmaking index
	loc decide_index_dau "index_sdUP_foodexp_dau index_sdUP_homeexp_dau index_sdUP_homefin_dau index_sdUP_chischool_dau index_sdUP_chihealth_dau index_sdUP_chimarr_dau index_sdUP_homesale_dau index_sdUP_otherexp_dau index_sdUP_fert_1_dau index_sdUP_h24_1_dau index_sdUP_h28_1_dau index_sdUP_h31_1_dau"
	egen index_sdUP_all_decisions_dau = weightave(`decide_index_dau'), normby(${normvar})
	lab var index_sdUP_all_decisions_dau "Women's Decisionmaking Index sd(${normvar})"
	
* Econ Opp Index
	* Using R1 mkt work participation
	loc econ_opp_index_dau_1 "index_sdUP_work_1_dau index_sdUP_inputs_1_dau"
	egen index_sdUP_role_prod_act_dau_1 = weightave(`econ_opp_index_dau_1'), normby(${normvar})
	lab var index_sdUP_role_prod_act_dau_1 "Economic Opportunities Index sd(${normvar}), R1 mkt work participation"

	* Using R3 mkt work participation and R4 inputs 
	loc econ_opp_index_dau_3 "index_sdUP_work_3_dau index_sdUP_inputs_4_dau"
	egen index_sdUP_role_prod_act_dau_3 = weightave(`econ_opp_index_dau_3'), normby(${normvar})
	lab var index_sdUP_role_prod_act_dau_3 "Economic Opportunities Index sd(${normvar}), R3 mkt work participation"	
	
* Social Capital Index
	loc soc_cap_index_dau "index_sdUP_tazkira_dau index_sdUP_political_dau index_sdUP_community_1_dau"
	egen index_sdUP_social_capital_dau = weightave(`soc_cap_index_dau'), normby(${normvar})
	lab var index_sdUP_social_capital_dau "Social Capital Index sd(${normvar})"

* Social Norms Index
	loc soc_norms_index_dau "index_sdUP_educ_dau index_sdUP_marriage_dau"
	egen index_sdUP_social_norms_dau = weightave(`soc_norms_index_dau'), normby(${normvar})
	lab var index_sdUP_social_norms_dau "Aspirations for Daughters Index sd(${normvar})"

* Total index (4 dimensions: decisionmaking, econ opp, social norms, social capital)
	* R1 mkt work participation
	loc all_index_dau_1 "index_sdUP_all_decisions_dau index_sdUP_role_prod_act_dau_1 index_sdUP_social_capital_dau index_sdUP_social_norms_dau" 
	egen index_sdUP_f_emp_dau_1 = weightave(`all_index_dau_1'), normby(${normvar})
	lab var index_sdUP_f_emp_dau_1 "Women's Empowerment Index sd(${normvar}) (4 dimensions), R1 mkt work participation"	
	
	* R3 mkt work participation
	loc all_index_dau_3 "index_sdUP_all_decisions_dau index_sdUP_role_prod_act_dau_3 index_sdUP_social_capital_dau index_sdUP_social_norms_dau" 
	egen index_sdUP_f_emp_dau_3 = weightave(`all_index_dau_3'), normby(${normvar})
	lab var index_sdUP_f_emp_dau_3 "Women's Empowerment Index sd(${normvar}) (4 dimensions), R3 mkt work participation"	
	
keep hhid 	index_sdUP_social_norms_dau index_sdUP_f_emp_dau* index_sdUP_all_decisions_dau index_sdUP_role_prod_act_dau* index_sdUP_social_capital_dau has_daughter
	
tempfile we_aspiration_daughter
save `we_aspiration_daughter'
restore
 
merge 1:1 hhid using `we_aspiration_daughter', assert(1 3) nogen 	


********************************************************************************
	** Part 8: Robustness Checks 
********************************************************************************	
* Creating indices including the robustness variables instead 
		
	loc work_1_vars_r   	`work_1_vars'
	loc work_3_vars_r   	`work_3_vars'
	loc inputs_1_vars_r    	`inputs_1_vars'
	loc inputs_4_vars_r    	`inputs_4_vars'
	loc educ_vars_r     	`educ_vars'
	loc marriage_vars_r     `marriage_vars'
	loc political_vars_r   	`political_vars'
	loc tazkira_vars_r   	`tazkira_vars'
	loc community_1_vars_r   `community_1_vars'
	loc community_4_vars_r   `community_4_vars'
	
	foreach index in $all {
		display "`index'"
		des ``index'_vars_r'
		egen index_sdUP_C_`index'_r = weightave(``index'_vars_r'), normby(${normvar})
		lab var index_sdUP_C_`index'_r "``index'_l' Index sd(${normvar}) Robustness"	
	}	
		         	 
* Decisionmaking index (10 components)
	loc decide_index_r "index_sdUP_C_foodexp_r index_sdUP_C_homeexp_r index_sdUP_C_homefin_r index_sdUP_C_chischool_r index_sdUP_C_chihealth_r index_sdUP_C_chimarr_r index_sdUP_C_homesale_r index_sdUP_C_otherexp_r index_sdUP_C_fert_1_r index_sdUP_C_h24_1_r index_sdUP_C_h28_1_r index_sdUP_C_h31_1_r"
	egen index_sdUP_C_all_decisions_r = weightave(`decide_index_r'), normby(${normvar})
	lab var index_sdUP_C_all_decisions_r "Women's Deciosionmaking Index sd(${normvar}) Robustness"	
		
* Econ Opp Index
	* Using R1 mkt work participation
	loc econ_opp_index_r_1  "index_sdUP_C_work_1_r index_sdUP_C_inputs_1_r"
	egen index_sdUP_C_role_prod_act_r_1 = weightave(`econ_opp_index_r_1'), normby(${normvar})
	lab var index_sdUP_C_role_prod_act_r_1 "Economic Opportunities Index sd(${normvar}) Robustness, R1 mkt work participation"

	* Using R3 mkt work participation
	loc econ_opp_index_r_3 "index_sdUP_C_work_3_r index_sdUP_C_inputs_4_r"
	egen index_sdUP_C_role_prod_act_r_3 = weightave(`econ_opp_index_r_3'), normby(${normvar})
	lab var index_sdUP_C_role_prod_act_r_3 "Economic Opportunities Index sd(${normvar}) Robustness, R3 mkt work participation"	
	
* Social Capital Index
	loc soc_cap_index_r "index_sdUP_C_tazkira_r index_sdUP_C_community_1_r index_sdUP_C_political_r"
	egen index_sdUP_C_social_capital_r = weightave(`soc_cap_index_r'), normby(${normvar})
	lab var index_sdUP_C_social_capital_r "Social Capital Index sd(${normvar}) Robustness"		
		
* Total index (3 dimensions: decisionmaking, econ opp, social capital)
	* Using R1 mkt work participation
	loc all_index3_r_1 "index_sdUP_C_all_decisions_r index_sdUP_C_role_prod_act_r_1 index_sdUP_C_social_capital_r"
	egen index_sdUP_C_f_emp_3c_r_1 = weightave(`all_index3_r_1'), normby(${normvar})
	lab var index_sdUP_C_f_emp_3c_r_1 "Women's Empowerment Index sd(${normvar}) (3 dimensions) Robustness, R1 mkt work participation"		
	
	* Using R3 mkt work participation
	loc all_index3_r_3 "index_sdUP_C_all_decisions_r index_sdUP_C_role_prod_act_r_3 index_sdUP_C_social_capital_r"
	egen index_sdUP_C_f_emp_3c_r_3 = weightave(`all_index3_r_3'), normby(${normvar})
	lab var index_sdUP_C_f_emp_3c_r_3 "Women's Empowerment Index sd(${normvar}) (3 dimensions) Robustness, R3 mkt work participation"		
	

********************************************************************************
	** Part 9: Male-headed households
********************************************************************************
	
	* First, get the most up to date "no_pm" flag from the roster 
	* Most of the indicators (all of decision-making) was collected in R2. Rest is spread between all other rounds.
		* Could consider using no_pm_2, but use the "completed" "all" variable for now.
	preserve 
		do"${Phone_Survey_do}/Construction/hh_composition.do"
	
		use "${hh_composition}", clear 
		keep hhid no_pm_all
		
		tempfile no_pm
		save `no_pm'
	restore
	
	preserve
	* Merge on the latest "no_pm" flag and construct hh_head_gender variable 
	* Here, majority of the data is coming from R2 (everything excep social norms index), so we use R2 no_pm status in this merge
		merge 1:1 hhid using "`no_pm'", keepusing(no_pm_all) keep(3) update replace 
	
		gen hh_head_gender = .
			replace hh_head_gender = 1 if no_pm_all == 0 // Asume HHH is male if there is a PM 
			replace hh_head_gender = 2 if no_pm_all == 1 // Assume HHH is female if there is no PM
		
		* Keep HHs with Male HHH	
		keep if hh_head_gender == 1 
		
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdUP_C_`index'_m = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdUP_C_`index'_m "``index'_l' Index sd(Control) - Men-headed HH"	
		}	
		
	* Decisionmaking index
		loc decide_index_m "index_sdUP_C_foodexp_m index_sdUP_C_homeexp_m index_sdUP_C_homefin_m index_sdUP_C_chischool_m index_sdUP_C_chihealth_m index_sdUP_C_chimarr_m index_sdUP_C_homesale_m index_sdUP_C_otherexp_m index_sdUP_C_fert_1_m index_sdUP_C_h24_1_m index_sdUP_C_h28_1_m index_sdUP_C_h31_1_m"
		egen index_sdUP_C_all_decisions_m = weightave(`decide_index_m'), normby(${normvar})
		lab var index_sdUP_C_all_decisions_m "Women's Decisionmaking Index sd(${normvar}) - Men-headed HH"			
		
	* Econ Opp Index - Using R1 mkt work participation
		loc econ_opp_index_m_1 "index_sdUP_C_work_1_m index_sdUP_C_inputs_1_m"
		egen index_sdUP_C_role_prod_act_m_1 = weightave(`econ_opp_index_m_1'), normby(${normvar})
		lab var index_sdUP_C_role_prod_act_m_1 "Economic Opportunities Index sd(${normvar}) - Men-headed HH, R1 mkt work participation"
		
	* Econ Opp Index - Using R3 mkt work participation
		loc econ_opp_index_m_3 "index_sdUP_C_work_3_m index_sdUP_C_inputs_4_m"
		egen index_sdUP_C_role_prod_act_m_3 = weightave(`econ_opp_index_m_3'), normby(${normvar})
		lab var index_sdUP_C_role_prod_act_m_3 "Economic Opportunities Index sd(${normvar}) - Men-headed HH, R3 mkt work participation"		

	* Social Capital Index
		loc soc_cap_index_m "index_sdUP_C_tazkira_m index_sdUP_C_community_1_m index_sdUP_C_political_m"
		egen index_sdUP_C_social_capital_m = weightave(`soc_cap_index_m'), normby(${normvar})
		lab var index_sdUP_C_social_capital_m "Social Capital Index sd(${normvar}) - Men-headed HH"	
		
	* Total index (3 dimensions: decisionmaking, econ opp, social capital) - Using R1 mkt work participation
		loc all_index3_m_1 "index_sdUP_C_all_decisions_m index_sdUP_C_role_prod_act_m_1 index_sdUP_C_social_capital_m"
		egen index_sdUP_C_f_emp_3c_m_1 = weightave(`all_index3_m_1'), normby(${normvar})
		lab var index_sdUP_C_f_emp_3c_m_1 "Women's Empowerment Index sd(${normvar}) (3 dimensions)- Men-headed HH, R1 mkt work participation"	
		
	* Total index (3 dimensions: decisionmaking, econ opp, social capital) - Using R3 mkt work participation
		loc all_index3_m_3 "index_sdUP_C_all_decisions_m index_sdUP_C_role_prod_act_m_3 index_sdUP_C_social_capital_m"
		egen index_sdUP_C_f_emp_3c_m_3 = weightave(`all_index3_m_3'), normby(${normvar})
		lab var index_sdUP_C_f_emp_3c_m_3 "Women's Empowerment Index sd(${normvar}) (3 dimensions)- Men-headed HH, R3 mkt work participation"		
	
		tempfile malehead
		save	`malehead'
	restore
	
	merge 1:1 hhid using `malehead', assert(1 3) nogen
	
	* Label	
		lab var foodexp "Food Expenditures and What to Cook"
		lab var h8_ac "Home Improvements/Repairs"
		lab var h7_ac "Managing Household Finances"
		lab var h6_ac "Buying or Selling Land or Property"
		lab var otherexp "Other Non-food Expenditures"
		lab var chischool "Children's School Attendance"
		lab var h13_ac "Children's Health Seeking"
		lab var chimarr "Children's Marriage"
		lab var h14_ac_1 "Her Fertility"
		lab var h28_ac_1 "Her Taking a Loan"
		lab var h24_ac_1 "Her Opening a Business"
		lab var h31_ac_1 "Her Working Outside of Home"
		lab var n2_1 "PW Approached Village Leaders About Issues"
		lab var did_labor_nohh_1 "PW Does Market Work (R1 indicator)"
		lab var did_labor_nohh_3 "PW Does Market Work (R3 indicator)"
		lab var h30_1 "PW Has Financial Assets in Her Own Name"
		lab var owner_manager_pf "PW is Owner or Manager of a HH Non-Agricultural Business"
		lab var z2_all "PW Has a Tazkira (National ID Card)" // s21
		lab var n1_1 "PW Attended Village Meetings"
		lab var z1_3_all "PW Voted in an Election (Presidential or Provincial)" // voted
		lab var mobile_yes_pf "PW Has a Mobile Phone"
		lab var index_sdUP_C_all_decisions "Decision-Making Index"
		lab var index_sdUP_C_role_prod_act_1 "Economic Opportunities Index, (R1 mkt work participation)"
		lab var index_sdUP_C_role_prod_act_3 "Economic Opportunities Index, (R3 mkt work participation)"
		lab var index_sdUP_C_social_capital "Political and Social Involvement Index"
		lab var index_sdUP_C_f_emp_3c_1 "Women's Empowerment Index (3 dimensions), (R1 mkt work participation)"
		lab var index_sdUP_C_f_emp_3c_3 "Women's Empowerment Index (3 dimensions), (R3 mkt work participation)"
	
	cap drop _merge 
	merge 1:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment all_rounds) update replace keep(3 4) nogen
	
* Save data
	if	`c(stata_version)'>=14	{
		saveold "${f_empowerment_ses_phonesvy}", replace v(13)
	}
	else {
		save "${f_empowerment_ses_phonesvy}", replace
	}	

	use "`empowerment'", clear 
				
* Define a variable with which to standardize the index	
		* UP only sample (standardize by control UP)
	keep if ultra_poor == 1 
	
	global normvar control 
	
	* Create indices for each of the sub sub components
		foreach index in $all_mkt {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index' = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index' "``index'_l' Index sd(${normvar})"	
		}	
		
	* Decisionmaking index
	loc decide_index "index_sdC_foodexp index_sdC_homeexp index_sdC_homefin index_sdC_chischool index_sdC_chihealth index_sdC_chimarr index_sdC_homesale index_sdC_otherexp index_sdC_fert_1 index_sdC_h24_1 index_sdC_h28_1 index_sdC_h31_1"
	egen index_sdC_all_decisions = weightave(`decide_index'), normby(${normvar})
	lab var index_sdC_all_decisions "Women's Decisionmaking Index sd(${normvar})"
	
* Econ Opp Index - R1 mkt work participation
	loc econ_opp_index_1 "index_sdC_work_1 index_sdC_inputs_1"
	egen index_sdC_role_prod_1 = weightave(`econ_opp_index_1'), normby(${normvar})
	lab var index_sdC_role_prod_1 "Economic Opportunities Index sd(${normvar}), R1 mkt work participation"		
	
* Econ Opp Index - Using R3 mkt work participation
	loc econ_opp_index_3 "index_sdC_work_3 index_sdC_inputs_4"
	egen index_sdC_role_prod_3 = weightave(`econ_opp_index_3'), normby(${normvar})
	lab var index_sdC_role_prod_3 "Economic Opportunities Index sd(${normvar}), R3 mkt work participation"
	
* Econ Opp Index - No mkt work participation
	loc econ_opp_index_nomkt "index_sdC_inputs_4"
	egen index_sdC_role_prod_nomkt = weightave(`econ_opp_index_nomkt'), normby(${normvar})
	lab var index_sdC_role_prod_nomkt "Economic Opportunities Index sd(${normvar}), no mkt work participation"	
	
* Social Capital Index
	loc soc_cap_index "index_sdC_tazkira index_sdC_community_1 index_sdC_political"
	egen index_sdC_social_capital = weightave(`soc_cap_index'), normby(${normvar})
	lab var index_sdC_social_capital "Social Capital Index sd(${normvar})"
	
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital) - Using R1 mkt work participation
	loc all_index3_1 "index_sdC_all_decisions index_sdC_role_prod_1 index_sdC_social_capital"
	egen index_sdC_f_emp_3c_1 = weightave(`all_index3_1'), normby(${normvar})
	lab var index_sdC_f_emp_3c_1 "Women's Empowerment Index sd(${normvar}) (3 dimensions), R1 mkt work participation"
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital) - Using R3 mkt work participation
	loc all_index3_3 "index_sdC_all_decisions index_sdC_role_prod_3 index_sdC_social_capital"
	egen index_sdC_f_emp_3c_3 = weightave(`all_index3_3'), normby(${normvar})
	lab var index_sdC_f_emp_3c_3 "Women's Empowerment Index sd(${normvar}) (3 dimensions), R3 mkt work participation"	
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital) - No mkt work participation
	loc all_index3_nomkt "index_sdC_all_decisions index_sdC_role_prod_nomkt index_sdC_social_capital"
	egen index_sdC_f_emp_3c_nomkt = weightave(`all_index3_nomkt'), normby(${normvar})
	lab var index_sdC_f_emp_3c_nomkt "Women's Empowerment Index sd(${normvar}) (3 dimensions), no mkt work participation"		
	
	
	**************** Create index Z score to be comparable with Banerjee et al. We take the full index although it does not necessarily has the same variables as in Banerjee ***************** 
*Start directly from the single variables, same as Banerjee 
	loc decide_index 		"h1_ac h2_ac h8_ac h7_ac h9_ac h10_ac h13_ac h11_ac h12_ac h6_ac h3_ac h4_ac h5_ac h14_ac_1 h24_ac_1 h28_ac_1 h31_ac_1"
	loc econ_opp_index_1 	"owner_manager_pf did_labor_nohh_1 h30_1 mobile_yes_pf"
	loc econ_opp_index_3 	"did_labor_nohh_3"
	
	loc soc_cap_index 		"z2_all z1_3_all n1_1 n2_1"
			
	* For these, computing index similarly as in Banerjee et al. (2015) science paper. Simple Z score
	foreach var in `decide_index' `econ_opp_index_1' `econ_opp_index_3' `soc_cap_index' {
		gen `var'_Z = .
			sum `var' if ultra_poor == 1
			if `r(N)' > 0 {
				replace `var'_Z = (`var' - `r(mean)') / `r(sd)' 
			}
		}

	loc decide_index_Z  		"h1_ac_Z  h2_ac_Z  h8_ac_Z  h7_ac_Z  h9_ac_Z  h10_ac_Z  h13_ac_Z  h11_ac_Z  h12_ac_Z  h6_ac_Z  h3_ac_Z  h4_ac_Z  h5_ac_Z  h14_ac_1_Z  h24_ac_1_Z  h28_ac_1_Z  h31_ac_1_Z "
	loc econ_opp_index_1_Z 		"owner_manager_pf_Z did_labor_nohh_1_Z h30_1_Z mobile_yes_pf_Z"
	loc econ_opp_index_3_Z 		"owner_manager_pf_Z did_labor_nohh_3_Z h30_1_Z mobile_yes_pf_Z"	
	loc soc_cap_index_Z 		"z2_all_Z z1_3_all_Z n1_1_Z n2_1_Z"
	
* Decisionmaking index
	egen index_Z_all_decisions = rowmean(`decide_index_Z')
	lab var index_Z_all_decisions "Women's Decisionmaking Index (Z score)"
	
* Econ Opp Index
	* Using R1 mkt work participation
	egen index_Z_role_prod_act_1 = rowmean(`econ_opp_index_1_Z')
	lab var index_Z_role_prod_act_1 "Economic Opportunities Index (Z score), R1 mkt work participation"
	
	* Using R3 mkt work participation
	egen index_Z_role_prod_act_3 = rowmean(`econ_opp_index_3_Z')
	lab var index_Z_role_prod_act_3 "Economic Opportunities Index (Z score), R3 mkt work participation"
	

* Social Capital Index
	egen index_Z_social_capital = rowmean(`soc_cap_index_Z')
	lab var index_Z_social_capital "Social Capital Index (Z score)"
	

	*Standardization
	foreach var in index_Z_all_decisions index_Z_role_prod_act_1 index_Z_role_prod_act_3 index_Z_social_capital {
		sum `var' if ultra_poor == 1
			if `r(N)' > 0 {
				replace `var' = (`var' - `r(mean)') / `r(sd)' 
			}
	}	
	
*  Decisionmaking index +  Econ Opp Index
	* Using R1 mkt work participation
	egen index_Z_decisions_eco_1 = rowmean(index_Z_all_decisions index_Z_role_prod_act_1)
	lab var index_Z_decisions_eco_1 "Decision + Economic Opportunities Index (Z score), R1 mkt work participation"
	
	* Using R3 mkt work participation
	egen index_Z_decisions_eco_3 = rowmean(index_Z_all_decisions index_Z_role_prod_act_3)
	lab var index_Z_decisions_eco_3 "Decision + Economic Opportunities Index (Z score), R3 mkt work participation"	
	

*  Decisionmaking index +  Econ Opp Index + Social Capital Index
	* Using R1 mkt work participation
	egen index_Z_f_emp_3c_1 = rowmean(index_Z_all_decisions index_Z_role_prod_act_1 index_Z_social_capital)
	lab var index_Z_f_emp_3c_1 "Women's Empowerment Index (Z score) (3 dimensions), R1 mkt work participation"	
	
	* Using R3 mkt work participation
	egen index_Z_f_emp_3c_3 = rowmean(index_Z_all_decisions index_Z_role_prod_act_3 index_Z_social_capital)
	lab var index_Z_f_emp_3c_3 "Women's Empowerment Index (Z score) (3 dimensions), R3 mkt work participation"	
	
	*Standardization	
	foreach var in index_Z_decisions_eco_1 index_Z_decisions_eco_3 index_Z_f_emp_3c_1 index_Z_f_emp_3c_3 {
		sum `var' if ultra_poor == 1
			if `r(N)' > 0 {
				replace `var' = (`var' - `r(mean)') / `r(sd)' 
			}
	}	

******************* Computing the indices only for household with daughters younger than 12 *****************************
preserve 

keep if !mi(has_daughter) // keep HHs with a young daughter 
keep if attrition_r4 == 0

	* Create indices
		foreach index in $all_dau {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_dau = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index'_dau  "``index'_l' Index sd(${normvar} - HH with daughters)"	
		}	

* Decisionmaking index
	loc decide_index_dau "index_sdC_foodexp_dau index_sdC_homeexp_dau index_sdC_homefin_dau index_sdC_chischool_dau index_sdC_chihealth_dau index_sdC_chimarr_dau index_sdC_homesale_dau index_sdC_otherexp_dau index_sdC_fert_1_dau index_sdC_h24_1_dau index_sdC_h28_1_dau index_sdC_h31_1_dau"
	egen index_sdC_all_decisions_dau = weightave(`decide_index_dau'), normby(${normvar})
	lab var index_sdC_all_decisions_dau "Women's Decisionmaking Index sd(${normvar})"
	
loc econ_opp_index_dau_1 "index_sdC_work_1_dau index_sdC_inputs_1_dau"
	egen index_sdC_role_prod_dau_1 = weightave(`econ_opp_index_dau_1'), normby(${normvar})
	lab var index_sdC_role_prod_dau_1 "Economic Opportunities Index sd(${normvar}), R1 mkt work participation"

	* Using R3 mkt work participation
	loc econ_opp_index_dau_3 "index_sdC_work_3_dau index_sdC_inputs_4_dau"
	egen index_sdC_role_prod_dau_3 = weightave(`econ_opp_index_dau_3'), normby(${normvar})
	lab var index_sdC_role_prod_dau_3 "Economic Opportunities Index sd(${normvar}), R3 mkt work participation"	
	
* Social Capital Index
	loc soc_cap_index_dau "index_sdC_tazkira_dau index_sdC_political_dau index_sdC_community_1_dau"
	egen index_sdC_social_capital_dau = weightave(`soc_cap_index_dau'), normby(${normvar})
	lab var index_sdC_social_capital_dau "Social Capital Index sd(${normvar})"

* Social Norms Index
	loc soc_norms_index_dau "index_sdC_educ_dau index_sdC_marriage_dau"
	egen index_sdC_social_norms_dau = weightave(`soc_norms_index_dau'), normby(${normvar})
	lab var index_sdC_social_norms_dau "Aspirations for Daughters Index sd(${normvar})"

	
* Total index (4 dimensions: decisionmaking, econ opp, social norms, social capital)
	* R1 mkt work participation
	loc all_index_dau_1 "index_sdC_all_decisions_dau index_sdC_role_prod_dau_1 index_sdC_social_capital_dau index_sdC_social_norms_dau" 
	egen index_sdC_f_emp_dau_1 = weightave(`all_index_dau_1'), normby(${normvar})
	lab var index_sdC_f_emp_dau_1 "Women's Empowerment Index sd(${normvar}) (4 dimensions), R1 mkt work participation"	
	
	* R3 mkt work participation
	loc all_index_dau_3 "index_sdC_all_decisions_dau index_sdC_role_prod_dau_3 index_sdC_social_capital_dau index_sdC_social_norms_dau" 
	egen index_sdC_f_emp_dau_3 = weightave(`all_index_dau_3'), normby(${normvar})
	lab var index_sdC_f_emp_dau_3 "Women's Empowerment Index sd(${normvar}) (4 dimensions), R3 mkt work participation"	
	
keep hhid 	index_sdC_social_norms_dau index_sdC_f_emp_dau* index_sdC_all_decisions_dau index_sdC_role_prod_dau* index_sdC_social_capital_dau

	
tempfile we_aspiration_daughter
save `we_aspiration_daughter'
restore
 
merge 1:1 hhid using `we_aspiration_daughter', assert(1 3) nogen 		
	
	
********************************************************************************
	** Part 8: Robustness Checks 
********************************************************************************	
* Creating indices including the robustness variables instead 
		
	loc work_vars_r   	 	`work_vars'
	loc inputs_1_vars_r    	`inputs_1_vars'
	loc inputs_4_vars_r    	`inputs_4_vars'
	loc educ_vars_r     	`educ_vars'
	loc marriage_vars_r     `marriage_vars'
	loc political_vars_r   	`political_vars'
	loc tazkira_vars_r   	`tazkira_vars'
	loc community_1_vars_r   `community_1_vars'
	loc community_4_vars_r   `community_4_vars'
	
	foreach index in $all {
		display "`index'"
		des ``index'_vars_r'
		egen index_sdC_`index'_r = weightave(``index'_vars_r'), normby(${normvar})
		lab var index_sdC_`index'_r "``index'_l' Index sd(${normvar}) Robustness"	
	}	
		         	 
* Decisionmaking index (10 components)
	loc decide_index_r "index_sdC_foodexp_r index_sdC_homeexp_r index_sdC_homefin_r index_sdC_chischool_r index_sdC_chihealth_r index_sdC_chimarr_r index_sdC_homesale_r index_sdC_otherexp_r index_sdC_fert_1_r index_sdC_h24_1_r index_sdC_h28_1_r index_sdC_h31_1_r"
	egen index_sdC_all_decisions_r = weightave(`decide_index_r'), normby(${normvar})
	lab var index_sdC_all_decisions_r "Women's Deciosionmaking Index sd(${normvar}) Robustness"	
		
* Econ Opp Index
	* Using R1 mkt work participation
	loc econ_opp_index_r_1  "index_sdC_work_1_r index_sdC_inputs_1_r"
	egen index_sdC_role_prod_r_1 = weightave(`econ_opp_index_r_1'), normby(${normvar})
	lab var index_sdC_role_prod_r_1 "Economic Opportunities Index sd(${normvar}) Robustness, R1 mkt work participation"

	* Using R3 mkt work participation
	loc econ_opp_index_r_3 "index_sdC_work_3_r index_sdC_inputs_4_r"
	egen index_sdC_role_prod_r_3 = weightave(`econ_opp_index_r_3'), normby(${normvar})
	lab var index_sdC_role_prod_r_3 "Economic Opportunities Index sd(${normvar}) Robustness, R3 mkt work participation"	
	
* Social Capital Index
	loc soc_cap_index_r "index_sdC_tazkira_r index_sdC_community_1_r index_sdC_political_r"
	egen index_sdC_social_capital_r = weightave(`soc_cap_index_r'), normby(${normvar})
	lab var index_sdC_social_capital_r "Social Capital Index sd(${normvar}) Robustness"		
		
* Total index (3 dimensions: decisionmaking, econ opp, social capital)
	* Using R1 mkt work participation
	loc all_index3_r_1 "index_sdC_all_decisions_r index_sdC_role_prod_r_1 index_sdC_social_capital_r"
	egen index_sdC_f_emp_3c_r_1 = weightave(`all_index3_r_1'), normby(${normvar})
	lab var index_sdC_f_emp_3c_r_1 "Women's Empowerment Index sd(${normvar}) (3 dimensions) Robustness, R1 mkt work participation"		
	
	* Using R3 mkt work participation
	loc all_index3_r_3 "index_sdC_all_decisions_r index_sdC_role_prod_r_3 index_sdC_social_capital_r"
	egen index_sdC_f_emp_3c_r_3 = weightave(`all_index3_r_3'), normby(${normvar})
	lab var index_sdC_f_emp_3c_r_3 "Women's Empowerment Index sd(${normvar}) (3 dimensions) Robustness, R3 mkt work participation"	
	
	
	
********************************************************************************
	** Part 9: Male-headed households
********************************************************************************
	
	* First, get the most up to date "no_pm" flag from the roster 
	preserve 
		use "${hh_composition}", clear 
		keep hhid no_pm_all
		
		tempfile no_pm
		save `no_pm'
	restore
	
	preserve
	* Merge on the latest "no_pm" flag and construct hh_head_gender variable 
	* Here, majority of the data is coming from R2 (everything excep social norms index), so we use R2 no_pm status in this merge
		merge 1:1 hhid using "`no_pm'", keepusing(no_pm_all) keep(3) update replace 
	
		gen hh_head_gender = .
			replace hh_head_gender = 1 if no_pm_all == 0 // Asume HHH is male if there is a PM 
			replace hh_head_gender = 2 if no_pm_all == 1 // Assume HHH is female if there is no PM
		
		* Keep HHs with Male HHH	
		keep if hh_head_gender == 1 
		
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_m = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index'_m "``index'_l' Index sd(Control) - Men-headed HH"	
		}	
		
	* Decisionmaking index
		loc decide_index_m "index_sdC_foodexp_m index_sdC_homeexp_m index_sdC_homefin_m index_sdC_chischool_m index_sdC_chihealth_m index_sdC_chimarr_m index_sdC_homesale_m index_sdC_otherexp_m index_sdC_fert_1_m index_sdC_h24_1_m index_sdC_h28_1_m index_sdC_h31_1_m"
		egen index_sdC_all_decisions_m = weightave(`decide_index_m'), normby(${normvar})
		lab var index_sdC_all_decisions_m "Women's Decisionmaking Index sd(${normvar}) - Men-headed HH"			
		
* Econ Opp Index - Using R1 mkt work participation
		loc econ_opp_index_m_1 "index_sdC_work_1_m index_sdC_inputs_1_m"
		egen index_sdC_role_prod_m_1 = weightave(`econ_opp_index_m_1'), normby(${normvar})
		lab var index_sdC_role_prod_m_1 "Economic Opportunities Index sd(${normvar}) - Men-headed HH, R1 mkt work participation"
		
	* Econ Opp Index - Using R3 mkt work participation
		loc econ_opp_index_m_3 "index_sdC_work_3_m index_sdC_inputs_4_m"
		egen index_sdC_role_prod_m_3 = weightave(`econ_opp_index_m_3'), normby(${normvar})
		lab var index_sdC_role_prod_m_3 "Economic Opportunities Index sd(${normvar}) - Men-headed HH, R3 mkt work participation"		

	* Social Capital Index
		loc soc_cap_index_m "index_sdC_tazkira_m index_sdC_community_1_m index_sdC_political_m"
		egen index_sdC_social_capital_m = weightave(`soc_cap_index_m'), normby(${normvar})
		lab var index_sdC_social_capital_m "Social Capital Index sd(${normvar}) - Men-headed HH"	
		
	* Total index (3 dimensions: decisionmaking, econ opp, social capital) - Using R1 mkt work participation
		loc all_index3_m_1 "index_sdC_all_decisions_m index_sdC_role_prod_m_1 index_sdC_social_capital_m"
		egen index_sdC_f_emp_3c_m_1 = weightave(`all_index3_m_1'), normby(${normvar})
		lab var index_sdC_f_emp_3c_m_1 "Women's Empowerment Index sd(${normvar}) (3 dimensions)- Men-headed HH, R1 mkt work participation"	
		
	* Total index (3 dimensions: decisionmaking, econ opp, social capital) - Using R3 mkt work participation
		loc all_index3_m_3 "index_sdC_all_decisions_m index_sdC_role_prod_m_3 index_sdC_social_capital_m"
		egen index_sdC_f_emp_3c_m_3 = weightave(`all_index3_m_3'), normby(${normvar})
		lab var index_sdC_f_emp_3c_m_3 "Women's Empowerment Index sd(${normvar}) (3 dimensions)- Men-headed HH, R3 mkt work participation"		
	

		tempfile malehead
		save	`malehead'
	restore
	
	merge 1:1 hhid using `malehead', assert(1 3) nogen
	
	* Create an index for a subsample of HHs survyed in all rounds 
	preserve 
	
		drop index_*
		
		keep if all_rounds == 1 
		
		* Create indices for each of the sub sub components
			foreach index in $all_mkt {
				display "`index'"
				des ``index'_vars'
				egen index_sdC_`index'_all = weightave(``index'_vars'), normby(${normvar})
				lab var index_sdC_`index'_all "``index'_l' Index sd(${normvar})"	
			}	
			
		* Decisionmaking index
		loc decide_index_all "index_sdC_foodexp_all index_sdC_homeexp_all index_sdC_homefin_all index_sdC_chischool_all index_sdC_chihealth_all index_sdC_chimarr_all index_sdC_homesale_all index_sdC_otherexp_all index_sdC_fert_1_all index_sdC_h24_1_all index_sdC_h28_1_all index_sdC_h31_1_all"
		egen index_sdC_all_decisions_all = weightave(`decide_index_all'), normby(${normvar})
		lab var index_sdC_all_decisions_all "Women's Decisionmaking Index sd(${normvar}) (all rounds)"
		
	* Econ Opp Index - R1 mkt work participation
		loc econ_opp_index_1_all "index_sdC_work_1_all index_sdC_inputs_1_all"
		egen index_sdC_role_prod_1_all = weightave(`econ_opp_index_1_all'), normby(${normvar})
		lab var index_sdC_role_prod_1_all "Economic Opportunities Index sd(${normvar}), R1 mkt work participation (all rounds)"		
		
	* Econ Opp Index - Using R3 mkt work participation
		loc econ_opp_index_3_all "index_sdC_work_3_all index_sdC_inputs_4_all"
		egen index_sdC_role_prod_3_all = weightave(`econ_opp_index_3_all'), normby(${normvar})
		lab var index_sdC_role_prod_3_all "Economic Opportunities Index sd(${normvar}), R3 mkt work participation (all rounds)"
		
	* Social Capital Index
		loc soc_cap_index_all "index_sdC_tazkira_all index_sdC_community_1_all index_sdC_political_all"
		egen index_sdC_social_capital_all = weightave(`soc_cap_index_all'), normby(${normvar})
		lab var index_sdC_social_capital_all "Social Capital Index sd(${normvar}) (all rounds)"
		
		
	* Total index (3 dimensions: decisionmaking, econ opp, social capital) - Using R1 mkt work participation
		loc all_index3_1_all "index_sdC_all_decisions_all index_sdC_role_prod_1_all index_sdC_social_capital_all"
		egen index_sdC_f_emp_3c_1_all = weightave(`all_index3_1_all'), normby(${normvar})
		lab var index_sdC_f_emp_3c_1_all "Women's Empowerment Index sd(${normvar}) (3 dimensions), R1 mkt work participation (all rounds)"
		
	* Total index (3 dimensions: decisionmaking, econ opp, social capital) - Using R3 mkt work participation
		loc all_index3_3_all "index_sdC_all_decisions_all index_sdC_role_prod_3_all index_sdC_social_capital_all"
		egen index_sdC_f_emp_3c_3_all = weightave(`all_index3_3_all'), normby(${normvar})
		lab var index_sdC_f_emp_3c_3_all "Women's Empowerment Index sd(${normvar}) (3 dimensions), R3 mkt work participation (all rounds)"	
		
		keep hhid index_*
		
		tempfile index_allrounds
		save `index_allrounds'
	restore 
	
	merge 1:1 hhid using `index_allrounds', assert(1 3) nogen
	
	cap drop _merge 
	merge 1:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor) update replace keep(3 4) nogen
	
	* Label	
		lab var foodexp "Food Expenditures and What to Cook"
		lab var h8_ac "Home Improvements/Repairs"
		lab var h7_ac "Managing Household Finances"
		lab var h6_ac "Buying or Selling Land or Property"
		lab var otherexp "Other Non-food Expenditures"
		lab var chischool "Children's School Attendance"
		lab var h13_ac "Children's Health Seeking"
		lab var chimarr "Children's Marriage"
		lab var h14_ac_1 "Her Fertility"
		lab var h28_ac_1 "Her Taking a Loan"
		lab var h24_ac_1 "Her Opening a Business"
		lab var h31_ac_1 "Her Working Outside of Home"
		lab var n2_1 "PW Approached Village Leaders About Issues"
		lab var did_labor_nohh_1 "PW Does Market Work (R1 indicator)"
		lab var did_labor_nohh_3 "PW Does Market Work (R3 indicator)"
		lab var h30_1 "PW Has Financial Assets in Her Own Name"
		lab var owner_manager_pf "PW is Owner or Manager of a HH Non-Agricultural Business"
		lab var z2_all "PW Has a Tazkira (National ID Card)" // s21
		lab var n1_1 "PW Attended Village Meetings"
		lab var n2_1 "PW Approached Village Leaders About Issues"
		lab var z1_3_all "PW Voted in an Election (Presidential or Provincial)" // voted
		lab var mobile_yes_pf "PW Has a Mobile Phone"
		lab var index_sdC_all_decisions "Decision-Making Index"
		lab var index_sdC_role_prod_1 "Economic Opportunities Index (R1 mkt work participation)"
		lab var index_sdC_role_prod_3 "Economic Opportunities Index (R3 mkt work participation)"
		lab var index_sdC_social_capital "Political and Social Involvement Index"
		lab var index_sdC_f_emp_3c_1 "Women's Empowerment Index (3 dimensions), (R1 mkt work participation)"
		lab var index_sdC_f_emp_3c_3 "Women's Empowerment Index (3 dimensions), (R3 mkt work participation)"
			
* Save data
	if	`c(stata_version)'>=14	{
		saveold "${f_empowerment_phonesvy}", replace v(13)
	}
	else {
		save "${f_empowerment_phonesvy}", replace
	}				

********************************************************************************************************	
* New addition (CMU paper / brief version): NUP and controls only index AND NUP and Treatment only index 
			
use "`empowerment'", clear 
	
preserve 	
* Define a variable with which to standardize the index	
	* UP only sample (standardize by control UP)
	gen      control_nup = 0 
		replace  control_nup = 1 if treatment == 0 &  ultra_poor == 1	
	
	global normvar control_nup 
	
	* Create indices for each of the sub sub components
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_NUP_`index' = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_NUP_`index' "``index'_l' Index sd(${normvar})"	
		}	
		
* Decisionmaking index
	loc decide_index "index_sdC_NUP_foodexp index_sdC_NUP_homeexp index_sdC_NUP_homefin index_sdC_NUP_chischool index_sdC_NUP_chihealth index_sdC_NUP_chimarr index_sdC_NUP_homesale index_sdC_NUP_otherexp index_sdC_NUP_fert_1 index_sdC_NUP_h24_1 index_sdC_NUP_h28_1 index_sdC_NUP_h31_1"
	egen index_sdC_NUP_all_decisions = weightave(`decide_index'), normby(${normvar})
	lab var index_sdC_NUP_all_decisions "Women's Decisionmaking Index sd(${normvar})"
	
* Econ Opp Index - R1 mkt work participation
	loc econ_opp_index_1 "index_sdC_NUP_work_1 index_sdC_NUP_inputs_1"
	egen index_sdC_NUP_role_prod_act_1 = weightave(`econ_opp_index_1'), normby(${normvar})
	lab var index_sdC_NUP_role_prod_act_1 "Economic Opportunities Index sd(${normvar}), R1 mkt work participation"

* Econ Opp Index - R3 mkt work participation
	loc econ_opp_index_3 "index_sdC_NUP_work_3 index_sdC_NUP_inputs_4"
	egen index_sdC_NUP_role_prod_act_3 = weightave(`econ_opp_index_3'), normby(${normvar})
	lab var index_sdC_NUP_role_prod_act_3 "Economic Opportunities Index sd(${normvar}), R3 mkt work participation"	
	
* Econ Opp Index - No mkt work participation
* Variabel name too long - note index_sdC_NUP_role_prod_act_nomkt is index_sdC_NUP_prod_act_nomkt instead 
	loc econ_opp_index_nomkt "index_sdC_NUP_inputs_4"
	egen index_sdC_NUP_prod_act_nomkt = weightave(`econ_opp_index_nomkt'), normby(${normvar})
	lab var index_sdC_NUP_prod_act_nomkt "Economic Opportunities Index sd(${normvar}), no mkt work participation"		
	
* Social Capital Index
	loc soc_cap_index "index_sdC_NUP_tazkira index_sdC_NUP_community_1 index_sdC_NUP_political"
	egen index_sdC_NUP_social_capital = weightave(`soc_cap_index'), normby(${normvar})
	lab var index_sdC_NUP_social_capital "Social Capital Index sd(${normvar})"
		
* Total index (3 dimensions: decisionmaking, econ opp, social capital) - R1 mkt work participation
	loc all_index3_1 "index_sdC_NUP_all_decisions index_sdC_NUP_role_prod_act_1 index_sdC_NUP_social_capital"
	egen index_sdC_NUP_f_emp_3c_1 = weightave(`all_index3_1'), normby(${normvar})
	lab var index_sdC_NUP_f_emp_3c_1 "Women's Empowerment Index sd(${normvar}) (3 dimensions), R1 mkt work participation"
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital) - R3 mkt work participation
	loc all_index3_3 "index_sdC_NUP_all_decisions index_sdC_NUP_role_prod_act_3 index_sdC_NUP_social_capital"
	egen index_sdC_NUP_f_emp_3c_3 = weightave(`all_index3_3'), normby(${normvar})
	lab var index_sdC_NUP_f_emp_3c_3 "Women's Empowerment Index sd(${normvar}) (3 dimensions), R3 mkt work participation"	
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital) - R3 mkt work participation
	loc all_index3_nomkt "index_sdC_NUP_all_decisions index_sdC_NUP_prod_act_nomkt index_sdC_NUP_social_capital"
	egen index_sdC_NUP_f_emp_3c_nomkt = weightave(`all_index3_nomkt'), normby(${normvar})
	lab var index_sdC_NUP_f_emp_3c_nomkt "Women's Empowerment Index sd(${normvar}) (3 dimensions), no mkt work participation"		
	
	keep hhid *sdC_NUP*
		tempfile sdC_NUP
		save `sdC_NUP'
restore 	
	
preserve 		
	gen      treat_nup = 0 
			replace  treat_nup = 1 if treatment == 1 &  ultra_poor == 1	
	
	global normvar treat_nup 
	
	* Create indices for each of the sub sub components
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdT_NUP_`index' = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdT_NUP_`index' "``index'_l' Index sd(${normvar})"	
		}	
		
* Decisionmaking index
	loc decide_index "index_sdT_NUP_foodexp index_sdT_NUP_homeexp index_sdT_NUP_homefin index_sdT_NUP_chischool index_sdT_NUP_chihealth index_sdT_NUP_chimarr index_sdT_NUP_homesale index_sdT_NUP_otherexp index_sdT_NUP_fert_1 index_sdT_NUP_h24_1 index_sdT_NUP_h28_1 index_sdT_NUP_h31_1"
	egen index_sdT_NUP_all_decisions = weightave(`decide_index'), normby(${normvar})
	lab var index_sdT_NUP_all_decisions "Women's Decisionmaking Index sd(${normvar})"
	
* Econ Opp Index - R1 mkt work participation
	loc econ_opp_index_1 "index_sdT_NUP_work_1 index_sdT_NUP_inputs_1"
	egen index_sdT_NUP_role_prod_act_1 = weightave(`econ_opp_index_1'), normby(${normvar})
	lab var index_sdT_NUP_role_prod_act_1 "Economic Opportunities Index sd(${normvar}), R1 mkt work participation"

* Econ Opp Index - R3 mkt work participation
	loc econ_opp_index_3 "index_sdT_NUP_work_3 index_sdT_NUP_inputs_4"
	egen index_sdT_NUP_role_prod_act_3 = weightave(`econ_opp_index_3'), normby(${normvar})
	lab var index_sdT_NUP_role_prod_act_3 "Economic Opportunities Index sd(${normvar}), R3 mkt work participation"	
	
* Econ Opp Index - no mkt work participation
* Variabel name too long - note index_sdC_NUP_role_prod_act_nomkt is index_sdC_NUP_prod_act_nomkt instead 
	loc econ_opp_index_nomkt "index_sdT_NUP_inputs_4"
	egen index_sdT_NUP_prod_act_nomkt = weightave(`econ_opp_index_nomkt'), normby(${normvar})
	lab var index_sdT_NUP_prod_act_nomkt "Economic Opportunities Index sd(${normvar}), no mkt work participation"		
	
* Social Capital Index
	loc soc_cap_index "index_sdT_NUP_tazkira index_sdT_NUP_community_1 index_sdT_NUP_political"
	egen index_sdT_NUP_social_capital = weightave(`soc_cap_index'), normby(${normvar})
	lab var index_sdT_NUP_social_capital "Social Capital Index sd(${normvar})"
		
* Total index (3 dimensions: decisionmaking, econ opp, social capital) - R1 mkt work participation
	loc all_index3_1 "index_sdT_NUP_all_decisions index_sdT_NUP_role_prod_act_1 index_sdT_NUP_social_capital"
	egen index_sdT_NUP_f_emp_3c_1 = weightave(`all_index3_1'), normby(${normvar})
	lab var index_sdT_NUP_f_emp_3c_1 "Women's Empowerment Index sd(${normvar}) (3 dimensions), R1 mkt work participation"
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital) - R3 mkt work participation
	loc all_index3_3 "index_sdT_NUP_all_decisions index_sdT_NUP_role_prod_act_3 index_sdT_NUP_social_capital"
	egen index_sdT_NUP_f_emp_3c_3 = weightave(`all_index3_3'), normby(${normvar})
	lab var index_sdT_NUP_f_emp_3c_3 "Women's Empowerment Index sd(${normvar}), (3 dimensions) no mkt work participation"
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital) - R3 mkt work participation
	loc all_index3_nomkt "index_sdT_NUP_all_decisions index_sdT_NUP_prod_act_nomkt index_sdT_NUP_social_capital"
	egen index_sdT_NUP_f_emp_3c_nomkt = weightave(`all_index3_nomkt'), normby(${normvar})
	lab var index_sdT_NUP_f_emp_3c_nomkt "Women's Empowerment Index sd(${normvar}) (3 dimensions), no mkt work participation"		
	
		keep hhid *sdT_NUP*
		tempfile sdT_NUP
		save `sdT_NUP'
restore 
		
		merge 1:1 hhid using "`sdC_NUP'", assert(1 3) nogen
		merge 1:1 hhid using "`sdT_NUP'", assert(1 3) nogen
		
* Save data
	if	`c(stata_version)'>=14	{
		saveold "${f_empowerment_nup_phonesvy}", replace v(13)
	}
	else {
		save "${f_empowerment_nup_phonesvy}", replace
	}			

