/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 6, 2019
Last udpate on: November 22, 2021

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates political involvement and food security indices.

CONTENT:

			Part 0. Define inputs and globals 
			Part 1. Prepare dataset, construct variables 
			Part 2. Create Food security index from panel data (FS collected in R1 and R4)
			Part 3. Create Food security indices for R1 and R4 separately and Political involevement index (only one round)


INPUTS:     
			Original data 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
			Profile data   		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

OUTPUTS:   
			Political involvement index	(unique ID hhid)		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/political_involvement_index_phonesvy.dta"
			Food security index (wide, unique ID hhid) 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/food_security_index_phonesvy.dta"
			Food security index (long, unique ID hhid round)	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/food_security_index_long_phonesvy.dta"	
			

			Notes & issues: 
				1. On tazkira questions z2 and z1_3: 
					Since we have data from multilple rounds, Tazkira questions were only asked in subsequent rounds if they were not asked in
					the previous round. However, due to some glitch, Tazkira was asked again of 23 HHs. For all of them, except one, responses
					between the two rounds are consistent. Only HHID 5353 in R1 said she had it and in R2 she said she never had it.
					Pick observation from R1, the first response.
				
				2. For political involvement. 
					We "fill" in missingness by pooling data from all rounds (i.e., pulling an observation from a latter round if the HH was not
					surveyed in the previous round). Majority of HHs would have answered these questions in R1, so we fill in for the ones that
					were *only* surveyed in later rounds (were missing from R1). This way we have data for the max number of HHs.
					
					For this, we always take the earlierst round the HH was surveyed in as a base (since this would be when most other HHs would've 
					been asked these questions also).
					
			
			
*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl all_hhlevel_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
	gl phone_svy_profile   		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

* Outputs
	gl polinvolvement			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/political_involvement_index_phonesvy.dta"
	gl foodsecurity 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/food_security_index_phonesvy.dta"
	gl foodsecurity_long		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/food_security_index_long_phonesvy.dta"
			
********************************************************************************
	** Part 1: Prepare dataset, construct variables (FS)
********************************************************************************

use "${all_hhlevel_phonesvy}", clear
	keep hhid round z2 z1_3 n1 n2 c14_1 c14_3 c14_5 c14_7 
	
	merge m:1 hhid using "${phone_svy_profile}", keepusing(treatment ultra_poor PRA_lottery attrition_r1 attrition_r2 attrition_r3 attrition_r4 all_rounds) keep(3) nogen
	
	*Creating control variable to use with the gweightave function (UP only standardization)
	gen 	control = 0 if treatment == 1
	replace control = 1 if treatment == 0 
	
	*Standardizing by control ultra poor (SES full sample standardization)
	gen      control_nup = 0 
	replace  control_nup = 1 if control == 1 &  ultra_poor == 1	
	
	*Standardizing by treatment ultra poor (SES full sample standardization)
	gen      treat_nup = 0 
	replace  treat_nup = 1 if treatment == 1 &  ultra_poor == 1	
	
/* Since we have data from multilple rounds, Tazkira questions were only asked in subsequent rounds if they were not asked in the previous round. However, * due to some glitch, Tazkira was asked again of 23 HHs. For all of them, except one, responses between the two rounds are consistent. Below is checking * * for that.

* HHID 5353 in R1 said she had it and in R2 she said she never had it. Pick observation from R1, the first response 

	keep hhid z2 z1_3 round 
	recode z2 (2=1)
	
	collapse (sum) z2 z1_3, by(hhid)
	
	keep if  z2 >1 | z1_3 >1
	tempfile temp
	save `temp'
	
	use "${all_hhlevel_phonesvy}", clear
	recode z2 (2=1)
	merge m:1 hhid using "`temp'"
	drop if mi(z2) & mi(z1_3)
	unique hhid if _merge==3
	keep if _merge==3
	br hhid round z2 z1_3 */
	

************************************************************************************
	** Part 2: Create Food security index from panel data (FS collected in R1 and R4)
************************************************************************************	

* Create index for all rounds together
	loc foodsec_survey_vars "c14_3 c14_5 c14_1"
	
	foreach var of local foodsec_survey_vars {
		local `var'_l: variable label `var'
		
		gen 	`var'_ac=1 if `var'==0
		replace `var'_ac=0 if `var'==1
		
		lab var `var'_ac "``var'_l'"
	}
	
* Labels
	loc c14_7_l "Everyone regularly eats at least two meals every day"
	loc c14_3_ac_l "No adult skips or cut the size of meals"
	loc c14_5_ac_l "No child skips or cut the size of meals"
	loc c14_1_ac_l "There was enough food"
	
	loc food_sec_1_l "Food security (round 1)"
	loc food_sec2_1_l "Food security (with enough food to eat) (round 1)"
	loc food_sec_4_l "Food security (round 4)"
	loc food_sec2_4_l "Food security (with enough food to eat) (round 4)"
	loc food_sec_l "Food security (all rounds)"
	loc food_sec2_l "Food security (with enough food to eat) (all rounds)"
	
	loc food_sec_vars "c14_7 c14_3_ac c14_5_ac"
	loc food_sec2_vars "c14_7 c14_3_ac c14_5_ac c14_1_ac"

	gl all "food_sec food_sec2"
	
	foreach index in $all {
		foreach var of local `index'_vars {
			lab var `var' "``var'_l'"
		}
	
	* Standardize by UP control
	preserve 
		keep if ultra_poor == 1 
		
			egen index_sdC_`index' = weightave(``index'_vars'), normby(control)
			lab var index_sdC_`index' "``index'_l' Index sd(Control), UP only"
			
				keep hhid round index_sdC_`index' 
				tempfile index_sdC_`index'
				save	`index_sdC_`index''
			
	restore	
	
	* Standardize by UP control [controls and NUP only]
	preserve 
			egen index_sdC_NUP_`index' = weightave(``index'_vars'), normby(control_nup)
			lab var index_sdC_NUP_`index' "``index'_l' Index sd(Control), NUP + Control"
			
				keep hhid round index_sdC_NUP_`index' 
				tempfile index_sdC_NUP_`index'
				save	`index_sdC_NUP_`index''
	restore	
	
	* Standardize by UP treatment [treatment and NUP only]
	preserve 		
			egen index_sdT_NUP_`index' = weightave(``index'_vars'), normby(treat_nup)
			lab var index_sdT_NUP_`index' "``index'_l' Index sd(Control), NUP + Treatment"
			
				keep hhid round index_sdT_NUP_`index' 
				tempfile index_sdT_NUP_`index'
				save	`index_sdT_NUP_`index''
	restore	
	
	preserve 
		keep if all_rounds == 1 & ultra_poor == 1 
		
			egen index_sdC_`index'_all = weightave(``index'_vars'), normby(control)
			lab var index_sdC_`index'_all "``index'_l' Index sd(Control), UP only"
			
				keep hhid round index_sdC_`index'_all 
				tempfile index_sdC_`index'_all
				save	`index_sdC_`index'_all'
			
	restore	
	
	merge 1:1 hhid round using `index_sdC_`index'', assert(1 3) nogen
	merge 1:1 hhid round using `index_sdC_NUP_`index'', assert(1 3) nogen
	merge 1:1 hhid round using `index_sdC_`index'_all', assert(1 3) nogen
	merge 1:1 hhid round using `index_sdT_NUP_`index'', assert(1 3) nogen
	
	* Standardize by UP control [full sample]
		egen index_sdUP_C_`index' = weightave(``index'_vars'), normby(control_nup)
		lab var index_sdUP_C_`index' "``index'_l' Index sd(Control), full sample"	
	
	* Standardize by UP 
		egen index_sdUP_`index' = weightave(``index'_vars'), normby(ultra_poor)
		lab var index_sdUP_`index' "``index'_l' Index sd(Ultra-Poor), full sample"
	}

preserve	
	* Food security available in R1 and R4
	keep if inlist(round,1,4)
	
	if	`c(stata_version)'>=14	{
		saveold "${foodsecurity_long}", replace v(13)
	}
	else {
		save "${foodsecurity_long}", replace
	}
restore	
	
	drop index_* *_ac


*************************************************************************************************************
	** Part 3. Reshape wide and create indices for each round separately (pol. involvement is just one round)		
**************************************************************************************************************	

	foreach var in z2 z1_3 n1 n2 c14_1 c14_3 c14_5 c14_7 {
		local l`var' : variable label `var'
	}	
	
	rename * *_
	rename (hhid_ round_ treatment_ ultra_poor_ PRA_lottery_ attrition_r1_ attrition_r2_ attrition_r3_ attrition_r4_) (hhid round treatment ultra_poor PRA_lottery attrition_r1 attrition_r2 attrition_r3 attrition_r4)
	reshape wide z2_ z1_3_ n1_ n2_ c14_1_ c14_3_ c14_5_ c14_7_ , i(hhid) j(round)
	
	foreach var in c14_1 c14_3 c14_5 c14_7 n1 n2 z1_3 z2 {
			foreach round in 1 2 3 4 {
				lab var `var'_`round' "`l`var''"
			}
		}	
		
	missings dropvars, force 	
	
	rename (control_ control_nup_) (control control_nup)
	
* n1, n2 were asked in the "full" version of R4 survey 
	foreach var in n1 n2 {
		gen 	`var'_all = `var'_1 if !mi(`var'_1)
		replace `var'_all = `var'_4 if mi(`var'_all)
	}
	
	foreach var in z1_3 z2 {
		gen 	`var'_all = `var'_1 if !mi(`var'_1)
		replace `var'_all = `var'_2 if mi(`var'_all)
		replace `var'_all = `var'_3 if mi(`var'_all)
		replace `var'_all = `var'_4 if mi(`var'_all)
	}
	
* Add back the labels 		
	foreach round of numlist 1 4 {
		label var c14_1_`round' "No food to eat due to lack of resources (last month) (round `round')"
		label var c14_3_`round' "Cut adult size of meals or skip meals due to lack of resources (last month) (round `round')"
		label var c14_5_`round' "Cut child size of meals or skip meals due to lack of resources (last month) (round `round')"
		label var c14_7_`round' "Does everyone in the household regularly eat at least two meals a day? (round `round')"
	}
	
	label var z1_3_all	"LHH done activity: Vote in the last presidential election"
	label var z2_all 	"Do you personally have a tazkira?"
	

	
*-----------------------*
* Political involvement *
*-----------------------*

/*
1. Voted in the last presidential election: s12, to be constructed from tazkira question z1_3 [note: it is actually excluded from political involvement calculation at the moment]
2. Voted in the last provincial council election: s13, we do not have 
3. Has a Tazkira (Afghan national identification card): s21, to be constructed from z2
4. Is a member of a political party: s10, we do not have 
5. Attended village meetings: n1 [unchanged]
6. Approached village leaders about village issue: n2 [unchanged]
*/

* Instead of Observed tazkira, we use a question of whether the PW currently has (or has ever had) a Tazkira 
	gen 	z2_index_all = 1 if inlist(z2_all, 1, 2)
	replace z2_index_all = 0 if inlist(z2_all, 0)
	replace z2_index_all = .p if inlist(z2_all, .p)
	loc z2_index_all_l "PW currently has or has ever had a Tazkira (all)"
	
* Instead of a direct "Have you voted in the last presidential election" question, we ask whether ove the past year LHH has voted in a pres. election
	gen 	z1_3_index_all = 1 if z1_3_all == 1 
	replace z1_3_index_all = 0 if z1_3_all == 0
	replace z1_3_index_all = .p if z1_3_all == .p
	loc z1_3_index_all_l "PW voted in the last presidential election (all)"
		
* Local for survey vars related to political involment
	loc pol_involv_all_vars "z2_index_all z1_3_index_all n1_all n2_all" // remove s10 as we do not have it 
	loc pol_involv_village_all_vars "n1_all n2_all"
	
* Labels
	lab var z1_3_index_all "Voted in the last presidential election (all)"
	lab var z2_index_all "Has a Tazkira (Afghan national identification card) (all)"
	lab var n1_all "Attended village meetings (all)"
	lab var n2_all "Approached village leaders about village issue (all)" 

	
*---------------*
* Food security *
*---------------*
	
/*
1. Everyone eats at least two meals every day: c14_7
2. No adult skips meal or cut the size of meals: c14_3
3. No child skips meal or cut the size of meals	c14_5
4. No food to eat: c14_1
*/	
	
* Local for survey vars related to political involment that need convertion to positive
	foreach round in 1 4 {
		foreach var of local foodsec_survey_vars {
			gen 	`var'_ac_`round'=1 if `var'_`round'==0
			replace `var'_ac_`round'=0 if `var'_`round'==1
			lab var `var'_ac_`round' "``var'_l'"
		}
	}
	
* Labels
	loc foodsec_survey_vars "c14_3_1 c14_5_1 c14_1_1 c14_3_4 c14_5_4 c14_1_4"

	loc food_sec_1_vars "c14_7_1 c14_3_ac_1 c14_5_ac_1"
	loc food_sec2_1_vars "c14_7_1 c14_3_ac_1 c14_5_ac_1 c14_1_ac_1"

	loc food_sec_4_vars "c14_7_4 c14_3_ac_4 c14_5_ac_4"
	loc food_sec2_4_vars "c14_7_4 c14_3_ac_4 c14_5_ac_4 c14_1_ac_4"
	
********************************************************************************
	** Part 2: Construct indices
********************************************************************************
	
	loc pol_involv_all_l "Political involvement"
	
	* Create index for each round separately 
	gl all "food_sec_1 food_sec2_1 food_sec_4 food_sec2_4 pol_involv_all"
		
	foreach index in $all {
	    
		preserve 
			keep if ultra_poor == 1 
			
			egen index_sdC_`index' = weightave(``index'_vars'), normby(control)
			lab var index_sdC_`index' "``index'_l' Index sd(Control), UP only"
			
				keep hhid index_sdC_`index' 
				tempfile index_sdC_`index'
				save	`index_sdC_`index''
		restore	
		
		* NUP only index 
		preserve			
			egen index_sdC_NUP_`index' = weightave(``index'_vars'), normby(control_nup)
			lab var index_sdC_NUP_`index' "``index'_l' Index sd(Control), Control + NUP"
			
				keep hhid index_sdC_NUP_`index' 
				tempfile index_sdC_NUP_`index'
				save	`index_sdC_NUP_`index''
		restore	
			
		* Standardize by UP control [full sample]
		egen index_sdUP_C_`index' = weightave(``index'_vars'), normby(control_nup)
		lab var index_sdUP_C_`index' "``index'_l' Index sd(Control), full sample"	
		
		* Standardize by UP 
		egen index_sdUP_`index' = weightave(``index'_vars'), normby(ultra_poor)
		lab var index_sdUP_`index' "``index'_l' Index sd(Ultra-Poor), full sample"	

		merge 1:1 hhid using `index_sdC_`index'', assert(1 3) nogen
		merge 1:1 hhid using `index_sdC_NUP_`index'', assert(1 3) nogen
	}

* Save datasets		
	* Political involvement
		preserve
			keep hhid treatment ultra_poor `pol_involv_all_vars' `pol_involv_village_all_vars' index_sdUP_pol_involv_all index_sdUP_C_pol_involv_all index_sdC_pol_involv_all index_sdC_NUP_pol_involv_all			
			if	`c(stata_version)'>=14	{
				saveold "${polinvolvement}", replace v(13)
			}
			else {
				save "${polinvolvement}", replace
			}
		restore
	
	* Food security
		preserve
			keep hhid treatment ultra_poor  `foodsec_survey_vars'  `food_sec_1_vars' `food_sec2_1_vars' `food_sec_4_vars' `food_sec2_4_vars' index_sdC_food_sec* index_sdUP_food_sec* index_sdUP_C_food_sec* index_sdC_NUP_food_sec*
			
			if	`c(stata_version)'>=14	{
				saveold "${foodsecurity}", replace v(13)
			}
			else {
				save "${foodsecurity}", replace
			}
		restore		
