/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 11, 2019
Last udpate on: November 22, 2021

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		Yulia Belyakova

********************************************************************************			

THIS DO FILE: 	Constructs the following variables: livestock revenue, agricultural revenue, and non-agricultural business revenue.

CONTENT:		Part 0 - Define inputs and globals 
				Part 1 - Value, number of livestock construction [number R1 and R4, value R4 only]
				Part 2 - Livestock sales revenue construction [panel data in R1 and R4]
				Part 3 - Crops construction [R2 and R4 for incomplete HHs only - constructing "_all" variable]
				Part 4 - Business [panel data in R1 and R4]
			 
			 
INPUTS:     	

	Original data				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
	Profile data 				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
	Original crop roster		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/crops_roster_phonesvy.dta"
	Original livestock roster 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_roster_phonesvy.dta"

OUTPUTS:  

	Livestock assets (wide)		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_assets_index_phonesvy.dta"
	Livestock assets (long)		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_assets_index_long_phonesvy.dta"
	Livestock revenue (wide)	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_revenue_index_phonesvy.dta"
	Livestock revenue (long)	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_revenue_index_long_phonesvy.dta"
	Crops (wide)				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/crop_production_index_phonesvy.dta"
	Non-ag biz revene (wide)	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/business_rev_earnings_phonesvy.dta"
	Non-ag biz revene (long)	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/business_rev_earnings_long_phonesvy.dta"
		

		Notes & Questions:
			
			Part 1. Does the household own X livestock? (lstock_yes), Quantity owned (lstock_num) and Livestock value (lstock_value)
				
				lstock_yes (k7):
					Note on R3: k6 asks whether HH owned livestock over the past 3 years. Then k7 asks whether the HH still owns any of the
						livestock from k6, so the meaning of k7 in R3 is the same. So, we can construct lstock_yes for R3 as well. 
				
				lstock_num:
					Note: we do not have this info in R2 or R3, so we will not be able to construct lstock_num for HHs that were only surveyed in R2-3.
					
				lstock_value: k8 is only asked in R4, so it is the main and only indicator 
					
					
			Part 2. Livestock sales revenue (tot_lstock_rev)
			
					1. Impute 3 DKs for k38 in R4 since we can do it relatively precisely using the approx. range provided by respondents.  
					2. Take k38_r4 from R4 (value of sales in the last 4 weeks) as the main indicator since the recall period matches the follow-up.
					3. "fill-in" with k38 from R1 (value of sales since April, converted to 4 weeks) for HHs not surveyed in R4 for which we don't
						have a value from (2).
						
						Note that R1 is asked per livestock type, but in R4 total sales for all types of livestock.
			
			Part 3. Cultivated the crop (Cultivated the crop) and Value of production in the last 12 months (tot_crop_rev)
			
					1. Use R2 as the main indicator since data on crops for the majority of the sample will come from this round 
					2. "fill in" with R4 data for HHs not surveyed in R2; crops were asked in R4 "long" surveyd only, so not the full sample 
					
			Part 4. HH operates a non-ag businesses (biz_yes) and Total non-ag biz revenues in past 4 weeks (tot_biz_rev)
				
					1. Impute R4 revenues using a range estimate (same procedure as for k38_r4 above)
		

   	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl all_hhlevel_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
	gl phone_svy_profile   		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
	gl crops_phonesvy 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/crops_roster_phonesvy.dta"
	gl livestock_phonesvy 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_roster_phonesvy.dta"

* Outputs
	gl livestock_assets_index_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_assets_index_phonesvy.dta" // wide data 
	gl livestock_assets_long_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_assets_index_long_phonesvy.dta" // long data 
	
	gl livestock_revenue_index_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_revenue_index_phonesvy.dta"
	gl livestock_revenue_long_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_revenue_index_long_phonesvy.dta"
	
	gl crop_production_index_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/crop_production_index_phonesvy.dta"
	gl crop_production_phonesvy_long	    "${TUP_DB}/Phone_Survey/DataSets/Intermediate/crop_production_index_phonesvy_long.dta"
	
	gl business_rev_earnings_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/business_rev_earnings_phonesvy.dta"
	gl business_rev_earn_long_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/business_rev_earnings_long_phonesvy.dta"
		
	
********************************************************************************
	** Part 1: Number, Value of Livestock Owned
********************************************************************************

use "${livestock_phonesvy}", clear
	
	keep hhid livestock round k7 k7_r3 
	
	* k7_r3 was kept separate since it is asked differently.
		* But the meaning of k7_r3 in R3 is the same as R1, R4 (do you still - or surrently - own X type of livestock?)
	replace k7 = k7_r3 if round == 3 
	drop k7_r3
	
	* Value of livestock owned, k8, is only asked in R4, so we merge it
	preserve 
		use "${livestock_phonesvy}", clear
	* Add UP and treatment variables for correct comparisons 
	merge m:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment) keep(3) nogen
			
			* Do not use R3-R4 data if restricting analysis 
			keep hhid livestock round k8 ultra_poor treatment
			keep if round == 4
			
			tempfile k8_round4
			save `k8_round4'
	restore
	
	merge 1:1 hhid round livestock using "`k8_round4'", keepusing(k8 ultra_poor treatment) nogen
	isid hhid livestock round 
	
*-------------------------	
** Does the household own?
*-------------------------

	* For "Does the household own?" and "Quantity owned", using k7 from R1 (Do you currently own). It is also repeated in R4.
	* In R3, k6 asks whether HH owned livestock over the past 3 years. Then k7 asks whether the HH still owns any of the livestock from k6, so
	* the meaning is the same.

	gen 	lstock_yes = .
		replace lstock_yes = 1 if k7 > 0 & !mi(k7) 			
		replace lstock_yes = 0 if k7 == 0  				  
		
	foreach missing in ".d" ".r" {	
		replace lstock_yes = `missing' if k7 == `missing' & lstock_yes == .
		}
	
*-------------------------		
** Quantity owned
*-------------------------

	* Construction rules for lstock_num:
			* We do not have this info in R2 or R3, so we will not be able to construct lstock_num for HHs that were only surveyed in R2-3.
	gen 		lstock_num = k7
		replace lstock_num = 0 if lstock_yes == 0
		replace lstock_num = . if round == 3 // see note just above  

*-------------------------	
** Quantity owned in Livestock Units (LU)	
*-------------------------	
/* Conversion factors taken from Annex 1 of https://www.fao.org/3/i2294e/i2294e00.pdf, “Other” region:
		cattle 	= 0.6
		sheep 	= 0.1 
		goats 	= 0.1
		chicken = 0.01
		
	These are meant for international comparisons, hence cow is not 1, but 0.6. */
	
	gen lstock_unit = .
		replace lstock_unit = 0.6 	* lstock_num if livestock == 1 // cow 
		replace lstock_unit = 0.1 	* lstock_num if inlist(livestock,2,3) // goat / sheep
		replace lstock_unit = 0.01 	* lstock_num if livestock == 4 
	
	* Now in terms of cows 
	gen lstock_unit_cow = .
		replace lstock_unit_cow = 0.6/0.6 	* lstock_num if livestock == 1 // cow 
		replace lstock_unit_cow = 0.1/0.6 	* lstock_num if inlist(livestock,2,3) // goat / sheep
		replace lstock_unit_cow = 0.01/0.6 	* lstock_num if livestock == 4 
				
*-------------------------		
** Value of livestock
*-------------------------

	* Construction rules for lstock_value:
		* 1. k8 is only asked in R4
		
	* Find median unit value
		bys livestock: egen unit_value_median = median(k8) 	if k8>0 		
		bys livestock: egen unit_value_med = max(unit_value_median)
		drop unit_value_median
		
		replace unit_value_med = . if round != 4 // replace as missing values in rounds other than R4 so it is not confusing 
		
	* Reported unit value 	
		gen unit_value = k8
		
	* Replacing outliers and don't know / don't answer in k8. We will follow what we do elsewhere, replacing with the mean (not including by treatment as too few observations otherwise)
		bys livestock ultra_poor: egen mean_unit_value = mean(k8) if k8 > 0 
		replace unit_value = mean_unit_value if k8 == .o  | k8 == .d | k8 == .r
		drop  mean_unit_value  ultra_poor treatment 
		
	* Find unit value in terms of cows [use actualy reported values]
		gen value_cow = unit_value if livestock== 1
		egen value_cow_max = max(value_cow) 
		gen unit_value_cow = unit_value/(value_cow_max)
		drop value_cow value_cow_max
	
	* Find livestock value
		gen lstock_value = unit_value * lstock_num if round == 4
		gen lstock_value_cow = unit_value_cow*lstock_num if round == 4
		
	* Livestock value with median imputation
		gen lstock_value_med = unit_value_med*lstock_num if round == 4
		
	* Replace with .d and .r for the corresponding missing values for the number of livestock 
		replace lstock_value   		= .d if lstock_num == .d & lstock_yes==1 & round == 4 	
		replace lstock_value_cow 	= .d if lstock_num == .d & lstock_yes==1 & round == 4 	
		replace lstock_unit         = .d if lstock_num == .d & lstock_yes==1 & round == 4 	
		replace lstock_value_med  	= .d if lstock_num == .d & lstock_yes==1

		replace lstock_value 		= 0 if  lstock_value == . & lstock_yes==0 & round == 4 	
		replace lstock_value_cow 	= 0 if  lstock_value == 0
		replace lstock_unit 		= 0 if  lstock_value == 0 
		replace lstock_value_med 	= 0 if lstock_yes==0 & round == 4
		
	* Generate variables of value conditional on having livestock
		gen lstock_value_yes = lstock_value if lstock_yes==1
		
		
* Reshape
	drop k7 k8
	rename * *_
	rename (hhid_ livestock_ round_) (hhid livestock round)
	reshape wide lstock_yes_ lstock_num_ lstock_unit_ lstock_unit_cow_ unit_value_ unit_value_med_ unit_value_cow_ lstock_value_ lstock_value_cow_ lstock_value_yes_ lstock_value_med_, i(hhid round) j(livestock)

*-------------------------
* Create totals
*-------------------------	

	* Generate total value of livestock
	egen tot_lstock_value 		= rowtotal(lstock_value_1 lstock_value_2 lstock_value_3 lstock_value_4), m
	egen tot_lstock_value_cow 	= rowtotal(lstock_value_cow_1 lstock_value_cow_2 lstock_value_cow_3 lstock_value_cow_4), m
	
	lab var tot_lstock_value 		"Total livestock value (AFN)"
	lab var tot_lstock_value_cow 	"Total livestock value (Cows)"
	
	* Using median
	egen tot_lstock_value_med 		= rowtotal(lstock_value_med_1 lstock_value_med_2 lstock_value_med_3 lstock_value_med_4), m
	lab var tot_lstock_value_med 		"Total livestock value (AFN), median imputed"
	
	* Generate total units of livestock in LU 
	egen tot_lstock_unit = rowtotal(lstock_unit_1 lstock_unit_2 lstock_unit_3 lstock_unit_4), m
	lab var tot_lstock_unit			"Total Livestock Units (LU)"
	
	* Generate total units of livestock in LU in terms of cows 
	egen tot_lstock_unit_cow = rowtotal(lstock_unit_cow_1 lstock_unit_cow_2 lstock_unit_cow_3 lstock_unit_cow_4), m
	lab var tot_lstock_unit_cow		"Total Livestock Units (LU) in Cows "

* Labeling and renaming
	loc	lstock1		cow 
	loc	lstock2		goat
	loc	lstock3		sheep
	loc	lstock4		chicken
	
	loc lstock_yes_l 			"HH owns any"
	loc lstock_num_l 			"Number of owned"
	loc lstock_unit_l			"Quantity owned in Livestock Units (LU)	"
	loc lstock_unit_cow_l		"Quantity owned in Cows"
	loc unit_value_l			"Unit value"
	loc unit_value_med_l		"Unit value (median imputed)"
	loc unit_value_cow_l		"Unit value in Cows"
	loc lstock_value_med_l 		"Livestock value (median imputed)"
	
	loc vars "lstock_yes lstock_num lstock_unit lstock_unit_cow unit_value unit_value_med unit_value_cow lstock_value lstock_value_cow lstock_value_yes lstock_value_med" 
	
	foreach var of local vars {
		forval lstocknum=1/4 {
			rename `var'_`lstocknum' `var'_`lstock`lstocknum''
			lab var `var'_`lstock`lstocknum'' "``var'_l' `lstock`lstocknum''"
			
			if inlist("`var'", "lstock_value", "lstock_value_yes", "lstock_value_cow") {
			lab var `var'_`lstock`lstocknum'' "Total value of `lstock`lstocknum'' ``var'_l'"
			}
		}
	}

	* Set lstock value back to missing if HH never reported it (does not own lstock)
	foreach var in unit_value {
		forval lstocknum=1/4 {
			replace `var'_`lstock`lstocknum'' = . if lstock_yes_`lstock`lstocknum'' == 0
		}
	}
	

*---------------------------------
* Generate if has any TUP livestock
*---------------------------------

	egen 	tup_lstock_yes = rowtotal(lstock_yes_cow lstock_yes_goat lstock_yes_sheep), missing
		replace tup_lstock_yes = 1 if tup_lstock_yes > 1 & !mi(tup_lstock_yes)			
		replace tup_lstock_yes = . if round == 3 // This is a different question in R3
	lab var tup_lstock_yes "Household Owns Any TUP Livestock"
	
* Save long dataset for panel regression 
	if	`c(stata_version)'>=14	{
		saveold "${livestock_assets_long_phonesvy}", replace v(13)
	}
	else {
		save "${livestock_assets_long_phonesvy}", replace	
	}
	
* Reshape wide 
qui ds 
foreach var in `r(varlist)' {
	local `var'_lab: var label `var'
}

rename * *_
rename (hhid_ round_) (hhid round) 

	reshape wide lstock_yes_cow_ lstock_num_cow_ lstock_unit_cow_ lstock_unit_cow_cow_ unit_value_cow_ unit_value_cow_cow_ lstock_value_cow_ lstock_value_cow_cow_ lstock_value_yes_cow_ lstock_yes_goat_ lstock_num_goat_ lstock_unit_goat_ lstock_unit_cow_goat_ unit_value_goat_ unit_value_cow_goat_ lstock_value_goat_ lstock_value_cow_goat_ lstock_value_yes_goat_ lstock_yes_sheep_ lstock_num_sheep_ lstock_unit_sheep_ lstock_unit_cow_sheep_ unit_value_sheep_ unit_value_cow_sheep_ lstock_value_sheep_ lstock_value_cow_sheep_ lstock_value_yes_sheep_ lstock_yes_chicken_ lstock_num_chicken_ lstock_unit_chicken_ lstock_unit_cow_chicken_ unit_value_chicken_ unit_value_cow_chicken_ lstock_value_chicken_ lstock_value_cow_chicken_ lstock_value_yes_chicken_ tot_lstock_value_ tot_lstock_value_cow_ tot_lstock_unit_ tot_lstock_unit_cow_ tup_lstock_yes_ lstock_value_med_cow_ lstock_value_med_goat_ lstock_value_med_sheep_ lstock_value_med_chicken_ tot_lstock_value_med_ unit_value_med_cow_ unit_value_med_goat_ unit_value_med_sheep_ unit_value_med_chicken_, i(hhid) j(round)

	foreach var in lstock_yes_cow_ lstock_num_cow_ lstock_unit_cow_ lstock_unit_cow_cow_ unit_value_cow_ unit_value_cow_cow_ lstock_value_cow_ lstock_value_cow_cow_ lstock_value_yes_cow_ lstock_yes_goat_ lstock_num_goat_ lstock_unit_goat_ lstock_unit_cow_goat_ unit_value_goat_ unit_value_cow_goat_ lstock_value_goat_ lstock_value_cow_goat_ lstock_value_yes_goat_ lstock_yes_sheep_ lstock_num_sheep_ lstock_unit_sheep_ lstock_unit_cow_sheep_ unit_value_sheep_ unit_value_cow_sheep_ lstock_value_sheep_ lstock_value_cow_sheep_ lstock_value_yes_sheep_ lstock_yes_chicken_ lstock_num_chicken_ lstock_unit_chicken_ lstock_unit_cow_chicken_ unit_value_chicken_ unit_value_cow_chicken_ lstock_value_chicken_ lstock_value_cow_chicken_ lstock_value_yes_chicken_ tot_lstock_value_ tot_lstock_value_cow_ tot_lstock_unit_ tot_lstock_unit_cow_ tup_lstock_yes_ lstock_value_med_cow_ lstock_value_med_goat_ lstock_value_med_sheep_ lstock_value_med_chicken_ tot_lstock_value_med_ unit_value_med_cow_ unit_value_med_goat_ unit_value_med_sheep_ unit_value_med_chicken_ {
		foreach i in 1 3 4  {
			label var `var'`i' "``var'lab' (round `i')"
		}
	}
	
	missings dropvars, force 
	
	merge 1:1 hhid using "${phone_svy_profile}", assert (2 3) keep(3) nogen keepusing(attrition_r1 attrition_r3 attrition_r4)

	* Save
	if	`c(stata_version)'>=14	{
		saveold "${livestock_assets_index_phonesvy}", replace v(13)
	}
	else {
		save "${livestock_assets_index_phonesvy}", replace
	}		

	
********************************************************************************
	** Part 2: Livestock sales revenue [panel data in R1 and R4]
********************************************************************************

*-------------------------------------	
* 1. Revenues from sales in livestock 
*-------------------------------------
use "${livestock_phonesvy}", clear
	keep hhid round k36 k36_r4 k38_r4 k38_dk k39_? k39_?? k39__97 // add reason for livestock sale 
	duplicates drop
	drop if round == 3 // no data on livestock sales 
	
	preserve 
		use "${livestock_phonesvy}", clear
	
		keep hhid livestock round k37 k38 k39_? k39_?? k39__97  // 231 
		keep if round == 1

*Imputing the "don't know" from k38 		
*Add UP and treatment variables for correct comparisons 
	merge m:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment) keep(3) nogen	
		
* Getting first price per animal and then multiplying again 
		gen sales_p = k38 / k37 	
		bys livestock treatment: egen mean_sales_p = mean(sales_p) if sales_p > 0
		replace k38 = k37*mean_sales_p if k38 == .d | k38 == .o
		
* Now imputing the don't know from k37 (the number of animals sold)
		bys livestock treatment: egen mean_k38 = mean(k38) if k38 > 0
		replace k38 = mean_k38 if k37 == .d 

* Saving the "regular" missings to be used after  
		gen k38_miss = 1 if k38 == .
		
		drop mean_sales_p ultra_poor treatment	k37	
		
		* Sum up livestock revenues 	
		unab varlist: k39_1 - k39__97
		
		foreach v of local varlist {
			local l`v' : variable label `v'
			di "`l`v''"
		}

		collapse (sum) k38 (max) round (sum) k38_miss (sum) k39_1 - k39__97, by(hhid)
		
		* Apply labels 
		foreach v of local varlist {
			lab var `v' "`l`v''"
		}
		
		* Put back the "DK" missings erased in the collapse 
		replace k38 = . if k38_miss == 4 
	
		rename k38 k38_r1 

		forval i = 1/10 {
			clonevar sale_reason_`i' = k39_`i'
				replace sale_reason_`i' = 1 if k39_`i'>1 & !mi(k39_`i')	
		}
		
		clonevar sale_reason__97 = k39__97
			replace sale_reason__97 = 1 if k39__97>1 & !mi(k39__97)
		
		* Convert k38 to 4-week period 
			* Merge on R1 survey date for each HH 
			merge 1:1 hhid using "${phone_svy_profile}", assert (2 3) keep(3) nogen keepusing(date_r1)
			
			* Create period from April 2020 to date of R1 survey in weeks 
			tempvar recall_period
			gen `recall_period' = (date_r1 - date("01apr2020", "DMY")) / 7
		
			gen k38_4weeks = k38_r1 * 4 / `recall_period'

			drop  k38_miss
			
		tempfile k38_r1
		save `k38_r1'
	restore 
		
	keep if round == 4 	
		
	* Merge on R1 variables	
	merge 1:1 hhid using "`k38_r1'", nogen

	merge m:1 hhid using "${phone_svy_profile}", assert (2 3) keep(3) nogen keepusing(ultra_poor ultra_poor treatment attrition_r1 attrition_r4) update replace 
	
*---------------------------------------------------------------------------	
* Generate variable for livestock sales (originally called lstock_rev_sales)
*---------------------------------------------------------------------------

	* In R4, we asked for a range estimate when the respose was "DK".
	* Impute ".d" in R4 with the median of k38 for HHs in the reported range for future use.
	tab k38_r1, m 		//  
	tab k38_r4, m	// 3 "DKs" and 3 .o
	tab k38_dk		// 3 estimates are given for the "DKs" above, so they can be imputed more precisely
	tab k38_dk, nol // we only have 2 ranges: 4,001 - 9,000 Afs and 9,001 - 15,000 Afs 
	
	gen k38_r4_range = 4 if inrange(k38_r4,4001,9000)
	replace k38_r4_range = 5 if inrange(k38_r4,9001,15000)
		
	bys k38_r4_range: egen k38_median = median(k38_r4) if k38_r4>0 & round == 4 & !mi(k38_r4_range)
	
	* Save the medians for the 2 ranges as defined above 
	preserve 
		keep k38_r4_range k38_median
		rename k38_r4_range k38_dk
		duplicates drop
		drop if mi(k38_median)
		
		tempfile k38_dk_med
		save `k38_dk_med'
	restore
		
	* Merge the medians on range	
		drop k38_median
		merge m:1 k38_dk using "`k38_dk_med'", keep(1 3) keepusing(k38_median) nogen
		
	* Replace k38 in R4 with the relevant range median (3 replacements)
		replace k38_r4 = k38_median if mi(k38_r4) & !mi(k38_median)
		drop k38_median
		
	* Now imputing the 3 outliers in R4 	
		bys round ultra_poor treatment: egen mean_k38_r4 = mean(k38_r4) if k38_r4 > 0
		replace k38_r4 = mean_k38_r4 if k38_r4 == .o 
		
	preserve 	
		* K38 variable for panel data regression
		keep hhid k38_r4 k38_4weeks attrition_r1 attrition_r4 ultra_poor
		*including k38_4weeks instead of k38_r1 to be consistent in the time covered 
		rename k38_4weeks k38_r1
		reshape long k38_r, i(hhid) j(round)
		rename k38_r k38
	
		lab var k38 "Livestock sales for panel regression (over 4 weeks - last 4 for r4 and averaged for r1)"
			
		* Panel totals indicator 
			gen 	tot_lstock_rev = k38
				replace tot_lstock_rev = 0 	 if tot_lstock_rev == . & attrition_r1 == 0	& round == 1 
				replace tot_lstock_rev = 0 	 if tot_lstock_rev == . & attrition_r4 == 0	& round == 4 
			
			winsor2 tot_lstock_rev, s(_win) c(0 95) by(ultra_poor round) 	
				replace tot_lstock_rev = 0 if tot_lstock_rev == 0	
				
		* Save panel indicator in a separate dataset 		

		if	`c(stata_version)'>=14	{
			saveold "${livestock_revenue_long_phonesvy}", replace v(13)
		}
		else {
			save "${livestock_revenue_long_phonesvy}", replace
		}			

	restore
		
	* Construct the totals indicator
		* R1 indicator 
		gen 	tot_lstock_rev_1 = k38_4weeks
			replace tot_lstock_rev_1 = 0 	 if tot_lstock_rev_1 == . & attrition_r1 == 0
		
		* R4 indicator 
		gen 	tot_lstock_rev_4 = k38_r4
			replace tot_lstock_rev_4 = 0 	 if tot_lstock_rev_4 == .  & attrition_r4 == 0
			
		* Winsorize 		
		winsor2 tot_lstock_rev_1, s(_win) c(0 95) by(ultra_poor)
			rename tot_lstock_rev_1_win tot_lstock_rev_win_1
			replace tot_lstock_rev_win_1 = 0 if tot_lstock_rev_1 == 0
		
		winsor2 tot_lstock_rev_4, s(_win) c(0 95) by(ultra_poor) 	
			rename tot_lstock_rev_4_win tot_lstock_rev_win_4
			replace tot_lstock_rev_win_4 = 0 if tot_lstock_rev_4 == 0
			
* Labels
	lab var tot_lstock_rev_1 "Sales of livestock (last 4 weeks) (round 1)"
	lab var tot_lstock_rev_4 "Sales of livestock (last 4 weeks) (round 4)"
	lab var tot_lstock_rev_win_1 "Sales of livestock - Winsorized (last 4 weeks) (round 1)"
	lab var tot_lstock_rev_win_4 "Sales of livestock - Winsorized (last 4 weeks) (round 4)"
	
/* Compare this to fl1 [this is part 4 weeks sales, but total, not per luivestock type]: 
	cap noi tabstat tot_lstock_rev_4 if tot_lstock_rev_4 > 0, stat(min p5 p50 mean p75 p95 max) // exclude 0
	cap noi tabstat tot_lstock_rev_4, stat(min p5 p50 mean p75 p95 max) // include 0*

	preserve 
		global fl1_data  "${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"

		use "${fl1_data}", clear 
			tabstat k38 if k38 > 0, stat(min p5 p50 mean p75 p95 max) // generally much higher than what we see in R1
			tabstat k38, stat(min p5 p50 mean p75 p95 max) 
	restore */
	
* Keep only relevant vars 
	keep hhid treatment tot_lstock_rev* sale_reason*
	
* Save
	if	`c(stata_version)'>=14	{
		saveold "${livestock_revenue_index_phonesvy}", replace v(13)
	}
	else {
		save "${livestock_revenue_index_phonesvy}", replace
	}			

	
********************************************************************************
	** Part 3: Crops [R2 and R4 for incomplete HHs only - constructing "_all" variable]
********************************************************************************

use "${crops_phonesvy}", clear

	keep hhid round crop k15 k20_1 k20_2 k21_1 k21_2
	duplicates drop 
	
* Merge on UP and HH size 
	merge m:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment attrition_r2 attrition_r4) keep(3) nogen

*---------------------
* Cultivated the crop
*---------------------

	gen crop_yes = k15
		lab var crop_yes "Household Has Any Crop"
		
* Drop HHs without this information 		
	drop if crop_yes == . 

*------------------------------------------------------------	
* Value of production in the last 12 months - including "0"s
*------------------------------------------------------------

	* Imputing only for outliers, otherwise too many "don't know" compared to some other variables where we did
	* We include the two rounds as round 4 was just for completion 
	bys  ultra_poor treatment: egen mean_k20_1 = mean(k20_1) if k20_1 > 0
	replace k20_1 = mean_k20_1 if k20_1 == .o 
	
	bys  ultra_poor treatment: egen mean_k20_2 = mean(k20_2) if k20_2 > 0
	replace k20_2 = mean_k20_2 if k20_2 == .o 	
	
	drop mean_k20_1 mean_k20_2
		
* Creating the total production variable 
	egen k20_tot = rowtotal(k20_1 k20_2)
		lab var k20_tot "Total crop revenue (AFN), 12 months"
		
	gen k20_tot_dmiss = 1 if (k20_1 == .d | k20_2 == .d)

	replace k20_tot = .d if k20_tot == . & k20_tot_dmiss == 1 
	
	gen	tot_crop_rev = k20_tot		
		replace tot_crop_rev = tot_crop_rev/13 // 52 weeks in a year. divided by 13 to get 4 weeks
		replace tot_crop_rev = .d if k20_tot_dmiss == 1 
	lab var tot_crop_rev "Total crop revenue (AFN), 4 weeks"
	
	drop k20_tot_dmiss

* Winsorize at 95% including the 0s 		
	winsor2 tot_crop_rev, s(_win) c(0 95) by(ultra_poor round) 
		replace tot_crop_rev_win = 0 if tot_crop_rev == 0
		label var tot_crop_rev_win "Total crop revenue - Winsorized at 95% (AFN), 4 weeks"

* Number of different types of crop cultuvated either for sale or for consumption
	egen crop_type = rowtotal(k21_1 k21_2)
		replace crop_type = 0 if inlist(crop,.d,.r) // if they don't know which crop they grow, don't count it
	
	bys hhid round: egen num_crop_type = total(crop_type)
	assert num_crop_type == 0 if crop_yes == 0
	lab var num_crop_type "Number of crops cultivated for consumption or for sale"
	drop crop_type crop k21_1 k21_2 
	
	duplicates drop 
	isid hhid round
	cou 

* Save long data 
	save "${crop_production_phonesvy_long}", replace 
	
* Reshape wide so we have values from the 2 rounds
	unab varlist: k15 - k20_2 crop_yes - tot_crop_rev_win num_crop_type 
	 
	foreach var in `varlist' { 
		local l`var' : variable label `var' 
	}	 

	rename (k15 k20_1 k20_2 crop_yes k20_tot tot_crop_rev tot_crop_rev_win num_crop_type) (k15_ k20_1_ k20_2_ crop_yes_ k20_tot_ tot_crop_rev_ tot_crop_rev_win_ num_crop_type_)
	
	* To reshape, imputed R1 households have missing round, which does not work  
	reshape wide k15_ k20_1_ k20_2_ crop_yes_ k20_tot_ tot_crop_rev_ tot_crop_rev_win_ num_crop_type_, i(hhid) j(round)
	
* Imputation for the 126 HHs that were surveyed in R1 but not in R2
	cap drop treatment 
	merge 1:1 hhid using "${phone_svy_profile}", keepusing (attrition_r1 attrition_r2 treatment) 
	
	drop if mi(attrition_r1) // empty observations 
	drop if attrition_r1 == 1 & _merge==2
	tab attrition_r1 if _merge == 2 // 126 observations
	drop _merge
	
* Impute crop revenue for HHs not surveyed in R2, but those we have in the total income calculation	
	preserve 
		bys treatment: egen mean_tot_crop_rev_2 = mean(tot_crop_rev_2) if tot_crop_rev_2 > 0
		
		keep treatment mean_tot_crop_rev_2
		keep if !mi(mean_tot_crop_rev_2)
		duplicates drop 
		
		tempfile mean_crop_rev_r2
		save `mean_crop_rev_r2'
	restore	
	
	merge m:1 treatment using "`mean_crop_rev_r2'", assert(3) nogen
	
	gen tot_crop_rev_imp_2 = tot_crop_rev_2
	replace tot_crop_rev_imp_2 = mean_tot_crop_rev_2 if mi(tot_crop_rev_2)
	
	replace tot_crop_rev_imp_2 = . if attrition_r1 == 1 // such that N for crops = N for total income (this replaces R2-only HHs)
	lab var tot_crop_rev_imp_2 "Total crop revenue (AFN), 4 weeks (imputed)"
	
	foreach var in k15 k20_1 k20_2 crop_yes k20_tot tot_crop_rev tot_crop_rev_win num_crop_type tot_crop_rev_imp { 
		cap noi label var `var'_2 "`l`var''" 
		cap noi label var `var'_4 "`l`var''" 
	}	 
	
	* Construction rules:
	* 1. Use R2 as the main indicator since data on crops for the majority of the sample will come from this round 
	* 2. "fill in" with R4 data for HHs not surveyed in R2 (this was the "full" R4 survey for HHs we missed in at least one round)
	foreach var in k15 k20_1 k20_2 crop_yes k20_tot tot_crop_rev tot_crop_rev_win num_crop_type {
		gen `var'_all = `var'_2
			replace `var'_all = `var'_4 if mi(`var'_all) & !mi(`var'_4)
			lab var `var'_all "`l`var'' (all)" 
	}	
		
* Keep only relevant vars 
	keep hhid crop_yes* tot_crop_rev* num_crop_type_2
		rename num_crop_type_2 num_crop_type
	
* Save
	if	`c(stata_version)'>=14	{
		saveold "${crop_production_index_phonesvy}", replace v(13)
	}
	else {
		save "${crop_production_index_phonesvy}", replace
	}	
	
	
********************************************************************************
	** Part 4: Business [panel data in round 1 and 4]
********************************************************************************

use "${all_hhlevel_phonesvy}", clear
	keep hhid round k23_a k32 k32_dk

	keep if inlist(round,1,4)
	
* Merge on UP and HH size 
	merge m:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment) keep(3) nogen	
	
* Drop household without this information
	drop if k23_a == . 
	
*-----------------------	
* Operate business
	gen biz_yes = k23_a
		lab var biz_yes "Household Has Any Business"
*-----------------------
	
* Revenues in last 4 weeks
	* In R4, we asked for a range estimate when the respose was "DK".
	/* Impute ".d" in R4 with the median of k32 for HHs in the reported range.
	
		1	<500 Afs
		2	500 - 3,000 Afs
		3	3,001 - 6,000
		4	6,001 - 9,000
		5	9,001 - 15,000
		6	15,001 - 20,000
		7	> 20,000            */

	gen k32_range = 1 if inrange(k32,0,499) & round == 4 // including 0
		replace k32_range = 2 if inrange(k32,500,3000) & round == 4
		replace k32_range = 3 if inrange(k32,3001,6000) & round == 4
		replace k32_range = 4 if inrange(k32,6001,9000) & round == 4
		replace k32_range = 5 if inrange(k32,9001,15000) & round == 4
		replace k32_range = 6 if inrange(k32,15001,20000) & round == 4
		replace k32_range = 7 if k32>20000 & !mi(k32) & round == 4
	
	bys k32_range: egen k32_median = median(k32) if k32>0 & round == 4 
	
	* Save the medians for the 7 ranges as defined above 
	preserve 
		keep k32_range k32_median
		rename k32_range k32_dk
		duplicates drop
		drop if mi(k32_median)
		
		tempfile k32_dk_med
		save `k32_dk_med'
	restore
		
	* Merge the medians on range	
		drop k32_median
		merge m:1 k32_dk using "`k32_dk_med'", keep(1 3) keepusing(k32_median) nogen
		
	* Replace k32 with the relevant range median 
		replace k32 = k32_median if mi(k32) & !mi(k32_median)
			drop k32_range k32_median
		
	* Imputing only for outliers, too many "don't know" compared to some other variables where we did
	* Only outlier is in R4
	bys round ultra_poor treatment: egen mean_k32 = mean(k32) if k32 > 0
	replace k32 = mean_k32 if k32 == .o 		
	drop mean_k32
	
*-----------------------	
* Tot biz revenue 	
*-----------------------

	gen tot_biz_rev = k32
		replace tot_biz_rev = 0 if biz_yes == 0
		lab var tot_biz_rev "Total business revenue (AFN), 4 weeks"
		
	* Winsorize at 95% including the 0s 		
	winsor2 tot_biz_rev, s(_win) c(0 95) by(ultra_poor round) 
		label var tot_biz_rev_win "Total business revenue - Winsorized at 95% (AFN), 4 weeks"
	
	* Impute total biz revenue for the don't knows - means by treatment/round 
	bys treatment round: egen mean_tot_biz_rev = mean(tot_biz_rev) if tot_biz_rev > 0
	
	gen tot_biz_rev_imp = tot_biz_rev
	replace tot_biz_rev_imp = mean_tot_biz_rev if mi(tot_biz_rev)
	lab var tot_biz_rev_imp "Total business revenue (AFN), 4 weeks (imputed)"

	drop mean_tot_biz_rev
	
* Save long data for panel regression 
	if	`c(stata_version)'>=14	{
		saveold "${business_rev_earn_long_phonesvy}", replace v(13)
	}
	else {
		save "${business_rev_earn_long_phonesvy}", replace
	}
	
* Reshape wide so we have values from the 2 rounds and can chose which one to use as the main indicator 
	unab varlist: k23_a - k32_dk biz_yes - tot_biz_rev_win tot_biz_rev_imp
	 
	foreach var in `varlist' { 
		local l`var' : variable label `var' 
	}	 

	rename (k23_a k32 k32_dk biz_yes tot_biz_rev tot_biz_rev_win tot_biz_rev_imp) (k23_a_ k32_ k32_dk_ biz_yes_  tot_biz_rev_ tot_biz_rev_win_ tot_biz_rev_imp_)
	reshape wide k23_a_ k32_ k32_dk_ biz_yes_ tot_biz_rev_ tot_biz_rev_win_ tot_biz_rev_imp_, i(hhid) j(round)
	
	foreach var in k23_a k32 k32_dk biz_yes tot_biz_rev tot_biz_rev_win tot_biz_rev_imp { 
		label var `var'_1 "`l`var''" 
		label var `var'_4 "`l`var''" 
	}	 	
	
	missings dropvars, force 
	
* Keep only relevant vars 
	keep hhid biz_yes* tot_biz_rev* tot_biz_rev_win*

	* Save
	if	`c(stata_version)'>=14	{
		saveold "${business_rev_earnings_phonesvy}", replace v(13)
	}
	else {
		save "${business_rev_earnings_phonesvy}", replace
	}
