/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 26, 2019
Last udpate on: November 30, 2021

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		Yulia Belyakova 

********************************************************************************			

CONTENT:		Part 0 - Reshape dataset 
				Part 1 - Constructing and labeling schooling variables  
  
INPUTS: 				Original dataset		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/current_roster_final_phonesvy.dta" 
						Profile info			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta" 
						  
OUTPUTS:     	  
				Wide dataset (unique ID is hhid childnum): 
												"${TUP_DB}/Phone_Survey/DataSets/Intermediate/schooling_phonesvy.dta" 
				
				Long data for panel regression (unque ID is hhid round childnum):
												"${TUP_DB}/Phone_Survey/DataSets/Intermediate/schooling_long_phonesvy.dta"
				 
  
	Issues & Questions:  
				1. Child-level data on schooling collected in R1 and R4.
					Order of children between R1 and R4 is most certainly inconsistent.
				  	
	
*******************************************************************************/

	clear all
	set more off
	set maxvar 20000

* Inputs
	global roster_final_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/current_roster_final_phonesvy.dta"		
	global phone_svy_profile   		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

* Outputs
	global schooling_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/schooling_phonesvy.dta"
	global schooling_long_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/schooling_long_phonesvy.dta"
	
********************************************************************************
	** Part 0: Keep relevant variables and reshape data 
********************************************************************************

use "${roster_final_phonesvy}", clear
	cap drop __000000 __000001
	
* Drop vars we don't need 
	drop pilot1_flag pilot2_flag call_status - schoolchild no_pm pm hh_only_pf
	
	drop if mi(childnum)
	
* Before reshapring, save long data with all rounds for panel data regression using all rounds
	preserve 
		foreach var in child_sex child_age x6 b15b x7a kid_6_14_m t_kid_6_14_m kid_15_17_m t_kid_15_17_m kid_15_18_m t_kid_15_18_m kid_6_17_m t_kid_6_17_m kid_6_18_m t_kid_6_18_m {
			rename `var' `var'_0
		}
	
		tempfile panel_long
		save `panel_long'
	restore 
	
* Reshape wide to construct a cross-section dataset from panel data 
	unab varlist: child_sex - t_kid_6_18_m 
	 
	foreach var in `varlist' { 
		local l`var' : variable label `var' 
	}	 

	rename * *_
	rename (hhid_ round_ childnum_ PRA_lottery_ treatment_ ultra_poor_) (hhid round childnum PRA_lottery treatment ultra_poor)
	reshape wide child_sex_ child_age_ x6_ b15b_ x7a_ kid_6_14_m_ t_kid_6_14_m_ kid_15_17_m_ t_kid_15_17_m_ kid_15_18_m_ t_kid_15_18_m_ kid_6_17_m_ t_kid_6_17_m_ kid_6_18_m_ t_kid_6_18_m_, i(hhid childnum) j(round) 

	foreach var in child_sex child_age x6 b15b x7a kid_6_14_m t_kid_6_14_m kid_15_17_m t_kid_15_17_m kid_15_18_m t_kid_15_18_m kid_6_17_m t_kid_6_17_m kid_6_18_m t_kid_6_18_m { 
		label var `var'_1 "`l`var''" 
		label var `var'_4 "`l`var''" 
	}	 
	
* Drop extra vars created by the reshape 
	missings dropvars, force	
	
* Merge on long data
	gen round = 0
	merge 1:1 hhid childnum round using "`panel_long'", nogen

********************************************************************************
	** Part 1: Schooling variables
********************************************************************************
	* School age children: between 6 and 18 inclusive
		
	foreach round of numlist 0 1 4 {	
		gen child_in_schooling_age_hh_`round' 	= 1 if inrange(child_age_`round',6,18) | x6_`round'!=. | b15b_`round'!=. // because we did not ask child age for all of R1
	}
	
	foreach round of numlist 0 1 4 {	
		gen boy_in_schooling_age_hh_`round' 	= 1 if child_in_schooling_age_hh_`round'==1 & child_sex_`round'==1
		gen girl_in_schooling_age_hh_`round' 	= 1 if child_in_schooling_age_hh_`round'==1 & child_sex_`round'==2
	}
	
	* Children in school (x6 == 1) among those in schooling age
	foreach round of numlist 0 1 4 {		
		gen 	child_inschool_hh_`round' 		= 1 if child_in_schooling_age_hh_`round' == 1   & x6_`round' == 1
	}
	
	foreach round of numlist 0 1 4 {	
		gen 	boy_inschool_hh_`round'			= 1 if boy_in_schooling_age_hh_`round'   == 1   & x6_`round' == 1
		gen 	girl_inschool_hh_`round'		= 1 if girl_in_schooling_age_hh_`round'  == 1   & x6_`round' == 1
	}
	
	* Children not in school (x6 == 0) among those in schooling age
	foreach round of numlist 0 1 4 {		
		replace child_inschool_hh_`round' 	= 0 if child_in_schooling_age_hh_`round' == 1 & x6_`round' == 0
		replace boy_inschool_hh_`round'		= 0 if boy_in_schooling_age_hh_`round' == 1   & x6_`round' == 0
		replace girl_inschool_hh_`round'	= 0 if girl_in_schooling_age_hh_`round' == 1  & x6_`round' == 0
	}
	
* Labels
	foreach round of numlist 0 1 4 {	
		lab var child_in_schooling_age_hh_`round' "Children in schooling age (round `round')"
		lab var boy_in_schooling_age_hh_`round' "Boy in schooling age (round `round')"
		lab var girl_in_schooling_age_hh_`round' "Girl in schooling age (round `round')"
		lab var child_inschool_hh_`round' "Children in schooling age in school (round `round')"
		lab var boy_inschool_hh_`round' "Boys (round `round')"
		lab var girl_inschool_hh_`round' "Girls (round `round')"
	}
	
* HHs with children in schooling age:
	foreach round of numlist 0 1 4 {	
		bys hhid: gen count_`round'= _n
		bys hhid: egen child_`round' = max(child_in_schooling_age_hh_`round')
		tab child_`round' if count_`round' == 1, m
		
		drop count_`round' child_`round'
	}
	
/*  

	child_0 |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |      1,744       92.03       92.03
          . |        151        7.97      100.00
------------+-----------------------------------
      Total |      1,895      100.00
(5,062 missing values generated)

    child_1 |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |      1,511       79.74       79.74
          . |        384       20.26      100.00
------------+-----------------------------------
      Total |      1,895      100.00
(5,840 missing values generated)

    child_4 |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |      1,484       78.31       78.31
          . |        411       21.69      100.00
------------+-----------------------------------
      Total |      1,895      100.00
   */
	
preserve 	
	keep if child_in_schooling_age_hh_1 == 1
	unique hhid if mi(kid_6_18_m_1)  // 27 pilot 1 HHs are missing this indicator (88 kids) because we do not have child gender info for these HHs
restore	
	
	* Calculate % of children going to school in the HH 
		* this is an indicator we will use for including baseline controls 
		
	preserve 	
	
		foreach round of numlist 0 1 4 {
			* number of school-aged children
			bys hhid round: egen numchild_`round' = total(child_in_schooling_age_hh_`round')
			* number of school-aged children in school
			bys hhid round: egen numchild_inschool_`round' = total(child_inschool_hh_`round')
			* share of school-aged children in school
			gen share_inschool_`round' = numchild_inschool_`round' / numchild_`round'
			lab var share_inschool_`round' "Share of school-aged children enrolled in school (round `round')"
		}
		
		keep hhid share_inschool_*
		duplicates drop 
		drop if mi(share_inschool_1) & mi(share_inschool_4)
		gen round = 0 
		gen n = 1 
	
		tempfile child_share
		save `child_share'
		
	restore 
	
	bys hhid: gen n = _n
	
	merge 1:1 hhid n using "`child_share'", keepusing(share_inschool_*) nogen
		
	* Rename to facilitate analysis 
	rename child_inschool_hh_1 child_inschool_hh 
	lab var child_inschool_hh	 "School Enrollment"  
	
	* Clean extra variables 
		* Main reason not enrolled 
	rename b15b_1 b15b
	rename b15b_4 b15b__4
	tab b15b, gen(b15b_)
	
	foreach var in b15b_1 b15b_2 b15b_3 b15b_4 b15b_5 b15b_6 b15b_7 b15b_8 b15b_9 b15b_10 b15b_11 {
	    rename `var' `var'_1
	}
	
	rename b15b b15b_99
	rename b15b__4 b15b
	tab b15b, gen(b15b_)
	
	foreach var in b15b_1 b15b_2 b15b_3 b15b_4 b15b_5 b15b_6 b15b_7 b15b_8 b15b_9 b15b_10 b15b_11 {
	    rename `var' `var'_4
	}
	
	rename b15b_99 b15b_1
	rename b15b b15b_4

	foreach var in b15b_1 b15b_2 b15b_3 b15b_4 b15b_5 b15b_6 b15b_7 b15b_8 b15b_9 b15b_10 b15b_11 {
	    foreach round in 1 4 {
			local `var'_`round'l: var lab `var'_`round'
			local `var'_`round'l: subinstr local `var'_`round'l "b15b==" "Reason not enrolled: ", all
			lab var `var'_`round' "``var'_`round'l'"
		}
	}
	
		* Exams 
	gen missed_any_exams = .
		replace missed_any_exams = 1 if inlist(x7a_1,2,3)
		replace missed_any_exams = 0 if inlist(x7a_1,0,-100,1)
		replace missed_any_exams = .d if x7a_1 == -97
		
		lab var missed_any_exams "Child missed any exams (if there were any)"

	* Merge endline profile data 
	cap drop PRA_lottery treatment
	merge m:1 hhid using "${phone_svy_profile}", keepus(anyround all_rounds PRA_lottery treatment) keep(3) nogen
		
* Save "long" data with R1 and 4 for panel regression	
preserve 
	drop if round == 0
	keep hhid round childnum *_0
	rename *_0 *

	if	`c(stata_version)'>=14	{
		saveold "${schooling_long_phonesvy}", replace v(13)
	}
	else {
		save "${schooling_long_phonesvy}", replace
	}
restore 	

	keep if round == 0
	drop round *_0
	
* Save
	if	`c(stata_version)'>=14	{
		saveold "${schooling_phonesvy}", replace v(13)
	}
	else {
		save "${schooling_phonesvy}", replace
	}
