/*******************************************************************************	 
 
Project:  		AFG-TUP 
Created on:  	
Last udpate on: 
 
Written by:  	Yulia Belyakova		 	 
 
********************************************************************************	 
 
THIS DO FILE: 	Construction for shocks variables 
 
 
CONTENT:		Part 0 - Constructing and labeling variables
				Part 1 - Preparing annual shocks (since April 2020)
				Part 2 - Preparing monthly shocks (in the past 4 weeks)
				Part 3 - Merging annual and monthly variables in a wide dataset
 
INPUTS: 				Original dataset		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/shocks_roster_phonesvy.dta"
						Profile info			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
						 
OUTPUTS:     	 
				Wide dataset (unique ID is hhid):
												"${TUP_DB}/Phone_Survey/DataSets/Intermediate/shocks_interm_phonesvy.dta" 
				
 
	Issues & Questions: 
				1. Variables with "_12mo" suffix contain information about annual shocks (in the past year, since April 2020).
					This info was collected in R1-3 of the phone survey.
				2. Variables with "_4wk" suffix contain information about shocks in the last 4 weeks from R4.
				
				
	 
 
*******************************************************************************/ 
 

* Inputs
global shocks						"${TUP_DB}/Phone_Survey/DataSets/Intermediate/shocks_roster_phonesvy.dta"
global phone_svy_profile   			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

* Output
global 	shocks_interm				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/shocks_interm_phonesvy.dta"


******************************************************************************** 
** Part 0: Construct and label variables
******************************************************************************** 
 
use "${shocks}", clear 
	merge m:1 hhid using "${phone_svy_profile}", keep(3) keepusing(treatment ultra_poor PRA_lottery call_status_r1 date_r*) nogen

	* Round 1 is annual shocks from R1; Round 2 is annual shocks from R2 (for HHs not survyed in R1);
		* artificial Round 3 is data on shocks between Round 1 and 2 collected in Round 2 from HHs that were already
		* asked about shocks in Round 1.
	replace round = 3 if round == 2 & call_status_r1 == 1 // R3 since date of last survey; R2 is since April 

	* drop partial interviews with missing shocks data 
	drop if g1 == .
	
	* Create a dummy for illness or death of HH member 
	gen illness = (inlist(shock,5) & g1_a == 1) 
		replace illness = g1 if mi(g1)

	gen death = (inlist(shock,6) & g1_a == 1) 
		replace death = g1 if mi(g1)	
		
	rename g1 anyshock
		
	gen lsock_shock = (shock == 2 & g1_a == 1) 
		replace lsock_shock = anyshock if mi(anyshock)
		
	lab var anyshock "Had Any Shock"
	lab var illness "Had Illness of a HH Member Shock"
	lab var death "Had Death of a HH Member Shock"
	lab var lsock_shock "Had Illness or Death of Livestock Shock"
	
	* HH had a shock and recovered 
	gen recover = (g3!=1)	
		replace recover = g3 if mi(g3)
		replace recover = 0 if g3 == . 	
		lab var recover "Somewhat, Mostly or Fully Recovered" 
	
	* Conditional "Not at all recovered"
 	gen recover_cond = (g3!=1)	
		replace recover_cond = g3 if mi(g3)	
		lab var recover_cond "Somewhat, Mostly or Fully Recovered (conditional)" 
	
	* We eliminated the "started begging" option early on in the surveye
	drop g2_8
	
	* To make consistent with the way this is done in Yemen
	forval i = 0/7  {
	    replace g2_`i' = 0 if g2_`i' == .
		replace g2_`i' = .d if g2__99 == 1
		replace g2_`i' = .r if g2__98 == 1
		replace g2_`i' = anyshock if mi(anyshock)
	}
	
	* Now a conditional version
	gen g2_cond__97 = g2__97
		replace g2_cond__97 = . if mi(anyshock) | anyshock == 0
		
	forval i = 0/7  {
		gen g2_cond_`i' = g2_`i'
		replace g2_cond_`i' = .d if g2__99 == 1
		replace g2_cond_`i' = .r if g2__98 == 1
		replace g2_cond_`i' = . if mi(anyshock) | anyshock == 0
	}
	
	* Label coping strategies consistent with Yemen 
		* Had shock and used [...] to finance coping 
	foreach suffix in "" "_cond" {
		lab var g2`suffix'_0 "Nothing"
		lab var g2`suffix'_1 "Decrease of Expenses"
		lab var g2`suffix'_2 "Loans"
		lab var g2`suffix'_3 "Gifts or Support"
		lab var g2`suffix'_4 "Savings"
		lab var g2`suffix'_5 "Sale of Assets"
		lab var g2`suffix'_6 "Increase Adult Workload"
		lab var g2`suffix'_7 "Children Working"
		lab var g2`suffix'__97 "Other"
	}
	
******************************************************************************** 
** Part 1: Preparing annual shocks (since April 2020) 
******************************************************************************** 	
	* Annual shocks (since April 2021 and up until R2, which was in April 2022): round 1 HHs and round 2 HHs that were not surveyed in R1, plus shocks between R1 and R2.
preserve 
	keep if inlist(round,1,2) // 3 excluded 
	
	foreach v of var * {
		local l`v' : variable label `v'
			if `"`l`v''"' == "" {
				local l`v' "`v'"
			}
	}
	
	* These are all dummy variables, so we collapse 
	collapse (max) anyshock illness death lsock_shock recover recover_cond g2_*, by(hhid)
	
	foreach v of var * {
		label var `v' `"`l`v''"'
		rename `v' `v'_12mo
	}
	

	rename hhid_12mo hhid
	
	tempfile annual_shocks
	save `annual_shocks'
restore 	

******************************************************************************** 
** Part 2: Preparing monthly shocks (past 4 weeks) 
******************************************************************************** 

* Keep surveys in R4 (last 4 weeks)
preserve	
	keep if inlist(round,4)

	foreach v of var * {
		local l`v' : variable label `v'
			if `"`l`v''"' == "" {
				local l`v' "`v'"
			}
	}
	
	* These are all dummy variables, so we collapse 
	collapse (max) anyshock illness death lsock_shock recover recover_cond g2_* treatment, by(hhid)
	
	foreach v of var * {
		label var `v' `"`l`v''"'
		rename `v' `v'_4wk
	}
	
	rename hhid_4wk hhid
	
	tempfile pastmonth_shocks
	save `pastmonth_shocks'
restore 

	keep hhid treatment ultra_poor PRA_lottery
	duplicates drop 
	
	
******************************************************************************** 
** Part 3: Merge annual and monthly variables in a wide dataset
******************************************************************************** 	
	merge 1:1 hhid using "`annual_shocks'", nogen
	merge 1:1 hhid using "`pastmonth_shocks'", nogen
	
* Save 	
	save "${shocks_interm}", replace