/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	March 13, 2019
Last udpate on: November 29, 2021

Written by:  	Thomas Escande			

Revision: 		Yulia Belyakova

********************************************************************************	

THIS DO FILE: 	Construct the time spent on each activities and earnings coming from it 


CONTENT:		Part 0 - Preparing data on activities done and total pay from all rounds 
				Part 1 - Preparing inside / outside activity hours from R3
				Part 2 - Creating and cleaning variables per activity
				Part 3 - Creating combinations of various variables
				Part 4 - Summing variables within the household
				Part 5 - Computing Unemployment and labor participation
				Part 6 - Preparing variables to be added in data for analysis dataset which are the variables which will ultimately be used in the analysis
				

INPUTS: 				Original dataset		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
						Profile info			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
						Activities roster 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/timeuse_roster_phonesvy.dta"
						Family member roster	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"

						
OUTPUTS:     	
				Wide datasets (unique ID is hhid):

				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_ses_phonesvy.dta"
				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_up_phonesvy.dta"
				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_hh_phonesvy.dta"

				Long versions of the dataset for panel regressions using all survey rouds (unique ID is round hhid):
				
				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_ses_long_phonesvy.dta"
				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_hh_long_phonesvy.dta"

	Issues & Questions:
	
		1. "Earn" from R4 has not been examined for outliers yet.
		2. Imputing outliers for "earn" is done by replaceing .o with the median by: UP/NUP and HH size (numadult) [1 HHID is missing numadult in R4]. 
			We create bucket 9 "buckets" for numadult: buckets 1-8 for numadult under 9, and one bucket for numadult > 9. This is because there are
				very few HHs with > 9 adults, so we group them in one bucket. This is one way to do it - review and decide.

*******************************************************************************/

********************************************************************************
** Create globals for directories and files 
********************************************************************************

	clear all
	set more off
	set maxvar 20000

	* Input files
		global all_hhlevel_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
		global phone_svy_profile   		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
		global timeuse				    "${TUP_DB}/Phone_Survey/DataSets/Intermediate/timeuse_roster_phonesvy.dta"
		global roster_phonesvy			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"
		global timeuse_hours			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/timeuse_hours_roster_phonesvy.dta"


		* Output files:
		global timeuse_ses_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_ses_phonesvy.dta"
		global timeuse_up_phonesvy 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_up_phonesvy.dta"
		global timeuse_hh_phonesvy 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_hh_phonesvy.dta"
		
		global timeuse_ses_long_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_ses_long_phonesvy.dta"
		global timeuse_hh_long_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_hh_long_phonesvy.dta"

********************************************************************************
** Part 0: Preparing data on activities done and total pay from all rounds 
********************************************************************************

	use "${timeuse}", clear
		
	* Rename so that LHH and PM are 2 members (var_1 is LHH; var_2 is PM)
	rename (k5_1 k5_1_m k30 k30_1 k30_m k30_1_m k30_1_with_outliers k30_1_m_with_outliers) ///
		(k5_1_1 k5_1_2 k30_1 k30_1_1 k30_2 k30_1_2 k30_1_with_outliers_1 k30_1_with_outliers_2)
		

	* Reshape (super) long so that LHH and PM are 2 members (ID = hhid activity round member)
	reshape long k5_1_ k30_ k30_1_ k30_1_with_outliers_, i(hhid activity round) j(member)
	rename *_ *
	
	lab var k5_1 "Did [you/PM] try to find work outside the home in the past 2 weeks?"
	lab var k30_1_with_outliers "How much did [you/PM] earn in the last 4 weeks? (with outliers)"
		
	* Drop .r/.n in activity when it is not selected 
	drop if mi(activity) & (k30 == 0 | k30 == .) 
			
	*Reshaping to have one variable per member  
		* To do this, need to replace .u with extended missing
		* we added the ".u" in the cleaning stage to identify incorrect missingness, 
		* but here it interferes with the reshape.
		ds, has(type numeric)
		foreach var in `r(varlist)' {
			replace `var' = . if `var' == .u
		}
		
		rename (k30_1 k30_1_with_outliers) (k30_earn k30_earn_with_outliers)
		
preserve 	
	* Reshape wide (var_round)
	keep hhid round activity member k5_1 k30 k30_earn k30_earn_with_outliers earn 
	rename * *_
	rename (hhid_ round_ activity_ member_) (hhid round activity member)
	
	reshape wide k5_1_ k30_ k30_earn_ k30_earn_with_outliers_ earn_ , i(hhid activity member) j(round)

	* We want to have 2 full rounds of data. We collected data on this from a few HHs (full surveys) in R4. Use these data to fill in missingness in R1 and R3 (if any). If we have data for all rounds (1, 3, 4), then we do not use the R4 data.
	foreach round in 1 3 4 { 
		foreach var in k5_1 k30 k30_earn k30_earn_with_outliers {
			gen 	`var'_all_`round' = `var'_`round'
			replace `var'_all_`round' = `var'_4 if mi(`var'_all_`round') & !mi(`var'_4)
		}
	}
		
	keep hhid member activity *all*
	
	* Reshape long back again 
	reshape long k5_1_all_ k30_all_ k30_earn_all_ k30_earn_with_outliers_all_, i(hhid activity member) j(round)

	rename *_ *
	
	lab var k5_1_all "Did [you/PM] try to find work outside the home in the past 2 weeks? (all)"
	lab var k30_earn_all "How much did [you/PM] earn in the last 4 weeks? (all)"
	lab var k30_earn_with_outliers_all "How much did [you/PM] earn in the last 4 weeks? (all, with outliers)"
	
	* Drop obs without any data 
	drop if k5_1_all == .
	
	tempfile r4_all_vars
	save `r4_all_vars'
restore 

	merge 1:1 hhid member activity round using `r4_all_vars', keepusing(*all*) nogen
		
	* For the rehape wide below to work, activity should never be missing 
	replace activity = 99 if activity == .n 
	replace activity = 98 if activity == .r 

	* Save labels 
	levelsof activity, local(levels) 
	local lbe : value label activity
	
	foreach l of local levels {
		local actlab`l' : label `lbe' `l'
		local actlab`l' = substr("`actlab`l''",3,.)
	}
	
	rename (k30 k30_all) (k30_ k30_all_)
	reshape wide k30_ k30_all_, i(hhid member round) j(activity)
	
	forval i = 0/9 {
		lab var k30_`i' "`actlab`i''"
		lab var k30_all_`i' "`actlab`i'' (all)"
	}
	
	lab var k30_98 "Don't know"
	lab var k30_all_98 "Don't know (all)"
	lab var k30_99 "Refuse"
	lab var k30_all_99 "Refuse (all)"
	
*Merging to get ultrapoor id
	merge m:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment PRA_lottery attrition_r1 attrition_r2 attrition_r3 attrition_r4) assert(2 3) keep(3) nogen
	
	* Get HH size to be used later for imputation of "earn" (earnings of other adults in HH in R4)	
	preserve 
		use "${roster_phonesvy}", clear 
			keep hhid round hh_mem numadult
			keep if round == 4
			duplicates drop 
		
		tempfile numadult
		save `numadult'
	restore 

	merge m:1 hhid round using "`numadult'", keepusing(numadult) keep(1 3)
		assert round == 4 if _merge == 3
		drop _merge
		* Remember that 1 ID is missing numadult info in R4
	
	* Merge on PM status (whether HH has a PM or not)
	preserve 
		use "${roster_phonesvy}", clear 
			keep hhid round no_pm
			duplicates drop 
		
		tempfile no_pm
		save `no_pm'
	restore 

	merge m:1 hhid round using "`no_pm'", keep(1 3) nogen
			
	label var member "PM or LHH"
	label define member_l 1 "LHH" 2 "PM"
	label val member member_l
		
	* Create a gender variable = 1 if it is the PM and 2 if it is the LHH
	gen gender = .
		replace gender = 1 if member == 2 // male 
		replace gender = 2 if member == 1 // female 
		label define gender 1 "Male" 2 "Female"
		label val gender gender 
		lab var gender "Gender"
	
********************************************************************************
** Part 1: Preparing inside / outside activity hours from R3
********************************************************************************		
	preserve 	
		use "${timeuse_hours}", clear 
		
		assert round == 3 
		
			* Total hours worked in a week 
			foreach var in k30_out_hrs k30_in_hrs k30_out_m_hrs k30_in_m_hrs {
				local `var'_l : var lab `var'
				bys hhid: egen tot_`var' = total(`var'), missing 
				
				gen `var'_d = (`var' == .d)
				bys hhid: egen `var'_d_tot = max(`var'_d)
				gen `var'_r = (`var' == .r)
				bys hhid: egen `var'_r_tot = max(`var'_r)
								
				replace tot_`var' = .d if `var'_d_tot == 1
				replace tot_`var' = .r if `var'_r_tot == 1
				
				lab var tot_`var' "``var'_l' - Weekly total"
			}
			
			drop *_d_tot *_r_tot
			
			* Include 0s for PWs that did not work
			foreach var in tot_k30_out_hrs tot_k30_in_hrs {
				replace `var' = 0 if `var' == . 
			}
			
			* Include 0s for PMs that did not work
			foreach var in tot_k30_out_m_hrs tot_k30_in_m_hrs {
				replace `var' = 0 if `var' == . & no_pm == 0
			}
			
			keep hhid tot*
			duplicates drop
			isid hhid 
		
			* Reshape long so that LHH and PM are 2 members 
			rename (tot_k30_out_hrs tot_k30_in_hrs) ///
				(tot_k30_out_hrs_1 tot_k30_in_hrs_1)
			rename (tot_k30_out_m_hrs tot_k30_in_m_hrs) ///
				(tot_k30_out_hrs_2 tot_k30_in_hrs_2)
			
			reshape long tot_k30_out_hrs_ tot_k30_in_hrs_, i(hhid) j(member)
			
			rename *_ * 
			
			* Scale hours to 4 weeks as in follow-up
			gen tot_k30_out_hrs_4w = tot_k30_out_hrs * 4  
			gen tot_k30_in_hrs_4w  = tot_k30_in_hrs  * 4 
			
			* Label 
			label var member "PM or LHH"
			label define member_l 1 "LHH" 2 "PM"
			label val member member_l
			
			label var tot_k30_out_hrs 		"Hours worked (w or w/o pay) outside the HH in past 7 days"
			label var tot_k30_in_hrs 		"Hours worked (w or w/o pay) inside the HH in past 7 days"
			label var tot_k30_out_hrs_4w 	"Hours worked (w or w/o pay) outside the HH (4 weeks)"
			label var tot_k30_in_hrs_4w 	"Hours worked (w or w/o pay) inside the HH (4 weeks)"
			
			gen round = 3 
			
			tempfile hours_data
			save `hours_data'
	restore
	
	* Merge on hours data to the rest of R3 time use data 
	merge 1:1 hhid member round using "`hours_data'", assert(1 3) nogen // master only did not perform IN/OUT activities, only None and HH chores 
		
********************************************************************************
** Part 2: Creating and cleaning variables per activity
********************************************************************************

	*Creating locals for each activity
		loc	act0	none
		loc	act1	livestock
		loc	act2	ownFarming
		loc	act3	ownBiz
		loc	act4	oFarm
		loc	act5	maid
		loc	act6	outWork
		loc	act7	salEmp
		loc act8  	oPaidWork
		loc act9 	HHChores

	*Per activities, creating one variable for whether the activity was done, for how long did the person do the activity and how much they earned,
	*over the last 4 weeks. Variables are generated in absolute and conditional on having done the activity (If did not do the activity becomes 0 in first case and missing in second case)
	
	forval	actnum=0/9	{
	    foreach suffix in "" "_all" {
			gen	did_`act`actnum''`suffix'				= .
				replace did_`act`actnum''`suffix' 		= 0 if k30`suffix'_`actnum' == 0
				replace did_`act`actnum''`suffix' 		= 1 if k30`suffix'_`actnum' == 1 
				replace did_`act`actnum''`suffix' 		= .d if k30`suffix'_99 == 1 // 1 HH respondent "DK"
				lab	var	did_`act`actnum''`suffix'		"Did `act`actnum'' in last 4 week `suffix'"
		}
	}


********************************************************************************
** Part 3: Creating combinations of various variables
********************************************************************************
	 foreach suffix in "" "_all" {
	* Total earnings in activities for which people receive a wage: other farming, maid, outside work, salaried employment and other paid work
		clonevar tot_earn_act_pmpw_4w`suffix' = k30_earn`suffix'
		label var tot_earn_act_pmpw_4w`suffix' "Total earnings in last 4 weeks from activities (PM + PW) (`suffix')"

		egen did_labor_nohh`suffix' 		=  rowtotal(did_livestock`suffix' did_ownFarming`suffix' did_ownBiz`suffix' did_oFarm`suffix' did_maid`suffix' did_outWork`suffix' did_salEmp`suffix' did_oPaidWork`suffix'), missing
			replace did_labor_nohh`suffix'	= 1 if did_labor_nohh`suffix' > 0 & !mi(did_labor_nohh`suffix')
		label var did_labor_nohh`suffix' 		"Did any type of paid or revenue generating work in the last 4 weeks (`suffix')"	
		
	*Did any paid work
		egen did_paidwork`suffix' 			=  rowtotal(did_oFarm`suffix' did_maid`suffix' did_outWork`suffix' did_salEmp`suffix' did_oPaidWork`suffix'), missing
			replace  did_paidwork`suffix'  	= 1 if  did_paidwork`suffix'  > 0 & !mi(did_paidwork`suffix')
		label var did_paidwork`suffix' 		"Did any type of paid work in the last 4 weeks (`suffix')"		
	
	*Did any type of self employment : ie livestock, agriculture or business
		egen did_selfemploy`suffix' 		=  rowtotal(did_livestock`suffix' did_ownFarming`suffix' did_ownBiz`suffix'), missing
			replace did_selfemploy`suffix'	= 1 if did_selfemploy`suffix'>0 & !mi(did_selfemploy`suffix')
		label var did_selfemploy`suffix' 	"Did any type of self employment in the last 4 weeks (`suffix')"		
		
	* All Other Work variable 
		egen did_oWork`suffix'				= rowtotal(did_oFarm`suffix' did_maid`suffix' did_outWork`suffix' did_salEmp`suffix' did_oPaidWork`suffix'), missing
			replace did_oWork`suffix'		= 1 if did_oWork`suffix'>0 & !mi(did_oWork`suffix')
		label var did_oWork`suffix' "Did any other work in last 4 weeks (`suffix')" 	
	 }
	 
**************************************************************************************************************************************
** Part 4: Treating outliers at the individual level before we sum: replace the .o with mean by gender, treatment and ultra_poor
**************************************************************************************************************************************
		
		merge m:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor) keep(3) nogen
		
		* Replacing .o, only in the earnings. Impute with the mean (by round, up, treatment, member)
		* Do it by UP/NUP and by gender for PM and PW earnings 
		foreach suffix in "" "_all" {
			egen mean_pmpw_earn`suffix' = mean(tot_earn_act_pmpw_4w`suffix'), by(round  ultra_poor treatment member)
			replace tot_earn_act_pmpw_4w`suffix' = mean_pmpw_earn`suffix' if tot_earn_act_pmpw_4w`suffix' == .o
			lab var mean_pmpw_earn`suffix' "Mean PM / PW pay (by round member UP) (`suffix')"
		}
			
		* Do it by UP/NUP and by HH size (numadult) for all other adults earnings 
			* Remember that 1 HHID is missing numadult in R4 
			* First, create bucket for numadult. Very few HHs with > 9 adults, so group them in one bucket.
	
			gen numadult_cat = 1 if inrange(numadult,1,2)
			replace numadult_cat = 2 if inrange(numadult,3,5)			
			replace numadult_cat = 3 if inrange(numadult,6,8)
			replace numadult_cat = 4 if numadult > 8   			//Including the missings here if needed			
			
		egen mean_oadult_earn = mean(earn), by(round  ultra_poor treatment numadult_cat)		
		replace earn = mean_oadult_earn if earn  == .o
				
	drop numadult_*
	
	* Replace Oth Adult earnings with 0 for HHs in R4 that have no adults other than PM and PW 
	replace earn = 0 if attrition_r4 == 0 & earn == . & round == 4 
	
	* Imputing Don't knows for PM and PW
	
	** Check whether missingness is random between T and C 
	foreach suffix in "" "_all" {
		gen tot_earn_pmpw_4w_miss`suffix' = inlist(tot_earn_act_pmpw_4w`suffix',.d,.n,.r)
			lab var tot_earn_pmpw_4w_miss`suffix' "Missingness in PM+PW earnings (`suffix')"
			bys round: reg tot_earn_pmpw_4w_miss`suffix' treatment if member == 1
			bys round: reg tot_earn_pmpw_4w_miss`suffix' treatment if member == 2
			
			bys treatment member round: sum tot_earn_pmpw_4w_miss`suffix'
			
		** Same check but if we only look at those missing conditional on having done Other Work (paid work)	
		gen tot_earn_pmpw_4w_mioW`suffix' = inlist(tot_earn_act_pmpw_4w`suffix',.d,.n,.r) & did_oWork == 1 
			lab var tot_earn_pmpw_4w_mioW`suffix' "Missingness in PM+PW earnings - conditional on doing other work (`suffix')"
			bys round: reg tot_earn_pmpw_4w_mioW`suffix' treatment if member == 1
			bys round: reg tot_earn_pmpw_4w_mioW`suffix' treatment if member == 2
			
			bys treatment member round: sum tot_earn_pmpw_4w_mioW`suffix'
	
		* Impute PM income when DK and PM did at least one type of market work that would be paid. Take the mean of PM labor income, by treatment and other work group, and impute with that.
		
		* Get the mean by: UP member did_oWork round 
		egen mean_pay`suffix' = mean(tot_earn_act_pmpw_4w`suffix'), by(ultra_poor member did_oWork`suffix' round)
			lab var mean_pay`suffix' "Mean pay by treatment, PM/PW, other work, and round"
			
			bys treatment member did_oWork`suffix' round: tab mean_pay`suffix' // 1 LHH responded "DK" to whether she did Other Work, so this mean is missing 
		
		* Impute for all, regardless of whether they did Other Work
		gen tot_earn_act_pmpw_4w_imp`suffix' = tot_earn_act_pmpw_4w`suffix'
			replace tot_earn_act_pmpw_4w_imp`suffix' = mean_pay`suffix' if inlist(tot_earn_act_pmpw_4w`suffix',.d,.n,.r) // DK's only, not simple missing 
			lab var tot_earn_act_pmpw_4w_imp`suffix' "Imputed PM/PW earnings"
			
		bys member round: sum tot_earn_act_pmpw_4w`suffix' tot_earn_act_pmpw_4w_imp`suffix' if ultra_poor == 1 

		* Create imputation dummy
		gen tot_hh_pay_imp_dum`suffix' = inlist(tot_earn_act_pmpw_4w`suffix',.d,.n,.r)
		lab var tot_hh_pay_imp_dum`suffix' "PM/PW earnings is missing (imputation dummy) (`suffix')"
	}
	

	
********************************************************************************************************************************************
** Part 5: Summing variables within the household (not used that much for now, if used later might need to add winsorized variables instead) 
********************************************************************************************************************************************

**** Without imputation first

* Note there is some missingness for the LHH income when "none" was selected in k30 (k30_0 == 1) in the early verion of the survey 
* later we do not condition that question, but for about ~33 HHs we have tot_earnings_act_4w = . because of that.

	foreach suffix in "" "_all" {
		
		*Earnings from PM+PW from all paying activities
		egen tot_pmpw_pay`suffix' = sum(tot_earn_act_pmpw_4w`suffix'), by(hhid round) missing
			label var tot_pmpw_pay`suffix' "Total earnings in last 4 weeks from activities (PM+PW) (`suffix')"
			
		*Earnings from all HH members from all paying activities	
		egen tot_hh_pay`suffix' = rsum(tot_pmpw_pay`suffix' earn), missing
		label var tot_hh_pay`suffix' "HH Paid Labor, (4 weeks) (`suffix')"
		
	** Now with imputation 	
		*Earnings from PM+PW from all paying activities
		egen tot_pmpw_pay_imp`suffix' = sum(tot_earn_act_pmpw_4w_imp`suffix'), by(hhid round) missing
			label var tot_pmpw_pay_imp`suffix' "Total earnings in last 4 weeks from activities (PM+PW) - Imputed (`suffix')"
			
		*Earnings from all HH members from all paying activities
		egen tot_hh_pay_imp`suffix' = rsum(tot_pmpw_pay_imp`suffix' earn), missing
		label var tot_hh_pay_imp`suffix' "HH Paid Labor, (4 weeks) - Imputed(`suffix')"
		
		*R4, sum up only for Extra HHs!	
		replace tot_hh_pay_imp`suffix' = . if incomplete_hh == 0 & round == 4 
	}
	
	
	
	
	
********************************************************************************
** Part 6: Computing Unemployment and labor participation
********************************************************************************

	*Employment
	foreach suffix in "" "_all" {
		egen employment`suffix' = rowtotal(k30`suffix'_1 k30`suffix'_2 k30`suffix'_3 k30`suffix'_4 k30`suffix'_5 k30`suffix'_6 k30`suffix'_7 k30`suffix'_8), missing
			replace employment`suffix'	= 1 if employment`suffix'>0 & !mi(employment`suffix')
			label var employment`suffix' "Paid employment or self employment (`suffix')"
	
	*Labor participation: of Working age and working or have been looking for a job in the past 2 weeks (assume LHH and PM are of working age)
		egen labor_particip`suffix' = rowtotal(employment`suffix' k5_1`suffix'), missing
			replace labor_particip`suffix' = 1 if labor_particip`suffix'>0 & !mi(labor_particip`suffix')
			label var labor_particip`suffix' "Labor participation: working or looking for a job (`suffix')"

	*Unemployment (of working age, looking for a job and not working in paid activity) / Underemployment (Work less than 15 days a month, 8 hours a day and is looking for a job)
		egen unemployment`suffix' = rowtotal(k30`suffix'_1 k30`suffix'_2 k30`suffix'_3 k30`suffix'_4 k30`suffix'_5 k30`suffix'_6 k30`suffix'_7 k30`suffix'_8), missing
			replace unemployment`suffix' = 99 if unemployment`suffix' == 0
			replace unemployment`suffix' = 0 if unemployment`suffix'>0 & !mi(unemployment`suffix')
			replace unemployment`suffix' = 1 if k5_1`suffix' == 1 & (k30`suffix'_0 == 1 | unemployment`suffix' == 99)
			label var unemployment`suffix' "Unemployed: doing no activity at all or focusing only on household chores"			
			
	}
	
*Saving the long dataset with ultra poor and non ultra poor	

		if	`c(stata_version)'>=14	{
			saveold "${timeuse_ses_long_phonesvy}", replace v(13)
		}
		else {
			save "${timeuse_ses_long_phonesvy}", replace
		}
			
* Reshape wide 
preserve

	unab varlist: k30_0 - unemployment_all
	
	foreach var in `varlist' {
		local l`var' : variable label `var'
	}	
			
	rename * *_
	rename (hhid_ round_ member_ ultra_poor_ treatment_ attrition_r1_ attrition_r2_ attrition_r3_ attrition_r4_ gender_ PRA_lottery_) (hhid round member ultra_poor treatment attrition_r1 attrition_r2 attrition_r3 attrition_r4 gender PRA_lottery)
	order hhid round member ultra_poor treatment attrition_r1 attrition_r2 attrition_r3 attrition_r4 gender PRA_lottery, first
	
	reshape wide k30_0_ - unemployment_all_, i(hhid member) j(round)
	
	foreach var in k30_0 k30_all_0 k30_1 k30_all_1 k30_2 k30_all_2 k30_3 k30_all_3 k30_4 k30_all_4 k30_5 k30_all_5 k30_6 k30_all_6 k30_7 k30_all_7 k30_8 k30_all_8 k30_9 k30_all_9 k30_98 k30_all_98 k30_99 k30_all_99 k5_1 incomplete_hh earn k30_earn k30_earn_with_outliers k5_1_all k30_earn_all k30_earn_with_outliers_all numadult no_pm tot_k30_out_hrs tot_k30_in_hrs tot_k30_out_hrs_4w tot_k30_in_hrs_4w did_none did_none_all did_livestock did_livestock_all did_ownFarming did_ownFarming_all did_ownBiz did_ownBiz_all did_oFarm did_oFarm_all did_maid did_maid_all did_outWork did_outWork_all did_salEmp did_salEmp_all did_oPaidWork did_oPaidWork_all did_HHChores did_HHChores_all tot_earn_act_pmpw_4w did_labor_nohh did_paidwork did_selfemploy did_oWork tot_earn_act_pmpw_4w_all did_labor_nohh_all did_paidwork_all did_selfemploy_all did_oWork_all tot_earn_pmpw_4w_miss tot_earn_pmpw_4w_mioW mean_pay tot_earn_act_pmpw_4w_imp tot_hh_pay_imp_dum tot_earn_pmpw_4w_miss_all tot_earn_pmpw_4w_mioW_all mean_pay_all tot_earn_act_pmpw_4w_imp_all tot_hh_pay_imp_dum_all tot_hh_pay tot_hh_pay_imp tot_hh_pay_all tot_hh_pay_imp_all employment labor_particip unemployment employment_all labor_particip_all unemployment_all tot_earn_act_pmpw_4w tot_earn_act_pmpw_4w_all tot_earn_act_pmpw_4w_imp tot_earn_act_pmpw_4w_imp_all {
		label var `var'_1 "`l`var'' (round 1)"
		label var `var'_3 "`l`var'' (round 3)"
		label var `var'_4 "`l`var'' (round 4)"
	}	
	
	missings dropvars, force 

*Saving the wide dataset with ultra poor and non ultra poor	
	
		if	`c(stata_version)'>=14	{
			saveold "${timeuse_ses_phonesvy}", replace v(13)
		}
		else {
			save "${timeuse_ses_phonesvy}", replace
		}
restore				
				
			
preserve 

	keep if ultra_poor == 1
	
	unab varlist: k30_0 - unemployment_all
	
	foreach var in `varlist' {
		local l`var' : variable label `var'
	}	
			
	rename * *_
	rename (hhid_ round_ member_ ultra_poor_ treatment_ attrition_r1_ attrition_r2_ attrition_r3_ attrition_r4_ gender_ PRA_lottery_) (hhid round member ultra_poor treatment attrition_r1 attrition_r2 attrition_r3 attrition_r4 gender PRA_lottery)
	order hhid round member ultra_poor treatment attrition_r1 attrition_r2 attrition_r3 attrition_r4 gender PRA_lottery, first
	
	reshape wide k30_0_ - unemployment_all_, i(hhid member) j(round)
	
	foreach var in k30_0 k30_all_0 k30_1 k30_all_1 k30_2 k30_all_2 k30_3 k30_all_3 k30_4 k30_all_4 k30_5 k30_all_5 k30_6 k30_all_6 k30_7 k30_all_7 k30_8 k30_all_8 k30_9 k30_all_9 k30_98 k30_all_98 k30_99 k30_all_99 k5_1 incomplete_hh earn k30_earn k30_earn_with_outliers k5_1_all k30_earn_all k30_earn_with_outliers_all numadult no_pm tot_k30_out_hrs tot_k30_in_hrs tot_k30_out_hrs_4w tot_k30_in_hrs_4w did_none did_none_all did_livestock did_livestock_all did_ownFarming did_ownFarming_all did_ownBiz did_ownBiz_all did_oFarm did_oFarm_all did_maid did_maid_all did_outWork did_outWork_all did_salEmp did_salEmp_all did_oPaidWork did_oPaidWork_all did_HHChores did_HHChores_all tot_earn_act_pmpw_4w did_labor_nohh did_paidwork did_selfemploy did_oWork tot_earn_act_pmpw_4w_all did_labor_nohh_all did_paidwork_all did_selfemploy_all did_oWork_all tot_earn_pmpw_4w_miss tot_earn_pmpw_4w_mioW mean_pay tot_earn_act_pmpw_4w_imp tot_hh_pay_imp_dum tot_earn_pmpw_4w_miss_all tot_earn_pmpw_4w_mioW_all mean_pay_all tot_earn_act_pmpw_4w_imp_all tot_hh_pay_imp_dum_all tot_hh_pay tot_hh_pay_imp tot_hh_pay_all tot_hh_pay_imp_all employment labor_particip unemployment employment_all labor_particip_all unemployment_all tot_earn_act_pmpw_4w tot_earn_act_pmpw_4w_all tot_earn_act_pmpw_4w_imp tot_earn_act_pmpw_4w_imp_all {
		label var `var'_1 "`l`var'' (round 1)"
		label var `var'_3 "`l`var'' (round 3)"
		label var `var'_4 "`l`var'' (round 4)"
	}	
	
	missings dropvars, force 

*Saving the wide dataset with ultra poor only
			if	`c(stata_version)'>=14	{
				saveold "${timeuse_up_phonesvy}", replace v(13)
			}
			else {
				save "${timeuse_up_phonesvy}", replace
			}	
restore


********************************************************************************
** Part 7: Preparing variables to be added in data for analysis dataset which are the variables which will ultimately be used in the analysis
********************************************************************************	
* Generate variables for female, male and all household as needed for merge

	* Primary female
	preserve
		keep if member == 1 
		isid hhid round 
		keep hhid round treatment attrition* did_* tot_earn_* employment* labor_particip* unemployment* k5_1 k5_1_all tot_k30_out_hrs - tot_k30_in_hrs_4w ///
			incomplete_hh earn k30_earn* k30_earn_with_outliers* tot_hh_pay* tot_hh_pay_imp* tot_hh_pay_imp_dum*  tot_pmpw_pay*
		
		rename * *_pf
				
		foreach var in hhid round treatment incomplete_hh earn k30_earn k30_earn_all k30_earn_with_outliers k30_earn_with_outliers_all tot_hh_pay tot_hh_pay_all tot_hh_pay_imp tot_hh_pay_imp_all tot_hh_pay_imp_dum tot_hh_pay_imp_dum_all tot_pmpw_pay tot_pmpw_pay_imp tot_pmpw_pay_all tot_pmpw_pay_imp_all attrition_r1 attrition_r2 attrition_r3 attrition_r4 {
			rename `var'_pf `var'
		}
		
		* Share of women receiving any income 
		foreach suffix in "" "_all" {
			gen any_income`suffix'_pf = (tot_earn_act_pmpw_4w_imp`suffix'_pf > 0 & !mi(tot_earn_act_pmpw_4w_imp`suffix'_pf))
			lab var any_income`suffix'_pf "PW received any income, imputed (`suffix')"
			tab any_income`suffix'_pf treatment, col
			
			lab var tot_earn_act_pmpw_4w`suffix'_pf "Paid Labor Income - PW (`suffix')"
			lab var tot_earn_act_pmpw_4w_imp`suffix'_pf "Paid Labor Income - PW, Imputed (`suffix')"
			rename (tot_earn_act_pmpw_4w`suffix'_pf tot_earn_act_pmpw_4w_imp`suffix'_pf) (tot_pf_pay`suffix' tot_pf_pay_imp`suffix')
		}
		
		tempfile time_pf
		save	`time_pf'
	restore
	
	* Primary male
		keep if member == 2
		isid hhid round
		keep hhid round treatment did_* tot_earn_* employment* labor_particip* unemployment* k5_1 k5_1_all tot_k30_out_hrs - tot_k30_in_hrs_4w
		
		* Var name too long 	
		rename * *_pm
		rename (hhid_pm round_pm treatment_pm) (hhid round treatment)
		
		* Share of men receiving any income 
		foreach suffix in "" "_all" {
			gen any_income`suffix'_pm = (tot_earn_act_pmpw_4w_imp`suffix'_pm > 0 & !mi(tot_earn_act_pmpw_4w_imp`suffix'_pm))
			lab var any_income`suffix'_pm "PM received any income, imputed (`suffix')"
			tab any_income`suffix'_pm treatment, col
			
			lab var tot_earn_act_pmpw_4w`suffix'_pm "Paid Labor Income - PM"
			lab var tot_earn_act_pmpw_4w_imp`suffix'_pm "Paid Labor Income - PM, Imputed"
			rename (tot_earn_act_pmpw_4w`suffix'_pm tot_earn_act_pmpw_4w_imp`suffix'_pm) (tot_pm_pay`suffix' tot_pm_pay_imp`suffix')
		}
		
		tempfile time_pm
		save	`time_pm'
		
	* Merge
		use `time_pf', clear
		merge 1:1 hhid round using `time_pm', keep(1 3) nogen
		
	* Order 
		order tot_k30_out_hrs_pf - tot_k30_in_hrs_4w_pf, after(labor_particip_pf)
		order tot_k30_out_hrs_pm - tot_k30_in_hrs_4w_pm, after(labor_particip_pm)
		
	* Sort
		sort hhid round 
		
		* Panel variables (R1, R4) are: k5_1 k30 k30_1 earn 
		* earn is a panel in R4 
	preserve 
	
		keep hhid round earn k5_1* k5_1_all* k30_earn* k30_earn_with_outliers* did_* tot_* employment_* labor_particip_* any_income_* attrition*

*Saving the long dataset with UP PM/PF	
		if	`c(stata_version)'>=14	{
			saveold "${timeuse_hh_long_phonesvy}", replace v(13)
		}
		else {
			save "${timeuse_hh_long_phonesvy}", replace
		}
	
	restore
	
	
	* Reshape wide 
	unab varlist: k5_1_pf - any_income_all_pm
	
	foreach var in `varlist' {
		local l`var' : variable label `var'
	}	
			
	rename * *_
	rename (hhid_ round_ attrition_r1_ attrition_r2_ attrition_r3_ attrition_r4_ treatment_) ///
		(hhid round attrition_r1 attrition_r2 attrition_r3 attrition_r4 treatment)
	order hhid round attrition_r1 attrition_r2 attrition_r3 attrition_r4 treatment, first 
	
	reshape wide k5_1_pf_ - any_income_all_pm_, i(hhid) j(round)
	 
	foreach v in earn k30_earn k30_earn_with_outliers k30_earn_all k30_earn_with_outliers_all tot_k30_out_hrs_4w_pf tot_k30_in_hrs_4w_pf did_none_pf did_none_all_pf did_livestock_pf did_livestock_all_pf did_ownFarming_pf did_ownFarming_all_pf did_ownBiz_pf did_ownBiz_all_pf did_oFarm_pf did_oFarm_all_pf did_maid_pf did_maid_all_pf did_outWork_pf did_outWork_all_pf did_salEmp_pf did_salEmp_all_pf did_oPaidWork_pf did_oPaidWork_all_pf did_HHChores_pf did_HHChores_all_pf tot_pf_pay did_labor_nohh_pf did_paidwork_pf did_selfemploy_pf did_oWork_pf tot_pf_pay_all did_labor_nohh_all_pf did_paidwork_all_pf did_selfemploy_all_pf did_oWork_all_pf tot_hh_pay_imp_dum tot_hh_pay_imp_dum_all tot_hh_pay tot_pf_pay_imp tot_hh_pay_imp tot_hh_pay_all tot_pf_pay_imp_all tot_hh_pay_imp_all employment_pf labor_particip_pf tot_k30_out_hrs_pf tot_k30_in_hrs_pf unemployment_pf employment_all_pf labor_particip_all_pf unemployment_all_pf any_income_pf any_income_all_pf tot_k30_out_hrs_4w_pm tot_k30_in_hrs_4w_pm did_none_pm did_none_all_pm did_livestock_pm did_livestock_all_pm did_ownFarming_pm did_ownFarming_all_pm did_ownBiz_pm did_ownBiz_all_pm did_oFarm_pm did_oFarm_all_pm did_maid_pm did_maid_all_pm did_outWork_pm did_outWork_all_pm did_salEmp_pm did_salEmp_all_pm did_oPaidWork_pm did_oPaidWork_all_pm did_HHChores_pm did_HHChores_all_pm tot_pm_pay did_labor_nohh_pm did_paidwork_pm did_selfemploy_pm did_oWork_pm tot_pm_pay_all did_labor_nohh_all_pm did_paidwork_all_pm did_selfemploy_all_pm did_oWork_all_pm tot_pm_pay_imp tot_pm_pay_imp_all employment_pm labor_particip_pm tot_k30_out_hrs_pm tot_k30_in_hrs_pm unemployment_pm employment_all_pm labor_particip_all_pm unemployment_all_pm any_income_pm any_income_all_pm k5_1_pf k5_1_all_pf k5_1_pm k5_1_all_pm tot_pmpw_pay tot_pmpw_pay_imp tot_pmpw_pay_all tot_pmpw_pay_imp_all {
		lab var `v'_1 "`l`v'' (round 1)"
		lab var `v'_3 "`l`v'' (round 3)"
		lab var `v'_4 "`l`v'' (round 4)"
	}
	
	missings dropvars, force 
	
	rename incomplete_hh_4 incomplete_hh
	
*Saving the wide dataset with UP PM/PF	
		if	`c(stata_version)'>=14	{
			saveold "${timeuse_hh_phonesvy}", replace v(13)
		}
		else {
			save "${timeuse_hh_phonesvy}", replace
		}
	
*********************************End of dofile***********************************************************************

