/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	March 9, 2019
Last udpate on: June 18, 2019

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Construct the wealth index based on asset ownership using Principal Component Analysis (PCA)


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Basic cleaning and preparation of the dataset
				Part 2 - Creating Index for the whole sample
				Part 3 - Creating Index for the ultra poor sample only


				INPUTS:     "${TUP_DB}/Followup_1/DataSets/Intermediate/other_assets_fl1.dta"
							"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
							"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"

						
OUTPUTS:     		 		"${TUP_DB}/Followup_1/DataSets/Intermediate/asset_index_ses_fl1.dta"
							"${TUP_DB}/Followup_1/DataSets/Intermediate/asset_index_up_fl1.dta"
Note: 			

*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off
set maxvar 20000

	* Input files
		global assets_data 	"${TUP_DB}/Followup_1/DataSets/Intermediate/l_hhassets_fl1.dta"
		global inputdata 	"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
		global sample_indicators_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta"
		global phone_svy_profile   	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

	* Output files
		global asset_index_ses_phonesvy  "${TUP_DB}/Followup_1_Phone/DataSets/Intermediate/asset_index_ses_fl1.dta"
		global asset_index_up_phonesvy   "${TUP_DB}/Followup_1_Phone/DataSets/Intermediate/asset_index_up_fl1.dta"
		
	* Controls globals 
		global controls i.PRA_lottery 
		global panel_controls i.PRA_lottery ib(4).round 		
		
		
********************************************************************************
	** Part 1: Basic cleaning and preparation of the dataset
********************************************************************************
	
	use "${assets_data}", clear
	
		drop l4
		drop if asset == - 99 | asset == -98 /*No one used any of these options*/
		keep if l1 == 1 //Only keeping families which owns at least one of the asset to facilitate later analysis
		
	* Rename suffix for each item
		rename l1 l1_ 
		rename l2 l2_ 
		rename l3 l3_ 
		rename l5 l5_ 
	
	*Reshape to get one variable per asset
		reshape wide l1_ l2_ l3_ l5_, i(hhid) j(asset)
	
	* Keep the phone survey sample 
		merge m:1 hhid using "${phone_svy_profile}", keepus(anyround attrition_r* all_rounds treatment PRA_lottery) keep(3) nogen
		
	* Keep the relevant phone survey sample (based on regression)
	
	* Merge on endline sample indicators 
		merge 1:1 hhid using "${sample_indicators_phonesvy}", assert(1 3) nogen keepusing(wealth_score_sdC_s)
			rename wealth_score_sdC_s sample 
	
	*Merging to get ultrapoor id and ownership of dwelling 
		merge 1:1 hhid using "${inputdata}", nogen keepusing(survey e1 a5) keep(3)

	*Ultra Poor as a dummy to be used for the standardization
		gen 	ultra_poor = survey
		replace ultra_poor = 0 if survey == 3

	*Creating local per type of asset
		loc	asset1	radio_CD
		loc	asset2	TV
		loc	asset3	DishTV
		loc	asset4	VCR_DVD
		loc	asset5	house_Land
		loc	asset6	nonHouse_Land
		loc	asset7	othHouse
		loc	asset8	fridge
		loc	asset9	generator
		loc	asset10	matress
		loc	asset11	mobile_phone
		loc	asset12	non_mobilephone
		loc	asset13	iron
		loc	asset14	bedframe
		loc	asset15	jewelry
		loc	asset16	mosquitonet
		loc	asset17	mosq_repel_candle
		loc	asset18	fan
		loc	asset19	camera
		loc	asset20	other
	
	*Creating dummy for ownership and a variable for the number owned of each asset
	forval	assetnum=1/20	{
		gen	own_`asset`assetnum''		= 0
		replace own_`asset`assetnum'' 	= 1 if l1_`assetnum' == 1 
		lab	var	own_`asset`assetnum''	"Household owns any `asset`assetnum''"

		gen num_`asset`assetnum'' 		= 0
		replace num_`asset`assetnum''   = l1_`assetnum' * l2_`assetnum' if !mi(l1_`assetnum')
		lab	var	num_`asset`assetnum''	"Number of `asset`assetnum'' owned by the household"
	}

	*Checking whether there can be issues when multiplying l1*l2 with one missing and not the other. Only issues are lands for which we don't ask
	forval	assetnum=1/20	{
		di "`asset`assetnum''"
		count if mi(l1_`assetnum') & !mi(l2_`assetnum')
		count if !mi(l1_`assetnum') & mi(l2_`assetnum')
	}

		replace num_house_Land 		= l1_5 * l3_5
		replace num_nonHouse_Land 	= l1_6 * l3_6 
		lab	var	num_house_Land		"Size of land on which the dwelling is"
		lab	var	num_nonHouse_Land	"Size of land owned by household, excluding land on which the house is"

	*Imputing the missing for the value of the land: Impute per ultrapoor and a5 
	*Impute 64 out of 206 (31%) for other land, 270 out of 1097 (25%) for house land and 3 out of 7 (43%) for other houses
		egen ud = concat(a5 ultra_poor)
		bys ud: egen median_ud_5 = median(l5_5) 	
		bys ud: egen median_ud_6 = median(l5_6) 
		egen median_ud_6_tot = median(l5_6)  /*If it is missing because blocks are too small compare to the number of observations available */ 	
		bys ud: egen median_ud_7 = median(l5_7) 
		egen median_ud_7_tot = median(l5_7) 	


	*land and other household (7 observations have other household) value
		gen value_house_land 	= 0
		gen value_nonhouse_land = 0
		gen value_otherhouse    = 0

		replace value_house_land 	= l5_5 if l1_5 == 1
		replace value_house_land 	=  median_ud_5 if l1_5 == 1 & mi(l5_5)
		replace value_nonhouse_land = l5_6 if l1_6 == 1
		replace value_nonhouse_land =  median_ud_6 if l1_6 == 1 & mi(l5_6)
		replace value_nonhouse_land = median_ud_6_tot if l1_6 == 1 & mi(l5_6) & mi(median_ud_6)
		replace value_otherhouse 	= l5_7 if l1_7 == 1
		replace value_otherhouse 	=  median_ud_7 if l1_7 == 1 & mi(l5_7)
		replace value_otherhouse = median_ud_7_tot if l1_7 == 1 & mi(l5_7) & mi(median_ud_7)

		gen total_value_houseland = value_otherhouse + value_nonhouse_land + value_house_land

		label var value_house_land 		"Self reported value of the land on which the dwelling is"
		label var value_nonhouse_land 	"Self reported value of other land owned by hh"
		label var value_otherhouse 		"Self reported value of other houses owned by hh"
		label var total_value_houseland "Total self reported value of land and other houses owned by hh"

	*Creating variable for Household ownership e1 
		gen own_dwelling = 0 
		replace own_dwelling = 1 	if e1 == 1 | e1 == 2 
		replace own_dwelling = .d 	if e1 == .d
		
		label var own_dwelling "HH owns the dwelling in which they live"
		
		
	*For others, coded as owning it if it is coming from a legacy but not yet processed or shared, as they will get them ultimately
		replace own_dwelling = 1 if hhid == 1045| hhid ==1054| hhid ==1060| hhid ==1196| hhid ==2119| hhid ==5877| hhid ==6014| hhid ==6420| hhid ==6448| hhid ==6499| hhid ==6537 | hhid ==6602
		
		
********************************************************************************
	** Part 2: Creating Index for the whole sample
********************************************************************************
	
	*Putting in locals all the assets used in the construction of the index
		loc	assets	num_radio_CD  num_TV  num_DishTV  num_VCR_DVD  num_fridge  num_generator  num_matress  num_mobile_phone  num_non_mobilephone ///
				num_iron  num_bedframe  num_jewelry  num_mosquitonet  num_mosq_repel_candle  num_fan  num_camera ///
 			/*num_other: Exclude for now, as they are extra assets but not sure that the ones who did not mention them actually don't have them or just did
 			not mention them */
			
		loc property own_dwelling own_house_Land own_nonHouse_Land own_othHouse 

	*Standardizing the asset index to the control group to have similar type of index to present  
		gen control = (treatment == 0)	
		
	* Create indices for the full follow-up sample first 
	*Generates the wealth index "wealthscore" based on asset ownership
		pca `assets', mineigen(1) means 
			predict wealth_score_full, score 
			lab var wealth_score_full "Asset-based wealth index from PCA (hh assets excluding land/property) - Whole sample" 

	*Standardizing 
		egen wealth_score_sdC_full = weightave(wealth_score_full), normby(control) 
		local lab_wealth_score_sdC_full : variable label wealth_score_full
		label var wealth_score_sdC_full "Standardized `lab_wealth_score_full'" 		
			
	*Generates the property index separately, as specified in PAP		
		pca `property', mineigen(1) means 
			predict property_score_full, score 
			lab var property_score_full "Property-based index (PCA), owning dwelling and land - Whole sample"
	
	* Create indices for the phone survey sample 
	preserve 
		drop *score* *sdC*
		keep if sample == 1 	
	
		assert (anyround == 1 | mi(anyround)) 
	
	*Generates the wealth index "wealthscore" based on asset ownership
		pca `assets', mineigen(1) means 
			predict wealth_score, score 
			lab var wealth_score "Asset-based wealth index (PCA) (hh assets excluding land/property) - Whole sample" 
		
	*Standardizing 
		egen wealth_score_sdC = weightave(wealth_score), normby(control) 
		local lab_wealth_score_sdC : variable label wealth_score
		label var wealth_score_sdC "Standardized `lab_wealth_score'" 		
			
	*Generates the property index separately, as specified in PAP	
		pca `property', mineigen(1) means 	
			predict property_score, score 
			lab var property_score "Property-based index (PCA), owning dwelling and land  - Whole sample" 

			keep hhid wealth_score wealth_score_sdC property_score
		
		tempfile wealth_phone_ses
		save `wealth_phone_ses'
	
	restore 
	
	merge 1:1 hhid using "`wealth_phone_ses'", assert(1 3) nogen
			
	*Saving dataset with wealth index for whole sample	
		if	`c(stata_version)'>=14	{
			saveold "${asset_index_ses_phonesvy}", replace v(13)
		}
		else {
			save "${asset_index_ses_phonesvy}", replace
		}	

			
********************************************************************************
	** Part 3: Creating Index for the ultra poor sample only
********************************************************************************

	* First for the full sample 
		drop *score* *sdC*
		
	*Keep only ultra poor
		keep if ultra_poor == 1

	*Generates the wealth index "wealthscore" based on asset ownership
		pca `assets', mineigen(1) means 
			predict wealth_score_full, score 
			lab var wealth_score_full "Asset-based wealth index from PCA (hh assets excluding land/property)" 

	*Standardizing 
		egen wealth_score_sdC_full = weightave(wealth_score_full), normby(control) 
		local lab_wealth_score_sdC_full : variable label wealth_score_full
		label var wealth_score_sdC_full "Standardized `lab_wealth_score_full'" 		
			
	*Generates the property index separately, as specified in PAP		
		pca `property', mineigen(1) means 
			predict property_score_full, score 
			lab var property_score_full "Property-based index (PCA), owning dwelling and land"
		
	* Phone survey sample 
	preserve 
		drop *score* *sdC*
		keep if sample == 1 	
	
		assert (anyround == 1 | mi(anyround)) 
	
	*Generates the wealth index "wealthscore" based on asset ownership
		pca `assets', mineigen(1) means 
			predict wealth_score, score 
			lab var wealth_score "Asset-based wealth index from PCA (hh assets excluding land/property)" 

	*Standardizing 
		egen wealth_score_sdC = weightave(wealth_score), normby(control) 
		local lab_wealth_score_sdC : variable label wealth_score
		label var wealth_score_sdC "Standardized `lab_wealth_score'" 		
			
	*Generates the property index separately, as specified in PAP		
		pca `property', mineigen(1) means 
			predict property_score, score 
			lab var property_score "Property-based index (PCA), owning dwelling and land"
		
		keep hhid wealth_score wealth_score_sdC property_score
		
		tempfile wealth_phone
		save `wealth_phone'
	
	restore 
	
	merge 1:1 hhid using "`wealth_phone'", assert(1 3) nogen
		
	* Subsample of HHs surveyed in all rounds 		
	preserve 
		drop *score* *sdC*
		keep if all_rounds == 1 
		
	*Generates the wealth index "wealthscore" based on asset ownership
		pca `assets', mineigen(1) means 
			predict wealth_score_all, score 
			lab var wealth_score_all "Asset-based wealth index from PCA (hh assets excluding land/property) (all rounds)" 

	*Standardizing 
		egen wealth_score_sdC_all = weightave(wealth_score_all), normby(control) 
		local lab_wealth_score_sdC_all : variable label wealth_score_all
		label var wealth_score_sdC_all "Standardized `lab_wealth_score' (all rounds)"
 		
		keep hhid *_all
		
		tempfile index_all
		save `index_all'
	restore 
			
	merge 1:1 hhid using "`index_all'", assert(1 3) nogen

	*Saving dataset with wealth index for ultra poor only	
				if	`c(stata_version)'>=14	{
				saveold "${asset_index_up_phonesvy}", replace v(13)
			}
			else {
				save "${asset_index_up_phonesvy}", replace
			}	
*********************************End of dofile***********************************************************************
