/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Nov 27, 2018
Last udpate on: Dec 20, 2018

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates the list of household to be verified:
				1.  Treatment households where it was reported that the beneficiary
					was not part of the HH or they didn't know him/her. 
				2.  Households with discrepancies in other things (ages, household
					head not part of the household, not baseline survey, etc)

CONTENT:		Part 0: Create globals for inputs and outputs
				Part 1: Get list of treatment households with inconsistencies
				Part 2: Get list of households with other inconsistencies
				
INPUTS:  		* all_HH_dataset_pii: Follow-up survey dataset merged and appended
					"${TUP_DB_PII}/Followup_1/DataSets/Final/all_HH_dataset_pii.dta"
				
				* fl1_sample: Follow-up sample
					"${DB_PII_Profile}/DataSets/Intermediate/Followup_Sample.dta"	
				
				* master_data: Data with all the ids
					"${TUP_DB_PII}/Profile_and_merging/DataSets/Final/master_data_with_all_ids.dta"
				
				* HH_verification: Verification exercise done by Mohammad during baseline		
					"/Volumes/Camila/Dropbox/World Bank/TUP/TUP_Afghanistan/Data Collection/Follow-up/Recipient/All_survey_verification_with all comments_June16.xlsx"
				
				* bl_prep: Baseline survey dataset
					"/Volumes/Camila/Dropbox/World Bank/TUP/TUP_Afghanistan/Data Analysis/TUP Baseline/Data/Final/Compiled/bl_analysis_prep.dta"

				* confirmation_excel_MISFA: Additional information sent by MISFA (Matin) after sending list of treatment household with inconsistencies
					"${DB_PII_Profile}/Output/Final/confirmation_recipient_name_11Dec2018_MISFA.xlsx"
   	
OUTPUTS:     	* confirmation_excel: Treatment household list to verify send to MISGA (Matin) 	
					"${DB_PII_Profile}/Output/Final/confirmation_recipient_name.xlsx"
				
				* HHs_to_verify: List of households to verify send to Mohammad
					"${DB_PII_Profile}/Output/Final/household_verification_20Dec2018.xlsx"

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for inputs and outputs
********************************************************************************

* Inputs
	global DB_PII_Profile 			"${TUP_DB_PII}/Profile_and_merging"
	
	global all_HH_dataset_pii 		"${TUP_DB_PII}/Followup_1/DataSets/Final/all_HH_dataset_pii.dta"
	global fl1_sample 				"${DB_PII_Profile}/DataSets/Intermediate/Followup_Sample.dta"	
	global master_data 				"${TUP_DB_PII}/Profile_and_merging/DataSets/Final/master_data_with_all_ids.dta"
	global HH_verification 			"/Volumes/Camila/Dropbox/World Bank/TUP/TUP_Afghanistan/Data Collection/Follow-up/Recipient/All_survey_verification_with all comments_June16.xlsx"
	global bl_prep 					"/Volumes/Camila/Dropbox/World Bank/TUP/TUP_Afghanistan/Data Analysis/TUP Baseline/Data/Final/Compiled/bl_analysis_prep.dta"
	global confirmation_excel_MISFA "${DB_PII_Profile}/Output/Final/confirmation_recipient_name_11Dec2018_MISFA.xlsx"
	
* Outputs
	
	if "`c(username)'" == "mcayala" { // Outputs are saved in Dropbox
		global confirmation_excel 	"${DB_PII_Profile}/Output/Final/confirmation_recipient_name.xlsx"
		global HHs_to_verify 		"${DB_PII_Profile}/Output/Final/household_verification_20Dec2018.xlsx"
	 }
		if "`c(username)'" != "mcayala" { // Outputs are saved in local GitHub
		}	
	
********************************************************************************
	** Part 1: Get list of treatment households with inconsistencies
********************************************************************************

* This refers to the list of households where it was reported that the beneficiary
* was not part of the HH or they didn't know him/her. We sent this list to Matin, so he
* can send us any additional information CHA or MISFA hav

* Open dataset of all HH surveyed in follow-up
	use "${all_HH_dataset_pii}", clear

* Merge treatment status and keep only treatment Ultra-Poor households	
	merge 1:1 hhid using "${fl1_sample}", keepus(treatment) assert(3) keep(3) nogen	
	keep if survey==1 & treatment==1
	
* Keep the ones that don't know respondent
	tab b24
	keep if inlist(b24, -100, -97, 36)
	
	* Of the ones who said "other", 1 "Don't know who this person is", 2 "Other", and 1 "Moved because of work"
		/*
			  Could you confirm which household |
		   member from this list corresponds to |
									  the name  |      Freq.     Percent        Cum.
		----------------------------------------+-----------------------------------
				  Don't know who this person is |         33        7.14        7.14
						 Other (please specify) |          4        0.87        8.01
							   ${hh_name_calc1} |        131       28.35       36.36
							   ${hh_name_calc2} |        246       53.25       89.61
							   ${hh_name_calc3} |         18        3.90       93.51
							   ${hh_name_calc4} |          1        0.22       93.72
							   ${hh_name_calc5} |          5        1.08       94.81
							   ${hh_name_calc6} |          3        0.65       95.45
							   ${hh_name_calc8} |          1        0.22       95.67
		This person is not part of the househol |         20        4.33      100.00
		----------------------------------------+-----------------------------------
										  Total |        462      100.00
		*/
		
* Get respondent's and roster names
	mdesc nickname_* nickname2_* //none of the 57 has nickname so we ignore this variable for now
	keep hhid hh_name_calc*

	tempfile list_to_send
	save	`list_to_send'
	
	use "${master_data}", clear
	
	merge 1:1 hhid using `list_to_send', keepus(hhid) keep(3)
	
	keep SNo_im No_im NewNumber hhid District Village CDCID Masjid father_spouse_name hhhead_name beneficiary_name
	order hhid SNo_im No_im NewNumber District Village CDCID Masjid father_spouse_name hhhead_name beneficiary_name
	sort District Village NewNumber
	
	lab var SNo_im "SNo"
	lab var No_im "No"
	lab var NewNumber "CHA ID (NewNumber)"
	lab var hhid "Household ID (DIME)"
	lab var father_spouse_name "Father / Spouse Name"
	lab var hhhead_name "Name of HH"
	lab var beneficiary_name "Name of Trainee for Animal Rearing (Actual Beneficiary)"
		
	*export excel using "${confirmation_excel}", sheetreplace  sheet("HH list") firstrow(varlabels) 	

* Create file to send to Mohammad so he can confirm if it is the right household
*--------------------------------------------------------------------------------
	
	* Use information sent by Matin (MISFA) on Dec 11, 2018 and saved in the outputs folder.
		import excel "${confirmation_excel_MISFA}", sheet("HH list") cellrange(A2:S66) firstrow clear
		
		rename 	(HouseholdIDDIME FatherSpouseNamemainlythi NameofHHmainlythiscolumni NameofTraineeforAnimalReari) ///
				(hhid 			father_spouse_name		  hhhead_name 				beneficiary_name)
		rename ملاحظات comments
		label var comments "comments"
		
		* Drop missing obs
		count if mi(hhid)
		assert `r(N)'==7
		drop if mi(hhid)
		
		* Merge names
		merge 1:1 hhid using `list_to_send', assert(3) nogen
		forval member = 1(1)35 {
			lab var hh_name_calc`member' "Name of household member #`member'"
		}
		drop SNo No NewNumber District Village CDCID Masjid
		
	export excel using "${HHs_to_verify}", sheetreplace  sheet("Treatment HHs") firstrow(varlabels) 	
	
********************************************************************************
	** Part 2: Get list of households with other inconsistencies
********************************************************************************
	
* We consider an inconsistency if:
* 1. There is a discrepancy looking at ages between baseline vs. follow-up
* 2. During the excersice done by Mohammad in baseline, the name of the HH head 
* 	 was not part of the roster

* For 1: There is a discrepancy looking at ages between baseline vs. follow-up
*------------------------------------------------------------------------------
	
	use "${all_HH_dataset_pii}", clear

		merge 1:1 hhid using "${fl1_sample}", keepus(treatment) assert(3) keep(3) nogen
		keep if survey==1
		
	* Generate ages flag	
		destring index_oldroster_* b8_year_*,replace
		
		* Transform age to year of birth
			forval old = 1/15 {
				gen birth_`old' = .
					lab var birth_`old' "Year of birth of member `old' reported in follow-up"
				forval new=1/16 {
					replace birth_`old' = 2018 - b8_year_`new' if index_oldroster_`new'==`old' & b8_year_`new'!=-99
				}
			}
			
		* Retrieve baseline key
			preserve 
				use "${master_data}",clear
				keep hhid bl_key
				keep if !mi(bl_key)
				tempfile bl_key
				save `bl_key',replace
			restore
			
		* Retrieve ages from baseline
			preserve
				use "${bl_prep}", clear
				rename KEY bl_key
				keep bl_key b8_? b8_1? b8_2? b8_3?

				forval hhmember= 1/31 {
					replace b8_`hhmember'=66 if b8_`hhmember'==660
					replace b8_`hhmember'=. if b8_`hhmember'>98
					gen birth_`hhmember'_bl = 2016 - b8_`hhmember'
						lab var birth_`hhmember'_bl "Year of birth of member `hhmember' reported in bl"
				}
				keep bl_key birth_*_bl
				isid bl_key
				tempfile bl_roster
				save `bl_roster',replace
			restore
			
			merge 1:1 hhid using `bl_key', keep(3) nogen
			merge 1:1 bl_key using `bl_roster', keep(3) nogen
			
			forval num=1/15 {
				gen flag_`num' = ((birth_`num'-birth_`num'_bl)>3 | (birth_`num'-birth_`num'_bl)<-3) if !mi(birth_`num') & !mi(birth_`num'_bl)
			}

			egen tot_ages_bl = rownonmiss(flag_1 flag_2 flag_3 flag_4 flag_5 flag_6 flag_7 flag_8 flag_9 flag_10 flag_11 flag_12 flag_13 flag_14 flag_15)
			egen tot_ages_bl_flagged = rowtotal(flag_1 flag_2 flag_3 flag_4 flag_5 flag_6 flag_7 flag_8 flag_9 flag_10 flag_11 flag_12 flag_13 flag_14 flag_15)
			gen perc_ages_bl = (tot_ages_bl_flagged/tot_ages_bl)
			gen perc_ages_bl_flag = (tot_ages_bl_flagged/tot_ages_bl)>=.5
			lab var perc_ages_bl_flag "Flag for discrepancy in ages wrt baseline"
	
		tab num_still_here perc_ages_bl_flag // 135 households we want to confirm
		/*
				   | Flag for discrepancy
		num_still_ | in ages wrt baseline
			  here |         0          1 |     Total
		-----------+----------------------+----------
				 1 |        12         31 |        43 
				 2 |        38         43 |        81 
				 3 |       103         19 |       122 
				 4 |       115         23 |       138 
				 5 |       147          5 |       152 
				 6 |       180          7 |       187 
				 7 |       159          2 |       161 
				 8 |       117          3 |       120 
				 9 |        56          1 |        57 
				10 |        31          1 |        32 
				11 |        18          0 |        18 
				12 |         4          0 |         4 
				13 |         1          0 |         1 
				14 |         1          0 |         1 
				15 |         2          0 |         2 
				18 |         1          0 |         1 
		-----------+----------------------+----------
			 Total |       985        135 |     1,120 

		*/
		
		keep hhid perc_ages_bl_flag
		tempfile hhs_discrepancy_age
		save	`hhs_discrepancy_age'
		

* 2. During the excercise done by Mohammad in baseline, the name of the HH head 
* 	 was not part of the roster
*------------------------------------------------------------------------------------

* Prepare excel file with verification done by Mohammad
*-----------------------------------------------

	* Import excel file with verification done by Mohammad:
		import excel "${HH_verification}", sheet("Sheet1") cellrange(A2:AU1396) firstrow clear
		drop Nameofhouseholdmember* AQ AR AS AT AU AU HouseholdHeadName

		rename  (HouseholdID Nameofhouseholdhead Fatherspousename2 		 	IsthepersonincolumnDEthe IsthepersonincolumnDEanot Inconsistencies0No1Yes) ///
				(hhid_bl	 hhh_name_verif		 father_spouse_name_verif	Is_hh_head				  Is_another_hh_member 		inconsistency)

	* Drop those not surveyed or not in CHA list
		tab Is_hh_head Is_another_hh_member
		drop if inlist(Is_hh_head, "not surveyed", "not in CHA list", "?")
		replace Is_another_hh_member="1" if Is_another_hh_member=="11"
		duplicates drop hhid_bl, force
		drop if mi(hhid_bl)
		tab Is_hh_head Is_another_hh_member		
		/*
		  Is the person |   Is the person in
		  in column D/E |  column D/E another
			the hh head |   member of the hh?
			(column G)? |     [0=No, 1=Yes]
		  [0=No, 1=Yes] |         0          1 |     Total
		----------------+----------------------+----------
					  0 |        91        187 |       278 
					  1 |     1,102          0 |     1,102 
		----------------+----------------------+----------
				  Total |     1,193        187 |     1,380 
		*/
	
	* Fix names and IDs
		foreach	strvar	in hhh_name_verif father_spouse_name_verif hhid_bl {
			replace	`strvar'	=	trim(itrim(`strvar'))
			replace `strvar' = subinstr(`strvar', ".", "",.) 
			replace `strvar' = subinstr(`strvar', "/", "",.) 
		}
		
		
		tempfile Mohammad_verification
		save	`Mohammad_verification'
			
* Prepare master data for merge
*------------------------------

	use "${master_data}", clear
	keep if !mi(hhid)
	keep hhid hhid_bl hhid_bl_wrong hhid_final_elig hhid_lottery
	tempfile master_data
	save	`master_data'

* Create list based on follow-up data
*-----------------------------------
	
* Open follow-up data
	use "${all_HH_dataset_pii}", clear

* Merge treatment status and other variables	
	merge 1:1 hhid using "${fl1_sample}", keepus(treatment father_spouse_name hhhead_name bl_oth_hh_why bl_oth_hh bl_key) assert(2 3) nogen keep(3)

* Keep only ultra-poor households	
	keep if survey==1
	
* Get bl_id
	merge 1:1 hhid using `master_data', keep(3) assert(2 3) nogen
	
		foreach	strvar	in hhhead_name father_spouse_name hhid_bl {
			replace	`strvar' = trim(itrim(`strvar'))
			replace `strvar' = subinstr(`strvar', ".", "",.) 
			replace `strvar' = subinstr(`strvar', "/", "",.) 
		}
	
	tempfile fl1_master_merged
	save	`fl1_master_merged'
	
* Merge with verification done by Mohammad: First round
*-------------------------------------------------------

	drop if mi(hhid_bl) // 32 obs
	merge 1:1 hhid_bl using `Mohammad_verification',  gen(merge_fl1_verif) 
	
	/*
		Result                           # of obs.
		-----------------------------------------
		not matched                           357
			from master                        52	(merge_fl1_verif==1)
			from using                        305	(merge_fl1_verif==2)

		matched                             1,075	(merge_fl1_verif==3)
		-----------------------------------------
	*/
	preserve
		keep if merge_fl1_verif == 3
		gen status = "Merged with Mohammad's file using hhid_bl"
		keep hhid status hhh_name_verif father_spouse_name_verif Is_hh_head Is_another_hh_member
		tempfile merged_fl1_verif
		save	`merged_fl1_verif'
	restore
	preserve
		keep if merge_fl1_verif == 2
		tempfile unmerged_verif
		save	`unmerged_verif'
	restore
	
* Check the ones that don't merge: some of these can be found in the baseline with the "HHID_old_Feb22".
* We retrieve this ID and try to merge again
	
	/*preserve
		keep if merge_fl1_verif != 3	
		gen 	a =  hhhead_name
		replace a =  hhh_name_verif if mi(a)
		gen 	b =  father_spouse_name
		replace b =  father_spouse_name_verif if mi( father_spouse_name)
		br merge_fl1_verif  a b  hhid hhid_bl hhid_lottery hhid_final_elig 
		sort a b
	restore*/

* Merge with verification done by Mohammad: Second round
*-------------------------------------------------------
	
* Merge with baseline to retrieve HHID_old_Feb22
	drop if merge_fl1_verif == 2
	rename hhid_bl HHID_survey
	isid HHID_survey
	merge 1:1 HHID_survey using "${bl_prep}", gen(merge_fl_bl) keepus(HHID_old_Feb22) //keep(3) 
		/*
			Result                           # of obs.
			-----------------------------------------
			not matched                         1,902
				from master                         0	(merge_fl_bl==1)
				from using                      1,902	(merge_fl_bl==2)

			matched                             1,127	(merge_fl_bl==3)
			-----------------------------------------

		*/	

* Merge with verification file using HHID_old_Feb22	
	keep if merge_fl1_verif == 1
	rename HHID_old_Feb22 hhid_bl
		* Save the ones without HHID_old_Feb22
		preserve
			keep if mi(hhid_bl)
			gen status = "Unmerged with Mohammad's file"
			keep hhid status hhh_name_verif father_spouse_name_verif Is_hh_head Is_another_hh_member
			tempfile unmerged_fl1_verif
			save 	`unmerged_fl1_verif'
		restore
	drop if mi(hhid_bl)
	isid hhid_bl
	drop hhh_name_verif father_spouse_name_verif Is_hh_head Is_another_hh_member
	merge 1:1 hhid_bl using `unmerged_verif', gen(merge_fl1_verif2) keep(1 3)
		/*
			Result                           # of obs.
			-----------------------------------------
			not matched                           297
				from master                        19  (merge_fl1_verif2==1)
				from using                        278  (merge_fl1_verif2==2)

			matched                                27  (merge_fl1_verif2==3)
			-----------------------------------------
		*/
	
	* Save the ones who merged
	preserve
		keep if merge_fl1_verif2 == 3
		gen status = "Merged with Mohammad's file using HHID_old_Feb22"
		keep hhid status hhh_name_verif father_spouse_name_verif Is_hh_head Is_another_hh_member
		tempfile merged_fl1_verif2
		save	`merged_fl1_verif2'
	restore	
	
	* Save the ones who didn't merge (to verify)
	preserve
		keep if merge_fl1_verif2 == 1
		gen status = "Unmerged with Mohammad's file"
		keep hhid status hhh_name_verif father_spouse_name_verif Is_hh_head Is_another_hh_member
		tempfile unmerged_fl1_verif2
		save	`unmerged_fl1_verif2'
	restore		
	
* Merge all cases to follow-up data
	
	use `fl1_master_merged', clear
	
	* Merged with hhid_bl
		merge 1:1 hhid using `merged_fl1_verif', assert(1 3) nogen update
	* Merged with HHID_old_Feb22
		merge 1:1 hhid using `merged_fl1_verif2', assert(1 4) nogen update replace
	* Unmerged
		merge 1:1 hhid using `unmerged_fl1_verif', assert(1 4) nogen update replace
		merge 1:1 hhid using `unmerged_fl1_verif2', assert(1 4) nogen update replace
	* Without baseline
		replace status = "No baseline" if mi(hhid_bl)
	
* Check if the merged ones are correct based on hhhead_name and father_spouse_name	
	gen diff_hhh_name 			= (hhhead_name!=hhh_name_verif)
	gen diff_father_spouse_name = (father_spouse_name!=father_spouse_name_verif)

	bys status: tab1 diff_hhh_name diff_father_spouse_name 

* Generate verification indicator. We'll verify:
	gen verify = .
	gen reason = . 
	lab def reason_l 1 "No baseline" 2 "No merge" 3 "Failed Mohammad's baseline verification" ///
					 4 "Different household surveyed in baseline" 5 "Age discrepancy"
	lab val reason reason_l
	* 1. The ones without baseline and didn't merge
		replace verify = 1 if inlist(status, "No baseline", "Unmerged with Mohammad's file") // 57 cases
		replace reason = 1 if inlist(status, "No baseline") 
		replace reason = 2 if inlist(status, "Unmerged with Mohammad's file") & mi(reason)
	* 2. The ones not part of roster based on Mohammad's verification
		replace verify = 1 if Is_hh_head == "0" & Is_another_hh_member == "0" // 72 cases 
		replace reason = 3 if Is_hh_head == "0" & Is_another_hh_member == "0" & mi(reason) // 72 cases 
	* 3. The ones we know a different household was surveyed in baseline
		replace verify = 1 if bl_oth_hh == 1 // 7 additional cases (9 in total, 2 of them flagged before in 2.)
		replace reason = 4 if bl_oth_hh == 1 & mi(reason) // 7 additional cases (9 in total, 2 of them flagged before in 2.)
	* 4. The ones with flag on ages
		merge 1:1 hhid using `hhs_discrepancy_age', assert(1 3) nogen
		replace verify = 1 if perc_ages_bl_flag == 1 // 125 additional
		replace reason = 5 if perc_ages_bl_flag == 1 & mi(reason) // 125 additional
	* 261 households in total to verify.
		tab verify
	* 20 out of the 57 cases with discrepancy in beneficiary are here. Drop these ones
		tab b24 verify, m
		drop if inlist(b24, -100, -97, 36) & verify==1
	
* Generate file
	keep if verify==1
	keep hhid father_spouse_name hhhead_name benef_name_coalesce nickname_* nickname2_* hh_name_calc*
	
		forval member = 1(1)35 {
			cap gen 	nickname`member' = nickname_`member' 
			cap replace nickname`member' = nickname2_`member' if mi(nickname`member')
			lab var hh_name_calc`member' "Name of household member #`member'"
			cap lab var nickname`member' "Nickname of household member #`member'"
			cap order nickname`member', after(hh_name_calc`member')
		}
	drop nickname_* nickname2_*
	replace benef_name_coalesce = "" if benef_name_coalesce == "0"
	order hhid father_spouse_name hhhead_name benef_name_coalesce
	
	export excel using "${HHs_to_verify}", sheetreplace sheet("Treatment and control HHs") firstrow(varlabels) 	
